pub struct CellRendererAccelBuilder { /* private fields */ }Since 4.10
A builder-pattern type to construct CellRendererAccel objects.
ImplementationsΒ
SourceΒimpl CellRendererAccelBuilder
impl CellRendererAccelBuilder
Sourcepub fn accel_key(self, accel_key: u32) -> Self
πDeprecated: Since 4.10
pub fn accel_key(self, accel_key: u32) -> Self
Since 4.10
The keyval of the accelerator.
Sourcepub fn accel_mode(self, accel_mode: CellRendererAccelMode) -> Self
πDeprecated: Since 4.10
pub fn accel_mode(self, accel_mode: CellRendererAccelMode) -> Self
Since 4.10
Determines if the edited accelerators are GTK accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK are allowed, and the accelerators are rendered in the same way as they are in menus.
Sourcepub fn accel_mods(self, accel_mods: ModifierType) -> Self
πDeprecated: Since 4.10
pub fn accel_mods(self, accel_mods: ModifierType) -> Self
Since 4.10
The modifier mask of the accelerator.
Sourcepub fn keycode(self, keycode: u32) -> Self
πDeprecated: Since 4.10
pub fn keycode(self, keycode: u32) -> Self
Since 4.10
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
pub fn align_set(self, align_set: bool) -> Self
Since 4.10
Sourcepub fn alignment(self, alignment: Alignment) -> Self
πDeprecated: Since 4.10
pub fn alignment(self, alignment: Alignment) -> Self
Since 4.10
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The βxalignβ property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
pub fn attributes(self, attributes: &AttrList) -> Self
Since 4.10
pub fn background(self, background: impl Into<GString>) -> Self
Since 4.10
Sourcepub fn background_rgba(self, background_rgba: &RGBA) -> Self
πDeprecated: Since 4.10
pub fn background_rgba(self, background_rgba: &RGBA) -> Self
Since 4.10
Background color as a gdk::RGBA
pub fn background_set(self, background_set: bool) -> Self
Since 4.10
pub fn editable(self, editable: bool) -> Self
Since 4.10
pub fn editable_set(self, editable_set: bool) -> Self
Since 4.10
Sourcepub fn ellipsize(self, ellipsize: EllipsizeMode) -> Self
πDeprecated: Since 4.10
pub fn ellipsize(self, ellipsize: EllipsizeMode) -> Self
Since 4.10
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
pango::EllipsizeMode::None turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
pub fn ellipsize_set(self, ellipsize_set: bool) -> Self
Since 4.10
pub fn family(self, family: impl Into<GString>) -> Self
Since 4.10
pub fn family_set(self, family_set: bool) -> Self
Since 4.10
pub fn font(self, font: impl Into<GString>) -> Self
Since 4.10
pub fn font_desc(self, font_desc: &FontDescription) -> Self
Since 4.10
pub fn foreground(self, foreground: impl Into<GString>) -> Self
Since 4.10
Sourcepub fn foreground_rgba(self, foreground_rgba: &RGBA) -> Self
πDeprecated: Since 4.10
pub fn foreground_rgba(self, foreground_rgba: &RGBA) -> Self
Since 4.10
Foreground color as a gdk::RGBA
pub fn foreground_set(self, foreground_set: bool) -> Self
Since 4.10
pub fn language(self, language: impl Into<GString>) -> Self
Since 4.10
pub fn language_set(self, language_set: bool) -> Self
Since 4.10
pub fn markup(self, markup: impl Into<GString>) -> Self
Since 4.10
Sourcepub fn max_width_chars(self, max_width_chars: i32) -> Self
πDeprecated: Since 4.10
pub fn max_width_chars(self, max_width_chars: i32) -> Self
Since 4.10
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cellβs siblings
have received their natural width.
Sourcepub fn placeholder_text(self, placeholder_text: impl Into<GString>) -> Self
πDeprecated: Since 4.10
pub fn placeholder_text(self, placeholder_text: impl Into<GString>) -> Self
Since 4.10
The text that will be displayed in the CellRenderer if
GtkCellRendererText:editable is true and the cell is empty.
pub fn rise(self, rise: i32) -> Self
Since 4.10
pub fn rise_set(self, rise_set: bool) -> Self
Since 4.10
pub fn scale(self, scale: f64) -> Self
Since 4.10
pub fn scale_set(self, scale_set: bool) -> Self
Since 4.10
pub fn single_paragraph_mode(self, single_paragraph_mode: bool) -> Self
Since 4.10
pub fn size(self, size: i32) -> Self
Since 4.10
pub fn size_points(self, size_points: f64) -> Self
Since 4.10
pub fn size_set(self, size_set: bool) -> Self
Since 4.10
pub fn stretch(self, stretch: Stretch) -> Self
Since 4.10
pub fn stretch_set(self, stretch_set: bool) -> Self
Since 4.10
pub fn strikethrough(self, strikethrough: bool) -> Self
Since 4.10
pub fn strikethrough_set(self, strikethrough_set: bool) -> Self
Since 4.10
pub fn style(self, style: Style) -> Self
Since 4.10
pub fn style_set(self, style_set: bool) -> Self
Since 4.10
pub fn text(self, text: impl Into<GString>) -> Self
Since 4.10
pub fn underline(self, underline: Underline) -> Self
Since 4.10
pub fn underline_set(self, underline_set: bool) -> Self
Since 4.10
pub fn variant(self, variant: Variant) -> Self
Since 4.10
pub fn variant_set(self, variant_set: bool) -> Self
Since 4.10
pub fn weight(self, weight: i32) -> Self
Since 4.10
pub fn weight_set(self, weight_set: bool) -> Self
Since 4.10
Sourcepub fn width_chars(self, width_chars: i32) -> Self
πDeprecated: Since 4.10
pub fn width_chars(self, width_chars: i32) -> Self
Since 4.10
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Sourcepub fn wrap_mode(self, wrap_mode: WrapMode) -> Self
πDeprecated: Since 4.10
pub fn wrap_mode(self, wrap_mode: WrapMode) -> Self
Since 4.10
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Sourcepub fn wrap_width(self, wrap_width: i32) -> Self
πDeprecated: Since 4.10
pub fn wrap_width(self, wrap_width: i32) -> Self
Since 4.10
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
pub fn cell_background(self, cell_background: impl Into<GString>) -> Self
Since 4.10
Sourcepub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
πDeprecated: Since 4.10
pub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
Since 4.10
Cell background as a gdk::RGBA
pub fn cell_background_set(self, cell_background_set: bool) -> Self
Since 4.10
pub fn height(self, height: i32) -> Self
Since 4.10
pub fn is_expanded(self, is_expanded: bool) -> Self
Since 4.10
pub fn is_expander(self, is_expander: bool) -> Self
Since 4.10
pub fn mode(self, mode: CellRendererMode) -> Self
Since 4.10
pub fn sensitive(self, sensitive: bool) -> Self
Since 4.10
pub fn visible(self, visible: bool) -> Self
Since 4.10
pub fn width(self, width: i32) -> Self
Since 4.10
pub fn xalign(self, xalign: f32) -> Self
Since 4.10
pub fn xpad(self, xpad: u32) -> Self
Since 4.10
pub fn yalign(self, yalign: f32) -> Self
Since 4.10
pub fn ypad(self, ypad: u32) -> Self
Since 4.10
Sourcepub fn build(self) -> CellRendererAccel
πDeprecated: Since 4.10
pub fn build(self) -> CellRendererAccel
Since 4.10
Build the CellRendererAccel.