pub struct CellRendererProgressBuilder { /* private fields */ }Since 4.10
A builder-pattern type to construct CellRendererProgress objects.
Implementations
Sourceimpl CellRendererProgressBuilder
impl CellRendererProgressBuilder
Sourcepub fn inverted(self, inverted: bool) -> Self
👎Deprecated: Since 4.10
pub fn inverted(self, inverted: bool) -> Self
Since 4.10
Whether progess is inverted.
Sourcepub fn pulse(self, pulse: i32) -> Self
👎Deprecated: Since 4.10
pub fn pulse(self, pulse: i32) -> Self
Since 4.10
Setting this to a non-negative value causes the cell renderer to enter “activity mode”, where a block bounces back and forth to indicate that some progress is made, without specifying exactly how much.
Each increment of the property causes the block to move by a little bit.
To indicate that the activity has not started yet, set the property
to zero. To indicate completion, set the property to G_MAXINT.
Sourcepub fn text(self, text: impl Into<GString>) -> Self
👎Deprecated: Since 4.10
pub fn text(self, text: impl Into<GString>) -> Self
Since 4.10
The “text” property determines the label which will be drawn
over the progress bar. Setting this property to None causes the default
label to be displayed. Setting this property to an empty string causes
no label to be displayed.
Sourcepub fn text_xalign(self, text_xalign: f32) -> Self
👎Deprecated: Since 4.10
pub fn text_xalign(self, text_xalign: f32) -> Self
Since 4.10
The “text-xalign” property controls the horizontal alignment of the text in the progress bar. Valid values range from 0 (left) to 1 (right). Reserved for RTL layouts.
Sourcepub fn text_yalign(self, text_yalign: f32) -> Self
👎Deprecated: Since 4.10
pub fn text_yalign(self, text_yalign: f32) -> Self
Since 4.10
The “text-yalign” property controls the vertical alignment of the text in the progress bar. Valid values range from 0 (top) to 1 (bottom).
Sourcepub fn value(self, value: i32) -> Self
👎Deprecated: Since 4.10
pub fn value(self, value: i32) -> Self
Since 4.10
The “value” property determines the percentage to which the progress bar will be “filled in”.
pub fn cell_background(self, cell_background: impl Into<GString>) -> Self
Since 4.10
Sourcepub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
👎Deprecated: Since 4.10
pub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
Since 4.10
Cell background as a gdk::RGBA
pub fn cell_background_set(self, cell_background_set: bool) -> Self
Since 4.10
pub fn height(self, height: i32) -> Self
Since 4.10
pub fn is_expanded(self, is_expanded: bool) -> Self
Since 4.10
pub fn is_expander(self, is_expander: bool) -> Self
Since 4.10
pub fn mode(self, mode: CellRendererMode) -> Self
Since 4.10
pub fn sensitive(self, sensitive: bool) -> Self
Since 4.10
pub fn visible(self, visible: bool) -> Self
Since 4.10
pub fn width(self, width: i32) -> Self
Since 4.10
pub fn xalign(self, xalign: f32) -> Self
Since 4.10
pub fn xpad(self, xpad: u32) -> Self
Since 4.10
pub fn yalign(self, yalign: f32) -> Self
Since 4.10
pub fn ypad(self, ypad: u32) -> Self
Since 4.10
Sourcepub fn orientation(self, orientation: Orientation) -> Self
👎Deprecated: Since 4.10
pub fn orientation(self, orientation: Orientation) -> Self
Since 4.10
The orientation of the orientable.
Sourcepub fn build(self) -> CellRendererProgress
👎Deprecated: Since 4.10
pub fn build(self) -> CellRendererProgress
Since 4.10
Build the CellRendererProgress.