pub struct IconThemeBuilder { /* private fields */ }Expand description
A builder-pattern type to construct IconTheme objects.
Implementations
Sourceimpl IconThemeBuilder
impl IconThemeBuilder
Sourcepub fn display(self, display: &impl IsA<Display>) -> Self
pub fn display(self, display: &impl IsA<Display>) -> Self
The display that this icon theme object is attached to.
Sourcepub fn resource_path(self, resource_path: impl Into<StrV>) -> Self
pub fn resource_path(self, resource_path: impl Into<StrV>) -> Self
Resource paths that will be looked at when looking for icons, similar to search paths.
The resources are considered as part of the hicolor icon theme
and must be located in subdirectories that are defined in the
hicolor icon theme, such as @path/16x16/actions/run.png.
Icons that are directly placed in the resource path instead
of a subdirectory are also considered as ultimate fallback.
Sourcepub fn search_path(self, search_path: impl Into<StrV>) -> Self
pub fn search_path(self, search_path: impl Into<StrV>) -> Self
s home directory.)
Sourcepub fn theme_name(self, theme_name: impl Into<GString>) -> Self
pub fn theme_name(self, theme_name: impl Into<GString>) -> Self
The name of the icon theme that is being used.
Unless set to a different value, this will be the value of
the GtkSettings:gtk-icon-theme-name property of the Settings
object associated to the display of the icontheme object.