pub struct LockButtonBuilder { /* private fields */ }Since 4.10
A builder-pattern type to construct LockButton objects.
Implementations
Sourceimpl LockButtonBuilder
impl LockButtonBuilder
Sourcepub fn permission(self, permission: &impl IsA<Permission>) -> Self
๐Deprecated: Since 4.10
pub fn permission(self, permission: &impl IsA<Permission>) -> Self
Since 4.10
The `GPermission object controlling this button. This widget will be removed in GTK 5
Sourcepub fn text_lock(self, text_lock: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn text_lock(self, text_lock: impl Into<GString>) -> Self
Since 4.10
The text to display when prompting the user to lock. This widget will be removed in GTK 5
Sourcepub fn text_unlock(self, text_unlock: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn text_unlock(self, text_unlock: impl Into<GString>) -> Self
Since 4.10
The text to display when prompting the user to unlock. This widget will be removed in GTK 5
Sourcepub fn tooltip_lock(self, tooltip_lock: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn tooltip_lock(self, tooltip_lock: impl Into<GString>) -> Self
Since 4.10
The tooltip to display when prompting the user to lock. This widget will be removed in GTK 5
๐Deprecated: Since 4.10
Since 4.10
The tooltip to display when the user cannot obtain authorization. This widget will be removed in GTK 5
Sourcepub fn tooltip_unlock(self, tooltip_unlock: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn tooltip_unlock(self, tooltip_unlock: impl Into<GString>) -> Self
Since 4.10
The tooltip to display when prompting the user to unlock. This widget will be removed in GTK 5
Sourcepub fn can_shrink(self, can_shrink: bool) -> Self
๐Deprecated: Since 4.10
Available on crate feature v4_12 only.
pub fn can_shrink(self, can_shrink: bool) -> Self
Since 4.10
v4_12 only.Whether the size of the button can be made smaller than the natural size of its contents.
For text buttons, setting this property will allow ellipsizing the label.
If the contents of a button are an icon or a custom widget, setting this property has no effect.
Sourcepub fn child(self, child: &impl IsA<Widget>) -> Self
๐Deprecated: Since 4.10
pub fn child(self, child: &impl IsA<Widget>) -> Self
Since 4.10
The child widget.
Sourcepub fn has_frame(self, has_frame: bool) -> Self
๐Deprecated: Since 4.10
pub fn has_frame(self, has_frame: bool) -> Self
Since 4.10
Whether the button has a frame.
Sourcepub fn icon_name(self, icon_name: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn icon_name(self, icon_name: impl Into<GString>) -> Self
Since 4.10
The name of the icon used to automatically populate the button.
Sourcepub fn label(self, label: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn label(self, label: impl Into<GString>) -> Self
Since 4.10
Text of the label inside the button, if the button contains a label widget.
Sourcepub fn use_underline(self, use_underline: bool) -> Self
๐Deprecated: Since 4.10
pub fn use_underline(self, use_underline: bool) -> Self
Since 4.10
If set, an underline in the text indicates that the following character is to be used as mnemonic.
Sourcepub fn can_focus(self, can_focus: bool) -> Self
๐Deprecated: Since 4.10
pub fn can_focus(self, can_focus: bool) -> Self
Since 4.10
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn can_target(self, can_target: bool) -> Self
๐Deprecated: Since 4.10
pub fn can_target(self, can_target: bool) -> Self
Since 4.10
Whether the widget can receive pointer events.
Sourcepub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
๐Deprecated: Since 4.10
pub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
Since 4.10
A list of css classes applied to this widget.
Sourcepub fn css_name(self, css_name: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn css_name(self, css_name: impl Into<GString>) -> Self
Since 4.10
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn cursor(self, cursor: &Cursor) -> Self
๐Deprecated: Since 4.10
pub fn cursor(self, cursor: &Cursor) -> Self
Since 4.10
The cursor used by @widget.
Sourcepub fn focus_on_click(self, focus_on_click: bool) -> Self
๐Deprecated: Since 4.10
pub fn focus_on_click(self, focus_on_click: bool) -> Self
Since 4.10
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Sourcepub fn focusable(self, focusable: bool) -> Self
๐Deprecated: Since 4.10
pub fn focusable(self, focusable: bool) -> Self
Since 4.10
Whether this widget itself will accept the input focus.
Sourcepub fn halign(self, halign: Align) -> Self
๐Deprecated: Since 4.10
pub fn halign(self, halign: Align) -> Self
Since 4.10
How to distribute horizontal space if widget gets extra space.
Sourcepub fn has_tooltip(self, has_tooltip: bool) -> Self
๐Deprecated: Since 4.10
pub fn has_tooltip(self, has_tooltip: bool) -> Self
Since 4.10
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Sourcepub fn height_request(self, height_request: i32) -> Self
๐Deprecated: Since 4.10
pub fn height_request(self, height_request: i32) -> Self
Since 4.10
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn hexpand(self, hexpand: bool) -> Self
๐Deprecated: Since 4.10
pub fn hexpand(self, hexpand: bool) -> Self
Since 4.10
Whether to expand horizontally.
Sourcepub fn hexpand_set(self, hexpand_set: bool) -> Self
๐Deprecated: Since 4.10
pub fn hexpand_set(self, hexpand_set: bool) -> Self
Since 4.10
Whether to use the hexpand property.
Sourcepub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
๐Deprecated: Since 4.10
pub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
Since 4.10
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn limit_events(self, limit_events: bool) -> Self
๐Deprecated: Since 4.10
Available on crate feature v4_18 only.
pub fn limit_events(self, limit_events: bool) -> Self
Since 4.10
v4_18 only.Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Sourcepub fn margin_bottom(self, margin_bottom: i32) -> Self
๐Deprecated: Since 4.10
pub fn margin_bottom(self, margin_bottom: i32) -> Self
Since 4.10
Margin on bottom side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_end(self, margin_end: i32) -> Self
๐Deprecated: Since 4.10
pub fn margin_end(self, margin_end: i32) -> Self
Since 4.10
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_start(self, margin_start: i32) -> Self
๐Deprecated: Since 4.10
pub fn margin_start(self, margin_start: i32) -> Self
Since 4.10
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_top(self, margin_top: i32) -> Self
๐Deprecated: Since 4.10
pub fn margin_top(self, margin_top: i32) -> Self
Since 4.10
Margin on top side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn name(self, name: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn name(self, name: impl Into<GString>) -> Self
Since 4.10
The name of the widget.
Sourcepub fn opacity(self, opacity: f64) -> Self
๐Deprecated: Since 4.10
pub fn opacity(self, opacity: f64) -> Self
Since 4.10
The requested opacity of the widget.
Sourcepub fn overflow(self, overflow: Overflow) -> Self
๐Deprecated: Since 4.10
pub fn overflow(self, overflow: Overflow) -> Self
Since 4.10
How content outside the widgetโs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn receives_default(self, receives_default: bool) -> Self
๐Deprecated: Since 4.10
pub fn receives_default(self, receives_default: bool) -> Self
Since 4.10
Whether the widget will receive the default action when it is focused.
Sourcepub fn sensitive(self, sensitive: bool) -> Self
๐Deprecated: Since 4.10
pub fn sensitive(self, sensitive: bool) -> Self
Since 4.10
Whether the widget responds to input.
Sourcepub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
Since 4.10
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
Since 4.10
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn valign(self, valign: Align) -> Self
๐Deprecated: Since 4.10
pub fn valign(self, valign: Align) -> Self
Since 4.10
How to distribute vertical space if widget gets extra space.
Sourcepub fn vexpand(self, vexpand: bool) -> Self
๐Deprecated: Since 4.10
pub fn vexpand(self, vexpand: bool) -> Self
Since 4.10
Whether to expand vertically.
Sourcepub fn vexpand_set(self, vexpand_set: bool) -> Self
๐Deprecated: Since 4.10
pub fn vexpand_set(self, vexpand_set: bool) -> Self
Since 4.10
Whether to use the vexpand property.
Sourcepub fn visible(self, visible: bool) -> Self
๐Deprecated: Since 4.10
pub fn visible(self, visible: bool) -> Self
Since 4.10
Whether the widget is visible.
Sourcepub fn width_request(self, width_request: i32) -> Self
๐Deprecated: Since 4.10
pub fn width_request(self, width_request: i32) -> Self
Since 4.10
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
๐Deprecated: Since 4.10
pub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
Since 4.10
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Sourcepub fn action_name(self, action_name: impl Into<GString>) -> Self
๐Deprecated: Since 4.10
pub fn action_name(self, action_name: impl Into<GString>) -> Self
Since 4.10
The name of the action with which this widget should be associated.
Sourcepub fn action_target(self, action_target: &Variant) -> Self
๐Deprecated: Since 4.10
pub fn action_target(self, action_target: &Variant) -> Self
Since 4.10
The target value of the actionable widgetโs action.
Sourcepub fn build(self) -> LockButton
๐Deprecated: Since 4.10
pub fn build(self) -> LockButton
Since 4.10
Build the LockButton.