ShortcutsShortcutBuilder

Struct ShortcutsShortcutBuilder 

pub struct ShortcutsShortcutBuilder { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.18

A builder-pattern type to construct ShortcutsShortcut objects.

Implementations

Source

impl ShortcutsShortcutBuilder

pub fn accel_size_group(self, accel_size_group: &SizeGroup) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The size group for the accelerator portion of this shortcut.

This is used internally by GTK, and must not be modified by applications. This widget will be removed in GTK 5

pub fn accelerator(self, accelerator: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

amp`; when used in .ui files. This widget will be removed in GTK 5

pub fn action_name(self, action_name: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

A detailed action name.

If this is set for a shortcut of type ShortcutType::Accelerator, then GTK will use the accelerators that are associated with the action via GtkApplicationExt::set_accels_for_action(), and setting accelerator is not necessary. This widget will be removed in GTK 5

pub fn direction(self, direction: TextDirection) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The text direction for which this shortcut is active.

If the shortcut is used regardless of the text direction, set this property to TextDirection::None. This widget will be removed in GTK 5

pub fn icon(self, icon: &impl IsA<Icon>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

An icon to represent the shortcut or gesture.

This property is used if shortcut-type is set to ShortcutType::Gesture.

For the other predefined gesture types, GTK provides an icon on its own. This widget will be removed in GTK 5

pub fn icon_set(self, icon_set: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

true if an icon has been set. This widget will be removed in GTK 5

pub fn shortcut_type(self, shortcut_type: ShortcutType) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The type of shortcut that is represented. This widget will be removed in GTK 5

pub fn subtitle(self, subtitle: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The subtitle for the shortcut or gesture.

This is typically used for gestures and should be a short, one-line text that describes the gesture itself. For the predefined gesture types, GTK provides a subtitle on its own. This widget will be removed in GTK 5

pub fn subtitle_set(self, subtitle_set: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

true if a subtitle has been set. This widget will be removed in GTK 5

pub fn title(self, title: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The textual description for the shortcut or gesture represented by this object.

This should be a short string that can fit in a single line. This widget will be removed in GTK 5

pub fn title_size_group(self, title_size_group: &SizeGroup) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The size group for the textual portion of this shortcut.

This is used internally by GTK, and must not be modified by applications. This widget will be removed in GTK 5

pub fn can_focus(self, can_focus: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget or any of its descendents can accept the input focus.

This property is meant to be set by widget implementations, typically in their instance init function.

pub fn can_target(self, can_target: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget can receive pointer events.

pub fn css_classes(self, css_classes: impl Into<StrV>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

A list of css classes applied to this widget.

pub fn css_name(self, css_name: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The name of this widget in the CSS tree.

This property is meant to be set by widget implementations, typically in their instance init function.

pub fn cursor(self, cursor: &Cursor) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The cursor used by @widget.

pub fn focus_on_click(self, focus_on_click: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

pub fn focusable(self, focusable: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether this widget itself will accept the input focus.

pub fn halign(self, halign: Align) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

How to distribute horizontal space if widget gets extra space.

pub fn has_tooltip(self, has_tooltip: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Enables or disables the emission of the query-tooltip signal on @widget.

A true value indicates that @widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

pub fn height_request(self, height_request: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Overrides for height request of the widget.

If this is -1, the natural request will be used.

pub fn hexpand(self, hexpand: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether to expand horizontally.

pub fn hexpand_set(self, hexpand_set: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether to use the hexpand property.

pub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The LayoutManager instance to use to compute the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations, typically in their instance init function.

pub fn limit_events(self, limit_events: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Available on crate feature v4_18 only.

Makes this widget act like a modal dialog, with respect to event delivery.

Global event controllers will not handle events with targets inside the widget, unless they are set up to ignore propagation limits. See EventControllerExt::set_propagation_limit().

pub fn margin_bottom(self, margin_bottom: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Margin on bottom side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Margin on top side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The name of the widget.

pub fn opacity(self, opacity: f64) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The requested opacity of the widget.

pub fn overflow(self, overflow: Overflow) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

How content outside the widgetโ€™s content area is treated.

This property is meant to be set by widget implementations, typically in their instance init function.

pub fn receives_default(self, receives_default: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget will receive the default action when it is focused.

pub fn sensitive(self, sensitive: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget responds to input.

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Sets the text of tooltip to be the given string, which is marked up with Pango markup.

Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

How to distribute vertical space if widget gets extra space.

pub fn vexpand(self, vexpand: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether to expand vertically.

pub fn vexpand_set(self, vexpand_set: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether to use the vexpand property.

pub fn visible(self, visible: bool) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Whether the widget is visible.

pub fn width_request(self, width_request: i32) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

Overrides for width request of the widget.

If this is -1, the natural request will be used.

pub fn accessible_role(self, accessible_role: AccessibleRole) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.18

The accessible role of the given Accessible implementation.

The accessible role cannot be changed once set.

pub fn build(self) -> ShortcutsShortcut

๐Ÿ‘ŽDeprecated:

Since 4.18

Build the ShortcutsShortcut.