pub struct TreeViewBuilder { /* private fields */ }Since 4.10
A builder-pattern type to construct TreeView objects.
ImplementationsΒ
SourceΒimpl TreeViewBuilder
impl TreeViewBuilder
Sourcepub fn activate_on_single_click(self, activate_on_single_click: bool) -> Self
πDeprecated: Since 4.10
pub fn activate_on_single_click(self, activate_on_single_click: bool) -> Self
Since 4.10
The activate-on-single-click property specifies whether the βrow-activatedβ signal will be emitted after a single click.
pub fn enable_grid_lines(self, enable_grid_lines: TreeViewGridLines) -> Self
Since 4.10
pub fn enable_search(self, enable_search: bool) -> Self
Since 4.10
pub fn enable_tree_lines(self, enable_tree_lines: bool) -> Self
Since 4.10
pub fn expander_column(self, expander_column: &TreeViewColumn) -> Self
Since 4.10
Sourcepub fn fixed_height_mode(self, fixed_height_mode: bool) -> Self
πDeprecated: Since 4.10
pub fn fixed_height_mode(self, fixed_height_mode: bool) -> Self
Since 4.10
pub fn headers_clickable(self, headers_clickable: bool) -> Self
Since 4.10
pub fn headers_visible(self, headers_visible: bool) -> Self
Since 4.10
Sourcepub fn hover_expand(self, hover_expand: bool) -> Self
πDeprecated: Since 4.10
pub fn hover_expand(self, hover_expand: bool) -> Self
Since 4.10
Enables or disables the hover expansion mode of @tree_view. Hover expansion makes rows expand or collapse if the pointer moves over them.
This mode is primarily intended for treeviews in popups, e.g.
in ComboBox or EntryCompletion.
Sourcepub fn hover_selection(self, hover_selection: bool) -> Self
πDeprecated: Since 4.10
pub fn hover_selection(self, hover_selection: bool) -> Self
Since 4.10
Enables or disables the hover selection mode of @tree_view.
Hover selection makes the selected row follow the pointer.
Currently, this works only for the selection modes
SelectionMode::Single and SelectionMode::Browse.
This mode is primarily intended for treeviews in popups, e.g.
in ComboBox or EntryCompletion.
Sourcepub fn level_indentation(self, level_indentation: i32) -> Self
πDeprecated: Since 4.10
pub fn level_indentation(self, level_indentation: i32) -> Self
Since 4.10
Extra indentation for each level.
pub fn model(self, model: &impl IsA<TreeModel>) -> Self
Since 4.10
pub fn reorderable(self, reorderable: bool) -> Self
Since 4.10
pub fn rubber_banding(self, rubber_banding: bool) -> Self
Since 4.10
pub fn search_column(self, search_column: i32) -> Self
Since 4.10
Sourcepub fn show_expanders(self, show_expanders: bool) -> Self
πDeprecated: Since 4.10
pub fn show_expanders(self, show_expanders: bool) -> Self
Since 4.10
true if the view has expanders.
pub fn tooltip_column(self, tooltip_column: i32) -> Self
Since 4.10
Sourcepub fn can_focus(self, can_focus: bool) -> Self
πDeprecated: Since 4.10
pub fn can_focus(self, can_focus: bool) -> Self
Since 4.10
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn can_target(self, can_target: bool) -> Self
πDeprecated: Since 4.10
pub fn can_target(self, can_target: bool) -> Self
Since 4.10
Whether the widget can receive pointer events.
Sourcepub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
πDeprecated: Since 4.10
pub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
Since 4.10
A list of css classes applied to this widget.
Sourcepub fn css_name(self, css_name: impl Into<GString>) -> Self
πDeprecated: Since 4.10
pub fn css_name(self, css_name: impl Into<GString>) -> Self
Since 4.10
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn cursor(self, cursor: &Cursor) -> Self
πDeprecated: Since 4.10
pub fn cursor(self, cursor: &Cursor) -> Self
Since 4.10
The cursor used by @widget.
Sourcepub fn focus_on_click(self, focus_on_click: bool) -> Self
πDeprecated: Since 4.10
pub fn focus_on_click(self, focus_on_click: bool) -> Self
Since 4.10
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Sourcepub fn focusable(self, focusable: bool) -> Self
πDeprecated: Since 4.10
pub fn focusable(self, focusable: bool) -> Self
Since 4.10
Whether this widget itself will accept the input focus.
Sourcepub fn halign(self, halign: Align) -> Self
πDeprecated: Since 4.10
pub fn halign(self, halign: Align) -> Self
Since 4.10
How to distribute horizontal space if widget gets extra space.
Sourcepub fn has_tooltip(self, has_tooltip: bool) -> Self
πDeprecated: Since 4.10
pub fn has_tooltip(self, has_tooltip: bool) -> Self
Since 4.10
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Sourcepub fn height_request(self, height_request: i32) -> Self
πDeprecated: Since 4.10
pub fn height_request(self, height_request: i32) -> Self
Since 4.10
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn hexpand(self, hexpand: bool) -> Self
πDeprecated: Since 4.10
pub fn hexpand(self, hexpand: bool) -> Self
Since 4.10
Whether to expand horizontally.
Sourcepub fn hexpand_set(self, hexpand_set: bool) -> Self
πDeprecated: Since 4.10
pub fn hexpand_set(self, hexpand_set: bool) -> Self
Since 4.10
Whether to use the hexpand property.
Sourcepub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
πDeprecated: Since 4.10
pub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
Since 4.10
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn limit_events(self, limit_events: bool) -> Self
πDeprecated: Since 4.10
Available on crate feature v4_18 only.
pub fn limit_events(self, limit_events: bool) -> Self
Since 4.10
v4_18 only.Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Sourcepub fn margin_bottom(self, margin_bottom: i32) -> Self
πDeprecated: Since 4.10
pub fn margin_bottom(self, margin_bottom: i32) -> Self
Since 4.10
Margin on bottom side of widget.
This property adds margin outside of the widgetβs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_end(self, margin_end: i32) -> Self
πDeprecated: Since 4.10
pub fn margin_end(self, margin_end: i32) -> Self
Since 4.10
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetβs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_start(self, margin_start: i32) -> Self
πDeprecated: Since 4.10
pub fn margin_start(self, margin_start: i32) -> Self
Since 4.10
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetβs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn margin_top(self, margin_top: i32) -> Self
πDeprecated: Since 4.10
pub fn margin_top(self, margin_top: i32) -> Self
Since 4.10
Margin on top side of widget.
This property adds margin outside of the widgetβs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Sourcepub fn name(self, name: impl Into<GString>) -> Self
πDeprecated: Since 4.10
pub fn name(self, name: impl Into<GString>) -> Self
Since 4.10
The name of the widget.
Sourcepub fn opacity(self, opacity: f64) -> Self
πDeprecated: Since 4.10
pub fn opacity(self, opacity: f64) -> Self
Since 4.10
The requested opacity of the widget.
Sourcepub fn overflow(self, overflow: Overflow) -> Self
πDeprecated: Since 4.10
pub fn overflow(self, overflow: Overflow) -> Self
Since 4.10
How content outside the widgetβs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn receives_default(self, receives_default: bool) -> Self
πDeprecated: Since 4.10
pub fn receives_default(self, receives_default: bool) -> Self
Since 4.10
Whether the widget will receive the default action when it is focused.
Sourcepub fn sensitive(self, sensitive: bool) -> Self
πDeprecated: Since 4.10
pub fn sensitive(self, sensitive: bool) -> Self
Since 4.10
Whether the widget responds to input.
Sourcepub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
πDeprecated: Since 4.10
pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
Since 4.10
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
πDeprecated: Since 4.10
pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
Since 4.10
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn valign(self, valign: Align) -> Self
πDeprecated: Since 4.10
pub fn valign(self, valign: Align) -> Self
Since 4.10
How to distribute vertical space if widget gets extra space.
Sourcepub fn vexpand(self, vexpand: bool) -> Self
πDeprecated: Since 4.10
pub fn vexpand(self, vexpand: bool) -> Self
Since 4.10
Whether to expand vertically.
Sourcepub fn vexpand_set(self, vexpand_set: bool) -> Self
πDeprecated: Since 4.10
pub fn vexpand_set(self, vexpand_set: bool) -> Self
Since 4.10
Whether to use the vexpand property.
Sourcepub fn visible(self, visible: bool) -> Self
πDeprecated: Since 4.10
pub fn visible(self, visible: bool) -> Self
Since 4.10
Whether the widget is visible.
Sourcepub fn width_request(self, width_request: i32) -> Self
πDeprecated: Since 4.10
pub fn width_request(self, width_request: i32) -> Self
Since 4.10
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
πDeprecated: Since 4.10
pub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
Since 4.10
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Sourcepub fn hadjustment(self, hadjustment: &impl IsA<Adjustment>) -> Self
πDeprecated: Since 4.10
pub fn hadjustment(self, hadjustment: &impl IsA<Adjustment>) -> Self
Since 4.10
Horizontal Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Sourcepub fn hscroll_policy(self, hscroll_policy: ScrollablePolicy) -> Self
πDeprecated: Since 4.10
pub fn hscroll_policy(self, hscroll_policy: ScrollablePolicy) -> Self
Since 4.10
Determines when horizontal scrolling should start.
Sourcepub fn vadjustment(self, vadjustment: &impl IsA<Adjustment>) -> Self
πDeprecated: Since 4.10
pub fn vadjustment(self, vadjustment: &impl IsA<Adjustment>) -> Self
Since 4.10
Vertical Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Sourcepub fn vscroll_policy(self, vscroll_policy: ScrollablePolicy) -> Self
πDeprecated: Since 4.10
pub fn vscroll_policy(self, vscroll_policy: ScrollablePolicy) -> Self
Since 4.10
Determines when vertical scrolling should start.