Enumeration
GtkAccessibleTextContentChange
since: 4.14
Members
| Name | Description |
|---|---|
GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_INSERT |
Contents change as the result of an insert operation. |
GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_REMOVE |
Contents change as the result of a remove operation. |