#[non_exhaustive]pub enum AssistantPageType {
Content,
Intro,
Confirm,
Summary,
Progress,
Custom,
}Since 4.10
Determines the role of a page inside a Assistant.
The role is used to handle buttons sensitivity and visibility.
Note that an assistant needs to end its page flow with a page of type
Confirm, Summary or
Progress to be correct.
The Cancel button will only be shown if the page isnโt โcommittedโ. See gtk_assistant_commit() for details.
Deprecated since 4.10
Assistant will be removed in GTK 5
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Content
Since 4.10
The page has regular contents. Both the Back and forward buttons will be shown.
Intro
Since 4.10
The page contains an introduction to the assistant task. Only the Forward button will be shown if there is a next page.
Confirm
Since 4.10
The page lets the user confirm or deny the changes. The Back and Apply buttons will be shown.
Summary
Since 4.10
The page informs the user of the changes done. Only the Close button will be shown.
Progress
Since 4.10
Used for tasks that take a long time to complete, blocks the assistant until the page is marked as complete. Only the back button will be shown.
Custom
Since 4.10
Used for when other page types are not appropriate. No buttons will be shown, and the application must add its own buttons through gtk_assistant_add_action_widget().