SvgError

Enum SvgError 

#[non_exhaustive]
pub enum SvgError { InvalidSyntax, InvalidElement, InvalidAttribute, MissingAttribute, InvalidReference, FailedUpdate, FailedRendering, IgnoredElement, LimitsExceeded, NotImplemented, FeatureDisabled, }
Available on crate feature v4_22 only.
Error codes in the GTK_SVG_ERROR domain for errors that happen during parsing or rendering of SVG.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidSyntax

The XML syntax is broken in some way



InvalidElement

An XML element is invalid (either because it is not part of SVG, or because it is in the wrong place, or because it not implemented in GTK)



InvalidAttribute

An attribute is invalid (either because it is not part of SVG, or because it is not implemented in GTK, or its value is problematic)



MissingAttribute

A required attribute is missing



InvalidReference

A reference does not point to a suitable element



FailedUpdate

An animation could not be updated



FailedRendering

Rendering is not according to expecations



IgnoredElement

An XML element is ignored, but it should not affect rendering (this error code is used for metadata and exension elements)



LimitsExceeded

An implementation limit has been hit, such as the number of loaded shapes.



NotImplemented

The SVG uses features that are not supported by Svg. It may be advisable to use a different SVG renderer.



FeatureDisabled

Implementations

Source

impl SvgError

pub fn attribute(error: &Error) -> Option<GString>

pub fn element(error: &Error) -> Option<GString>

pub fn input(error: &Error) -> Option<GString>

Available on crate feature v4_24 only.
pub fn quark() -> Quark