#[non_exhaustive]pub enum TreeViewColumnSizing {
GrowOnly,
Autosize,
Fixed,
}๐Deprecated:
Since 4.20
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GrowOnly
๐Deprecated:
Since 4.20
Columns only get bigger in reaction to changes in the model
Autosize
๐Deprecated:
Since 4.20
Columns resize to be the optimal size every time the model changes.
Fixed
๐Deprecated:
Since 4.20
Columns are a fixed numbers of pixels wide.