#[non_exhaustive]pub enum TreeViewDropPosition {
Before,
After,
IntoOrBefore,
IntoOrAfter,
}๐Deprecated:
Since 4.20
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Before
๐Deprecated:
Since 4.20
dropped row is inserted before
After
๐Deprecated:
Since 4.20
dropped row is inserted after
IntoOrBefore
๐Deprecated:
Since 4.20
dropped row becomes a child or is inserted before
IntoOrAfter
๐Deprecated:
Since 4.20
dropped row becomes a child or is inserted after