pub fn default_language() -> LanguageExpand description
Returns the [pango::Language][crate::pango::Language] for the default language
currently in effect.
Note that this can change over the life of an application.
The default language is derived from the current locale. It determines, for example, whether GTK uses the right-to-left or left-to-right text direction.
This function is equivalent to [pango::Language::default()][crate::pango::Language::default()].
See that function for details.
Returns
the default language