pub fn disable_portals()Expand description
Prevents GTK from using portals.
This is equivalent to setting GDK_DEBUG=no-portals in the environment.
This should only be used in portal implementations, apps must not call it.
pub fn disable_portals()Prevents GTK from using portals.
This is equivalent to setting GDK_DEBUG=no-portals in the environment.
This should only be used in portal implementations, apps must not call it.