disable_setlocale

Function disable_setlocale 

pub fn disable_setlocale()
s locale, or if you wanted to set different values for different locale categories.

Most programs should not need to call this function.