pub trait CellRendererTextExt: IsA<CellRendererText> + 'static {
Show 121 methods
// Provided methods
fn set_fixed_height_from_font(&self, number_of_rows: i32) { ... }
fn is_align_set(&self) -> bool { ... }
fn alignment(&self) -> Alignment { ... }
fn set_alignment(&self, alignment: Alignment) { ... }
fn attributes(&self) -> Option<AttrList> { ... }
fn set_attributes(&self, attributes: Option<&AttrList>) { ... }
fn set_background(&self, background: Option<&str>) { ... }
fn background_rgba(&self) -> Option<RGBA> { ... }
fn set_background_rgba(&self, background_rgba: Option<&RGBA>) { ... }
fn is_background_set(&self) -> bool { ... }
fn is_editable(&self) -> bool { ... }
fn set_editable(&self, editable: bool) { ... }
fn is_editable_set(&self) -> bool { ... }
fn ellipsize(&self) -> EllipsizeMode { ... }
fn set_ellipsize(&self, ellipsize: EllipsizeMode) { ... }
fn is_ellipsize_set(&self) -> bool { ... }
fn family(&self) -> Option<GString> { ... }
fn set_family(&self, family: Option<&str>) { ... }
fn is_family_set(&self) -> bool { ... }
fn font(&self) -> Option<GString> { ... }
fn set_font(&self, font: Option<&str>) { ... }
fn font_desc(&self) -> Option<FontDescription> { ... }
fn set_font_desc(&self, font_desc: Option<&FontDescription>) { ... }
fn set_foreground(&self, foreground: Option<&str>) { ... }
fn foreground_rgba(&self) -> Option<RGBA> { ... }
fn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>) { ... }
fn is_foreground_set(&self) -> bool { ... }
fn language(&self) -> Option<GString> { ... }
fn set_language(&self, language: Option<&str>) { ... }
fn is_language_set(&self) -> bool { ... }
fn set_markup(&self, markup: Option<&str>) { ... }
fn max_width_chars(&self) -> i32 { ... }
fn set_max_width_chars(&self, max_width_chars: i32) { ... }
fn placeholder_text(&self) -> Option<GString> { ... }
fn set_placeholder_text(&self, placeholder_text: Option<&str>) { ... }
fn rise(&self) -> i32 { ... }
fn set_rise(&self, rise: i32) { ... }
fn is_rise_set(&self) -> bool { ... }
fn scale(&self) -> f64 { ... }
fn set_scale(&self, scale: f64) { ... }
fn is_scale_set(&self) -> bool { ... }
fn is_single_paragraph_mode(&self) -> bool { ... }
fn set_single_paragraph_mode(&self, single_paragraph_mode: bool) { ... }
fn size(&self) -> i32 { ... }
fn set_size(&self, size: i32) { ... }
fn size_points(&self) -> f64 { ... }
fn set_size_points(&self, size_points: f64) { ... }
fn is_size_set(&self) -> bool { ... }
fn stretch(&self) -> Stretch { ... }
fn set_stretch(&self, stretch: Stretch) { ... }
fn is_stretch_set(&self) -> bool { ... }
fn is_strikethrough(&self) -> bool { ... }
fn set_strikethrough(&self, strikethrough: bool) { ... }
fn is_strikethrough_set(&self) -> bool { ... }
fn style(&self) -> Style { ... }
fn set_style(&self, style: Style) { ... }
fn is_style_set(&self) -> bool { ... }
fn text(&self) -> Option<GString> { ... }
fn set_text(&self, text: Option<&str>) { ... }
fn underline(&self) -> Underline { ... }
fn set_underline(&self, underline: Underline) { ... }
fn is_underline_set(&self) -> bool { ... }
fn variant(&self) -> Variant { ... }
fn set_variant(&self, variant: Variant) { ... }
fn is_variant_set(&self) -> bool { ... }
fn weight(&self) -> i32 { ... }
fn set_weight(&self, weight: i32) { ... }
fn is_weight_set(&self) -> bool { ... }
fn width_chars(&self) -> i32 { ... }
fn set_width_chars(&self, width_chars: i32) { ... }
fn wrap_mode(&self) -> WrapMode { ... }
fn set_wrap_mode(&self, wrap_mode: WrapMode) { ... }
fn wrap_width(&self) -> i32 { ... }
fn set_wrap_width(&self, wrap_width: i32) { ... }
fn connect_edited<F: Fn(&Self, TreePath, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_align_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_alignment_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_attributes_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_editable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_editable_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_ellipsize_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_ellipsize_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_family_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_family_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_desc_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_language_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_language_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_markup_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_max_width_chars_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_rise_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_rise_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_scale_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_scale_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_single_paragraph_mode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_points_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stretch_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stretch_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_style_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_style_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_variant_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_variant_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_weight_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_weight_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_width_chars_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_wrap_mode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_wrap_width_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Since 4.10
Trait containing all CellRendererText methods.
ΒImplementors
CellRendererAccel, CellRendererCombo, CellRendererSpin, CellRendererText
Provided MethodsΒ
Sourcefn set_fixed_height_from_font(&self, number_of_rows: i32)
πDeprecated: Since 4.10
fn set_fixed_height_from_font(&self, number_of_rows: i32)
Since 4.10
Sets the height of a renderer to explicitly be determined by the βfontβ and βy_padβ property set on it. Further changes in these properties do not affect the height, so they must be accompanied by a subsequent call to this function. Using this function is inflexible, and should really only be used if calculating the size of a cell is too slow (ie, a massive number of cells displayed). If @number_of_rows is -1, then the fixed height is unset, and the height is determined by the properties again.
ΒDeprecated since 4.10
Βnumber_of_rows
Number of rows of text each cell renderer is allocated, or -1
fn is_align_set(&self) -> bool
Since 4.10
Sourcefn alignment(&self) -> Alignment
πDeprecated: Since 4.10
fn alignment(&self) -> Alignment
Since 4.10
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The βxalignβ property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
Sourcefn set_alignment(&self, alignment: Alignment)
πDeprecated: Since 4.10
fn set_alignment(&self, alignment: Alignment)
Since 4.10
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The βxalignβ property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
fn attributes(&self) -> Option<AttrList>
Since 4.10
fn set_attributes(&self, attributes: Option<&AttrList>)
Since 4.10
fn set_background(&self, background: Option<&str>)
Since 4.10
Sourcefn background_rgba(&self) -> Option<RGBA>
πDeprecated: Since 4.10
fn background_rgba(&self) -> Option<RGBA>
Since 4.10
Background color as a gdk::RGBA
Sourcefn set_background_rgba(&self, background_rgba: Option<&RGBA>)
πDeprecated: Since 4.10
fn set_background_rgba(&self, background_rgba: Option<&RGBA>)
Since 4.10
Background color as a gdk::RGBA
fn is_background_set(&self) -> bool
Since 4.10
fn is_editable(&self) -> bool
Since 4.10
fn set_editable(&self, editable: bool)
Since 4.10
fn is_editable_set(&self) -> bool
Since 4.10
Sourcefn ellipsize(&self) -> EllipsizeMode
πDeprecated: Since 4.10
fn ellipsize(&self) -> EllipsizeMode
Since 4.10
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
pango::EllipsizeMode::None turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
Sourcefn set_ellipsize(&self, ellipsize: EllipsizeMode)
πDeprecated: Since 4.10
fn set_ellipsize(&self, ellipsize: EllipsizeMode)
Since 4.10
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
pango::EllipsizeMode::None turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
fn is_ellipsize_set(&self) -> bool
Since 4.10
fn family(&self) -> Option<GString>
Since 4.10
fn set_family(&self, family: Option<&str>)
Since 4.10
fn is_family_set(&self) -> bool
Since 4.10
fn font(&self) -> Option<GString>
Since 4.10
fn set_font(&self, font: Option<&str>)
Since 4.10
fn font_desc(&self) -> Option<FontDescription>
Since 4.10
fn set_font_desc(&self, font_desc: Option<&FontDescription>)
Since 4.10
fn set_foreground(&self, foreground: Option<&str>)
Since 4.10
Sourcefn foreground_rgba(&self) -> Option<RGBA>
πDeprecated: Since 4.10
fn foreground_rgba(&self) -> Option<RGBA>
Since 4.10
Foreground color as a gdk::RGBA
Sourcefn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>)
πDeprecated: Since 4.10
fn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>)
Since 4.10
Foreground color as a gdk::RGBA
fn is_foreground_set(&self) -> bool
Since 4.10
fn language(&self) -> Option<GString>
Since 4.10
fn set_language(&self, language: Option<&str>)
Since 4.10
fn is_language_set(&self) -> bool
Since 4.10
fn set_markup(&self, markup: Option<&str>)
Since 4.10
Sourcefn max_width_chars(&self) -> i32
πDeprecated: Since 4.10
fn max_width_chars(&self) -> i32
Since 4.10
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cellβs siblings
have received their natural width.
Sourcefn set_max_width_chars(&self, max_width_chars: i32)
πDeprecated: Since 4.10
fn set_max_width_chars(&self, max_width_chars: i32)
Since 4.10
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cellβs siblings
have received their natural width.
Sourcefn placeholder_text(&self) -> Option<GString>
πDeprecated: Since 4.10
fn placeholder_text(&self) -> Option<GString>
Since 4.10
The text that will be displayed in the CellRenderer if
GtkCellRendererText:editable is true and the cell is empty.
Sourcefn set_placeholder_text(&self, placeholder_text: Option<&str>)
πDeprecated: Since 4.10
fn set_placeholder_text(&self, placeholder_text: Option<&str>)
Since 4.10
The text that will be displayed in the CellRenderer if
GtkCellRendererText:editable is true and the cell is empty.
fn rise(&self) -> i32
Since 4.10
fn set_rise(&self, rise: i32)
Since 4.10
fn is_rise_set(&self) -> bool
Since 4.10
fn scale(&self) -> f64
Since 4.10
fn set_scale(&self, scale: f64)
Since 4.10
fn is_scale_set(&self) -> bool
Since 4.10
fn is_single_paragraph_mode(&self) -> bool
Since 4.10
fn set_single_paragraph_mode(&self, single_paragraph_mode: bool)
Since 4.10
fn size(&self) -> i32
Since 4.10
fn set_size(&self, size: i32)
Since 4.10
fn size_points(&self) -> f64
Since 4.10
fn set_size_points(&self, size_points: f64)
Since 4.10
fn is_size_set(&self) -> bool
Since 4.10
fn stretch(&self) -> Stretch
Since 4.10
fn set_stretch(&self, stretch: Stretch)
Since 4.10
fn is_stretch_set(&self) -> bool
Since 4.10
fn is_strikethrough(&self) -> bool
Since 4.10
fn set_strikethrough(&self, strikethrough: bool)
Since 4.10
fn is_strikethrough_set(&self) -> bool
Since 4.10
fn style(&self) -> Style
Since 4.10
fn set_style(&self, style: Style)
Since 4.10
fn is_style_set(&self) -> bool
Since 4.10
fn text(&self) -> Option<GString>
Since 4.10
fn set_text(&self, text: Option<&str>)
Since 4.10
fn underline(&self) -> Underline
Since 4.10
fn set_underline(&self, underline: Underline)
Since 4.10
fn is_underline_set(&self) -> bool
Since 4.10
fn variant(&self) -> Variant
Since 4.10
fn set_variant(&self, variant: Variant)
Since 4.10
fn is_variant_set(&self) -> bool
Since 4.10
fn weight(&self) -> i32
Since 4.10
fn set_weight(&self, weight: i32)
Since 4.10
fn is_weight_set(&self) -> bool
Since 4.10
Sourcefn width_chars(&self) -> i32
πDeprecated: Since 4.10
fn width_chars(&self) -> i32
Since 4.10
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Sourcefn set_width_chars(&self, width_chars: i32)
πDeprecated: Since 4.10
fn set_width_chars(&self, width_chars: i32)
Since 4.10
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Sourcefn wrap_mode(&self) -> WrapMode
πDeprecated: Since 4.10
fn wrap_mode(&self) -> WrapMode
Since 4.10
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Sourcefn set_wrap_mode(&self, wrap_mode: WrapMode)
πDeprecated: Since 4.10
fn set_wrap_mode(&self, wrap_mode: WrapMode)
Since 4.10
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Sourcefn wrap_width(&self) -> i32
πDeprecated: Since 4.10
fn wrap_width(&self) -> i32
Since 4.10
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Sourcefn set_wrap_width(&self, wrap_width: i32)
πDeprecated: Since 4.10
fn set_wrap_width(&self, wrap_width: i32)
Since 4.10
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Sourcefn connect_edited<F: Fn(&Self, TreePath, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
πDeprecated: Since 4.10
fn connect_edited<F: Fn(&Self, TreePath, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_align_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_alignment_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_attributes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_editable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_editable_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_ellipsize_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_ellipsize_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_family_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_family_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_font_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_font_desc_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_foreground_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_foreground_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_foreground_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_language_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_markup_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_max_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_rise_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_rise_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_scale_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_scale_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_single_paragraph_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_size_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_size_points_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_size_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_stretch_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_stretch_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_strikethrough_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_strikethrough_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_style_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_style_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_text_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_underline_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_variant_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_variant_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_weight_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_weight_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_wrap_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_wrap_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Dyn CompatibilityΒ
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.