FlowBoxChildExt

Trait FlowBoxChildExt 

pub trait FlowBoxChildExt: IsA<FlowBoxChild> + 'static {
    // Provided methods
    fn changed(&self) { ... }
    fn child(&self) -> Option<Widget> { ... }
    fn index(&self) -> i32 { ... }
    fn is_selected(&self) -> bool { ... }
    fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... }
    fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn emit_activate(&self) { ... }
    fn connect_child_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all FlowBoxChild methods.

Implementors

FlowBoxChild

Provided Methods

fn changed(&self)

t fully control the data model, you have to duplicate the data that affects the sorting and filtering functions into the widgets themselves.

Another alternative is to call FlowBox::invalidate_sort() on any model change, but that is more expensive.

fn child(&self) -> Option<Widget>

Gets the child widget of @self.

Returns

the child widget of @self

fn index(&self) -> i32

Gets the current index of the @self in its FlowBox container.

Returns

the index of the @self, or -1 if the @self is not in a flow box

fn is_selected(&self) -> bool

Returns whether the @self is currently selected in its FlowBox container.

Returns

true if @self is selected

fn set_child(&self, child: Option<&impl IsA<Widget>>)

Sets the child widget of @self.

child

the child widget

fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

.

fn emit_activate(&self)

fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors