pub trait IMMulticontextExt: IsA<IMMulticontext> + 'static {
// Provided methods
fn context_id(&self) -> GString { ... }
fn set_context_id(&self, context_id: Option<&str>) { ... }
}Expand description
Provided Methods
Sourcefn context_id(&self) -> GString
fn context_id(&self) -> GString
Gets the id of the currently active delegate of the @self.
Returns
the id of the currently active delegate
Sourcefn set_context_id(&self, context_id: Option<&str>)
fn set_context_id(&self, context_id: Option<&str>)
Sets the context id for @self.
This causes the currently active delegate of @self to be replaced by the delegate corresponding to the new context id.
Setting this to a non-None value overrides the system-wide
IM module setting. See the gtk-im-module
property.
context_id
the id to use
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".