ListBoxRowExt

Trait ListBoxRowExt 

pub trait ListBoxRowExt: IsA<ListBoxRow> + 'static {
Show 16 methods // Provided methods fn changed(&self) { ... } fn is_activatable(&self) -> bool { ... } fn child(&self) -> Option<Widget> { ... } fn header(&self) -> Option<Widget> { ... } fn index(&self) -> i32 { ... } fn is_selectable(&self) -> bool { ... } fn is_selected(&self) -> bool { ... } fn set_activatable(&self, activatable: bool) { ... } fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... } fn set_header(&self, header: Option<&impl IsA<Widget>>) { ... } fn set_selectable(&self, selectable: bool) { ... } fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn emit_activate(&self) { ... } fn connect_activatable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all ListBoxRow methods.

Implementors

ListBoxRow

Provided Methods

fn changed(&self)

t fully control the data model you have to duplicate the data that affects the listbox row functions into the row widgets themselves. Another alternative is to call ListBox::invalidate_sort() on any model change, but that is more expensive.

fn is_activatable(&self) -> bool

Gets whether the row is activatable.

Returns

true if the row is activatable

fn child(&self) -> Option<Widget>

Gets the child widget of @self.

Returns

the child widget of @self

fn header(&self) -> Option<Widget>

Returns the current header of the @self.

This can be used in a `callback::Gtk::ListBoxUpdateHeaderFunc to see if there is a header set already, and if so to update the state of it.

Returns

the current header

fn index(&self) -> i32

Gets the current index of the @self in its ListBox container.

Returns

the index of the @self, or -1 if the @self is not in a listbox

fn is_selectable(&self) -> bool

Gets whether the row can be selected.

Returns

true if the row is selectable

fn is_selected(&self) -> bool

Returns whether the child is currently selected in its ListBox container.

Returns

true if @self is selected

fn set_activatable(&self, activatable: bool)

Set whether the row is activatable.

activatable

true to mark the row as activatable

fn set_child(&self, child: Option<&impl IsA<Widget>>)

Sets the child widget of @self_.

child

the child widget

fn set_header(&self, header: Option<&impl IsA<Widget>>)

Sets the current header of the @self.

This is only allowed to be called from a `callback::Gtk::ListBoxUpdateHeaderFunc. It will replace any existing header in the row, and be shown in front of the row in the listbox.

the header

fn set_selectable(&self, selectable: bool)

Set whether the row can be selected.

selectable

true to mark the row as selectable

fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

s parent ListBox.

fn emit_activate(&self)

fn connect_activatable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors