TextChildAnchorExt

Trait TextChildAnchorExt 

pub trait TextChildAnchorExt: IsA<TextChildAnchor> + 'static {
    // Provided methods
    fn is_deleted(&self) -> bool { ... }
    fn widgets(&self) -> Vec<Widget> { ... }
}
Trait containing all TextChildAnchor methods.

Implementors

TextChildAnchor

Provided Methods

fn is_deleted(&self) -> bool

otherwise all deleted child anchors will also be finalized.

Returns

true if the child anchor has been deleted from its buffer

fn widgets(&self) -> Vec<Widget>

Gets a list of all widgets anchored at this child anchor.

The order in which the widgets are returned is not defined.

Returns

an array of widgets anchored at @self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors