pub trait TreeDragDestExt: IsA<TreeDragDest> + 'static {
// Provided methods
fn drag_data_received(&self, dest: &TreePath, value: &Value) -> bool { ... }
fn row_drop_possible(&self, dest_path: &TreePath, value: &Value) -> bool { ... }
}👎Deprecated:
Since 4.10
Provided Methods
Sourcefn drag_data_received(&self, dest: &TreePath, value: &Value) -> bool
👎Deprecated: Since 4.10
fn drag_data_received(&self, dest: &TreePath, value: &Value) -> bool
Since 4.10
Asks the TreeDragDest to insert a row before the path @dest,
deriving the contents of the row from @value. If @dest is
outside the tree so that inserting before it is impossible, false
will be returned. Also, false may be returned if the new row is
not created for some model-specific reason. Should robustly handle
a @dest no longer found in the model!
Deprecated since 4.10
Use list models instead
dest
row to drop in front of
value
data to drop
Returns
whether a new row was created before position @dest
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".