TreeModelSortExt

Trait TreeModelSortExt 

pub trait TreeModelSortExt: IsA<TreeModelSort> + 'static {
    // Provided methods
    fn clear_cache(&self) { ... }
    fn convert_child_iter_to_iter(
        &self,
        child_iter: &TreeIter,
    ) -> Option<TreeIter> { ... }
    fn convert_child_path_to_path(
        &self,
        child_path: &TreePath,
    ) -> Option<TreePath> { ... }
    fn convert_iter_to_child_iter(&self, sorted_iter: &TreeIter) -> TreeIter { ... }
    fn convert_path_to_child_path(
        &self,
        sorted_path: &TreePath,
    ) -> Option<TreePath> { ... }
    fn model(&self) -> TreeModel { ... }
    fn iter_is_valid(&self, iter: &TreeIter) -> bool { ... }
    fn reset_default_sort_func(&self) { ... }
}
👎Deprecated:

Since 4.10

Trait containing all TreeModelSort methods.

Implementors

TreeModelSort

Provided Methods

fn clear_cache(&self)

👎Deprecated:

Since 4.10

t change often) and there has been a lot of unreffed access to nodes. As a side effect of this function, all unreffed iters will be invalid.

Deprecated since 4.10
fn convert_child_iter_to_iter(&self, child_iter: &TreeIter) -> Option<TreeIter>

👎Deprecated:

Since 4.10

Sets @sort_iter to point to the row in @self that corresponds to the row pointed at by @child_iter. If @sort_iter was not set, false is returned. Note: a boolean is only returned since 2.14.

Deprecated since 4.10
child_iter

A valid TreeIter pointing to a row on the child model

Returns

true, if @sort_iter was set, i.e. if @sort_iter is a valid iterator pointer to a visible row in the child model.

sort_iter

An uninitialized TreeIter

fn convert_child_path_to_path(&self, child_path: &TreePath) -> Option<TreePath>

👎Deprecated:

Since 4.10

t a valid path on the child model, then None is returned.

Deprecated since 4.10
child_path

A TreePath to convert

Returns

A newly allocated TreePath

fn convert_iter_to_child_iter(&self, sorted_iter: &TreeIter) -> TreeIter

👎Deprecated:

Since 4.10

Sets @child_iter to point to the row pointed to by @sorted_iter.

Deprecated since 4.10
sorted_iter

A valid TreeIter pointing to a row on @self.

Returns
child_iter

An uninitialized TreeIter

fn convert_path_to_child_path(&self, sorted_path: &TreePath) -> Option<TreePath>

👎Deprecated:

Since 4.10

Converts @sorted_path to a path on the child model of @self. That is, @sorted_path points to a location in @self. The returned path will point to the same location in the model not being sorted. If @sorted_path does not point to a location in the child model, None is returned.

Deprecated since 4.10
sorted_path

A TreePath to convert

Returns

A newly allocated TreePath

fn model(&self) -> TreeModel

👎Deprecated:

Since 4.10

Returns the model the TreeModelSort is sorting.

Deprecated since 4.10
Returns

the “child model” being sorted

fn iter_is_valid(&self, iter: &TreeIter) -> bool

👎Deprecated:

Since 4.10

purposes.

Checks if the given iter is a valid iter for this TreeModelSort.

Deprecated since 4.10
iter

A TreeIter

Returns

true if the iter is valid, false if the iter is invalid.

fn reset_default_sort_func(&self)

👎Deprecated:

Since 4.10

state.

Deprecated since 4.10

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors