pub struct ATContext { /* private fields */ }Expand description
Communicates with platform-specific assistive technologies API.
Each platform supported by GTK implements a ATContext subclass, and
is responsible for updating the accessible state in response to state
changes in Accessible.
This is an Abstract Base Class, you cannot instantiate it.
Properties
accessible
The Accessible that created the ATContext instance.
Readable | Writable | Construct Only
accessible-role
The accessible role used by the AT context.
Depending on the given role, different states and properties can be set or retrieved.
Readable | Writable | Construct
display
The gdk::Display for the ATContext.
Readable | Writable
realized
Whether the ATContext has been realized or not.
Readable
Signals
state-change
Emitted when the attributes of the accessible for the
ATContext instance change.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ATContext
impl ATContext
Sourcepub fn create(
accessible_role: AccessibleRole,
accessible: &impl IsA<Accessible>,
display: &impl IsA<Display>,
) -> Option<ATContext>
pub fn create( accessible_role: AccessibleRole, accessible: &impl IsA<Accessible>, display: &impl IsA<Display>, ) -> Option<ATContext>
Creates a new ATContext instance for the given accessible role,
accessible instance, and display connection.
The ATContext implementation being instantiated will depend on the
platform.
accessible_role
the accessible role used by the ATContext
accessible
the Accessible implementation using the ATContext
display
the gdk::Display used by the ATContext
Returns
the ATContext
Sourcepub fn accessible(&self) -> Accessible
pub fn accessible(&self) -> Accessible
Sourcepub fn accessible_role(&self) -> AccessibleRole
pub fn accessible_role(&self) -> AccessibleRole
Sourcepub fn set_accessible_role(&self, accessible_role: AccessibleRole)
pub fn set_accessible_role(&self, accessible_role: AccessibleRole)
The accessible role used by the AT context.
Depending on the given role, different states and properties can be set or retrieved.
Sourcepub fn set_display<P: IsA<Display>>(&self, display: Option<&P>)
pub fn set_display<P: IsA<Display>>(&self, display: Option<&P>)
The gdk::Display for the ATContext.
Sourcepub fn is_realized(&self) -> bool
pub fn is_realized(&self) -> bool
Whether the ATContext has been realized or not.
Sourcepub fn connect_state_change<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_state_change<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the attributes of the accessible for the
ATContext instance change.
pub fn connect_accessible_role_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_display_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_realized_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId