pub struct AccessibleHyperlink { /* private fields */ }Expand description
Represents a link (i.e. a uri).
A widget that contains one or more links should implement
the AccessibleHypertext interface and return
AccessibleHyperlink objects for each of the links.
Implements
[trait@glib::ObjectExt], AccessibleExt, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AccessibleHyperlink
impl AccessibleHyperlink
Sourcepub fn new(
parent: &impl IsA<AccessibleHypertext>,
index: u32,
uri: &str,
bounds: &mut AccessibleTextRange,
) -> AccessibleHyperlink
pub fn new( parent: &impl IsA<AccessibleHypertext>, index: u32, uri: &str, bounds: &mut AccessibleTextRange, ) -> AccessibleHyperlink
Creates an accessible object that represents a hyperlink.
This is meant to be used with an implementation of the
AccessibleHypertext interface.
parent
the parent
index
the index of this link in the parent
uri
the uri
bounds
the text range that the link occupies (or 0, 0)
Sourcepub fn builder() -> AccessibleHyperlinkBuilder
pub fn builder() -> AccessibleHyperlinkBuilder
Creates a new builder-pattern struct instance to construct AccessibleHyperlink objects.
This method returns an instance of AccessibleHyperlinkBuilder which can be used to create AccessibleHyperlink objects.
Sourcepub fn set_platform_state(&self, state: AccessiblePlatformState, enabled: bool)
pub fn set_platform_state(&self, state: AccessiblePlatformState, enabled: bool)