pub struct AccessibleRange { /* private fields */ }v4_10 only.Expand description
An interface for accessible objects containing a numeric value.
AccessibleRange describes ranged controls for Assistive Technologies.
Ranged controls have a single value within an allowed range that can optionally be changed by the user.
This interface is expected to be implemented by controls using the following roles:
GTK_ACCESSIBLE_ROLE_METERGTK_ACCESSIBLE_ROLE_PROGRESS_BARGTK_ACCESSIBLE_ROLE_SCROLLBARGTK_ACCESSIBLE_ROLE_SLIDERGTK_ACCESSIBLE_ROLE_SPIN_BUTTON
If that is not the case, a warning will be issued at run time.
In addition to this interface, its implementers are expected to provide the correct values for the following properties:
GTK_ACCESSIBLE_PROPERTY_VALUE_MAXGTK_ACCESSIBLE_PROPERTY_VALUE_MINGTK_ACCESSIBLE_PROPERTY_VALUE_NOWGTK_ACCESSIBLE_PROPERTY_VALUE_TEXT
Implements
AccessibleRangeExt, AccessibleExt, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AccessibleRange
impl AccessibleRange
pub const NONE: Option<&'static AccessibleRange> = None