pub struct AlertDialog { /* private fields */ }Expand description
Collects the arguments that are needed to present a message to the user.
The message is shown with the choose()
function.
If you don’t need to wait for a button to be clicked, you can use
show().
Properties
buttons
Labels for buttons to show in the alert.
The labels should be translated and may contain
a _ character to indicate the mnemonic character.
If this property is not set, then a ‘Close’ button is automatically created.
Readable | Writable
cancel-button
Determines what happens when the Escape key is pressed while the alert is shown.
If this property holds the index of a button in buttons,
then pressing Escape is treated as if that button was pressed. If it is -1
or not a valid index for the buttons array, then an error is returned.
If buttons is NULL, then the automatically created ‘Close’ button
is treated as both cancel and default button, so 0 is returned.
Readable | Writable
default-button
Determines what happens when the Return key is pressed while the alert is shown.
If this property holds the index of a button in buttons,
then pressing Return is treated as if that button was pressed. If it is -1
or not a valid index for the buttons array, then nothing happens.
If buttons is NULL, then the automatically created ‘Close’ button
is treated as both cancel and default button, so 0 is returned.
Readable | Writable
detail
The detail text for the alert.
Readable | Writable
message
The message for the alert.
Readable | Writable
modal
Whether the alert is modal.
Readable | Writable
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AlertDialog
impl AlertDialog
Sourcepub fn builder() -> AlertDialogBuilder
pub fn builder() -> AlertDialogBuilder
Creates a new builder-pattern struct instance to construct AlertDialog objects.
This method returns an instance of AlertDialogBuilder which can be used to create AlertDialog objects.
Sourcepub fn choose<P: FnOnce(Result<i32, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn choose<P: FnOnce(Result<i32, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
pub fn choose_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, ) -> Pin<Box_<dyn Future<Output = Result<i32, Error>> + 'static>>
Sourcepub fn is_modal(&self) -> bool
pub fn is_modal(&self) -> bool
Returns whether the alert blocks interaction with the parent window while it is presented.
Returns
true if the alert is modal
Sets the index of the cancel button.
See cancel-button for
details of how this value is used.
button
the new cancel button
Sets the index of the default button.
See default-button for
details of how this value is used.
button
the new default button
Sourcepub fn set_detail(&self, detail: &str)
pub fn set_detail(&self, detail: &str)
Sourcepub fn set_message(&self, message: &str)
pub fn set_message(&self, message: &str)
Sourcepub fn set_modal(&self, modal: bool)
pub fn set_modal(&self, modal: bool)
Sets whether the alert blocks interaction with the parent window while it is presented.
modal
the new value
Sourcepub fn show(&self, parent: Option<&impl IsA<Window>>)
pub fn show(&self, parent: Option<&impl IsA<Window>>)
Shows the alert to the user.
This function is a simpler version of choose()
intended for dialogs with a single button.
If you want to cancel the dialog or if the alert has more than one
button, you should use that function instead and provide it with a
[gio::Cancellable][crate::gio::Cancellable] and callback respectively.
parent
the parent window
pub fn connect_detail_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_message_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_modal_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId