AppChooserDialog

Struct AppChooserDialog 

pub struct AppChooserDialog { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

The application selection widgets should be implemented according to the design of each platform and/or application requiring them. AppChooserDialog shows a AppChooserWidget inside a Dialog.

An example GtkAppChooserDialog

Note that AppChooserDialog does not have any interesting methods of its own. Instead, you should get the embedded AppChooserWidget using widget() and call its methods if the generic AppChooser interface is not sufficient for your needs.

To set the heading that is shown above the AppChooserWidget, use set_heading().

CSS nodes

AppChooserDialog has a single CSS node with the name window and style class .appchooser.

Properties

gfile

The GFile used by the AppChooserDialog.

The dialogโ€™s AppChooserWidget content type will be guessed from the file, if present.

Readable | Writable | Construct Only

heading

The text to show at the top of the dialog.

The string may contain Pango markup.

Readable | Writable

Dialog

use-header-bar

true if the dialog uses a headerbar for action buttons instead of the action-area.

For technical reasons, this property is declared as an integer property, but you should only set it to true or false.

Creating a dialog with headerbar

Builtin Dialog subclasses such as ColorChooserDialog set this property according to platform conventions (using the gtk-dialogs-use-header setting).

Here is how you can achieve the same:

โš ๏ธ The following code is in c โš ๏ธ

g_object_get (settings, "gtk-dialogs-use-header", &header, NULL);
dialog = g_object_new (GTK_TYPE_DIALOG, header, TRUE, NULL);

Readable | Writable | Construct Only

Window

application

The Application associated with the window.

The application will be kept alive for at least as long as it has any windows associated with it (see g_application_hold() for a way to keep it alive without windows).

Normally, the connection between the application and the window will remain until the window is destroyed, but you can explicitly remove it by setting the this property to NULL.

Readable | Writable

child

The child widget.

Readable | Writable

decorated

Whether the window should have a frame (also known as decorations).

Readable | Writable

default-height

The default height of the window.

Readable | Writable

default-widget

The default widget.

Readable | Writable

default-width

The default width of the window.

Readable | Writable

deletable

Whether the window frame should have a close button.

Readable | Writable

destroy-with-parent

If this window should be destroyed when the parent is destroyed.

Readable | Writable

display

The display that will display this window.

Readable | Writable

focus-visible

Whether โ€˜focus rectanglesโ€™ are currently visible in this window.

This property is maintained by GTK based on user input and should not be set by applications.

Readable | Writable

focus-widget

The focus widget.

Readable | Writable

fullscreened

Whether the window is fullscreen.

Setting this property is the equivalent of calling GtkWindowExt::fullscreen() or GtkWindowExt::unfullscreen(); either operation is asynchronous, which means you will need to connect to the ::notify signal in order to know whether the operation was successful.

Readable | Writable

gravity

The gravity to use when resizing the window programmatically.

Gravity describes which point of the window we want to keep fixed (meaning that the window will grow in the opposite direction). For example, a gravity of GTK_WINDOW_GRAVITY_TOP_RIGHT means that we want the to fix top right corner of the window.

Readable | Writable

handle-menubar-accel

Whether the window frame should handle F10 for activating menubars.

Readable | Writable

hide-on-close

If this window should be hidden instead of destroyed when the user clicks the close button.

Readable | Writable

icon-name

Specifies the name of the themed icon to use as the window icon.

See IconTheme for more details.

Readable | Writable

is-active

Whether the toplevel is the currently active window.

Readable

maximized

Whether the window is maximized.

Setting this property is the equivalent of calling GtkWindowExt::maximize() or GtkWindowExt::unmaximize(); either operation is asynchronous, which means you will need to connect to the ::notify signal in order to know whether the operation was successful.

Readable | Writable

mnemonics-visible

Whether mnemonics are currently visible in this window.

This property is maintained by GTK based on user input, and should not be set by applications.

Readable | Writable

If true, the window is modal.

Readable | Writable

resizable

If true, users can resize the window.

Readable | Writable

startup-id

A write-only property for setting windowโ€™s startup notification identifier.

Writable

suspended

Whether the window is suspended.

See GtkWindowExt::is_suspended() for details about what suspended means.

Readable

title

The title of the window.

Readable | Writable

titlebar

The titlebar widget.

Readable | Writable

transient-for

The transient parent of the window.

Readable | Writable | Construct

Widget

can-focus

Whether the widget or any of its descendents can accept the input focus.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

can-target

Whether the widget can receive pointer events.

Readable | Writable

css-classes

A list of css classes applied to this widget.

Readable | Writable

css-name

The name of this widget in the CSS tree.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable | Construct Only

cursor

The cursor used by @widget.

Readable | Writable

focus-on-click

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writable

focusable

Whether this widget itself will accept the input focus.

Readable | Writable

halign

How to distribute horizontal space if widget gets extra space.

Readable | Writable

has-default

Whether the widget is the default widget.

Readable

has-focus

Whether the widget has the input focus.

Readable

has-tooltip

Enables or disables the emission of the query-tooltip signal on @widget.

A true value indicates that @widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Readable | Writable

height-request

Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writable

hexpand

Whether to expand horizontally.

Readable | Writable

hexpand-set

Whether to use the hexpand property.

Readable | Writable

layout-manager

The LayoutManager instance to use to compute the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

limit-events

Makes this widget act like a modal dialog, with respect to event delivery.

Global event controllers will not handle events with targets inside the widget, unless they are set up to ignore propagation limits. See EventControllerExt::set_propagation_limit().

Readable | Writable

margin-bottom

Margin on bottom side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-end

Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-start

Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-top

Margin on top side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

name

The name of the widget.

Readable | Writable

opacity

The requested opacity of the widget.

Readable | Writable

overflow

How content outside the widgetโ€™s content area is treated.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

parent

The parent widget of this widget.

Readable

receives-default

Whether the widget will receive the default action when it is focused.

Readable | Writable

root

The Root widget of the widget tree containing this widget.

This will be NULL if the widget is not contained in a root widget.

Readable

scale-factor

The scale factor of the widget.

Readable

sensitive

Whether the widget responds to input.

Readable | Writable

tooltip-markup

Sets the text of tooltip to be the given string, which is marked up with Pango markup.

Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writable

tooltip-text

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writable

valign

How to distribute vertical space if widget gets extra space.

Readable | Writable

vexpand

Whether to expand vertically.

Readable | Writable

vexpand-set

Whether to use the vexpand property.

Readable | Writable

visible

Whether the widget is visible.

Readable | Writable

width-request

Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writable

Accessible

accessible-role

The accessible role of the given Accessible implementation.

The accessible role cannot be changed once set.

Readable | Writable

AppChooser

content-type

The content type of the AppChooser object.

See GContentType for more information about content types.

Readable | Writable | Construct Only

Implements

DialogExt, GtkWindowExt, WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, NativeExt, RootExt, ShortcutManagerExt, AppChooserExt, DialogExtManual, WidgetExtManual, AccessibleExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl AppChooserDialog

pub fn new( parent: Option<&impl IsA<Window>>, flags: DialogFlags, file: &impl IsA<File>, ) -> AppChooserDialog

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new AppChooserDialog for the provided GFile.

The dialog will show applications that can open the file.

Deprecated since 4.10

This widget will be removed in GTK 5

parent

a Window

flags

flags for this dialog

file

a GFile

Returns

a newly created AppChooserDialog

pub fn for_content_type( parent: Option<&impl IsA<Window>>, flags: DialogFlags, content_type: &str, ) -> AppChooserDialog

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new AppChooserDialog for the provided content type.

The dialog will show applications that can open the content type.

Deprecated since 4.10

This widget will be removed in GTK 5

parent

a Window

flags

flags for this dialog

content_type

a content type string

Returns

a newly created AppChooserDialog

pub fn heading(&self) -> Option<GString>

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the text to display at the top of the dialog.

Deprecated since 4.10

This widget will be removed in GTK 5

Returns

the text to display at the top of the dialog, or None, in which case a default text is displayed

pub fn widget(&self) -> Widget

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the AppChooserWidget of this dialog.

Deprecated since 4.10

This widget will be removed in GTK 5

Returns

the AppChooserWidget of @self

pub fn set_heading(&self, heading: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the text to display at the top of the dialog.

If the heading is not set, the dialog displays a default text.

Deprecated since 4.10

This widget will be removed in GTK 5

heading

a string containing Pango markup

pub fn gfile(&self) -> Option<File>

๐Ÿ‘ŽDeprecated:

Since 4.10

The GFile used by the AppChooserDialog.

The dialogโ€™s AppChooserWidget content type will be guessed from the file, if present.

pub fn connect_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10