pub struct ApplicationWindow { /* private fields */ }Expand description
A Window subclass that integrates with Application.
Notably, ApplicationWindow can handle an application menubar.
This class implements the [gio::ActionGroup][crate::gio::ActionGroup] and [gio::ActionMap][crate::gio::ActionMap]
interfaces, to let you add window-specific actions that will be exported
by the associated Application, together with its application-wide
actions. Window-specific actions are prefixed with the “win.”
prefix and application-wide actions are prefixed with the “app.”
prefix. Actions must be addressed with the prefixed name when
referring to them from a menu model.
Note that widgets that are placed inside a ApplicationWindow
can also activate these actions, if they implement the
Actionable interface.
The settings gtk-shell-shows-app-menu and
gtk-shell-shows-menubar tell GTK whether the
desktop environment is showing the application menu and menubar
models outside the application as part of the desktop shell.
For instance, on OS X, both menus will be displayed remotely;
on Windows neither will be.
If the desktop environment does not display the menubar, it can be shown in
the ApplicationWindow by setting the
show-menubar property to true. If the
desktop environment does not display the application menu, then it will
automatically be included in the menubar or in the window’s client-side
decorations.
See PopoverMenu for information about the XML language
used by Builder for menu models.
See also: GtkApplicationExt::set_menubar().
A GtkApplicationWindow with a menubar
The code sample below shows how to set up a ApplicationWindow
with a menu bar defined on the Application:
⚠️ The following code is in c ⚠️
GtkApplication *app = gtk_application_new ("org.gtk.test", 0);
GtkBuilder *builder = gtk_builder_new_from_string (
"<interface>"
" <menu id='menubar'>"
" <submenu>"
" <attribute name='label' translatable='yes'>_Edit</attribute>"
" <item>"
" <attribute name='label' translatable='yes'>_Copy</attribute>"
" <attribute name='action'>win.copy</attribute>"
" </item>"
" <item>"
" <attribute name='label' translatable='yes'>_Paste</attribute>"
" <attribute name='action'>win.paste</attribute>"
" </item>"
" </submenu>"
" </menu>"
"</interface>",
-1);
GMenuModel *menubar = G_MENU_MODEL (gtk_builder_get_object (builder, "menubar"));
gtk_application_set_menubar (GTK_APPLICATION (app), menubar);
g_object_unref (builder);
// ...
GtkWidget *window = gtk_application_window_new (app);Properties
show-menubar
If this property is true, the window will display a menubar unless it is shown by the desktop shell.
See GtkApplicationExt::set_menubar().
If false, the window will not display a menubar, regardless of whether the desktop shell is showing it or not.
Readable | Writable | Construct
Window
application
The Application associated with the window.
The application will be kept alive for at least as long as it has any windows associated with it (see g_application_hold() for a way to keep it alive without windows).
Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it by setting the this property to NULL.
Readable | Writable
child
The child widget.
Readable | Writable
decorated
Whether the window should have a frame (also known as decorations).
Readable | Writable
default-height
The default height of the window.
Readable | Writable
default-widget
The default widget.
Readable | Writable
default-width
The default width of the window.
Readable | Writable
deletable
Whether the window frame should have a close button.
Readable | Writable
destroy-with-parent
If this window should be destroyed when the parent is destroyed.
Readable | Writable
display
The display that will display this window.
Readable | Writable
focus-visible
Whether ‘focus rectangles’ are currently visible in this window.
This property is maintained by GTK based on user input and should not be set by applications.
Readable | Writable
focus-widget
The focus widget.
Readable | Writable
fullscreened
Whether the window is fullscreen.
Setting this property is the equivalent of calling
GtkWindowExt::fullscreen() or GtkWindowExt::unfullscreen();
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writable
gravity
The gravity to use when resizing the window programmatically.
Gravity describes which point of the window we want to keep
fixed (meaning that the window will grow in the opposite direction).
For example, a gravity of GTK_WINDOW_GRAVITY_TOP_RIGHT means that we
want the to fix top right corner of the window.
Readable | Writable
handle-menubar-accel
Whether the window frame should handle F10 for activating menubars.
Readable | Writable
hide-on-close
If this window should be hidden instead of destroyed when the user clicks the close button.
Readable | Writable
icon-name
Specifies the name of the themed icon to use as the window icon.
See IconTheme for more details.
Readable | Writable
is-active
Whether the toplevel is the currently active window.
Readable
maximized
Whether the window is maximized.
Setting this property is the equivalent of calling
GtkWindowExt::maximize() or GtkWindowExt::unmaximize();
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writable
mnemonics-visible
Whether mnemonics are currently visible in this window.
This property is maintained by GTK based on user input, and should not be set by applications.
Readable | Writable
modal
If true, the window is modal.
Readable | Writable
resizable
If true, users can resize the window.
Readable | Writable
startup-id
A write-only property for setting window’s startup notification identifier.
Writable
suspended
Whether the window is suspended.
See GtkWindowExt::is_suspended() for details about what suspended means.
Readable
title
The title of the window.
Readable | Writable
titlebar
The titlebar widget.
Readable | Writable
transient-for
The transient parent of the window.
Readable | Writable | Construct
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
Signals
save-state
The handler for this signal should persist any application-specific state of @window into @dict.
Note that window management state such as maximized, fullscreen, or window size should not be saved as part of this. They are handled by GTK.
See restore-window.
Window
activate-default
Emitted when the user activates the default widget.
This is a keybinding signal.
The keybindings for this signal are all forms of the Enter key.
Action
activate-focus
Emitted when the user activates the currently focused widget of @window.
This is a keybinding signal.
The default binding for this signal is ␣.
Action
close-request
Emitted when the user clicks on the close button of the window.
enable-debugging
Emitted when the user enables or disables interactive debugging.
When @toggle is true, interactive debugging is toggled on or off, when it is false, the debugger will be pointed at the widget under the pointer.
This is a keybinding signal.
The default bindings for this signal are Ctrl+Shift+I and Ctrl+Shift+D.
Action
force-close
Emitted when the compositor has decided to eliminate a window.
@window has to be in a hidden state after this signal was handled.
keys-changed
Emitted when the set of accelerators or mnemonics that are associated with the window changes.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See WidgetExt::keynav_failed() for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a gdk::Surface.
This means that WidgetExt::realize() has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the gdk::Surface associated with @widget is destroyed.
This means that WidgetExt::unrealize() has been called
or the widget has been unmapped (that is, it is going to be hidden).
ActionGroup
action-added
Signals that a new action was just added to the group.
This signal is emitted after the action has been added and is now visible.
Detailed
action-enabled-changed
Signals that the enabled status of the named action has changed.
Detailed
action-removed
Signals that an action is just about to be removed from the group.
This signal is emitted before the action is removed, so the action is still visible and can be queried from the signal handler.
Detailed
action-state-changed
Signals that the state of the named action has changed.
Detailed
Implements
ApplicationWindowExt, GtkWindowExt, WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, NativeExt, RootExt, ShortcutManagerExt, [trait@gio::prelude::ActionGroupExt], [trait@gio::prelude::ActionMapExt], WidgetExtManual, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ApplicationWindow
impl ApplicationWindow
pub const NONE: Option<&'static ApplicationWindow> = None
Sourcepub fn new(application: &impl IsA<Application>) -> ApplicationWindow
pub fn new(application: &impl IsA<Application>) -> ApplicationWindow
Creates a new ApplicationWindow.
application
an application
Returns
a newly created ApplicationWindow
Sourcepub fn builder() -> ApplicationWindowBuilder
pub fn builder() -> ApplicationWindowBuilder
Creates a new builder-pattern struct instance to construct ApplicationWindow objects.
This method returns an instance of ApplicationWindowBuilder which can be used to create ApplicationWindow objects.