pub struct BookmarkList { /* private fields */ }Expand description
A list model that wraps GBookmarkFile.
It presents a GListModel and fills it asynchronously with the
GFileInfos returned from that function.
The GFileInfos in the list have some attributes in the recent namespace
added: recent::private (boolean) and recent:applications (stringv). They
also have the GFile referred by the URI in standard::file attribute.
Properties
attributes
The attributes to query.
Readable | Writable
filename
The bookmark file to load.
Readable | Writable | Construct Only
io-priority
Priority used when loading.
Readable | Writable
item-type
The type of items. See [ListModelExtManual::item_type()][crate::gio::prelude::ListModelExtManual::item_type()].
Readable
loading
true if files are being loaded.
Readable
n-items
The number of items. See [ListModelExtManual::n_items()][crate::gio::prelude::ListModelExtManual::n_items()].
Readable
Implements
[trait@glib::ObjectExt], [trait@gio::prelude::ListModelExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl BookmarkList
impl BookmarkList
Sourcepub fn new(
filename: Option<impl AsRef<Path>>,
attributes: Option<&str>,
) -> BookmarkList
pub fn new( filename: Option<impl AsRef<Path>>, attributes: Option<&str>, ) -> BookmarkList
Creates a new BookmarkList with the given @attributes.
filename
The bookmark file to load
attributes
The attributes to query
Returns
a new BookmarkList
Sourcepub fn attributes(&self) -> Option<GString>
pub fn attributes(&self) -> Option<GString>
Sourcepub fn filename(&self) -> PathBuf
pub fn filename(&self) -> PathBuf
Returns the filename of the bookmark file that this list is loading.
Returns
the filename of the .xbel file
Sourcepub fn is_loading(&self) -> bool
pub fn is_loading(&self) -> bool
Sourcepub fn set_attributes(&self, attributes: Option<&str>)
pub fn set_attributes(&self, attributes: Option<&str>)
pub fn connect_attributes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_io_priority_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl BookmarkList
impl BookmarkList
Sourcepub fn io_priority(&self) -> Priority
pub fn io_priority(&self) -> Priority
Sourcepub fn set_io_priority(&self, io_priority: Priority)
pub fn set_io_priority(&self, io_priority: Priority)
Sets the IO priority to use while loading files.
The default IO priority is G_PRIORITY_DEFAULT.
io_priority
IO priority to use
Sourcepub fn builder() -> BookmarkListBuilder
pub fn builder() -> BookmarkListBuilder
Creates a new builder-pattern struct instance to construct
BookmarkList objects.
This method returns an instance of
BookmarkListBuilder which can
be used to create BookmarkList objects.