pub struct BoxLayout { /* private fields */ }Expand description
Arranges children in a single row or column.
Whether it is a row or column depends on the value of its
orientation property. Within the other dimension
all children all allocated the same size. The BoxLayout will respect
the halign and valign
properties of each child widget.
If you want all children to be assigned the same size, you can use
the homogeneous property.
If you want to specify the amount of space placed between each child,
you can use the spacing property.
Properties
baseline-child
The child that determines the baseline of the box in vertical layout.
If the child does baseline positioning, then its baseline is lined up with the baseline of the box. If it doesn’t, then the bottom edge of the child is used.
Readable | Writable
baseline-position
The position of the allocated baseline within the extra space allocated to each child.
This property is only relevant for horizontal layouts containing at least one child with a baseline alignment.
Readable | Writable
homogeneous
Whether the box layout should distribute the available space equally among the children.
Readable | Writable
spacing
The space to put between the children.
Readable | Writable
Implements
LayoutManagerExt, [trait@glib::ObjectExt], OrientableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl BoxLayout
impl BoxLayout
Sourcepub fn new(orientation: Orientation) -> BoxLayout
pub fn new(orientation: Orientation) -> BoxLayout
Sourcepub fn builder() -> BoxLayoutBuilder
pub fn builder() -> BoxLayoutBuilder
Creates a new builder-pattern struct instance to construct BoxLayout objects.
This method returns an instance of BoxLayoutBuilder which can be used to create BoxLayout objects.
Sourcepub fn baseline_child(&self) -> i32
pub fn baseline_child(&self) -> i32
Gets the value set by gtk_box_layout_set_baseline_child().
Returns
the index of the child that determines the baseline in vertical layout, or -1
Sourcepub fn baseline_position(&self) -> BaselinePosition
pub fn baseline_position(&self) -> BaselinePosition
Sourcepub fn is_homogeneous(&self) -> bool
pub fn is_homogeneous(&self) -> bool
Sourcepub fn set_baseline_child(&self, child: i32)
pub fn set_baseline_child(&self, child: i32)
Sets the index of the child that determines the baseline in vertical layout.
child
the child position, or -1
Sourcepub fn set_baseline_position(&self, position: BaselinePosition)
pub fn set_baseline_position(&self, position: BaselinePosition)
Sets the baseline position of a box layout.
The baseline position affects only horizontal boxes with at least one baseline aligned child. If there is more vertical space available than requested, and the baseline is not allocated by the parent then the given @position is used to allocate the baseline within the extra space available.
position
Sourcepub fn set_homogeneous(&self, homogeneous: bool)
pub fn set_homogeneous(&self, homogeneous: bool)
Sourcepub fn set_spacing(&self, spacing: u32)
pub fn set_spacing(&self, spacing: u32)
pub fn connect_baseline_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_baseline_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_homogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId