pub struct BuilderScope { /* private fields */ }Expand description
Provides language binding support to Builder.
The goal of BuilderScope is to look up programming-language-specific
values for strings that are given in a Builder UI file.
The primary intended audience is bindings that want to provide deeper
integration of Builder into the language.
A BuilderScope instance may be used with multiple Builder objects,
even at once.
By default, GTK will use its own implementation of BuilderScope
for the C language which can be created via Gtk::BuilderCScope::new().
If you implement BuilderScope for a language binding, you
may want to (partially) derive from or fall back to a Gtk::BuilderCScope,
as that class implements support for automatic lookups from C symbols.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl BuilderScope
impl BuilderScope
pub const NONE: Option<&'static BuilderScope> = None