pub struct CellArea { /* private fields */ }Since 4.10
List views use widgets for displaying their contents
with adjacent rows which were requested and rendered with the same
CellAreaContext.
Use [CellAreaClassExt::install_cell_property()][crate::subclass::prelude::CellAreaClassExt::install_cell_property()] to install cell
properties for a cell area class and CellAreaClassExt::find_cell_property()
or CellAreaClassExt::list_cell_properties() to get information about
existing cell properties.
To set the value of a cell property, use [CellAreaExtManual::cell_set_property()][crate::prelude::CellAreaExtManual::cell_set_property()],
Gtk::CellArea::cell_set() or Gtk::CellArea::cell_set_valist(). To obtain
the value of a cell property, use [CellAreaExtManual::cell_get_property()][crate::prelude::CellAreaExtManual::cell_get_property()]
Gtk::CellArea::cell_get() or Gtk::CellArea::cell_get_valist().
This is an Abstract Base Class, you cannot instantiate it.
Properties
edit-widget
The widget currently editing the edited cell
This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().
Readable
edited-cell
The cell in the area that is currently edited
This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().
Readable
focus-cell
The cell in the area that currently has focus
Readable | Writable
Signals
add-editable
Indicates that editing has started on @renderer and that @editable should be added to the owning cell-layouting widget at @cell_area.
apply-attributes
This signal is emitted whenever applying attributes to @area from @model
focus-changed
Indicates that focus changed on this @area. This signal is emitted either as a result of focus handling or event handling.
It’s possible that the signal is emitted even if the currently focused renderer did not change, this is because focus may change to the same renderer in the same cell area for a different row of data.
remove-editable
Indicates that editing finished on @renderer and that @editable should be removed from the owning cell-layouting widget.
Implements
CellAreaExt, [trait@glib::ObjectExt], BuildableExt, CellLayoutExt, CellAreaExtManual, CellLayoutExtManual
GLib type: GObject with reference counted clone semantics.
Implementations