CellAreaBox

Struct CellAreaBox 

pub struct CellAreaBox { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

List views use widgets for displaying their contents A cell area that renders GtkCellRenderers into a row or a column

The CellAreaBox renders cell renderers into a row or a column depending on its Orientation.

GtkCellAreaBox uses a notion of packing. Packing refers to adding cell renderers with reference to a particular position in a CellAreaBox. There are two reference positions: the start and the end of the box. When the CellAreaBox is oriented in the Orientation::Vertical orientation, the start is defined as the top of the box and the end is defined as the bottom. In the Orientation::Horizontal orientation start is defined as the left side and the end is defined as the right side.

Alignments of CellRenderers rendered in adjacent rows can be configured by configuring the CellAreaBox align child cell property with gtk_cell_area_cell_set_property() or by specifying the โ€œalignโ€ argument to gtk_cell_area_box_pack_start() and gtk_cell_area_box_pack_end().

Properties

spacing

The amount of space to reserve between cells.

Readable | Writable

CellArea

edit-widget

The widget currently editing the edited cell

This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().

Readable

edited-cell

The cell in the area that is currently edited

This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().

Readable

focus-cell

The cell in the area that currently has focus

Readable | Writable

Orientable

orientation

The orientation of the orientable.

Readable | Writable

Implements

CellAreaExt, [trait@glib::ObjectExt], BuildableExt, CellLayoutExt, OrientableExt, CellAreaExtManual, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl CellAreaBox

pub fn new() -> CellAreaBox

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new CellAreaBox.

Deprecated since 4.10
Returns

a newly created CellAreaBox

pub fn builder() -> CellAreaBoxBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct CellAreaBox objects.

This method returns an instance of CellAreaBoxBuilder which can be used to create CellAreaBox objects.

pub fn spacing(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the spacing added between cell renderers.

Deprecated since 4.10
Returns

the space added between cell renderers in @self.

pub fn pack_end( &self, renderer: &impl IsA<CellRenderer>, expand: bool, align: bool, fixed: bool, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Adds @renderer to @self, packed with reference to the end of @self.

The @renderer is packed after (away from end of) any other CellRenderer packed with reference to the end of @self.

Deprecated since 4.10
renderer

the CellRenderer to add

expand

whether @renderer should receive extra space when the area receives more than its natural size

align

whether @renderer should be aligned in adjacent rows

fixed

whether @renderer should have the same size in all rows

pub fn pack_start( &self, renderer: &impl IsA<CellRenderer>, expand: bool, align: bool, fixed: bool, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Adds @renderer to @self, packed with reference to the start of @self.

The @renderer is packed after any other CellRenderer packed with reference to the start of @self.

Deprecated since 4.10
renderer

the CellRenderer to add

expand

whether @renderer should receive extra space when the area receives more than its natural size

align

whether @renderer should be aligned in adjacent rows

fixed

whether @renderer should have the same size in all rows

pub fn set_spacing(&self, spacing: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the spacing to add between cell renderers in @self.

Deprecated since 4.10
spacing

the space to add between CellRenderers

pub fn connect_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10