pub struct CellRenderer { /* private fields */ }Since 4.10
List views use widgets for displaying their contents An object for rendering a single cell
The CellRenderer is a base class of a set of objects used for
rendering a cell to a [cairo::Context][crate::cairo::Context]. These objects are used primarily by
the TreeView widget, though they arenโt tied to them in any
specific way. It is worth noting that CellRenderer is not a
Widget and cannot be treated as such.
The primary use of a CellRenderer is for drawing a certain graphical
elements on a [cairo::Context][crate::cairo::Context]. Typically, one cell renderer is used to
draw many cells on the screen. To this extent, it isnโt expected that a
CellRenderer keep any permanent state around. Instead, any state is set
just prior to use using GObjects property system. Then, the
cell is measured using gtk_cell_renderer_get_preferred_size(). Finally, the cell
is rendered in the correct location using gtk_cell_renderer_snapshot().
There are a number of rules that must be followed when writing a new
CellRenderer. First and foremost, itโs important that a certain set
of properties will always yield a cell renderer of the same size,
barring a style change. The CellRenderer also has a number of
generic properties that are expected to be honored by all children.
Beyond merely rendering a cell, cell renderers can optionally
provide active user interface elements. A cell renderer can be
โactivatableโ like CellRendererToggle,
which toggles when it gets activated by a mouse click, or it can be
โeditableโ like CellRendererText, which
allows the user to edit the text using a widget implementing the
CellEditable interface, e.g. Entry.
To make a cell renderer activatable or editable, you have to
implement the CellRendererClass.activate or
CellRendererClass.start_editing virtual functions, respectively.
Many properties of CellRenderer and its subclasses have a
corresponding โsetโ property, e.g. โcell-background-setโ corresponds
to โcell-backgroundโ. These โsetโ properties reflect whether a property
has been set or not. You should not set them independently.
This is an Abstract Base Class, you cannot instantiate it.
Properties
cell-background
Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Signals
editing-canceled
This signal gets emitted when the user cancels the process of editing a cell. For example, an editable cell renderer could be written to cancel editing when the user presses Escape.
See also: gtk_cell_renderer_stop_editing().
editing-started
This signal gets emitted when a cell starts to be edited.
The intended use of this signal is to do special setup
on @editable, e.g. adding a EntryCompletion or setting
up additional columns in a ComboBox.
See gtk_cell_editable_start_editing() for information on the lifecycle of the @editable and a way to do setup that doesnโt depend on the @renderer.
Note that GTK doesnโt guarantee that cell renderers will continue to use the same kind of widget for editing in future releases, therefore you should check the type of @editable before doing any specific setup, as in the following example:
โ ๏ธ The following code is in c โ ๏ธ
static void
text_editing_started (GtkCellRenderer *cell,
GtkCellEditable *editable,
const char *path,
gpointer data)
{
if (GTK_IS_ENTRY (editable))
{
GtkEntry *entry = GTK_ENTRY (editable);
// ... create a GtkEntryCompletion
gtk_entry_set_completion (entry, completion);
}
}Implements
CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRenderer
impl CellRenderer
pub const NONE: Option<&'static CellRenderer> = None
Since 4.10