pub struct CellRendererAccel { /* private fields */ }Since 4.10
Applications editing keyboard accelerators should provide their own implementation according to platform design guidelines Renders a keyboard accelerator in a cell
CellRendererAccel displays a keyboard accelerator (i.e. a key
combination like Control + a). If the cell renderer is editable,
the accelerator can be changed by simply typing the new combination.
Properties
accel-key
The keyval of the accelerator.
Readable | Writable
accel-mode
Determines if the edited accelerators are GTK accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK are allowed, and the accelerators are rendered in the same way as they are in menus.
Readable | Writable
accel-mods
The modifier mask of the accelerator.
Readable | Writable
keycode
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Readable | Writable
CellRendererText
align-set
Readable | Writable
alignment
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The โxalignโ property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
Readable | Writable
attributes
Readable | Writable
background
Writable
background-rgba
Background color as a gdk::RGBA
Readable | Writable
background-set
Readable | Writable
editable
Readable | Writable
editable-set
Readable | Writable
ellipsize
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
[pango::EllipsizeMode::None][crate::pango::EllipsizeMode::None] turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
Readable | Writable
ellipsize-set
Readable | Writable
family
Readable | Writable
family-set
Readable | Writable
font
Readable | Writable
font-desc
Readable | Writable
foreground
Writable
foreground-rgba
Foreground color as a gdk::RGBA
Readable | Writable
foreground-set
Readable | Writable
language
Readable | Writable
language-set
Readable | Writable
markup
Writable
max-width-chars
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cellโs siblings
have received their natural width.
Readable | Writable
placeholder-text
The text that will be displayed in the CellRenderer if
GtkCellRendererText:editable is true and the cell is empty.
Readable | Writable
rise
Readable | Writable
rise-set
Readable | Writable
scale
Readable | Writable
scale-set
Readable | Writable
single-paragraph-mode
Readable | Writable
size
Readable | Writable
size-points
Readable | Writable
size-set
Readable | Writable
stretch
Readable | Writable
stretch-set
Readable | Writable
strikethrough
Readable | Writable
strikethrough-set
Readable | Writable
style
Readable | Writable
style-set
Readable | Writable
text
Readable | Writable
underline
Readable | Writable
underline-set
Readable | Writable
variant
Readable | Writable
variant-set
Readable | Writable
weight
Readable | Writable
weight-set
Readable | Writable
width-chars
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Readable | Writable
wrap-mode
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Readable | Writable
wrap-width
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Signals
accel-cleared
Gets emitted when the user has removed the accelerator.
accel-edited
Gets emitted when the user has selected a new accelerator.
CellRendererText
edited
This signal is emitted after @renderer has been edited.
It is the responsibility of the application to update the model and store @new_text at the position indicated by @path.
CellRenderer
editing-canceled
This signal gets emitted when the user cancels the process of editing a cell. For example, an editable cell renderer could be written to cancel editing when the user presses Escape.
See also: gtk_cell_renderer_stop_editing().
editing-started
This signal gets emitted when a cell starts to be edited.
The intended use of this signal is to do special setup
on @editable, e.g. adding a EntryCompletion or setting
up additional columns in a ComboBox.
See gtk_cell_editable_start_editing() for information on the lifecycle of the @editable and a way to do setup that doesnโt depend on the @renderer.
Note that GTK doesnโt guarantee that cell renderers will continue to use the same kind of widget for editing in future releases, therefore you should check the type of @editable before doing any specific setup, as in the following example:
โ ๏ธ The following code is in c โ ๏ธ
static void
text_editing_started (GtkCellRenderer *cell,
GtkCellEditable *editable,
const char *path,
gpointer data)
{
if (GTK_IS_ENTRY (editable))
{
GtkEntry *entry = GTK_ENTRY (editable);
// ... create a GtkEntryCompletion
gtk_entry_set_completion (entry, completion);
}
}Implements
CellRendererTextExt, CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererAccel
impl CellRendererAccel
Sourcepub fn new() -> CellRendererAccel
๐Deprecated: Since 4.10
pub fn new() -> CellRendererAccel
Since 4.10
Sourcepub fn builder() -> CellRendererAccelBuilder
๐Deprecated: Since 4.10
pub fn builder() -> CellRendererAccelBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct CellRendererAccel objects.
This method returns an instance of CellRendererAccelBuilder which can be used to create CellRendererAccel objects.
Sourcepub fn set_accel_key(&self, accel_key: u32)
๐Deprecated: Since 4.10
pub fn set_accel_key(&self, accel_key: u32)
Since 4.10
The keyval of the accelerator.
Sourcepub fn accel_mode(&self) -> CellRendererAccelMode
๐Deprecated: Since 4.10
pub fn accel_mode(&self) -> CellRendererAccelMode
Since 4.10
Determines if the edited accelerators are GTK accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK are allowed, and the accelerators are rendered in the same way as they are in menus.
Sourcepub fn set_accel_mode(&self, accel_mode: CellRendererAccelMode)
๐Deprecated: Since 4.10
pub fn set_accel_mode(&self, accel_mode: CellRendererAccelMode)
Since 4.10
Determines if the edited accelerators are GTK accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK are allowed, and the accelerators are rendered in the same way as they are in menus.
Sourcepub fn accel_mods(&self) -> ModifierType
๐Deprecated: Since 4.10
pub fn accel_mods(&self) -> ModifierType
Since 4.10
The modifier mask of the accelerator.
Sourcepub fn set_accel_mods(&self, accel_mods: ModifierType)
๐Deprecated: Since 4.10
pub fn set_accel_mods(&self, accel_mods: ModifierType)
Since 4.10
The modifier mask of the accelerator.
Sourcepub fn keycode(&self) -> u32
๐Deprecated: Since 4.10
pub fn keycode(&self) -> u32
Since 4.10
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Sourcepub fn set_keycode(&self, keycode: u32)
๐Deprecated: Since 4.10
pub fn set_keycode(&self, keycode: u32)
Since 4.10
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Sourcepub fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Gets emitted when the user has removed the accelerator.
path_string
the path identifying the row of the edited cell
Sourcepub fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_accel_key_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_accel_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_accel_mods_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_keycode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10