pub struct CellRendererPixbuf { /* private fields */ }Since 4.10
List views use widgets to display their contents. You
should use Image for icons, and Picture for images
Renders a pixbuf in a cell
A CellRendererPixbuf can be used to render an image in a cell. It allows
to render either a given [gdk_pixbuf::Pixbuf][crate::gdk_pixbuf::Pixbuf] (set via the
GtkCellRendererPixbuf:pixbuf property) or a named icon (set via the
GtkCellRendererPixbuf:icon-name property).
To support the tree view, CellRendererPixbuf also supports rendering two
alternative pixbufs, when the GtkCellRenderer:is-expander property is true.
If the GtkCellRenderer:is-expanded property is true and the
GtkCellRendererPixbuf:pixbuf-expander-open property is set to a pixbuf, it
renders that pixbuf, if the GtkCellRenderer:is-expanded property is false
and the GtkCellRendererPixbuf:pixbuf-expander-closed property is set to a
pixbuf, it renders that one.
Properties
gicon
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Readable | Writable
icon-name
The name of the themed icon to display. This property only has an effect if not overridden by the โpixbufโ property.
Readable | Writable
icon-size
The IconSize value that specifies the size of the rendered icon.
Readable | Writable
pixbuf
Writable
pixbuf-expander-closed
Readable | Writable
pixbuf-expander-open
Readable | Writable
texture
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Implements
CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererPixbuf
impl CellRendererPixbuf
Sourcepub fn new() -> CellRendererPixbuf
๐Deprecated: Since 4.10
pub fn new() -> CellRendererPixbuf
Since 4.10
Creates a new CellRendererPixbuf. Adjust rendering
parameters using object properties. Object properties can be set
globally (with g_object_set()). Also, with TreeViewColumn, you
can bind a property to a value in a TreeModel. For example, you
can bind the โpixbufโ property on the cell renderer to a pixbuf value
in the model, thus rendering a different image in each row of the
TreeView.
Deprecated since 4.10
Returns
the new cell renderer
Sourcepub fn builder() -> CellRendererPixbufBuilder
๐Deprecated: Since 4.10
pub fn builder() -> CellRendererPixbufBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct CellRendererPixbuf objects.
This method returns an instance of CellRendererPixbufBuilder which can be used to create CellRendererPixbuf objects.
Sourcepub fn gicon(&self) -> Option<Icon>
๐Deprecated: Since 4.10
pub fn gicon(&self) -> Option<Icon>
Since 4.10
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Sourcepub fn set_gicon<P: IsA<Icon>>(&self, gicon: Option<&P>)
๐Deprecated: Since 4.10
pub fn set_gicon<P: IsA<Icon>>(&self, gicon: Option<&P>)
Since 4.10
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Sourcepub fn icon_name(&self) -> Option<GString>
๐Deprecated: Since 4.10
pub fn icon_name(&self) -> Option<GString>
Since 4.10
The name of the themed icon to display. This property only has an effect if not overridden by the โpixbufโ property.
Sourcepub fn set_icon_name(&self, icon_name: Option<&str>)
๐Deprecated: Since 4.10
pub fn set_icon_name(&self, icon_name: Option<&str>)
Since 4.10
The name of the themed icon to display. This property only has an effect if not overridden by the โpixbufโ property.
Sourcepub fn icon_size(&self) -> IconSize
๐Deprecated: Since 4.10
pub fn icon_size(&self) -> IconSize
Since 4.10
The IconSize value that specifies the size of the rendered icon.
Sourcepub fn set_icon_size(&self, icon_size: IconSize)
๐Deprecated: Since 4.10
pub fn set_icon_size(&self, icon_size: IconSize)
Since 4.10
The IconSize value that specifies the size of the rendered icon.
pub fn set_pixbuf(&self, pixbuf: Option<&Pixbuf>)
Since 4.10
pub fn pixbuf_expander_closed(&self) -> Option<Pixbuf>
Since 4.10
pub fn set_pixbuf_expander_closed( &self, pixbuf_expander_closed: Option<&Pixbuf>, )
Since 4.10
pub fn pixbuf_expander_open(&self) -> Option<Pixbuf>
Since 4.10
pub fn set_pixbuf_expander_open(&self, pixbuf_expander_open: Option<&Pixbuf>)
Since 4.10
pub fn texture(&self) -> Option<Texture>
Since 4.10
pub fn set_texture<P: IsA<Texture>>(&self, texture: Option<&P>)
Since 4.10
pub fn connect_gicon_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_icon_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_pixbuf_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_pixbuf_expander_closed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_pixbuf_expander_open_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_texture_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10