pub struct CellRendererSpinner { /* private fields */ }Since 4.10
List views use widgets to display their contents.
You should use Spinner instead
Renders a spinning animation in a cell
CellRendererSpinner renders a spinning animation in a cell, very
similar to Spinner. It can often be used as an alternative
to a CellRendererProgress for displaying indefinite activity,
instead of actual progress.
To start the animation in a cell, set the GtkCellRendererSpinner:active
property to true and increment the GtkCellRendererSpinner:pulse property
at regular intervals. The usual way to set the cell renderer properties
for each cell is to bind them to columns in your tree model using e.g.
gtk_tree_view_column_add_attribute().
Properties
active
Whether the spinner is active (ie. shown) in the cell
Readable | Writable
pulse
Pulse of the spinner. Increment this value to draw the next frame of the spinner animation. Usually, you would update this value in a timeout.
By default, the Spinner widget draws one full cycle of the animation,
consisting of 12 frames, in 750 milliseconds.
Readable | Writable
size
The IconSize value that specifies the size of the rendered spinner.
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Implements
CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererSpinner
impl CellRendererSpinner
Sourcepub fn new() -> CellRendererSpinner
๐Deprecated: Since 4.10
pub fn new() -> CellRendererSpinner
Since 4.10
Returns a new cell renderer which will show a spinner to indicate activity.
Deprecated since 4.10
Returns
a new CellRenderer
Sourcepub fn builder() -> CellRendererSpinnerBuilder
๐Deprecated: Since 4.10
pub fn builder() -> CellRendererSpinnerBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct CellRendererSpinner objects.
This method returns an instance of CellRendererSpinnerBuilder which can be used to create CellRendererSpinner objects.
Sourcepub fn is_active(&self) -> bool
๐Deprecated: Since 4.10
pub fn is_active(&self) -> bool
Since 4.10
Whether the spinner is active (ie. shown) in the cell
Sourcepub fn set_active(&self, active: bool)
๐Deprecated: Since 4.10
pub fn set_active(&self, active: bool)
Since 4.10
Whether the spinner is active (ie. shown) in the cell
Sourcepub fn pulse(&self) -> u32
๐Deprecated: Since 4.10
pub fn pulse(&self) -> u32
Since 4.10
Pulse of the spinner. Increment this value to draw the next frame of the spinner animation. Usually, you would update this value in a timeout.
By default, the Spinner widget draws one full cycle of the animation,
consisting of 12 frames, in 750 milliseconds.
Sourcepub fn set_pulse(&self, pulse: u32)
๐Deprecated: Since 4.10
pub fn set_pulse(&self, pulse: u32)
Since 4.10
Pulse of the spinner. Increment this value to draw the next frame of the spinner animation. Usually, you would update this value in a timeout.
By default, the Spinner widget draws one full cycle of the animation,
consisting of 12 frames, in 750 milliseconds.
Sourcepub fn size(&self) -> IconSize
๐Deprecated: Since 4.10
pub fn size(&self) -> IconSize
Since 4.10
The IconSize value that specifies the size of the rendered spinner.
Sourcepub fn set_size(&self, size: IconSize)
๐Deprecated: Since 4.10
pub fn set_size(&self, size: IconSize)
Since 4.10
The IconSize value that specifies the size of the rendered spinner.
pub fn connect_active_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_pulse_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10