CellRendererToggle

Struct CellRendererToggle 

pub struct CellRendererToggle { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

List views use widgets to display their contents. You should use ToggleButton instead Renders a toggle button in a cell

CellRendererToggle renders a toggle button in a cell. The button is drawn as a radio or a checkbutton, depending on the GtkCellRendererToggle:radio property. When activated, it emits the GtkCellRendererToggle::toggled signal.

Properties

activatable

Readable | Writable

active

Readable | Writable

inconsistent

Readable | Writable

radio

Readable | Writable

CellRenderer

cell-background

Writable

cell-background-rgba

Cell background as a gdk::RGBA

Readable | Writable

cell-background-set

Readable | Writable

editing

Readable

height

Readable | Writable

is-expanded

Readable | Writable

is-expander

Readable | Writable

mode

Readable | Writable

sensitive

Readable | Writable

visible

Readable | Writable

width

Readable | Writable

xalign

Readable | Writable

xpad

Readable | Writable

yalign

Readable | Writable

ypad

Readable | Writable

Signals

toggled

The ::toggled signal is emitted when the cell is toggled.

It is the responsibility of the application to update the model with the correct value to store at @path. Often this is simply the opposite of the value currently stored at @path.

CellRenderer

editing-canceled

This signal gets emitted when the user cancels the process of editing a cell. For example, an editable cell renderer could be written to cancel editing when the user presses Escape.

See also: gtk_cell_renderer_stop_editing().

editing-started

This signal gets emitted when a cell starts to be edited. The intended use of this signal is to do special setup on @editable, e.g. adding a EntryCompletion or setting up additional columns in a ComboBox.

See gtk_cell_editable_start_editing() for information on the lifecycle of the @editable and a way to do setup that doesnโ€™t depend on the @renderer.

Note that GTK doesnโ€™t guarantee that cell renderers will continue to use the same kind of widget for editing in future releases, therefore you should check the type of @editable before doing any specific setup, as in the following example:

โš ๏ธ The following code is in c โš ๏ธ

static void
text_editing_started (GtkCellRenderer *cell,
                      GtkCellEditable *editable,
                      const char      *path,
                      gpointer         data)
{
  if (GTK_IS_ENTRY (editable))
    {
      GtkEntry *entry = GTK_ENTRY (editable);

      // ... create a GtkEntryCompletion

      gtk_entry_set_completion (entry, completion);
    }
}

Implements

CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl CellRendererToggle

pub fn new() -> CellRendererToggle

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new CellRendererToggle. Adjust rendering parameters using object properties. Object properties can be set globally (with g_object_set()). Also, with TreeViewColumn, you can bind a property to a value in a TreeModel. For example, you can bind the โ€œactiveโ€ property on the cell renderer to a boolean value in the model, thus causing the check button to reflect the state of the model.

Deprecated since 4.10
Returns

the new cell renderer

pub fn builder() -> CellRendererToggleBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct CellRendererToggle objects.

This method returns an instance of CellRendererToggleBuilder which can be used to create CellRendererToggle objects.

pub fn is_activatable(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the cell renderer is activatable. See gtk_cell_renderer_toggle_set_activatable().

Deprecated since 4.10
Returns

true if the cell renderer is activatable.

pub fn is_active(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the cell renderer is active. See gtk_cell_renderer_toggle_set_active().

Deprecated since 4.10
Returns

true if the cell renderer is active.

pub fn is_radio(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether weโ€™re rendering radio toggles rather than checkboxes.

Deprecated since 4.10
Returns

true if weโ€™re rendering radio toggles rather than checkboxes

pub fn set_activatable(&self, setting: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Makes the cell renderer activatable.

Deprecated since 4.10
setting

the value to set.

pub fn set_active(&self, setting: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Activates or deactivates a cell renderer.

Deprecated since 4.10
setting

the value to set.

pub fn set_radio(&self, radio: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

If @radio is true, the cell renderer renders a radio toggle (i.e. a toggle in a group of mutually-exclusive toggles). If false, it renders a check toggle (a standalone boolean option). This can be set globally for the cell renderer, or changed just before rendering each cell in the model (for TreeView, you set up a per-row setting using TreeViewColumn to associate model columns with cell renderer properties).

Deprecated since 4.10
radio

true to make the toggle look like a radio button

pub fn is_inconsistent(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn set_inconsistent(&self, inconsistent: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_toggled<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

The ::toggled signal is emitted when the cell is toggled.

It is the responsibility of the application to update the model with the correct value to store at @path. Often this is simply the opposite of the value currently stored at @path.

path

string representation of TreePath describing the event location

pub fn connect_activatable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_active_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_inconsistent_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_radio_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10