pub struct ColorChooser { /* private fields */ }Since 4.10
Use ColorDialog and ColorDialogButton
instead of widgets implementing ColorChooser
ColorChooser is an interface that is implemented by widgets
for choosing colors.
Depending on the situation, colors may be allowed to have alpha (translucency).
In GTK, the main widgets that implement this interface are
ColorChooserWidget, ColorChooserDialog and
ColorButton.
Properties
rgba
The currently selected color, as a gdk::RGBA struct.
The property can be set to change the current selection programmatically.
Readable | Writable
use-alpha
Whether colors may have alpha (translucency).
When ::use-alpha is false, the gdk::RGBA struct obtained
via the rgba property will be
forced to have alpha == 1.
Implementations are expected to show alpha by rendering the color over a non-uniform background (like a checkerboard pattern).
Readable | Writable
Signals
color-activated
Emitted when a color is activated from the color chooser.
This usually happens when the user clicks a color swatch, or a color is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.
Implements
ColorChooserExt, ColorChooserExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ColorChooser
impl ColorChooser
pub const NONE: Option<&'static ColorChooser> = None
Since 4.10