pub struct ColorChooserDialog { /* private fields */ }Since 4.10
Use ColorDialog instead
ColorChooserDialog implements the ColorChooser interface
and does not provide much API of its own.
To create a ColorChooserDialog, use new().
To change the initially selected color, use
ColorChooserExt::set_rgba(). To get the selected color use
ColorChooserExt::rgba().
ColorChooserDialog has been deprecated in favor of ColorDialog.
CSS nodes
ColorChooserDialog has a single CSS node with the name window and style
class .colorchooser.
Properties
show-editor
Whether the color chooser dialog is showing the single-color editor.
It can be set to switch the color chooser into single-color editing mode.
Readable | Writable
Dialog
use-header-bar
header, NULL); dialog = g_object_new (GTK_TYPE_DIALOG, header, TRUE, NULL);
Readable | Writable | Construct Only
</details>
<details><summary><h4>Window</h4></summary>
#### `application`
The [`Application`][crate::Application] associated with the window.
The application will be kept alive for at least as long as it
has any windows associated with it (see g_application_hold()
for a way to keep it alive without windows).
Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it by setting the this property to `NULL`.
Readable | Writable
#### `child`
The child widget.
Readable | Writable
#### `decorated`
Whether the window should have a frame (also known as *decorations*).
Readable | Writable
#### `default-height`
The default height of the window.
Readable | Writable
#### `default-widget`
The default widget.
Readable | Writable
#### `default-width`
The default width of the window.
Readable | Writable
#### `deletable`
Whether the window frame should have a close button.
Readable | Writable
#### `destroy-with-parent`
If this window should be destroyed when the parent is destroyed.
Readable | Writable
#### `display`
The display that will display this window.
Readable | Writable
#### `focus-visible`
Whether 'focus rectangles' are currently visible in this window.
This property is maintained by GTK based on user input
and should not be set by applications.
Readable | Writable
#### `focus-widget`
The focus widget.
Readable | Writable
#### `fullscreened`
Whether the window is fullscreen.
Setting this property is the equivalent of calling
[`GtkWindowExt::fullscreen()`][crate::prelude::GtkWindowExt::fullscreen()] or [`GtkWindowExt::unfullscreen()`][crate::prelude::GtkWindowExt::unfullscreen()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writable
#### `gravity`
The gravity to use when resizing the window programmatically.
Gravity describes which point of the window we want to keep
fixed (meaning that the window will grow in the opposite direction).
For example, a gravity of `GTK_WINDOW_GRAVITY_TOP_RIGHT` means that we
want the to fix top right corner of the window.
Readable | Writable
#### `handle-menubar-accel`
for activating
menubars.
Readable | Writable
#### `hide-on-close`
If this window should be hidden instead of destroyed when the user clicks
the close button.
Readable | Writable
#### `icon-name`
Specifies the name of the themed icon to use as the window icon.
See [`IconTheme`][crate::IconTheme] for more details.
Readable | Writable
#### `is-active`
Whether the toplevel is the currently active window.
Readable
#### `maximized`
Whether the window is maximized.
Setting this property is the equivalent of calling
[`GtkWindowExt::maximize()`][crate::prelude::GtkWindowExt::maximize()] or [`GtkWindowExt::unmaximize()`][crate::prelude::GtkWindowExt::unmaximize()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writable
#### `mnemonics-visible`
Whether mnemonics are currently visible in this window.
This property is maintained by GTK based on user input,
and should not be set by applications.
Readable | Writable
#### `modal`
If true, the window is modal.
Readable | Writable
#### `resizable`
If true, users can resize the window.
Readable | Writable
#### `startup-id`
A write-only property for setting window's startup notification identifier.
Writable
#### `suspended`
Whether the window is suspended.
See [`GtkWindowExt::is_suspended()`][crate::prelude::GtkWindowExt::is_suspended()] for details about what suspended means.
Readable
#### `title`
The title of the window.
Readable | Writable
#### `titlebar`
The titlebar widget.
Readable | Writable
#### `transient-for`
The transient parent of the window.
Readable | Writable | Construct
</details>
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>ColorChooser</h4></summary>
#### `rgba`
The currently selected color, as a [`gdk::RGBA`][crate::gdk::RGBA] struct.
The property can be set to change the current selection
programmatically.
Readable | Writable
#### `use-alpha`
Whether colors may have alpha (translucency).
When ::use-alpha is [`false`], the [`gdk::RGBA`][crate::gdk::RGBA] struct obtained
via the [`rgba`][struct@crate::ColorChooser#rgba] property will be
forced to have alpha == 1.
Implementations are expected to show alpha by rendering the color
over a non-uniform background (like a checkerboard pattern).
Readable | Writable
</details>
# Implements
[`DialogExt`][trait@crate::prelude::DialogExt], [`GtkWindowExt`][trait@crate::prelude::GtkWindowExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`NativeExt`][trait@crate::prelude::NativeExt], [`RootExt`][trait@crate::prelude::RootExt], [`ShortcutManagerExt`][trait@crate::prelude::ShortcutManagerExt], [`ColorChooserExt`][trait@crate::prelude::ColorChooserExt], [`DialogExtManual`][trait@crate::prelude::DialogExtManual], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual], [`ColorChooserExtManual`][trait@crate::prelude::ColorChooserExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ColorChooserDialog
impl ColorChooserDialog
Sourcepub fn new(
title: Option<&str>,
parent: Option<&impl IsA<Window>>,
) -> ColorChooserDialog
👎Deprecated: Since 4.10
pub fn new( title: Option<&str>, parent: Option<&impl IsA<Window>>, ) -> ColorChooserDialog
Since 4.10
Creates a new ColorChooserDialog.
Deprecated since 4.10
Use ColorDialog instead
title
Title of the dialog
parent
Transient parent of the dialog
Returns
a new ColorChooserDialog
Sourcepub fn builder() -> ColorChooserDialogBuilder
👎Deprecated: Since 4.10
pub fn builder() -> ColorChooserDialogBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct ColorChooserDialog objects.
This method returns an instance of ColorChooserDialogBuilder which can be used to create ColorChooserDialog objects.
Sourcepub fn shows_editor(&self) -> bool
👎Deprecated: Since 4.10
pub fn shows_editor(&self) -> bool
Since 4.10
Whether the color chooser dialog is showing the single-color editor.
It can be set to switch the color chooser into single-color editing mode.
Sourcepub fn set_show_editor(&self, show_editor: bool)
👎Deprecated: Since 4.10
pub fn set_show_editor(&self, show_editor: bool)
Since 4.10
Whether the color chooser dialog is showing the single-color editor.
It can be set to switch the color chooser into single-color editing mode.
pub fn connect_show_editor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10