pub struct ColumnView { /* private fields */ }Expand description
[rubberband]
[`ColumnView`][crate::ColumnView] uses a single CSS node named columnview. It may carry the
.column-separators style class, when [`show-column-separators`][struct@crate::ColumnView#show-column-separators]
property is set. Header widgets appear below a node with name header.
The rows are contained in a [`ListView`][crate::ListView] widget, so there is a listview
node with the same structure as for a standalone [`ListView`][crate::ListView] widget.
If [`show-row-separators`][struct@crate::ColumnView#show-row-separators] is set, it will be passed
on to the list view, causing its CSS node to carry the .separators style class.
For rubberband selection, a node with name rubberband is used.
The main columnview node may also carry style classes to select
the style of [list presentation](https://docs.gtk.org/gtk4/section-list-widget.html#list-styles):
.rich-list, .navigation-sidebar or .data-table.
# Accessibility
[`ColumnView`][crate::ColumnView] uses the [enum@Gtk.AccessibleRole.tree_grid] role, header title
widgets are using the [enum@Gtk.AccessibleRole.column_header] role. The row widgets
are using the [enum@Gtk.AccessibleRole.row] role, and individual cells are using
the [enum@Gtk.AccessibleRole.grid_cell] role
## Properties
#### `columns`
The list of columns.
Readable
#### `enable-rubberband`
Allow rubberband selection.
Readable | Writable
#### `header-factory`
Factory for creating header widgets.
The factory must be for configuring [`ListHeader`][crate::ListHeader] objects.
Readable | Writable
#### `model`
Model for the items displayed.
Readable | Writable
#### `reorderable`
Whether columns are reorderable.
Readable | Writable
#### `row-factory`
The factory used for configuring rows.
The factory must be for configuring [`ColumnViewRow`][crate::ColumnViewRow] objects.
Readable | Writable
#### `show-column-separators`
Show separators between columns.
Readable | Writable
#### `show-row-separators`
Show separators between rows.
Readable | Writable
#### `single-click-activate`
Activate rows on single click and select them on hover.
Readable | Writable
#### `sorter`
Sorter with the sorting choices of the user.
Readable
#### `tab-behavior`
key
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Scrollable</h4></summary>
#### `hadjustment`
Horizontal [`Adjustment`][crate::Adjustment] of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
#### `hscroll-policy`
Determines when horizontal scrolling should start.
Readable | Writable
#### `vadjustment`
Vertical [`Adjustment`][crate::Adjustment] of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
#### `vscroll-policy`
Determines when vertical scrolling should start.
Readable | Writable
</details>
## Signals
#### `activate`
Emitted when a row has been activated by the user, usually via activating
the GtkListBase|list.activate-item action.
This allows for a convenient way to handle activation in a columnview.
See [`ListItemExt::set_activatable()`][crate::prelude::ListItemExt::set_activatable()] for details on how to use this
signal.
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`ScrollableExt`][trait@crate::prelude::ScrollableExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ColumnView
impl ColumnView
Sourcepub fn new(model: Option<impl IsA<SelectionModel>>) -> ColumnView
pub fn new(model: Option<impl IsA<SelectionModel>>) -> ColumnView
Creates a new ColumnView.
You most likely want to call append_column()
to add columns next.
model
the list model to use
Returns
a new ColumnView
Sourcepub fn builder() -> ColumnViewBuilder
pub fn builder() -> ColumnViewBuilder
Creates a new builder-pattern struct instance to construct ColumnView objects.
This method returns an instance of ColumnViewBuilder which can be used to create ColumnView objects.
Sourcepub fn append_column(&self, column: &ColumnViewColumn)
pub fn append_column(&self, column: &ColumnViewColumn)
Appends the @column to the end of the columns in @self.
column
a column that hasn’t been added to a ColumnView yet
Sourcepub fn columns(&self) -> ListModel
pub fn columns(&self) -> ListModel
Gets the list of columns in this column view.
This list is constant over the lifetime of @self and can be used to
monitor changes to the columns of @self by connecting to the
items-changed signal.
Returns
The list managing the columns
Sourcepub fn enables_rubberband(&self) -> bool
pub fn enables_rubberband(&self) -> bool
Returns whether rows can be selected by dragging with the mouse.
Returns
true if rubberband selection is enabled
Sourcepub fn header_factory(&self) -> Option<ListItemFactory>
Available on crate feature v4_12 only.
pub fn header_factory(&self) -> Option<ListItemFactory>
v4_12 only.Sourcepub fn model(&self) -> Option<SelectionModel>
pub fn model(&self) -> Option<SelectionModel>
Sourcepub fn is_reorderable(&self) -> bool
pub fn is_reorderable(&self) -> bool
Sourcepub fn row_factory(&self) -> Option<ListItemFactory>
Available on crate feature v4_12 only.
pub fn row_factory(&self) -> Option<ListItemFactory>
v4_12 only.Sourcepub fn shows_column_separators(&self) -> bool
pub fn shows_column_separators(&self) -> bool
Returns whether the list should show separators between columns.
Returns
true if the list shows column separators
Sourcepub fn shows_row_separators(&self) -> bool
pub fn shows_row_separators(&self) -> bool
Returns whether the list should show separators between rows.
Returns
true if the list shows separators
Sourcepub fn is_single_click_activate(&self) -> bool
pub fn is_single_click_activate(&self) -> bool
Returns whether rows will be activated on single click and selected on hover.
Returns
true if rows are activated on single click
Sourcepub fn sorter(&self) -> Option<Sorter>
pub fn sorter(&self) -> Option<Sorter>
Returns a special sorter that reflects the users sorting choices in the column view.
To allow users to customizable sorting by clicking on column headers, this sorter needs to be set on the sort model underneath the model that is displayed by the view.
See ColumnViewColumn::set_sorter() for setting up
per-column sorting.
Here is an example: ⚠️ The following code is in c ⚠️
gtk_column_view_column_set_sorter (column, sorter);
gtk_column_view_append_column (view, column);
sorter = g_object_ref (gtk_column_view_get_sorter (view)));
model = gtk_sort_list_model_new (store, sorter);
selection = gtk_no_selection_new (model);
gtk_column_view_set_model (view, selection);Returns
the Sorter of @self
Sourcepub fn tab_behavior(&self) -> ListTabBehavior
Available on crate feature v4_12 only.
pub fn tab_behavior(&self) -> ListTabBehavior
v4_12 only.Sourcepub fn insert_column(&self, position: u32, column: &ColumnViewColumn)
pub fn insert_column(&self, position: u32, column: &ColumnViewColumn)
Sourcepub fn remove_column(&self, column: &ColumnViewColumn)
pub fn remove_column(&self, column: &ColumnViewColumn)
Sourcepub fn scroll_to(
&self,
pos: u32,
column: Option<&ColumnViewColumn>,
flags: ListScrollFlags,
scroll: Option<ScrollInfo>,
)
Available on crate feature v4_12 only.
pub fn scroll_to( &self, pos: u32, column: Option<&ColumnViewColumn>, flags: ListScrollFlags, scroll: Option<ScrollInfo>, )
v4_12 only.Scroll to the row at the given position - or cell if a column is given - and performs the actions specified in @flags.
This function works no matter if the columnview is shown or focused. If it isn’t, then the changes will take effect once that happens.
pos
position of the item. Must be less than the number of items in the view.
column
The column to scroll to
or NULL to not scroll columns
flags
actions to perform
scroll
details of how to perform
the scroll operation or None to scroll into view
Sourcepub fn set_enable_rubberband(&self, enable_rubberband: bool)
pub fn set_enable_rubberband(&self, enable_rubberband: bool)
Sets whether selections can be changed by dragging with the mouse.
enable_rubberband
whether to enable rubberband selection
Sourcepub fn set_header_factory(&self, factory: Option<&impl IsA<ListItemFactory>>)
Available on crate feature v4_12 only.
pub fn set_header_factory(&self, factory: Option<&impl IsA<ListItemFactory>>)
v4_12 only.Sets the factory to use for populating the
ListHeader objects used in section headers.
If this factory is set to NULL, the list will not show
section headers.
factory
the factory to use
Sourcepub fn set_model(&self, model: Option<&impl IsA<SelectionModel>>)
pub fn set_model(&self, model: Option<&impl IsA<SelectionModel>>)
Sourcepub fn set_reorderable(&self, reorderable: bool)
pub fn set_reorderable(&self, reorderable: bool)
Sets whether columns should be reorderable by dragging.
reorderable
whether columns should be reorderable
Sourcepub fn set_row_factory(&self, factory: Option<&impl IsA<ListItemFactory>>)
Available on crate feature v4_12 only.
pub fn set_row_factory(&self, factory: Option<&impl IsA<ListItemFactory>>)
v4_12 only.Sets the factory used for configuring rows.
The factory must be for configuring ColumnViewRow objects.
If this factory is not set - which is the default - then the defaults will be used.
This factory is not used to set the widgets displayed in the individual
cells. For that see GtkColumnViewColumn::set_factory() and
ColumnViewCell.
factory
The row factory
Sourcepub fn set_show_column_separators(&self, show_column_separators: bool)
pub fn set_show_column_separators(&self, show_column_separators: bool)
Sets whether the list should show separators between columns.
show_column_separators
whether to show column separators
Sourcepub fn set_show_row_separators(&self, show_row_separators: bool)
pub fn set_show_row_separators(&self, show_row_separators: bool)
Sets whether the list should show separators between rows.
show_row_separators
whether to show row separators
Sourcepub fn set_single_click_activate(&self, single_click_activate: bool)
pub fn set_single_click_activate(&self, single_click_activate: bool)
Sets whether rows should be activated on single click and selected on hover.
single_click_activate
whether to activate items on single click
Sourcepub fn set_tab_behavior(&self, tab_behavior: ListTabBehavior)
Available on crate feature v4_12 only.
pub fn set_tab_behavior(&self, tab_behavior: ListTabBehavior)
v4_12 only.Sourcepub fn sort_by_column(
&self,
column: Option<&ColumnViewColumn>,
direction: SortType,
)
pub fn sort_by_column( &self, column: Option<&ColumnViewColumn>, direction: SortType, )
Sets the sorting of the view.
This function should be used to set up the initial sorting. At runtime, users can change the sorting of a column view by clicking on the list headers.
This call only has an effect if the sorter returned by
sorter() is set on a sort model,
and ColumnViewColumn::set_sorter() has been called
on @column to associate a sorter with the column.
If @column is unset, the view will be unsorted.
column
the column to sort by
direction
the direction to sort in
Sourcepub fn connect_activate<F: Fn(&Self, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activate<F: Fn(&Self, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a row has been activated by the user, usually via activating the GtkListBase|list.activate-item action.
This allows for a convenient way to handle activation in a columnview.
See ListItemExt::set_activatable() for details on how to use this
signal.
position
position of item to activate
pub fn connect_columns_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_rubberband_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_header_factory_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_12 only.pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_reorderable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_row_factory_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_12 only.pub fn connect_show_column_separators_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_row_separators_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_single_click_activate_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_sorter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_tab_behavior_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_12 only.Trait Implementations
Sourceimpl Clone for ColumnView
impl Clone for ColumnView
Sourceimpl Debug for ColumnView
impl Debug for ColumnView
Sourceimpl Default for ColumnView
impl Default for ColumnView
impl Eq for ColumnView
Sourceimpl HasParamSpec for ColumnView
impl HasParamSpec for ColumnView
type ParamSpec = ParamSpecObject
Sourcetype SetValue = ColumnView
type SetValue = ColumnView
type BuilderFn = fn(&str) -> ParamSpecObjectBuilder<'_, ColumnView>
fn param_spec_builder() -> Self::BuilderFn
Sourceimpl Hash for ColumnView
impl Hash for ColumnView
impl IsA<Accessible> for ColumnView
impl IsA<Buildable> for ColumnView
impl IsA<ConstraintTarget> for ColumnView
impl IsA<Scrollable> for ColumnView
impl IsA<Widget> for ColumnView
Sourceimpl Ord for ColumnView
impl Ord for ColumnView
Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
Comparison for two GObjects.
Compares the memory addresses of the provided objects.
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl ParentClassIs for ColumnView
impl ParentClassIs for ColumnView
Sourceimpl<OT: ObjectType> PartialEq<OT> for ColumnView
impl<OT: ObjectType> PartialEq<OT> for ColumnView
Sourceimpl<OT: ObjectType> PartialOrd<OT> for ColumnView
impl<OT: ObjectType> PartialOrd<OT> for ColumnView
Sourcefn partial_cmp(&self, other: &OT) -> Option<Ordering>
fn partial_cmp(&self, other: &OT) -> Option<Ordering>
Partial comparison for two GObjects.
Compares the memory addresses of the provided objects.
Sourceimpl StaticType for ColumnView
impl StaticType for ColumnView
Sourcefn static_type() -> Type
fn static_type() -> Type
Self.Auto Trait Implementations
impl !Send for ColumnView
impl !Sync for ColumnView
impl Freeze for ColumnView
impl RefUnwindSafe for ColumnView
impl Unpin for ColumnView
impl UnsafeUnpin for ColumnView
impl UnwindSafe for ColumnView