pub struct ColumnViewCell { /* private fields */ }Expand description
Represents items in a cell in ColumnView.
The ColumnViewCells are managed by the ColumnView
widget (with its factory) and cannot be created by applications, but
they need to be populated by application code. This is done by calling
set_child().
ColumnViewCells exist in 2 stages:
-
The unbound stage where the listitem is not currently connected to an item in the list. In that case, the
itemproperty is set toNone. -
The bound stage where the listitem references an item from the list. The
itemproperty is notNone.
Properties
child
Widget used for display.
Readable | Writable
focusable
If the item can be focused with the keyboard.
Readable | Writable
item
Displayed item.
Readable
position
Position of the item.
Readable
selected
If the item is currently selected.
Readable
ListItem
accessible-description
The accessible description to set on the listitem.
Readable | Writable
accessible-label
The accessible label to set on the listitem.
Readable | Writable
activatable
If the item can be activated by the user.
Readable | Writable
child
Widget used for display.
Readable | Writable
focusable
If the item can be focused with the keyboard.
Readable | Writable
item
Displayed item.
Readable
position
Position of the item.
Readable
selectable
If the item can be selected by the user.
Readable | Writable
selected
If the item is currently selected.
Readable
Implements
ListItemExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ColumnViewCell
impl ColumnViewCell
Sourcepub fn builder() -> ColumnViewCellBuilder
pub fn builder() -> ColumnViewCellBuilder
Creates a new builder-pattern struct instance to construct ColumnViewCell objects.
This method returns an instance of ColumnViewCellBuilder which can be used to create ColumnViewCell objects.
Sourcepub fn position(&self) -> u32
pub fn position(&self) -> u32
Gets the position in the model that @self currently displays.
If @self is unbound, GTK_INVALID_LIST_POSITION is returned.
Returns
The position of this item
Sourcepub fn is_selected(&self) -> bool
pub fn is_selected(&self) -> bool