pub struct ComboBox { /* private fields */ }Since 4.10
Use DropDown instead
window.popup
A [`ComboBox`][crate::ComboBox] with an entry has a single CSS node with name combobox.
It contains a box with the .linked class. That box contains an entry and
a button, both with the .combo class added. The button also contains another
node with name arrow.
## Accessibility
[`ComboBox`][crate::ComboBox] uses the [enum@Gtk.AccessibleRole.combo_box] role.
## Properties
#### `active`
The item which is currently active.
If the model is a non-flat treemodel, and the active item is not an
immediate child of the root of the tree, this property has the value
`gtk_tree_path_get_indices (path)[0]`, where `path` is the
[`TreePath`][crate::TreePath] of the active item.
Readable | Writable
#### `active-id`
The value of the ID column of the active row.
Readable | Writable
#### `button-sensitivity`
Whether the dropdown button is sensitive when
the model is empty.
Readable | Writable
#### `child`
The child widget.
Readable | Writable
#### `entry-text-column`
The model column to associate with strings from the entry.
This is property only relevant if the combo was created with
[`has-entry`][struct@crate::ComboBox#has-entry] is [`true`].
Readable | Writable
#### `has-entry`
Whether the combo box has an entry.
Readable | Writable | Construct Only
#### `has-frame`
The `has-frame` property controls whether a frame is drawn around the entry.
Readable | Writable
#### `id-column`
The model column that provides string IDs for the values
in the model, if != -1.
Readable | Writable
#### `model`
The model from which the combo box takes its values.
Readable | Writable
#### `popup-fixed-width`
Whether the popup's width should be a fixed width matching the
allocated width of the combo box.
Readable | Writable
#### `popup-shown`
Whether the combo boxes dropdown is popped up.
Note that this property is mainly useful, because
it allows you to connect to notify::popup-shown.
Readable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>CellEditable</h4></summary>
#### `editing-canceled`
Indicates whether editing on the cell has been canceled.
Readable | Writable
</details>
## Signals
#### `activate`
Emitted to when the combo box is activated.
The `::activate` signal on [`ComboBox`][crate::ComboBox] is an action signal and
emitting it causes the combo box to pop up its dropdown.
Action
#### `changed`
Emitted when the active item is changed.
The can be due to the user selecting a different item from the list,
or due to a call to [`ComboBoxExt::set_active_iter()`][crate::prelude::ComboBoxExt::set_active_iter()]. It will
also be emitted while typing into the entry of a combo box with an entry.
#### `format-entry-text`
value,
-1);
return g_strdup_printf ("`g`", value);
}
```text
#### `move-active`
Emitted to move the active selection.
This is an [keybinding signal](class.SignalAction.html).
Action
#### `popdown`
Emitted to popdown the combo box list.
This is an [keybinding signal](class.SignalAction.html).
The default bindings for this signal are Alt+Up and Escape.
Action
#### `popup`
Emitted to popup the combo box list.
This is an [keybinding signal](class.SignalAction.html).
The default binding for this signal is Alt+Down.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
<details><summary><h4>CellEditable</h4></summary>
#### `editing-done`
This signal is a sign for the cell renderer to update its
value from the @cell_editable.
Implementations of [`CellEditable`][crate::CellEditable] are responsible for
emitting this signal when they are done editing, e.g.
[`Entry`][crate::Entry] emits this signal when the user presses Enter. Typical things to
do in a handler for ::editing-done are to capture the edited value,
disconnect the @cell_editable from signals on the [`CellRenderer`][crate::CellRenderer], etc.
gtk_cell_editable_editing_done() is a convenience method
for emitting `GtkCellEditable::editing-done`.
#### `remove-widget`
This signal is meant to indicate that the cell is finished
editing, and the @cell_editable widget is being removed and may
subsequently be destroyed.
Implementations of [`CellEditable`][crate::CellEditable] are responsible for
emitting this signal when they are done editing. It must
be emitted after the `GtkCellEditable::editing-done` signal,
to give the cell renderer a chance to update the cell's value
before the widget is removed.
gtk_cell_editable_remove_widget() is a convenience method
for emitting `GtkCellEditable::remove-widget`.
</details>
# Implements
[`ComboBoxExt`][trait@crate::prelude::ComboBoxExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`CellEditableExt`][trait@crate::prelude::CellEditableExt], [`CellLayoutExt`][trait@crate::prelude::CellLayoutExt], [`ComboBoxExtManual`][trait@crate::prelude::ComboBoxExtManual], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual], [`CellLayoutExtManual`][trait@crate::prelude::CellLayoutExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ComboBox
impl ComboBox
pub const NONE: Option<&'static ComboBox> = None
Since 4.10
Sourcepub fn with_entry() -> ComboBox
👎Deprecated: Since 4.10
pub fn with_entry() -> ComboBox
Since 4.10
Sourcepub fn with_model(model: &impl IsA<TreeModel>) -> ComboBox
👎Deprecated: Since 4.10
pub fn with_model(model: &impl IsA<TreeModel>) -> ComboBox
Since 4.10
Sourcepub fn with_model_and_entry(model: &impl IsA<TreeModel>) -> ComboBox
👎Deprecated: Since 4.10
pub fn with_model_and_entry(model: &impl IsA<TreeModel>) -> ComboBox
Since 4.10
Sourcepub fn builder() -> ComboBoxBuilder
👎Deprecated: Since 4.10
pub fn builder() -> ComboBoxBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct ComboBox objects.
This method returns an instance of ComboBoxBuilder which can be used to create ComboBox objects.