ComboBoxText

Struct ComboBoxText 

pub struct ComboBoxText { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

Use DropDown with a StringList instead A ComboBoxText is a simple variant of ComboBox for text-only use cases.

An example GtkComboBoxText

ComboBoxText hides the model-view complexity of ComboBox.

To create a ComboBoxText, use new() or with_entry().

You can add items to a ComboBoxText with append_text(), insert_text() or prepend_text() and remove options with remove().

If the ComboBoxText contains an entry (via the has-entry property), its contents can be retrieved using active_text().

You should not call ComboBoxExt::set_model() or attempt to pack more cells into this combo box via its CellLayout interface.

GtkComboBoxText as GtkBuildable

The ComboBoxText implementation of the Buildable interface supports adding items directly using the <items> element and specifying <item> elements for each item. Each <item> element can specify the โ€œidโ€ corresponding to the appended text and also supports the regular translation attributes โ€œtranslatableโ€, โ€œcontextโ€ and โ€œcommentsโ€.

Here is a UI definition fragment specifying ComboBoxText items:

<object class="GtkComboBoxText">
  <items>
    <item translatable="yes" id="factory">Factory</item>
    <item translatable="yes" id="home">Home</item>
    <item translatable="yes" id="subway">Subway</item>
  </items>
</object>

CSS nodes

combobox
โ•ฐโ”€โ”€ box.linked
    โ”œโ”€โ”€ entry.combo
    โ”œโ”€โ”€ button.combo
    โ•ฐโ”€โ”€ window.popup

ComboBoxText has a single CSS node with name combobox. It adds the style class .combo to the main CSS nodes of its entry and button children, and the .linked class to the node of its internal box.

Implements

ComboBoxExt, WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, CellEditableExt, CellLayoutExt, ComboBoxExtManual, WidgetExtManual, AccessibleExtManual, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl ComboBoxText

pub fn new() -> ComboBoxText

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new ComboBoxText.

Deprecated since 4.10

Use DropDown

Returns

A new ComboBoxText

pub fn with_entry() -> ComboBoxText

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new ComboBoxText with an entry.

Deprecated since 4.10

Use DropDown

Returns

a new ComboBoxText

pub fn builder() -> ComboBoxTextBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct ComboBoxText objects.

This method returns an instance of ComboBoxTextBuilder which can be used to create ComboBoxText objects.

pub fn append(&self, id: Option<&str>, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Appends @text to the list of strings stored in @self.

If @id is non-None then it is used as the ID of the row.

This is the same as calling insert() with a position of -1.

Deprecated since 4.10

Use DropDown

id

a string ID for this value

text

A string

pub fn append_text(&self, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Appends @text to the list of strings stored in @self.

This is the same as calling insert_text() with a position of -1.

Deprecated since 4.10

Use DropDown

text

A string

pub fn active_text(&self) -> Option<GString>

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the currently active string in @self.

If no row is currently selected, None is returned. If @self contains an entry, this function will return its contents (which will not necessarily be an item from the list).

Deprecated since 4.10

Use DropDown

Returns

a newly allocated string containing the currently active text. Must be freed with g_free().

pub fn insert(&self, position: i32, id: Option<&str>, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Inserts @text at @position in the list of strings stored in @self.

If @id is non-None then it is used as the ID of the row. See id-column.

If @position is negative then @text is appended.

Deprecated since 4.10

Use DropDown

position

An index to insert @text

id

a string ID for this value

text

A string to display

pub fn insert_text(&self, position: i32, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Inserts @text at @position in the list of strings stored in @self.

If @position is negative then @text is appended.

This is the same as calling insert() with a None ID string.

Deprecated since 4.10

Use DropDown

position

An index to insert @text

text

A string

pub fn prepend(&self, id: Option<&str>, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Prepends @text to the list of strings stored in @self.

If @id is non-None then it is used as the ID of the row.

This is the same as calling insert() with a position of 0.

Deprecated since 4.10

Use DropDown

id

a string ID for this value

text

a string

pub fn prepend_text(&self, text: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Prepends @text to the list of strings stored in @self.

This is the same as calling insert_text() with a position of 0.

Deprecated since 4.10

Use DropDown

text

A string

pub fn remove(&self, position: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Removes the string at @position from @self.

Deprecated since 4.10

Use DropDown

position

Index of the item to remove

pub fn remove_all(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Removes all the text entries from the combo box.

Deprecated since 4.10

Use DropDown