pub struct ConstraintLayout { /* private fields */ }Expand description
=150@required, ==250@medium)]
Finally, it's also possible to use simple arithmetic operators:
// width of button1 must be equal to width of button2 // divided by 2 plus 12 [button1(button2 / 2 + 12)]
# Implements
[`LayoutManagerExt`][trait@crate::prelude::LayoutManagerExt], [`trait@glib::ObjectExt`], [`BuildableExt`][trait@crate::prelude::BuildableExt]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ConstraintLayout
impl ConstraintLayout
Sourcepub fn new() -> ConstraintLayout
pub fn new() -> ConstraintLayout
Sourcepub fn add_constraint(&self, constraint: Constraint)
pub fn add_constraint(&self, constraint: Constraint)
Adds a constraint to the layout manager.
The source and target
properties of constraint can be:
- set to
NULLto indicate that the constraint refers to the widget usinglayout - set to the
Widgetusinglayout - set to a child of the
Widgetusinglayout - set to a
ConstraintGuidethat is part oflayout
The @self acquires the ownership of @constraint after calling this function.
constraint
Sourcepub fn add_guide(&self, guide: ConstraintGuide)
pub fn add_guide(&self, guide: ConstraintGuide)
Adds a guide to layout.
A guide can be used as the source or target of constraints, like a widget, but it is not visible.
The layout acquires the ownership of guide after calling
this function.
guide
a ConstraintGuide object
Sourcepub fn observe_constraints(&self) -> ListModel
pub fn observe_constraints(&self) -> ListModel
Returns a GListModel to track the constraints that are
part of the layout.
Calling this function will enable extra internal bookkeeping to track constraints and emit signals on the returned listmodel. It may slow down operations a lot.
Applications should try hard to avoid calling this function because of the slowdowns.
Returns
a
GListModel tracking the layout’s constraints
Sourcepub fn observe_guides(&self) -> ListModel
pub fn observe_guides(&self) -> ListModel
Returns a GListModel to track the guides that are
part of the layout.
Calling this function will enable extra internal bookkeeping to track guides and emit signals on the returned listmodel. It may slow down operations a lot.
Applications should try hard to avoid calling this function because of the slowdowns.
Returns
a
GListModel tracking the layout’s guides
Sourcepub fn remove_all_constraints(&self)
pub fn remove_all_constraints(&self)
Removes all constraints from the layout manager.
Sourcepub fn remove_constraint(&self, constraint: &Constraint)
pub fn remove_constraint(&self, constraint: &Constraint)
Removes constraint from the layout manager,
so that it no longer influences the layout.
constraint
Sourcepub fn remove_guide(&self, guide: &ConstraintGuide)
pub fn remove_guide(&self, guide: &ConstraintGuide)
Removes guide from the layout manager,
so that it no longer influences the layout.
guide
a ConstraintGuide object
Sourceimpl ConstraintLayout
impl ConstraintLayout
Sourcepub fn add_constraints_from_description<'a, W: IsA<Widget>>(
&self,
lines: impl IntoStrV,
hspacing: i32,
vspacing: i32,
views: impl IntoIterator<Item = (&'a str, &'a W)>,
) -> Result<Vec<Constraint>, Error>
pub fn add_constraints_from_description<'a, W: IsA<Widget>>( &self, lines: impl IntoStrV, hspacing: i32, vspacing: i32, views: impl IntoIterator<Item = (&'a str, &'a W)>, ) -> Result<Vec<Constraint>, Error>
=20)]-|
// Operators [button1(button2 / 3 + 50)]
// Named attributes [button1(==button2.height)]
## `lines`
an array of Visual Format Language lines
defining a set of constraints
## `hspacing`
default horizontal spacing value, or -1 for the fallback value
## `vspacing`
default vertical spacing value, or -1 for the fallback value
## `views`
a dictionary of `[ name, target ]`
pairs; the `name` keys map to the view names in the VFL lines, while
the `target` values map to children of the widget using a [`ConstraintLayout`][crate::ConstraintLayout],
or guides
# Returns
the list of
[`Constraint`][crate::Constraint] instances that were added to the layoutTrait Implementations
Sourceimpl Clone for ConstraintLayout
impl Clone for ConstraintLayout
Sourceimpl Debug for ConstraintLayout
impl Debug for ConstraintLayout
Sourceimpl Default for ConstraintLayout
impl Default for ConstraintLayout
impl Eq for ConstraintLayout
Sourceimpl HasParamSpec for ConstraintLayout
impl HasParamSpec for ConstraintLayout
type ParamSpec = ParamSpecObject
Sourcetype SetValue = ConstraintLayout
type SetValue = ConstraintLayout
type BuilderFn = fn(&str) -> ParamSpecObjectBuilder<'_, ConstraintLayout>
fn param_spec_builder() -> Self::BuilderFn
Sourceimpl Hash for ConstraintLayout
impl Hash for ConstraintLayout
impl IsA<Buildable> for ConstraintLayout
impl IsA<LayoutManager> for ConstraintLayout
Sourceimpl Ord for ConstraintLayout
impl Ord for ConstraintLayout
Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
Comparison for two GObjects.
Compares the memory addresses of the provided objects.
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl ParentClassIs for ConstraintLayout
impl ParentClassIs for ConstraintLayout
type Parent = LayoutManager
Sourceimpl<OT: ObjectType> PartialEq<OT> for ConstraintLayout
impl<OT: ObjectType> PartialEq<OT> for ConstraintLayout
Sourceimpl<OT: ObjectType> PartialOrd<OT> for ConstraintLayout
impl<OT: ObjectType> PartialOrd<OT> for ConstraintLayout
Sourcefn partial_cmp(&self, other: &OT) -> Option<Ordering>
fn partial_cmp(&self, other: &OT) -> Option<Ordering>
Partial comparison for two GObjects.
Compares the memory addresses of the provided objects.
Sourceimpl StaticType for ConstraintLayout
impl StaticType for ConstraintLayout
Sourcefn static_type() -> Type
fn static_type() -> Type
Self.Auto Trait Implementations
impl !Send for ConstraintLayout
impl !Sync for ConstraintLayout
impl Freeze for ConstraintLayout
impl RefUnwindSafe for ConstraintLayout
impl Unpin for ConstraintLayout
impl UnsafeUnpin for ConstraintLayout
impl UnwindSafe for ConstraintLayout