pub struct CssProvider { /* private fields */ }Expand description
A style provider for CSS.
It is able to parse CSS-like input in order to style widgets.
An application can make GTK parse a specific CSS style sheet by calling
load_from_file() or
load_from_resource()
and adding the provider with StyleContextExt::add_provider() or
StyleContext::add_provider_for_display().
In addition, certain files will be read when GTK is initialized.
First, the file $XDG_CONFIG_HOME/gtk-4.0/gtk.css is loaded if it
exists. Then, GTK loads the first existing file among
XDG_DATA_HOME/themes/THEME/gtk-VERSION/gtk-VARIANT.css,
$HOME/.themes/THEME/gtk-VERSION/gtk-VARIANT.css,
$XDG_DATA_DIRS/themes/THEME/gtk-VERSION/gtk-VARIANT.css and
DATADIR/share/themes/THEME/gtk-VERSION/gtk-VARIANT.css,
where THEME is the name of the current theme (see the
gtk-theme-name setting), VARIANT is the
variant to load (see the
gtk-application-prefer-dark-theme setting),
DATADIR is the prefix configured when GTK was compiled (unless
overridden by the GTK_DATA_PREFIX environment variable), and
VERSION is the GTK version number. If no file is found for the
current version, GTK tries older versions all the way back to 4.0.
To track errors while loading CSS, connect to the
parsing-error signal.
Properties
prefers-color-scheme
Define the color scheme used for rendering the user interface.
The UI can be set to either [enum@Gtk.InterfaceColorScheme.LIGHT], or [enum@Gtk.InterfaceColorScheme.DARK] mode. Other values will be interpreted the same as [enum@Gtk.InterfaceColorScheme.LIGHT].
This setting is be available for media queries in CSS:
@media (prefers-color-scheme: dark) {
// some dark mode styling
}Changing this setting will reload the style sheet.
Readable | Writable
prefers-contrast
Define the contrast mode to use for the user interface.
When set to [enum@Gtk.InterfaceContrast.MORE] or [enum@Gtk.InterfaceContrast.LESS], the UI is rendered in high or low contrast.
When set to [enum@Gtk.InterfaceContrast.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-contrast: more) {
// some style with high contrast
}Changing this setting will reload the style sheet.
Readable | Writable
prefers-reduced-motion
Define the type of reduced motion to use for the user interface.
When set to [enum@Gtk.ReducedMotion.REDUCE] the UI is rendered in with reduced motion animations.
When set to [enum@Gtk.ReducedMotion.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-reduced-motion: reduce) {
// some style with reduced motion
}Changing this setting will reload the style sheet.
Readable | Writable
Signals
parsing-error
Signals that a parsing error occurred.
The expected error values are in the CssParserError
and CssParserWarning enumerations.
The @path, @line and @position describe the actual location of the error as accurately as possible.
Parsing errors are never fatal, so the parsing will resume after the error. Errors may however cause parts of the given data or even all of it to not be parsed at all. So it is a useful idea to check that the parsing succeeds by connecting to this signal.
Errors in the CssParserWarning enumeration should not
be treated as fatal errors.
Note that this signal may be emitted at any time as the css provider may opt to defer parsing parts or all of the input to a later time than when a loading function was called.
StyleProvider
gtk-private-changed
Implements
[trait@glib::ObjectExt], StyleProviderExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CssProvider
impl CssProvider
Sourcepub fn new() -> CssProvider
pub fn new() -> CssProvider
Sourcepub fn builder() -> CssProviderBuilder
pub fn builder() -> CssProviderBuilder
Creates a new builder-pattern struct instance to construct CssProvider objects.
This method returns an instance of CssProviderBuilder which can be used to create CssProvider objects.
Sourcepub fn load_from_bytes(&self, data: &Bytes)
pub fn load_from_bytes(&self, data: &Bytes)
Loads @data into @self.
This clears any previously loaded information.
data
GBytes containing the data to load
Sourcepub fn load_from_data(&self, data: &str)
👎Deprecated: Since 4.12
pub fn load_from_data(&self, data: &str)
Since 4.12
Loads @data into @self.
This clears any previously loaded information.
Deprecated since 4.12
Use load_from_string()
or load_from_bytes() instead
data
CSS data to be parsed
length
the length of @data in bytes, or -1 for NUL terminated strings
Sourcepub fn load_from_file(&self, file: &impl IsA<File>)
pub fn load_from_file(&self, file: &impl IsA<File>)
Loads the data contained in @file into @self.
This clears any previously loaded information.
file
GFile pointing to a file to load
Sourcepub fn load_from_path(&self, path: impl AsRef<Path>)
pub fn load_from_path(&self, path: impl AsRef<Path>)
Loads the data contained in @path into @self.
This clears any previously loaded information.
path
the path of a filename to load, in the GLib filename encoding
Sourcepub fn load_from_resource(&self, resource_path: &str)
pub fn load_from_resource(&self, resource_path: &str)
Loads the data contained in the resource at @resource_path into the @self.
This clears any previously loaded information.
resource_path
a GResource resource path
Sourcepub fn load_from_string(&self, string: &str)
pub fn load_from_string(&self, string: &str)
Sourcepub fn load_named(&self, name: &str, variant: Option<&str>)
👎Deprecated: Since 4.20
pub fn load_named(&self, name: &str, variant: Option<&str>)
Since 4.20
Loads a theme from the usual theme paths.
The actual process of finding the theme might change between releases, but it is guaranteed that this function uses the same mechanism to load the theme that GTK uses for loading its own theme.
Deprecated since 4.20
Using any of the other theme loaders, combine with media queries.
name
A theme name
variant
variant to load, for example, “dark”, or
None for the default
Sourcepub fn to_str(&self) -> GString
pub fn to_str(&self) -> GString
Converts the @self into a string representation in CSS format.
Using load_from_string() with the return
value from this function on a new provider created with
new() will basically create a duplicate
of this @self.
Returns
a new string representing the @self.
Sourcepub fn prefers_color_scheme(&self) -> InterfaceColorScheme
pub fn prefers_color_scheme(&self) -> InterfaceColorScheme
Define the color scheme used for rendering the user interface.
The UI can be set to either [enum@Gtk.InterfaceColorScheme.LIGHT], or [enum@Gtk.InterfaceColorScheme.DARK] mode. Other values will be interpreted the same as [enum@Gtk.InterfaceColorScheme.LIGHT].
This setting is be available for media queries in CSS:
@media (prefers-color-scheme: dark) {
// some dark mode styling
}Changing this setting will reload the style sheet.
Sourcepub fn set_prefers_color_scheme(
&self,
prefers_color_scheme: InterfaceColorScheme,
)
pub fn set_prefers_color_scheme( &self, prefers_color_scheme: InterfaceColorScheme, )
Define the color scheme used for rendering the user interface.
The UI can be set to either [enum@Gtk.InterfaceColorScheme.LIGHT], or [enum@Gtk.InterfaceColorScheme.DARK] mode. Other values will be interpreted the same as [enum@Gtk.InterfaceColorScheme.LIGHT].
This setting is be available for media queries in CSS:
@media (prefers-color-scheme: dark) {
// some dark mode styling
}Changing this setting will reload the style sheet.
Sourcepub fn prefers_contrast(&self) -> InterfaceContrast
pub fn prefers_contrast(&self) -> InterfaceContrast
Define the contrast mode to use for the user interface.
When set to [enum@Gtk.InterfaceContrast.MORE] or [enum@Gtk.InterfaceContrast.LESS], the UI is rendered in high or low contrast.
When set to [enum@Gtk.InterfaceContrast.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-contrast: more) {
// some style with high contrast
}Changing this setting will reload the style sheet.
Sourcepub fn set_prefers_contrast(&self, prefers_contrast: InterfaceContrast)
pub fn set_prefers_contrast(&self, prefers_contrast: InterfaceContrast)
Define the contrast mode to use for the user interface.
When set to [enum@Gtk.InterfaceContrast.MORE] or [enum@Gtk.InterfaceContrast.LESS], the UI is rendered in high or low contrast.
When set to [enum@Gtk.InterfaceContrast.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-contrast: more) {
// some style with high contrast
}Changing this setting will reload the style sheet.
Sourcepub fn prefers_reduced_motion(&self) -> ReducedMotion
pub fn prefers_reduced_motion(&self) -> ReducedMotion
Define the type of reduced motion to use for the user interface.
When set to [enum@Gtk.ReducedMotion.REDUCE] the UI is rendered in with reduced motion animations.
When set to [enum@Gtk.ReducedMotion.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-reduced-motion: reduce) {
// some style with reduced motion
}Changing this setting will reload the style sheet.
Sourcepub fn set_prefers_reduced_motion(&self, prefers_reduced_motion: ReducedMotion)
pub fn set_prefers_reduced_motion(&self, prefers_reduced_motion: ReducedMotion)
Define the type of reduced motion to use for the user interface.
When set to [enum@Gtk.ReducedMotion.REDUCE] the UI is rendered in with reduced motion animations.
When set to [enum@Gtk.ReducedMotion.NO_PREFERENCE] (the default), the user interface will be rendered in default mode.
This setting is be available for media queries in CSS:
@media (prefers-reduced-motion: reduce) {
// some style with reduced motion
}Changing this setting will reload the style sheet.
Sourcepub fn connect_parsing_error<F: Fn(&Self, &CssSection, &Error) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_parsing_error<F: Fn(&Self, &CssSection, &Error) + 'static>( &self, f: F, ) -> SignalHandlerId
Signals that a parsing error occurred.
The expected error values are in the CssParserError
and CssParserWarning enumerations.
The @path, @line and @position describe the actual location of the error as accurately as possible.
Parsing errors are never fatal, so the parsing will resume after the error. Errors may however cause parts of the given data or even all of it to not be parsed at all. So it is a useful idea to check that the parsing succeeds by connecting to this signal.
Errors in the CssParserWarning enumeration should not
be treated as fatal errors.
Note that this signal may be emitted at any time as the css provider may opt to defer parsing parts or all of the input to a later time than when a loading function was called.
section
section the error happened in
error
The parsing error
pub fn connect_prefers_color_scheme_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_prefers_contrast_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_prefers_reduced_motion_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId