EntryCompletion

Struct EntryCompletion 

pub struct EntryCompletion { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

EntryCompletion is an auxiliary object to provide completion functionality for Entry.

It implements the CellLayout interface, to allow the user to add extra cells to the TreeView with completion matches.

โ€œCompletion functionalityโ€ means that when the user modifies the text in the entry, EntryCompletion checks which rows in the model match the current content of the entry, and displays a list of matches. By default, the matching is done by comparing the entry text case-insensitively against the text column of the model (see set_text_column()), but this can be overridden with a custom match function (see set_match_func()).

When the user selects a completion, the content of the entry is updated. By default, the content of the entry is replaced by the text column of the model, but this can be overridden by connecting to the match-selected signal and updating the entry in the signal handler. Note that you should return true from the signal handler to suppress the default behaviour.

To add completion functionality to an entry, use EntryExt::set_completion().

EntryCompletion uses a TreeModelFilter model to represent the subset of the entire model that is currently matching. While the EntryCompletion signals match-selected and cursor-on-match take the original model and an iter pointing to that model as arguments, other callbacks and signals (such as GtkCellLayoutDataFunc or apply-attributes)] will generally take the filter model as argument. As long as you are only calling TreeModelExtManual::get(), this will make no difference to you. If for some reason, you need the original model, use TreeModelFilterExt::model(). Donโ€™t forget to use TreeModelFilterExt::convert_iter_to_child_iter() to obtain a matching iter.

Properties

cell-area

The CellArea used to layout cell renderers in the treeview column.

If no area is specified when creating the entry completion with EntryCompletion::with_area(), a horizontally oriented CellAreaBox will be used.

Readable | Writable | Construct Only

inline-completion

Determines whether the common prefix of the possible completions should be inserted automatically in the entry.

Note that this requires text-column to be set, even if you are using a custom match function.

Readable | Writable

inline-selection

Determines whether the possible completions on the popup will appear in the entry as you navigate through them.

Readable | Writable

minimum-key-length

The minimum key length as set for completion.

Readable | Writable

model

The model used as data source.

Readable | Writable

Determines whether the possible completions should be shown in a popup window.

Readable | Writable

Determines whether the completions popup window will be resized to the width of the entry.

Readable | Writable

Determines whether the completions popup window will shown for a single possible completion.

You probably want to set this to false if you are using inline-completion.

Readable | Writable

text-column

The column of the model containing the strings.

Note that the strings must be UTF-8.

Readable | Writable

Signals

cursor-on-match

Emitted when a match from the cursor is on a match of the list.

The default behaviour is to replace the contents of the entry with the contents of the text column in the row pointed to by @iter.

Note that @model is the model that was passed to EntryCompletion::set_model().

insert-prefix

Emitted when the inline autocompletion is triggered.

The default behaviour is to make the entry display the whole prefix and select the newly inserted part.

Applications may connect to this signal in order to insert only a smaller part of the @prefix into the entry - e.g. the entry used in the FileChooser inserts only the part of the prefix up to the next โ€˜/โ€™.

match-selected

Emitted when a match from the list is selected.

The default behaviour is to replace the contents of the entry with the contents of the text column in the row pointed to by @iter.

Note that @model is the model that was passed to EntryCompletion::set_model().

no-matches

Emitted when the filter model has zero number of rows in completion_complete method.

In other words when EntryCompletion is out of suggestions.

Implements

[trait@glib::ObjectExt], BuildableExt, CellLayoutExt, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl EntryCompletion

pub fn new() -> EntryCompletion

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new EntryCompletion object.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

A newly created EntryCompletion object

pub fn with_area(area: &impl IsA<CellArea>) -> EntryCompletion

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new EntryCompletion object using the specified @area.

The CellArea is used to layout cells in the underlying TreeViewColumn for the drop-down menu.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

area

the CellArea used to layout cells

Returns

A newly created EntryCompletion object

pub fn builder() -> EntryCompletionBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct EntryCompletion objects.

This method returns an instance of EntryCompletionBuilder which can be used to create EntryCompletion objects.

pub fn complete(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Requests a completion operation, or in other words a refiltering of the current list with completions, using the current key.

The completion list view will be updated accordingly.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

pub fn compute_prefix(&self, key: &str) -> Option<GString>

๐Ÿ‘ŽDeprecated:

Since 4.10

Computes the common prefix that is shared by all rows in @self that start with @key.

If no row matches @key, None will be returned. Note that a text column must have been set for this function to work, see set_text_column() for details.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

key

The text to complete for

Returns

The common prefix all rows starting with @key

pub fn completion_prefix(&self) -> Option<GString>

๐Ÿ‘ŽDeprecated:

Since 4.10

Get the original text entered by the user that triggered the completion or None if thereโ€™s no completion ongoing.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

the prefix for the current completion

pub fn is_inline_completion(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the common prefix of the possible completions should be automatically inserted in the entry.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

true if inline completion is turned on

pub fn is_inline_selection(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if inline-selection mode is turned on.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

true if inline-selection mode is on

pub fn minimum_key_length(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the minimum key length as set for @self.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

The currently used minimum key length

pub fn model(&self) -> Option<TreeModel>

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the model the EntryCompletion is using as data source.

Returns None if the model is unset.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

A TreeModel

pub fn is_popup_completion(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the completions should be presented in a popup window.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

true if popup completion is turned on

pub fn is_popup_set_width(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the completion popup window will be resized to the width of the entry.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

true if the popup window will be resized to the width of the entry

pub fn is_popup_single_match(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns whether the completion popup window will appear even if there is only a single match.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

true if the popup window will appear regardless of the number of matches

pub fn text_column(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the column in the model of @self to get strings from.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

the column containing the strings

pub fn insert_prefix(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Requests a prefix insertion.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

pub fn set_inline_completion(&self, inline_completion: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets whether the common prefix of the possible completions should be automatically inserted in the entry.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

inline_completion

true to do inline completion

pub fn set_inline_selection(&self, inline_selection: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets whether it is possible to cycle through the possible completions inside the entry.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

inline_selection

true to do inline selection

pub fn set_match_func<P: Fn(&EntryCompletion, &str, &TreeIter) -> bool + 'static>( &self, func: P, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the match function for @self to be @func.

The match function is used to determine if a row should or should not be in the completion list.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

func

the EntryCompletionMatchFunc to use

func_data

user data for @func

func_notify

destroy notify for @func_data.

pub fn set_minimum_key_length(&self, length: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Requires the length of the search key for @self to be at least @length.

This is useful for long lists, where completing using a small key takes a lot of time and will come up with meaningless results anyway (ie, a too large dataset).

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

length

the minimum length of the key in order to start completing

pub fn set_model(&self, model: Option<&impl IsA<TreeModel>>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the model for a EntryCompletion.

If @self already has a model set, it will remove it before setting the new model. If model is None, then it will unset the model.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

model

the TreeModel

pub fn set_popup_completion(&self, popup_completion: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets whether the completions should be presented in a popup window.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

true to do popup completion

pub fn set_popup_set_width(&self, popup_set_width: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets whether the completion popup window will be resized to be the same width as the entry.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

true to make the width of the popup the same as the entry

pub fn set_popup_single_match(&self, popup_single_match: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets whether the completion popup window will appear even if there is only a single match.

You may want to set this to false if you are using inline-completion.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

true if the popup should appear even for a single match

pub fn set_text_column(&self, column: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Convenience function for setting up the most used case of this code: a completion list with just strings.

This function will set up @self to have a list displaying all (and just) strings in the completion list, and to get those strings from @column in the model of @self.

This functions creates and adds a CellRendererText for the selected column. If you need to set the text column, but donโ€™t want the cell renderer, use g_object_set() to set the text-column property directly.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

column

the column in the model of @self to get strings from

pub fn cell_area(&self) -> Option<CellArea>

๐Ÿ‘ŽDeprecated:

Since 4.10

The CellArea used to layout cell renderers in the treeview column.

If no area is specified when creating the entry completion with with_area(), a horizontally oriented CellAreaBox will be used.

pub fn connect_cursor_on_match<F: Fn(&Self, &TreeModel, &TreeIter) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Emitted when a match from the cursor is on a match of the list.

The default behaviour is to replace the contents of the entry with the contents of the text column in the row pointed to by @iter.

Note that @model is the model that was passed to set_model().

model

the TreeModel containing the matches

iter

a TreeIter positioned at the selected match

Returns

true if the signal has been handled

pub fn connect_insert_prefix<F: Fn(&Self, &str) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Emitted when the inline autocompletion is triggered.

The default behaviour is to make the entry display the whole prefix and select the newly inserted part.

Applications may connect to this signal in order to insert only a smaller part of the @prefix into the entry - e.g. the entry used in the FileChooser inserts only the part of the prefix up to the next โ€˜/โ€™.

prefix

the common prefix of all possible completions

Returns

true if the signal has been handled

pub fn connect_match_selected<F: Fn(&Self, &TreeModel, &TreeIter) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Emitted when a match from the list is selected.

The default behaviour is to replace the contents of the entry with the contents of the text column in the row pointed to by @iter.

Note that @model is the model that was passed to set_model().

model

the TreeModel containing the matches

iter

a TreeIter positioned at the selected match

Returns

true if the signal has been handled

pub fn connect_no_matches<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Emitted when the filter model has zero number of rows in completion_complete method.

In other words when EntryCompletion is out of suggestions.

pub fn connect_inline_completion_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_inline_selection_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_minimum_key_length_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_popup_completion_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_popup_set_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_popup_single_match_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_text_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Source

impl EntryCompletion

pub fn entry(&self) -> Option<Entry>

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the entry @self has been attached to.

Deprecated since 4.10

GtkEntryCompletion will be removed in GTK 5.

Returns

The entry @self has been attached to