pub struct EventControllerLegacy { /* private fields */ }Expand description
Provides raw access to the event stream.
It should only be used as a last resort if none of the other event controllers or gestures do the job.
Signals
event
Emitted for each GDK event delivered to @controller.
Implements
EventControllerExt, [trait@glib::ObjectExt], EventControllerExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl EventControllerLegacy
impl EventControllerLegacy
Sourcepub fn new() -> EventControllerLegacy
pub fn new() -> EventControllerLegacy
Sourcepub fn builder() -> EventControllerLegacyBuilder
pub fn builder() -> EventControllerLegacyBuilder
Creates a new builder-pattern struct instance to construct EventControllerLegacy objects.
This method returns an instance of EventControllerLegacyBuilder which can be used to create EventControllerLegacy objects.
Sourcepub fn connect_event<F: Fn(&Self, &Event) -> Propagation + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_event<F: Fn(&Self, &Event) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted for each GDK event delivered to @controller.
event
the gdk::Event which triggered this signal
Returns
true to stop other handlers from being invoked for the event
and the emission of this signal. false to propagate the event further.