pub struct Filter { /* private fields */ }Expand description
Describes the filtering to be performed by a FilterListModel.
The model will use the filter to determine if it should include items
or not by calling FilterExt::match_() for each item and only
keeping the ones that the function returns true for.
Filters may change what items they match through their lifetime. In that
case, they will emit the changed signal to notify
that previous filter results are no longer valid and that items should
be checked again via FilterExt::match_().
GTK provides various pre-made filter implementations for common filtering operations. These filters often include properties that can be linked to various widgets to easily allow searches.
However, in particular for large lists or complex search methods, it is
also possible to subclass Filter and provide one’s own filter.
Signals
changed
Emitted whenever the filter changed.
Users of the filter should then check items again via
FilterExt::match_().
FilterListModel handles this signal automatically.
Depending on the @change parameter, not all items need
to be checked, but only some. Refer to the FilterChange
documentation for details.
Implements
FilterExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations