pub struct FlowBox { /* private fields */ }Expand description
[rubberband]
[`FlowBox`][crate::FlowBox] uses a single CSS node with name flowbox. [`FlowBoxChild`][crate::FlowBoxChild]
uses a single CSS node with name flowboxchild. For rubberband selection,
a subnode with name rubberband is used.
# Accessibility
[`FlowBox`][crate::FlowBox] uses the [enum@Gtk.AccessibleRole.grid] role, and [`FlowBoxChild`][crate::FlowBoxChild]
uses the [enum@Gtk.AccessibleRole.grid_cell] role.
## Properties
#### `accept-unpaired-release`
Whether to accept unpaired release events.
Readable | Writable
#### `activate-on-single-click`
Determines whether children can be activated with a single
click, or require a double-click.
Readable | Writable
#### `column-spacing`
The amount of horizontal space between two children.
Readable | Writable
#### `homogeneous`
Determines whether all children should be allocated the
same size.
Readable | Writable
#### `max-children-per-line`
The maximum amount of children to request space for consecutively
in the given orientation.
Readable | Writable
#### `min-children-per-line`
The minimum number of children to allocate consecutively
in the given orientation.
Setting the minimum children per line ensures
that a reasonably small height will be requested
for the overall minimum width of the box.
Readable | Writable
#### `row-spacing`
The amount of vertical space between two children.
Readable | Writable
#### `selection-mode`
The selection mode used by the flow box.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Orientable</h4></summary>
#### `orientation`
The orientation of the orientable.
Readable | Writable
</details>
## Signals
#### `activate-cursor-child`
Emitted when the user activates the @box_.
This is a [keybinding signal](class.SignalAction.html).
Action
#### `child-activated`
Emitted when a child has been activated by the user.
#### `move-cursor`
move vertically by pages
Action
#### `select-all`
.
Action
#### `selected-children-changed`
Emitted when the set of selected children changes.
Use [`FlowBox::selected_foreach()`][crate::FlowBox::selected_foreach()] or
[`FlowBox::selected_children()`][crate::FlowBox::selected_children()] to obtain the
selected children.
#### `toggle-cursor-child`
.
Action
#### `unselect-all`
.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`OrientableExt`][trait@crate::prelude::OrientableExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl FlowBox
impl FlowBox
Sourcepub fn builder() -> FlowBoxBuilder
pub fn builder() -> FlowBoxBuilder
Creates a new builder-pattern struct instance to construct FlowBox objects.
This method returns an instance of FlowBoxBuilder which can be used to create FlowBox objects.
Sourcepub fn bind_model<P: Fn(&Object) -> Widget + 'static>(
&self,
model: Option<&impl IsA<ListModel>>,
create_widget_func: P,
)
pub fn bind_model<P: Fn(&Object) -> Widget + 'static>( &self, model: Option<&impl IsA<ListModel>>, create_widget_func: P, )
Binds @model to @self.
If @self was already bound to a model, that previous binding is destroyed.
The contents of @self are cleared and then filled with widgets that
represent items from @model. @self is updated whenever @model changes.
If @model is None, @self is left empty.
It is undefined to add or remove widgets directly (for example, with
insert()) while @self is bound to a model.
Note that using a model is incompatible with the filtering and sorting
functionality in FlowBox. When using a model, filtering and sorting
should be implemented by the model.
model
the GListModel to be bound to @self
create_widget_func
a function that creates widgets for items
Sourcepub fn activates_on_single_click(&self) -> bool
pub fn activates_on_single_click(&self) -> bool
Sourcepub fn child_at_index(&self, idx: i32) -> Option<FlowBoxChild>
pub fn child_at_index(&self, idx: i32) -> Option<FlowBoxChild>
Gets the nth child in the @self.
idx
the position of the child
Returns
the child widget, which will
always be a FlowBoxChild or None in case no child widget
with the given index exists.
Sourcepub fn child_at_pos(&self, x: i32, y: i32) -> Option<FlowBoxChild>
pub fn child_at_pos(&self, x: i32, y: i32) -> Option<FlowBoxChild>
Gets the child in the (@x, @y) position.
Both @x and @y are assumed to be relative to the origin of @self.
x
the x coordinate of the child
y
the y coordinate of the child
Returns
the child widget, which will
always be a FlowBoxChild or None in case no child widget
exists for the given x and y coordinates.
Sourcepub fn column_spacing(&self) -> u32
pub fn column_spacing(&self) -> u32
Sourcepub fn is_homogeneous(&self) -> bool
pub fn is_homogeneous(&self) -> bool
Sourcepub fn max_children_per_line(&self) -> u32
pub fn max_children_per_line(&self) -> u32
Sourcepub fn min_children_per_line(&self) -> u32
pub fn min_children_per_line(&self) -> u32
Sourcepub fn row_spacing(&self) -> u32
pub fn row_spacing(&self) -> u32
Sourcepub fn selected_children(&self) -> Vec<FlowBoxChild>
pub fn selected_children(&self) -> Vec<FlowBoxChild>
Sourcepub fn selection_mode(&self) -> SelectionMode
pub fn selection_mode(&self) -> SelectionMode
Sourcepub fn insert(&self, widget: &impl IsA<Widget>, position: i32)
pub fn insert(&self, widget: &impl IsA<Widget>, position: i32)
Inserts the @widget into @self at @position.
If a sort function is set, the widget will actually be inserted at the calculated position.
If @position is -1, or larger than the total number of children in the @self, then the @widget will be appended to the end.
widget
the Widget to add
position
the position to insert @child in
Sourcepub fn invalidate_filter(&self)
pub fn invalidate_filter(&self)
Updates the filtering for all children.
Call this function when the result of the filter function on the @self is changed due to an external factor. For instance, this would be used if the filter function just looked for a specific search term, and the entry with the string has changed.
Sourcepub fn invalidate_sort(&self)
pub fn invalidate_sort(&self)
Updates the sorting for all children.
Call this when the result of the sort function on @self is changed due to an external factor.
Sourcepub fn remove_all(&self)
Available on crate feature v4_12 only.
pub fn remove_all(&self)
v4_12 only.Removes all children from @self.
This function does nothing if @self is backed by a model.
Sourcepub fn select_all(&self)
pub fn select_all(&self)
Select all children of @self, if the selection mode allows it.
Sourcepub fn select_child(&self, child: &impl IsA<FlowBoxChild>)
pub fn select_child(&self, child: &impl IsA<FlowBoxChild>)
Sourcepub fn selected_foreach<P: FnMut(&FlowBox, &FlowBoxChild)>(&self, func: P)
pub fn selected_foreach<P: FnMut(&FlowBox, &FlowBoxChild)>(&self, func: P)
Calls a function for each selected child.
Note that the selection cannot be modified from within this function.
func
the function to call for each selected child
Sourcepub fn set_activate_on_single_click(&self, single: bool)
pub fn set_activate_on_single_click(&self, single: bool)
Sourcepub fn set_column_spacing(&self, spacing: u32)
pub fn set_column_spacing(&self, spacing: u32)
Sourcepub fn set_filter_func<P: Fn(&FlowBoxChild) -> bool + 'static>(
&self,
filter_func: P,
)
pub fn set_filter_func<P: Fn(&FlowBoxChild) -> bool + 'static>( &self, filter_func: P, )
By setting a filter function on the @self one can decide dynamically which of the children to show.
For instance, to implement a search function that only shows the children matching the search terms.
The @filter_func will be called for each child after the call, and
it will continue to be called each time a child changes (via
FlowBoxChildExt::changed()) or when
invalidate_filter() is called.
Note that using a filter function is incompatible with using a model
(see bind_model()).
filter_func
callback that lets you filter which children to show
Sourcepub fn set_hadjustment(&self, adjustment: &impl IsA<Adjustment>)
pub fn set_hadjustment(&self, adjustment: &impl IsA<Adjustment>)
Hooks up an adjustment to focus handling in @self.
The adjustment is also used for autoscrolling during
rubberband selection. See ScrolledWindow::hadjustment()
for a typical way of obtaining the adjustment, and
set_vadjustment() for setting the vertical
adjustment.
The adjustments have to be in pixel units and in the same coordinate system as the allocation for immediate children of the box.
adjustment
an adjustment which should be adjusted when the focus is moved among the descendents of @container
Sourcepub fn set_homogeneous(&self, homogeneous: bool)
pub fn set_homogeneous(&self, homogeneous: bool)
Sourcepub fn set_max_children_per_line(&self, n_children: u32)
pub fn set_max_children_per_line(&self, n_children: u32)
s orientation.
Setting the maximum number of children per line limits the overall natural size request to be no more than @n_children children long in the given orientation.
n_children
the maximum number of children per line
Sourcepub fn set_min_children_per_line(&self, n_children: u32)
pub fn set_min_children_per_line(&self, n_children: u32)
Sourcepub fn set_row_spacing(&self, spacing: u32)
pub fn set_row_spacing(&self, spacing: u32)
Sourcepub fn set_selection_mode(&self, mode: SelectionMode)
pub fn set_selection_mode(&self, mode: SelectionMode)
Sourcepub fn set_vadjustment(&self, adjustment: &impl IsA<Adjustment>)
pub fn set_vadjustment(&self, adjustment: &impl IsA<Adjustment>)
Hooks up an adjustment to focus handling in @self.
The adjustment is also used for autoscrolling during
rubberband selection. See ScrolledWindow::vadjustment()
for a typical way of obtaining the adjustment, and
set_hadjustment() for setting the horizontal
adjustment.
The adjustments have to be in pixel units and in the same coordinate system as the allocation for immediate children of the box.
adjustment
an adjustment which should be adjusted when the focus is moved among the descendents of @container
Sourcepub fn unselect_all(&self)
pub fn unselect_all(&self)
Unselect all children of @self, if the selection mode allows it.
Sourcepub fn unselect_child(&self, child: &impl IsA<FlowBoxChild>)
pub fn unselect_child(&self, child: &impl IsA<FlowBoxChild>)
Sourcepub fn accepts_unpaired_release(&self) -> bool
pub fn accepts_unpaired_release(&self) -> bool
Whether to accept unpaired release events.
Sourcepub fn set_accept_unpaired_release(&self, accept_unpaired_release: bool)
pub fn set_accept_unpaired_release(&self, accept_unpaired_release: bool)
Whether to accept unpaired release events.
Sourcepub fn connect_activate_cursor_child<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activate_cursor_child<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the user activates the @box_.
This is a keybinding signal.
pub fn emit_activate_cursor_child(&self)
Sourcepub fn connect_child_activated<F: Fn(&Self, &FlowBoxChild) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_child_activated<F: Fn(&Self, &FlowBoxChild) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
move vertically by pages
step
the granularity of the move, as a MovementStep
count
the number of @step units to move
extend
whether to extend the selection
modify
whether to modify the selection
Returns
true to stop other handlers from being invoked for the event.
false to propagate the event further.
pub fn emit_move_cursor( &self, step: MovementStep, count: i32, extend: bool, modify: bool, ) -> bool
Sourcepub fn connect_select_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_select_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_select_all(&self)
Sourcepub fn connect_selected_children_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_selected_children_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the set of selected children changes.
Use selected_foreach() or
selected_children() to obtain the
selected children.
Sourcepub fn connect_toggle_cursor_child<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_toggle_cursor_child<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_toggle_cursor_child(&self)
Sourcepub fn connect_unselect_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_unselect_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_unselect_all(&self)
pub fn connect_accept_unpaired_release_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_activate_on_single_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_column_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_homogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_max_children_per_line_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_min_children_per_line_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_row_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selection_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl FlowBox
impl FlowBox
pub fn unbind_model(&self)
pub fn unset_filter_func(&self)
pub fn unset_sort_func(&self)
Sourcepub fn set_sort_func<P: Fn(&FlowBoxChild, &FlowBoxChild) -> Ordering + 'static>(
&self,
sort_func: P,
)
pub fn set_sort_func<P: Fn(&FlowBoxChild, &FlowBoxChild) -> Ordering + 'static>( &self, sort_func: P, )
By setting a sort function on the @self, one can dynamically reorder the children of the box, based on the contents of the children.
The @sort_func will be called for each child after the call,
and will continue to be called each time a child changes (via
FlowBoxChildExt::changed()) and when
invalidate_sort() is called.
Note that using a sort function is incompatible with using a model
(see bind_model()).
sort_func
the sort function