pub struct FontButton { /* private fields */ }Since 4.10
Use FontDialogButton instead
The FontButton allows to open a font chooser dialog to change
the font.
It is suitable widget for selecting a font in a preference dialog.
CSS nodes
fontbutton
โฐโโ button.font
โฐโโ [content]FontButton has a single CSS node with name fontbutton which
contains a button node with the .font style class.
Properties
modal
Whether the font chooser dialog should be modal.
Readable | Writable
title
The title of the font chooser dialog.
Readable | Writable
use-font
Whether the buttons label will be drawn in the selected font.
Readable | Writable
use-size
Whether the buttons label will use the selected font size.
Readable | Writable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widgetโs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
FontChooser
font
The font description as a string, e.g. โSans Italic 12โ.
Readable | Writable
font-desc
The font description as a [pango::FontDescription][crate::pango::FontDescription].
Readable | Writable
font-features
The selected font features.
The format of the string is compatible with CSS and with Pango attributes.
Readable
language
The language for which the font features were selected.
Readable | Writable
level
The level of granularity to offer for selecting fonts.
Readable | Writable
preview-text
The string with which to preview the font.
Readable | Writable
show-preview-entry
Whether to show an entry to change the preview text.
Readable | Writable
Signals
activate
Emitted to when the font button is activated.
The ::activate signal on FontButton is an action signal and
emitting it causes the button to present its dialog.
Action
font-set
Emitted when the user selects a font.
When handling this signal, use FontChooserExt::font()
to find out which font was just selected.
Note that this signal is only emitted when the user changes the font. If you need to react to programmatic font changes as well, use the notify::font signal.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See WidgetExt::keynav_failed() for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widgetโs tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a gdk::Surface.
This means that WidgetExt::realize() has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the gdk::Surface associated with @widget is destroyed.
This means that WidgetExt::unrealize() has been called
or the widget has been unmapped (that is, it is going to be hidden).
FontChooser
font-activated
Emitted when a font is activated.
This usually happens when the user double clicks an item, or an item is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.
Implements
WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, FontChooserExt, WidgetExtManual, AccessibleExtManual, FontChooserExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FontButton
impl FontButton
Sourcepub fn new() -> FontButton
๐Deprecated: Since 4.10
pub fn new() -> FontButton
Since 4.10
Creates a new font picker widget.
Deprecated since 4.10
Use FontDialogButton instead
Returns
a new font picker widget.
Sourcepub fn with_font(fontname: &str) -> FontButton
๐Deprecated: Since 4.10
pub fn with_font(fontname: &str) -> FontButton
Since 4.10
Creates a new font picker widget showing the given font.
Deprecated since 4.10
Use FontDialogButton instead
fontname
Name of font to display in font chooser dialog
Returns
a new font picker widget.
Sourcepub fn builder() -> FontButtonBuilder
๐Deprecated: Since 4.10
pub fn builder() -> FontButtonBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct FontButton objects.
This method returns an instance of FontButtonBuilder which can be used to create FontButton objects.
Sourcepub fn is_modal(&self) -> bool
๐Deprecated: Since 4.10
pub fn is_modal(&self) -> bool
Since 4.10
Gets whether the dialog is modal.
Deprecated since 4.10
Use FontDialogButton instead
Returns
true if the dialog is modal
Sourcepub fn title(&self) -> GString
๐Deprecated: Since 4.10
pub fn title(&self) -> GString
Since 4.10
Retrieves the title of the font chooser dialog.
Deprecated since 4.10
Use FontDialogButton instead
Returns
an internal copy of the title string which must not be freed.
Sourcepub fn uses_font(&self) -> bool
๐Deprecated: Since 4.10
pub fn uses_font(&self) -> bool
Since 4.10
Returns whether the selected font is used in the label.
Deprecated since 4.10
Use FontDialogButton instead
Returns
whether the selected font is used in the label.
Sourcepub fn uses_size(&self) -> bool
๐Deprecated: Since 4.10
pub fn uses_size(&self) -> bool
Since 4.10
Returns whether the selected size is used in the label.
Deprecated since 4.10
Use FontDialogButton instead
Returns
whether the selected size is used in the label.
Sourcepub fn set_modal(&self, modal: bool)
๐Deprecated: Since 4.10
pub fn set_modal(&self, modal: bool)
Since 4.10
Sets whether the dialog should be modal.
Deprecated since 4.10
Use FontDialogButton instead
modal
true to make the dialog modal
Sourcepub fn set_title(&self, title: &str)
๐Deprecated: Since 4.10
pub fn set_title(&self, title: &str)
Since 4.10
Sets the title for the font chooser dialog.
Deprecated since 4.10
Use FontDialogButton instead
title
a string containing the font chooser dialog title
Sourcepub fn set_use_font(&self, use_font: bool)
๐Deprecated: Since 4.10
pub fn set_use_font(&self, use_font: bool)
Since 4.10
If @use_font is true, the font name will be written
using the selected font.
Deprecated since 4.10
Use FontDialogButton instead
use_font
If true, font name will be written using font chosen.
Sourcepub fn set_use_size(&self, use_size: bool)
๐Deprecated: Since 4.10
pub fn set_use_size(&self, use_size: bool)
Since 4.10
If @use_size is true, the font name will be written using
the selected size.
Deprecated since 4.10
Use FontDialogButton instead
use_size
If true, font name will be written using the
selected size.
Sourcepub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
Emitted to when the font button is activated.
The ::activate signal on FontButton is an action signal and
emitting it causes the button to present its dialog.
pub fn emit_activate(&self)
Since 4.10
Sourcepub fn connect_font_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_font_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
Emitted when the user selects a font.
When handling this signal, use FontChooserExt::font()
to find out which font was just selected.
Note that this signal is only emitted when the user changes the font. If you need to react to programmatic font changes as well, use the notify::font signal.
pub fn connect_modal_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_use_font_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_use_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10