pub struct FontDialog { /* private fields */ }Expand description
Asynchronous API to present a font chooser dialog.
FontDialog collects the arguments that are needed to present
the dialog to the user, such as a title for the dialog and whether
it should be modal.
The dialog is shown with the choose_font()
function or its variants.
See FontDialogButton for a convenient control
that uses FontDialog and presents the results.
Properties
filter
A filter to restrict what fonts are shown in the font chooser dialog.
Readable | Writable
font-map
A custom font map to select fonts from.
A custom font map can be used to present application-specific fonts instead of or in addition to the normal system fonts.
Readable | Writable
language
The language for which the font features are selected.
Readable | Writable
modal
Whether the font chooser dialog is modal.
Readable | Writable
title
A title that may be shown on the font chooser
dialog that is presented by FontDialog::choose_font().
Readable | Writable
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FontDialog
impl FontDialog
Sourcepub fn new() -> FontDialog
pub fn new() -> FontDialog
Sourcepub fn builder() -> FontDialogBuilder
pub fn builder() -> FontDialogBuilder
Creates a new builder-pattern struct instance to construct FontDialog objects.
This method returns an instance of FontDialogBuilder which can be used to create FontDialog objects.
Sourcepub fn choose_face<P: FnOnce(Result<FontFace, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
initial_value: Option<&impl IsA<FontFace>>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn choose_face<P: FnOnce(Result<FontFace, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, initial_value: Option<&impl IsA<FontFace>>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Presents a font chooser dialog to the user.
The font chooser dialog will be set up for selecting a font face.
A font face represents a font family and style, but no specific font size.
parent
the parent window
initial_value
the initial value
cancellable
a cancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn choose_face_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, initial_value: Option<&(impl IsA<FontFace> + Clone + 'static)>, ) -> Pin<Box_<dyn Future<Output = Result<FontFace, Error>> + 'static>>
Sourcepub fn choose_family<P: FnOnce(Result<FontFamily, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
initial_value: Option<&impl IsA<FontFamily>>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn choose_family<P: FnOnce(Result<FontFamily, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, initial_value: Option<&impl IsA<FontFamily>>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
pub fn choose_family_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, initial_value: Option<&(impl IsA<FontFamily> + Clone + 'static)>, ) -> Pin<Box_<dyn Future<Output = Result<FontFamily, Error>> + 'static>>
Sourcepub fn choose_font<P: FnOnce(Result<FontDescription, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
initial_value: Option<&FontDescription>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn choose_font<P: FnOnce(Result<FontDescription, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, initial_value: Option<&FontDescription>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Presents a font chooser dialog to the user.
The font chooser dialog will be set up for selecting a font.
If you want to let the user select font features as well,
use choose_font_and_features() instead.
parent
the parent window
initial_value
the font to select initially
cancellable
a cancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn choose_font_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, initial_value: Option<&FontDescription>, ) -> Pin<Box_<dyn Future<Output = Result<FontDescription, Error>> + 'static>>
Sourcepub fn filter(&self) -> Option<Filter>
pub fn filter(&self) -> Option<Filter>
Returns the filter that decides which fonts to display in the font chooser dialog.
Returns
the filter
Sourcepub fn font_map(&self) -> Option<FontMap>
pub fn font_map(&self) -> Option<FontMap>
Returns the fontmap from which fonts are selected,
or NULL for the default fontmap.
Returns
the fontmap
Sourcepub fn is_modal(&self) -> bool
pub fn is_modal(&self) -> bool
Returns whether the font chooser dialog blocks interaction with the parent window while it is presented.
Returns
true if the font chooser dialog is modal
Sourcepub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
pub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
Adds a filter that decides which fonts to display in the font chooser dialog.
The filter must be able to handle both [pango::FontFamily][crate::pango::FontFamily]
and [pango::FontFace][crate::pango::FontFace] objects.
filter
the filter
Sourcepub fn set_font_map(&self, fontmap: Option<&impl IsA<FontMap>>)
pub fn set_font_map(&self, fontmap: Option<&impl IsA<FontMap>>)
Sets the fontmap from which fonts are selected.
If @fontmap is NULL, the default fontmap is used.
fontmap
the fontmap
Sourcepub fn set_language(&self, language: &Language)
pub fn set_language(&self, language: &Language)
Sourcepub fn set_modal(&self, modal: bool)
pub fn set_modal(&self, modal: bool)
Sets whether the font chooser dialog blocks interaction with the parent window while it is presented.
modal
the new value
pub fn connect_filter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_font_map_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_modal_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl FontDialog
impl FontDialog
Sourcepub fn choose_font_and_features<P: FnOnce(Result<(Option<FontDescription>, GString, Language), Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
initial_value: Option<&FontDescription>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn choose_font_and_features<P: FnOnce(Result<(Option<FontDescription>, GString, Language), Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, initial_value: Option<&FontDescription>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Presents a font chooser dialog to the user.
The font chooser dialog will be set up for selecting a font and specify features for the selected font.
Font features affect how the font is rendered, for example enabling glyph variants or ligatures.
parent
the parent window
initial_value
the font to select initially
cancellable
a cancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn choose_font_and_features_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, initial_value: Option<&FontDescription>, ) -> Pin<Box_<dyn Future<Output = Result<(Option<FontDescription>, GString, Language), Error>> + 'static>>