Label

Struct Label 

pub struct Label { /* private fields */ }
for more…“; GtkWidget *label = gtk_label_new (NULL); gtk_label_set_markup (GTK_LABEL (label), text);


It is possible to implement custom handling for links and their tooltips
with the [`activate-link`][struct@crate::Label#activate-link] signal and the
[`current_uri()`][Self::current_uri()] function.

## Properties


#### `attributes`
 A list of style attributes to apply to the text of the label.

Readable | Writable


#### `ellipsize`
 The preferred place to ellipsize the string, if the label does
not have enough room to display the entire string.

Note that setting this property to a value other than
[enum.Pango.EllipsizeMode.none] has the side-effect that the label requests
only enough space to display the ellipsis "...". In particular, this
means that ellipsizing labels do not work well in notebook tabs, unless
the [`tab-expand`][struct@crate::NotebookPage#tab-expand] child property is set to true.

Other ways to set a label's width are [`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()]
and [`Label::set_width_chars()`][crate::Label::set_width_chars()].

Readable | Writable


#### `extra-menu`
 A menu model whose contents will be appended to the context menu.

Readable | Writable


#### `justify`
 The alignment of the lines in the text of the label, relative to each other.

This does *not* affect the alignment of the label within its allocation.
See [`xalign`][struct@crate::Label#xalign] for that.

Readable | Writable


#### `label`
 The contents of the label.

If the string contains Pango markup (see `parse_markup()`),
you will have to set the [`use-markup`][struct@crate::Label#use-markup] property to
true in order for the label to display the markup attributes. See also
[`Label::set_markup()`][crate::Label::set_markup()] for a convenience function that sets both
this property and the [`use-markup`][struct@crate::Label#use-markup] property at the
same time.

If the string contains underlines acting as mnemonics, you will have to
set the [`use-underline`][struct@crate::Label#use-underline] property to true in order
for the label to display them.

Readable | Writable


#### `lines`
 The number of lines to which an ellipsized, wrapping label
should display before it gets ellipsized. This both prevents the label
from ellipsizing before this many lines are displayed, and limits the
height request of the label to this many lines.

::: warning
    Setting this property has unintuitive and unfortunate consequences
    for the minimum _width_ of the label. Specifically, if the height
    of the label is such that it fits a smaller number of lines than
    the value of this property, the label can not be ellipsized at all,
    which means it must be wide enough to fit all the text fully.

This property has no effect if the label is not wrapping or ellipsized.

Set this property to -1 if you don't want to limit the number of lines.

Readable | Writable


#### `max-width-chars`
 The desired maximum width of the label, in characters.

If this property is set to -1, the width will be calculated automatically.

See the section on [text layout](class.Label.html#text-layout) for details
of how [`width-chars`][struct@crate::Label#width-chars] and [`max-width-chars`][struct@crate::Label#max-width-chars]
determine the width of ellipsized and wrapped labels.

Readable | Writable


#### `mnemonic-keyval`
 The mnemonic accelerator key for the label.

Readable


#### `mnemonic-widget`
 The widget to be activated when the labels mnemonic key is pressed.

Readable | Writable


#### `natural-wrap-mode`
 Select the line wrapping for the natural size request.

This only affects the natural size requested. For the actual wrapping
used, see the [`wrap-mode`][struct@crate::Label#wrap-mode] property.

The default is [enum@Gtk.NaturalWrapMode.inherit], which inherits
the behavior of the [`wrap-mode`][struct@crate::Label#wrap-mode] property.

Readable | Writable


#### `selectable`
 Whether the label text can be selected with the mouse.

Readable | Writable


#### `single-line-mode`
 Whether the label is in single line mode.

In single line mode, the height of the label does not depend on the
actual text, it is always set to ascent + descent of the font. This
can be an advantage in situations where resizing the label because
of text changes would be distracting, e.g. in a statusbar.

Readable | Writable


#### `tabs`
 Custom tabs for this label.

Readable | Writable


#### `use-markup`
 True if the text of the label includes Pango markup.

See `parse_markup()`.

Readable | Writable


#### `use-underline`
 True if the text of the label indicates a mnemonic with an `_`
before the mnemonic character.

Readable | Writable


#### `width-chars`
 The desired width of the label, in characters.

If this property is set to -1, the width will be calculated automatically.

See the section on [text layout](class.Label.html#text-layout) for details
of how [`width-chars`][struct@crate::Label#width-chars] and [`max-width-chars`][struct@crate::Label#max-width-chars]
determine the width of ellipsized and wrapped labels.

Readable | Writable


#### `wrap`
 True if the label text will wrap if it gets too wide.

Readable | Writable


#### `wrap-mode`
 Controls how the line wrapping is done.

This only affects the formatting if line wrapping is on (see the
[`wrap`][struct@crate::Label#wrap] property). The default is [enum@Pango.WrapMode.word],
which means wrap on word boundaries.

For sizing behavior, also consider the [`natural-wrap-mode`][struct@crate::Label#natural-wrap-mode]
property.

Readable | Writable


#### `xalign`
 The horizontal alignment of the label text inside its size allocation.

Compare this to [`halign`][struct@crate::Widget#halign], which determines how the
labels size allocation is positioned in the space available for the label.

Readable | Writable


#### `yalign`
 The vertical alignment of the label text inside its size allocation.

Compare this to [`valign`][struct@crate::Widget#valign], which determines how the
labels size allocation is positioned in the space available for the label.

Readable | Writable
<details><summary><h4>Widget</h4></summary>


#### `can-focus`
 Whether the widget or any of its descendents can accept
the input focus.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `can-target`
 Whether the widget can receive pointer events.

Readable | Writable


#### `css-classes`
 A list of css classes applied to this widget.

Readable | Writable


#### `css-name`
 The name of this widget in the CSS tree.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable | Construct Only


#### `cursor`
 The cursor used by @widget.

Readable | Writable


#### `focus-on-click`
 Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writable


#### `focusable`
 Whether this widget itself will accept the input focus.

Readable | Writable


#### `halign`
 How to distribute horizontal space if widget gets extra space.

Readable | Writable


#### `has-default`
 Whether the widget is the default widget.

Readable


#### `has-focus`
 Whether the widget has the input focus.

Readable


#### `has-tooltip`
 Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.

A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.

Readable | Writable


#### `height-request`
 Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writable


#### `hexpand`
 Whether to expand horizontally.

Readable | Writable


#### `hexpand-set`
 Whether to use the `hexpand` property.

Readable | Writable


#### `layout-manager`
 The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `limit-events`
 Makes this widget act like a modal dialog, with respect to
event delivery.

Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].

Readable | Writable


#### `margin-bottom`
 Margin on bottom side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-end`
 Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-start`
 Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-top`
 Margin on top side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `name`
 The name of the widget.

Readable | Writable


#### `opacity`
 The requested opacity of the widget.

Readable | Writable


#### `overflow`
 How content outside the widget's content area is treated.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `parent`
 The parent widget of this widget.

Readable


#### `receives-default`
 Whether the widget will receive the default action when it is focused.

Readable | Writable


#### `root`
 The [`Root`][crate::Root] widget of the widget tree containing this widget.

This will be `NULL` if the widget is not contained in a root widget.

Readable


#### `scale-factor`
 The scale factor of the widget.

Readable


#### `sensitive`
 Whether the widget responds to input.

Readable | Writable


#### `tooltip-markup`
 Sets the text of tooltip to be the given string, which is marked up
with Pango markup.

Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `tooltip-text`
 Sets the text of tooltip to be the given string.

Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `valign`
 How to distribute vertical space if widget gets extra space.

Readable | Writable


#### `vexpand`
 Whether to expand vertically.

Readable | Writable


#### `vexpand-set`
 Whether to use the `vexpand` property.

Readable | Writable


#### `visible`
 Whether the widget is visible.

Readable | Writable


#### `width-request`
 Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>


#### `accessible-role`
 The accessible role of the given [`Accessible`][crate::Accessible] implementation.

The accessible role cannot be changed once set.

Readable | Writable
</details>

## Signals


#### `activate-current-link`
  key.

Action


#### `activate-link`
 Gets emitted to activate a URI.

Applications may connect to it to override the default behaviour,
which is to call [`FileLauncher::launch()`][crate::FileLauncher::launch()].




#### `copy-clipboard`
 .

Action


#### `move-cursor`
  move to the ends of the buffer

Action
<details><summary><h4>Widget</h4></summary>


#### `destroy`
 Signals that all holders of a reference to the widget should release
the reference that they hold.

May result in finalization of the widget if all references are released.

This signal is not suitable for saving widget state.




#### `direction-changed`
 Emitted when the text direction of a widget changes.




#### `hide`
 Emitted when @widget is hidden.




#### `keynav-failed`
 Emitted if keyboard navigation fails.

See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.




#### `map`
 Emitted when @widget is going to be mapped.

A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.

The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].




#### `mnemonic-activate`
 Emitted when a widget is activated via a mnemonic.

The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.




#### `move-focus`
  to move backward.

Action


#### `query-tooltip`
 s tooltip is about to be shown.

This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.

Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.

The signal handler is free to manipulate @tooltip with the therefore
destined function calls.




#### `realize`
 Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].

This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).




#### `show`
 Emitted when @widget is shown.




#### `state-flags-changed`
 Emitted when the widget state changes.

See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].




#### `unmap`
 Emitted when @widget is going to be unmapped.

A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.

As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.




#### `unrealize`
 Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.

This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).


</details>

# Implements

[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`AccessibleHypertextExt`][trait@crate::prelude::AccessibleHypertextExt], [`AccessibleTextExt`][trait@crate::prelude::AccessibleTextExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Label

pub fn new(str: Option<&str>) -> Label

Creates a new label with the given text inside it.

You can pass NULL to get an empty label widget.

str

the text of the label

Returns

the new label

pub fn with_mnemonic(str: &str) -> Label

Creates a new label with the given text inside it, and a mnemonic.

If characters in @str are preceded by an underscore, they are underlined. If you need a literal underscore character in a label, use ‘__’ (two underscores). The first underlined character represents a keyboard accelerator called a mnemonic. The mnemonic key can be used to activate another widget, chosen automatically, or explicitly using set_mnemonic_widget().

If set_mnemonic_widget() is not called, then the first activatable ancestor of the label will be chosen as the mnemonic widget. For instance, if the label is inside a button or menu item, the button or menu item will automatically become the mnemonic widget and be activated by the mnemonic.

str

the text of the label, with an underscore in front of the mnemonic character

Returns

the new label

pub fn builder() -> LabelBuilder

Creates a new builder-pattern struct instance to construct Label objects.

This method returns an instance of LabelBuilder which can be used to create Label objects.

pub fn attributes(&self) -> Option<AttrList>

Gets the label’s attribute list.

This is the pango::AttrList that was set on the label using set_attributes(), if any. This function does not reflect attributes that come from the label’s markup (see set_markup()). If you want to get the effective attributes for the label, use pango_layout_get_attributes (gtk_label_get_layout (self)).

Returns

the attribute list

pub fn current_uri(&self) -> Option<GString>

Returns the URI for the active link in the label.

The active link is the one under the mouse pointer or, in a selectable label, the link in which the text cursor is currently positioned.

This function is intended for use in a activate-link handler or for use in a query-tooltip handler.

Returns

the active URI

pub fn ellipsize(&self) -> EllipsizeMode

Returns the ellipsization mode of the label.

See set_ellipsize().

Returns

the ellipsization mode

pub fn extra_menu(&self) -> Option<MenuModel>

Gets the extra menu model of the label.

See set_extra_menu().

Returns

the menu model

pub fn justify(&self) -> Justification

Returns the justification of the label.

See set_justify().

Returns

the justification value

pub fn label(&self) -> GString

Fetches the text from a label.

The returned text includes any embedded underlines indicating mnemonics and Pango markup. (See text()).

Returns

the text of the label widget

pub fn layout(&self) -> Layout

Gets the Pango layout used to display the label.

The layout is useful to e.g. convert text positions to pixel positions, in combination with layout_offsets(). The returned layout is owned by the @label so need not be freed by the caller. The @label is free to recreate its layout at any time, so it should be considered read-only.

Returns

the pango::Layout for this label

pub fn layout_offsets(&self) -> (i32, i32)

Obtains the coordinates where the label will draw its Pango layout.

The coordinates are useful to convert mouse events into coordinates inside the pango::Layout, e.g. to take some action if some part of the label is clicked. Remember when using the pango::Layout functions you need to convert to and from pixels using PANGO_PIXELS() or Pango::SCALE.

Returns
x

location to store X offset of layout

y

location to store Y offset of layout

pub fn lines(&self) -> i32

Gets the number of lines to which an ellipsized, wrapping label should be limited.

See set_lines().

Returns

the number of lines

pub fn max_width_chars(&self) -> i32

Retrieves the maximum width of the label in characters.

See set_width_chars().

Returns

the maximum width of the label, in characters

pub fn mnemonic_widget(&self) -> Option<Widget>

Retrieves the mnemonic target of this label.

See set_mnemonic_widget().

Returns

s mnemonic, or NULL if none has been set and the default algorithm will be used.

pub fn natural_wrap_mode(&self) -> NaturalWrapMode

Available on crate feature v4_6 only.

Returns natural line wrap mode used by the label.

See set_natural_wrap_mode().

Returns

the natural line wrap mode

pub fn is_selectable(&self) -> bool

Returns whether the label is selectable.

Returns

true if the user can copy text from the label

pub fn selection_bounds(&self) -> Option<(i32, i32)>

Gets the selected range of characters in the label.

The returned @start and @end positions are in characters.

Returns

true if selection is non-empty

start

return location for start of selection

end

return location for end of selection

pub fn is_single_line_mode(&self) -> bool

Returns whether the label is in single line mode.

Returns

true if the label is in single line mode

pub fn tabs(&self) -> Option<TabArray>

Available on crate feature v4_8 only.

(8-space) tabs are used.

Returns

copy of default tab array, or NULL if standard tabs are used

pub fn text(&self) -> GString

Gets the text of the label.

The returned text is as it appears on screen. This does not include any embedded underlines indicating mnemonics or Pango markup. (See label())

Returns

the text in the label widget

pub fn uses_markup(&self) -> bool

s text is interpreted as Pango markup.

See set_use_markup().

Returns

s text will be parsed for markup

pub fn uses_underline(&self) -> bool

Returns whether underlines in the label indicate mnemonics.

See set_use_underline().

Returns

true if underlines in the label indicate mnemonics

pub fn width_chars(&self) -> i32

Retrieves the desired width of the label in characters.

See set_width_chars().

Returns

the desired width of the label, in characters

pub fn wraps(&self) -> bool

Returns whether lines in the label are automatically wrapped.

See set_wrap().

Returns

true if the lines of the label are automatically wrapped

pub fn wrap_mode(&self) -> WrapMode

Returns line wrap mode used by the label.

See set_wrap_mode().

Returns

the line wrap mode

pub fn xalign(&self) -> f32

Gets the xalign of the label.

See the xalign property.

Returns

the xalign value

pub fn yalign(&self) -> f32

Gets the yalign of the label.

See the yalign property.

Returns

the yalign value

pub fn select_region(&self, start_offset: i32, end_offset: i32)

Selects a range of characters in the label, if the label is selectable.

See set_selectable(). If the label is not selectable, this function has no effect. If @start_offset or @end_offset are -1, then the end of the label will be substituted.

start_offset

start offset, in characters

end_offset

end offset, in characters

pub fn set_attributes(&self, attrs: Option<&AttrList>)

Apply attributes to the label text.

The attributes set with this function will be applied and merged with any other attributes previously effected by way of the use-underline or use-markup properties

While it is not recommended to mix markup strings with manually set attributes, if you must; know that the attributes will be applied to the label after the markup string is parsed.

attrs

a list of style attributes

pub fn set_ellipsize(&self, mode: EllipsizeMode)

Sets the mode used to ellipsize the text.

The text will be ellipsized if there is not enough space to render the entire string.

mode

the ellipsization mode

pub fn set_extra_menu(&self, model: Option<&impl IsA<MenuModel>>)

Sets a menu model to add to the context menu of the label.

model

a menu model

pub fn set_justify(&self, jtype: Justification)

Sets the alignment of lines in the label relative to each other.

This function has no effect on labels containing only a single line.

[enum@Gtk.Justification.left] is the default value when the widget is first created with new().

If you instead want to set the alignment of the label as a whole, use WidgetExt::set_halign() instead.

jtype

the new justification

pub fn set_label(&self, str: &str)

Sets the text of the label.

The label is interpreted as including embedded underlines and/or Pango markup depending on the values of the use-underline and use-markup properties.

str

the new text to set for the label

pub fn set_lines(&self, lines: i32)

t want to limit the number of lines.

lines

the desired number of lines, or -1

pub fn set_markup(&self, str: &str)

“; char *markup;

markup = g_markup_printf_escaped (format, str); gtk_label_set_markup (GTK_LABEL (self), markup); g_free (markup);


This function sets the [`use-markup`][struct@crate::Label#use-markup] property
to true.

Also see [`set_text()`][Self::set_text()].
## `str`
the markup string
pub fn set_markup_with_mnemonic(&self, str: &str)

s text and attribute list based on the parse results. If characters in @str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.

The mnemonic key can be used to activate another widget, chosen automatically, or explicitly using set_mnemonic_widget().

str

the markup string

pub fn set_max_width_chars(&self, n_chars: i32)

Sets the maximum width of the label in characters.

n_chars

the new maximum width, in characters.

pub fn set_mnemonic_widget(&self, widget: Option<&impl IsA<Widget>>)

Associate the label with its mnemonic target.

If the label has been set so that it has a mnemonic key (using i.e. set_markup_with_mnemonic(), set_text_with_mnemonic(), with_mnemonic() or the use_underline property) the label can be associated with a widget that is the target of the mnemonic. When the label is inside a widget (like a Button or a Notebook tab) it is automatically associated with the correct widget, but sometimes (i.e. when the target is a Entry next to the label) you need to set it explicitly using this function.

The target widget will be accelerated by emitting the mnemonic-activate signal on it. The default handler for this signal will activate the widget if there are no mnemonic collisions and toggle focus between the colliding widgets otherwise.

widget

the target widget

pub fn set_natural_wrap_mode(&self, wrap_mode: NaturalWrapMode)

Available on crate feature v4_6 only.

Selects the line wrapping for the natural size request.

This only affects the natural size requested, for the actual wrapping used, see the wrap-mode property.

wrap_mode

the line wrapping mode

pub fn set_selectable(&self, setting: bool)

Makes text in the label selectable.

Selectable labels allow the user to select text from the label, for copy-and-paste.

setting

true to allow selecting text in the label

pub fn set_single_line_mode(&self, single_line_mode: bool)

Sets whether the label is in single line mode.

single_line_mode

true to enable single line mode

pub fn set_tabs(&self, tabs: Option<&TabArray>)

Available on crate feature v4_8 only.

Sets tab stops for the label.

tabs

tab stops

pub fn set_text(&self, str: &str)

Sets the text for the label.

It overwrites any text that was there before and clears any previously set mnemonic accelerators, and sets the use-underline and use-markup properties to false.

Also see set_markup().

str

the text to show in @self

pub fn set_text_with_mnemonic(&self, str: &str)

Sets the text for the label, with mnemonics.

If characters in @str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic. The mnemonic key can be used to activate another widget, chosen automatically, or explicitly using set_mnemonic_widget().

str

the text

pub fn set_use_markup(&self, setting: bool)

Sets whether the text of the label contains markup.

See set_markup().

setting

s text should be parsed for markup.

pub fn set_use_underline(&self, setting: bool)

Sets whether underlines in the text indicate mnemonics.

setting

true if underlines in the text indicate mnemonics

pub fn set_width_chars(&self, n_chars: i32)

Sets the desired width in characters of the label.

n_chars

the new desired width, in characters.

pub fn set_wrap(&self, wrap: bool)

s width using WidgetExt::set_size_request().

wrap

whether to wrap lines

pub fn set_wrap_mode(&self, wrap_mode: WrapMode)

Controls how line wrapping is done.

This only affects the label if line wrapping is on. (See set_wrap())

The default is [enum@Pango.WrapMode.word], which means wrap on word boundaries.

For sizing behavior, also consider the natural-wrap-mode property.

wrap_mode

the line wrapping mode

pub fn set_xalign(&self, xalign: f32)

Sets the xalign of the label.

See the xalign property.

xalign

the new xalign value, between 0 and 1

pub fn set_yalign(&self, yalign: f32)

Sets the yalign of the label.

See the yalign property.

yalign

the new yalign value, between 0 and 1

key.

Gets emitted to activate a URI.

Applications may connect to it to override the default behaviour, which is to call FileLauncher::launch().

uri

the URI that is activated

Returns

true if the link has been activated

pub fn connect_copy_clipboard<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

.

pub fn emit_copy_clipboard(&self)

pub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool) + 'static>( &self, f: F, ) -> SignalHandlerId

move to the ends of the buffer

step

the granularity of the move, as a MovementStep

count

the number of @step units to move

extend_selection

true if the move should extend the selection

pub fn emit_move_cursor( &self, step: MovementStep, count: i32, extend_selection: bool, )

pub fn connect_attributes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_ellipsize_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_extra_menu_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_justify_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_lines_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_max_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_mnemonic_keyval_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_mnemonic_widget_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_natural_wrap_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v4_6 only.
pub fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_single_line_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_tabs_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v4_8 only.
pub fn connect_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_use_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_wrap_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_wrap_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_xalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_yalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Source

impl Label

pub fn mnemonic_keyval(&self) -> Key

Return the mnemonic accelerator.

If the label has been set so that it has a mnemonic key this function returns the keyval used for the mnemonic accelerator. If there is no mnemonic set up it returns GDK_KEY_VoidSymbol.

Returns

GDK keyval usable for accelerators, or GDK_KEY_VoidSymbol