pub struct LayoutChild { /* private fields */ }Expand description
The base class for objects that are meant to hold layout properties.
If a LayoutManager has per-child properties, like their packing type,
or the horizontal and vertical span, or the icon name, then the layout
manager should use a LayoutChild implementation to store those properties.
A LayoutChild instance is only ever valid while a widget is part
of a layout.
This is an Abstract Base Class, you cannot instantiate it.
Properties
child-widget
The widget that is associated to the LayoutChild instance.
Readable | Writable | Construct Only
layout-manager
The layout manager that created the LayoutChild instance.
Readable | Writable | Construct Only
Implements
LayoutChildExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl LayoutChild
impl LayoutChild
pub const NONE: Option<&'static LayoutChild> = None