pub struct ListBox { /* private fields */ }Expand description
row[.activatable]
[`ListBox`][crate::ListBox] uses a single CSS node named list. It may carry the .separators
style class, when the [`show-separators`][struct@crate::ListBox#show-separators] property is set.
Each [`ListBoxRow`][crate::ListBoxRow] uses a single CSS node named row. The row nodes get the
.activatable style class added when appropriate.
It may also carry the .boxed-list style class. In this case, the list will be
automatically surrounded by a frame and have separators.
The main list node may also carry style classes to select
the style of [list presentation](https://docs.gtk.org/gtk4/section-list-widget.html#list-styles):
.rich-list, .navigation-sidebar or .data-table.
# Accessibility
[`ListBox`][crate::ListBox] uses the [enum@Gtk.AccessibleRole.list] role and [`ListBoxRow`][crate::ListBoxRow] uses
the [enum@Gtk.AccessibleRole.list_item] role.
## Properties
#### `accept-unpaired-release`
Whether to accept unpaired release events.
Readable | Writable
#### `activate-on-single-click`
Determines whether children can be activated with a single
click, or require a double-click.
Readable | Writable
#### `selection-mode`
The selection mode used by the list box.
Readable | Writable
#### `show-separators`
Whether to show separators between rows.
Readable | Writable
#### `tab-behavior`
key
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
## Signals
#### `activate-cursor-row`
Emitted when the cursor row is activated.
Action
#### `move-cursor`
move vertically by pages
Action
#### `row-activated`
Emitted when a row has been activated by the user.
#### `row-selected`
Emitted when a new row is selected, or (with a [`None`] @row)
when the selection is cleared.
When the @box_ is using [`SelectionMode::Multiple`][crate::SelectionMode::Multiple], this signal will not
give you the full picture of selection changes, and you should use
the [`selected-rows-changed`][struct@crate::ListBox#selected-rows-changed] signal instead.
#### `select-all`
.
Action
#### `selected-rows-changed`
Emitted when the set of selected rows changes.
#### `toggle-cursor-row`
.
Action
#### `unselect-all`
.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ListBox
impl ListBox
Sourcepub fn builder() -> ListBoxBuilder
pub fn builder() -> ListBoxBuilder
Creates a new builder-pattern struct instance to construct ListBox objects.
This method returns an instance of ListBoxBuilder which can be used to create ListBox objects.
Sourcepub fn bind_model<P: Fn(&Object) -> Widget + 'static>(
&self,
model: Option<&impl IsA<ListModel>>,
create_widget_func: P,
)
pub fn bind_model<P: Fn(&Object) -> Widget + 'static>( &self, model: Option<&impl IsA<ListModel>>, create_widget_func: P, )
Binds @model to @self.
If @self was already bound to a model, that previous binding is destroyed.
The contents of @self are cleared and then filled with widgets that
represent items from @model. @self is updated whenever @model changes.
If @model is None, @self is left empty.
It is undefined to add or remove widgets directly (for example, with
insert()) while @self is bound to a model.
Note that using a model is incompatible with the filtering and sorting
functionality in ListBox. When using a model, filtering and sorting
should be implemented by the model.
model
the GListModel to be bound to @self
create_widget_func
a function
that creates widgets for items or None in case you also passed None as @model
Sourcepub fn drag_highlight_row(&self, row: &impl IsA<ListBoxRow>)
pub fn drag_highlight_row(&self, row: &impl IsA<ListBoxRow>)
Add a drag highlight to a row.
This is a helper function for implementing DnD onto a ListBox.
The passed in @row will be highlighted by setting the
StateFlags::DROP_ACTIVE state and any previously highlighted
row will be unhighlighted.
The row will also be unhighlighted when the widget gets a drag leave event.
row
Sourcepub fn drag_unhighlight_row(&self)
pub fn drag_unhighlight_row(&self)
If a row has previously been highlighted via gtk_list_box_drag_highlight_row(), it will have the highlight removed.
Sourcepub fn activates_on_single_click(&self) -> bool
pub fn activates_on_single_click(&self) -> bool
Sourcepub fn adjustment(&self) -> Option<Adjustment>
pub fn adjustment(&self) -> Option<Adjustment>
Gets the adjustment (if any) that the widget uses to for vertical scrolling.
Returns
the adjustment
Sourcepub fn row_at_index(&self, index_: i32) -> Option<ListBoxRow>
pub fn row_at_index(&self, index_: i32) -> Option<ListBoxRow>
Sourcepub fn row_at_y(&self, y: i32) -> Option<ListBoxRow>
pub fn row_at_y(&self, y: i32) -> Option<ListBoxRow>
Sourcepub fn selected_row(&self) -> Option<ListBoxRow>
pub fn selected_row(&self) -> Option<ListBoxRow>
Gets the selected row, or None if no rows are selected.
Note that the box may allow multiple selection, in which
case you should use selected_foreach() to
find all selected rows.
Returns
the selected row
Sourcepub fn selected_rows(&self) -> Vec<ListBoxRow>
pub fn selected_rows(&self) -> Vec<ListBoxRow>
Sourcepub fn selection_mode(&self) -> SelectionMode
pub fn selection_mode(&self) -> SelectionMode
Sourcepub fn shows_separators(&self) -> bool
pub fn shows_separators(&self) -> bool
Sourcepub fn tab_behavior(&self) -> ListTabBehavior
Available on crate feature v4_18 only.
pub fn tab_behavior(&self) -> ListTabBehavior
v4_18 only.Sourcepub fn insert(&self, child: &impl IsA<Widget>, position: i32)
pub fn insert(&self, child: &impl IsA<Widget>, position: i32)
Insert the @child into the @self at @position.
If a sort function is set, the widget will actually be inserted at the calculated position.
If @position is -1, or larger than the total number of items in the @self, then the @child will be appended to the end.
child
the Widget to add
position
the position to insert @child in
Sourcepub fn invalidate_filter(&self)
pub fn invalidate_filter(&self)
Update the filtering for all rows.
Call this when result of the filter function on the @self is changed due to an external factor. For instance, this would be used if the filter function just looked for a specific search string and the entry with the search string has changed.
Sourcepub fn invalidate_headers(&self)
pub fn invalidate_headers(&self)
Update the separators for all rows.
Call this when result of the header function on the @self is changed due to an external factor.
Sourcepub fn invalidate_sort(&self)
pub fn invalidate_sort(&self)
Update the sorting for all rows.
Call this when result of the sort function on the @self is changed due to an external factor.
Sourcepub fn remove_all(&self)
Available on crate feature v4_12 only.
pub fn remove_all(&self)
v4_12 only.Removes all rows from @self.
This function does nothing if @self is backed by a model.
Sourcepub fn select_all(&self)
pub fn select_all(&self)
Select all children of @self, if the selection mode allows it.
Sourcepub fn select_row(&self, row: Option<&impl IsA<ListBoxRow>>)
pub fn select_row(&self, row: Option<&impl IsA<ListBoxRow>>)
Sourcepub fn selected_foreach<P: FnMut(&ListBox, &ListBoxRow)>(&self, func: P)
pub fn selected_foreach<P: FnMut(&ListBox, &ListBoxRow)>(&self, func: P)
Calls a function for each selected child.
Note that the selection cannot be modified from within this function.
func
the function to call for each selected child
Sourcepub fn set_activate_on_single_click(&self, single: bool)
pub fn set_activate_on_single_click(&self, single: bool)
Sourcepub fn set_adjustment(&self, adjustment: Option<&impl IsA<Adjustment>>)
pub fn set_adjustment(&self, adjustment: Option<&impl IsA<Adjustment>>)
Sets the adjustment (if any) that the widget uses to for vertical scrolling.
For instance, this is used to get the page size for PageUp/Down key handling.
In the normal case when the @self is packed inside
a ScrolledWindow the adjustment from that will
be picked up automatically, so there is no need
to manually do that.
adjustment
the adjustment
Sourcepub fn set_filter_func<P: Fn(&ListBoxRow) -> bool + 'static>(
&self,
filter_func: P,
)
pub fn set_filter_func<P: Fn(&ListBoxRow) -> bool + 'static>( &self, filter_func: P, )
By setting a filter function on the @self one can decide dynamically which of the rows to show.
For instance, to implement a search function on a list that filters the original list to only show the matching rows.
The @filter_func will be called for each row after the call, and
it will continue to be called each time a row changes (via
ListBoxRowExt::changed()) or when invalidate_filter()
is called.
Note that using a filter function is incompatible with using a model
(see bind_model()).
filter_func
callback that lets you filter which rows to show
Sourcepub fn set_header_func<P: Fn(&ListBoxRow, Option<&ListBoxRow>) + 'static>(
&self,
update_header: P,
)
pub fn set_header_func<P: Fn(&ListBoxRow, Option<&ListBoxRow>) + 'static>( &self, update_header: P, )
t affect the header. In this case it is important for performance to not blindly replace an existing header with an identical one.
The @update_header function will be called for each row after the call,
and it will continue to be called each time a row changes (via
ListBoxRowExt::changed()) and when the row before changes (either
by ListBoxRowExt::changed() on the previous row, or when the previous
row becomes a different row). It is also called for all rows when
invalidate_headers() is called.
update_header
callback that lets you add row headers
Sourcepub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
pub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
Sourcepub fn set_selection_mode(&self, mode: SelectionMode)
pub fn set_selection_mode(&self, mode: SelectionMode)
Sourcepub fn set_show_separators(&self, show_separators: bool)
pub fn set_show_separators(&self, show_separators: bool)
Sourcepub fn set_tab_behavior(&self, behavior: ListTabBehavior)
Available on crate feature v4_18 only.
pub fn set_tab_behavior(&self, behavior: ListTabBehavior)
v4_18 only.Sourcepub fn unselect_all(&self)
pub fn unselect_all(&self)
Unselect all children of @self, if the selection mode allows it.
Sourcepub fn unselect_row(&self, row: &impl IsA<ListBoxRow>)
pub fn unselect_row(&self, row: &impl IsA<ListBoxRow>)
Sourcepub fn accepts_unpaired_release(&self) -> bool
pub fn accepts_unpaired_release(&self) -> bool
Whether to accept unpaired release events.
Sourcepub fn set_accept_unpaired_release(&self, accept_unpaired_release: bool)
pub fn set_accept_unpaired_release(&self, accept_unpaired_release: bool)
Whether to accept unpaired release events.
Sourcepub fn connect_activate_cursor_row<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activate_cursor_row<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the cursor row is activated.
pub fn emit_activate_cursor_row(&self)
Sourcepub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) + 'static>( &self, f: F, ) -> SignalHandlerId
move vertically by pages
step
the granularity of the move, as a MovementStep
count
the number of @step units to move
extend
whether to extend the selection
modify
whether to modify the selection
pub fn emit_move_cursor( &self, step: MovementStep, count: i32, extend: bool, modify: bool, )
Sourcepub fn connect_row_activated<F: Fn(&Self, &ListBoxRow) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_row_activated<F: Fn(&Self, &ListBoxRow) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_row_selected<F: Fn(&Self, Option<&ListBoxRow>) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_row_selected<F: Fn(&Self, Option<&ListBoxRow>) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a new row is selected, or (with a None @row)
when the selection is cleared.
When the @box_ is using SelectionMode::Multiple, this signal will not
give you the full picture of selection changes, and you should use
the selected-rows-changed signal instead.
row
the selected row
Sourcepub fn connect_select_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_select_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_select_all(&self)
Sourcepub fn connect_selected_rows_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_selected_rows_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the set of selected rows changes.
Sourcepub fn connect_toggle_cursor_row<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_toggle_cursor_row<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_toggle_cursor_row(&self)
Sourcepub fn connect_unselect_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_unselect_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_unselect_all(&self)
pub fn connect_accept_unpaired_release_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_activate_on_single_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selection_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_separators_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_tab_behavior_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_18 only.Sourceimpl ListBox
impl ListBox
pub fn unbind_model(&self)
pub fn unset_filter_func(&self)
pub fn unset_header_func(&self)
Sourcepub fn set_sort_func<P: Fn(&ListBoxRow, &ListBoxRow) -> Ordering + 'static>(
&self,
sort_func: P,
)
pub fn set_sort_func<P: Fn(&ListBoxRow, &ListBoxRow) -> Ordering + 'static>( &self, sort_func: P, )
Sets a sort function.
By setting a sort function on the @self one can dynamically reorder the rows of the list, based on the contents of the rows.
The @sort_func will be called for each row after the call, and will
continue to be called each time a row changes (via
ListBoxRowExt::changed()) and when invalidate_sort()
is called.
Note that using a sort function is incompatible with using a model
(see bind_model()).
sort_func
the sort function
pub fn unset_sort_func(&self)