ListStore

Struct ListStore 

pub struct ListStore { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

Use Gio::ListStore instead A list-like data structure that can be used with the TreeView.

The ListStore object is a list model for use with a TreeView widget. It implements the TreeModel interface, and consequentialy, can use all of the methods available there. It also implements the TreeSortable interface so it can be sorted by the view. Finally, it also implements the tree drag and drop interfaces.

The ListStore can accept most GTypes as a column type, though it canโ€™t accept all custom types. Internally, it will keep a copy of data passed in (such as a string or a boxed pointer). Columns that accept GObjects are handled a little differently. The ListStore will keep a reference to the object instead of copying the value. As a result, if the object is modified, it is up to the application writer to call TreeModelExt::row_changed() to emit the row_changed signal. This most commonly affects lists with gdk::Textures stored.

An example for creating a simple list store:

โš ๏ธ The following code is in c โš ๏ธ

enum {
  COLUMN_STRING,
  COLUMN_INT,
  COLUMN_BOOLEAN,
  N_COLUMNS
};

{
  GtkListStore *list_store;
  GtkTreePath *path;
  GtkTreeIter iter;
  int i;

  list_store = gtk_list_store_new (N_COLUMNS,
                                   G_TYPE_STRING,
                                   G_TYPE_INT,
                                   G_TYPE_BOOLEAN);

  for (i = 0; i < 10; i++)
    {
      char *some_data;

      some_data = get_some_data (i);

      // Add a new row to the model
      gtk_list_store_append (list_store, &iter);
      gtk_list_store_set (list_store, &iter,
                          COLUMN_STRING, some_data,
                          COLUMN_INT, i,
                          COLUMN_BOOLEAN,  FALSE,
                          -1);

      // As the store will keep a copy of the string internally,
      // we free some_data.
      g_free (some_data);
    }

  // Modify a particular row
  path = gtk_tree_path_new_from_string ("4");
  gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store),
                           &iter,
                           path);
  gtk_tree_path_free (path);
  gtk_list_store_set (list_store, &iter,
                      COLUMN_BOOLEAN, TRUE,
                      -1);
}

ListStore is deprecated since GTK 4.10, and should not be used in newly written code. You should use Gio::ListStore instead, and the various list models provided by GTK.

Performance Considerations

Internally, the ListStore was originally implemented with a linked list with a tail pointer. As a result, it was fast at data insertion and deletion, and not fast at random data access. The ListStore sets the GTK_TREE_MODEL_ITERS_PERSIST flag, which means that TreeIters can be cached while the row exists. Thus, if access to a particular row is needed often and your code is expected to run on older versions of GTK, it is worth keeping the iter around.

Atomic Operations

It is important to note that only the methods gtk_list_store_insert_with_values() and gtk_list_store_insert_with_valuesv() are atomic, in the sense that the row is being appended to the store and the values filled in in a single operation with regard to TreeModel signaling. In contrast, using e.g. gtk_list_store_append() and then gtk_list_store_set() will first create a row, which triggers the GtkTreeModel::row-inserted signal on ListStore. The row, however, is still empty, and any signal handler connecting to GtkTreeModel::row-inserted on this particular store should be prepared for the situation that the row might be empty. This is especially important if you are wrapping the ListStore inside a TreeModelFilter and are using a TreeModelFilterVisibleFunc. Using any of the non-atomic operations to append rows to the ListStore will cause the TreeModelFilterVisibleFunc to be visited with an empty row first; the function must be prepared for that.

GtkListStore as GtkBuildable

The GtkListStore implementation of the Buildable interface allows to specify the model columns with a <columns> element that may contain multiple <column> elements, each specifying one model column. The โ€œtypeโ€ attribute specifies the data type for the column.

Additionally, it is possible to specify content for the list store in the UI definition, with the <data> element. It can contain multiple <row> elements, each specifying to content for one row of the list model. Inside a <row>, the <col> elements specify the content for individual cells.

Note that it is probably more common to define your models in the code, and one might consider it a layering violation to specify the content of a list store in a UI definition, data, not presentation, and common wisdom is to separate the two, as far as possible.

An example of a UI Definition fragment for a list store:

<object class="GtkListStore">
  <columns>
    <column type="gchararray"/>
    <column type="gchararray"/>
    <column type="gint"/>
  </columns>
  <data>
    <row>
      <col id="0">John</col>
      <col id="1">Doe</col>
      <col id="2">25</col>
    </row>
    <row>
      <col id="0">Johan</col>
      <col id="1">Dahlin</col>
      <col id="2">50</col>
    </row>
  </data>
</object>

Implements

[trait@glib::ObjectExt], BuildableExt, TreeDragDestExt, TreeDragSourceExt, TreeModelExt, TreeSortableExt, TreeModelExtManual, TreeSortableExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl ListStore

pub fn append(&self) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

Appends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

Returns
iter

An unset TreeIter to set to the appended row

pub fn clear(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Removes all rows from the list store.

Deprecated since 4.10

Use list models

pub fn insert(&self, position: i32) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new row at @position. @iter will be changed to point to this new row. If @position is -1 or is larger than the number of rows on the list, then the new row will be appended to the list. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

position

position to insert the new row, or -1 for last

Returns
iter

An unset TreeIter to set to the new row

pub fn insert_after(&self, sibling: Option<&TreeIter>) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

Inserts a new row after @sibling. If @sibling is None, then the row will be prepended to the beginning of the list. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

sibling

A valid TreeIter

Returns
iter

An unset TreeIter to set to the new row

pub fn insert_before(&self, sibling: Option<&TreeIter>) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

Inserts a new row before @sibling. If @sibling is None, then the row will be appended to the end of the list. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

sibling

A valid TreeIter

Returns
iter

An unset TreeIter to set to the new row

pub fn iter_is_valid(&self, iter: &TreeIter) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Checks if the given iter is a valid iter for this ListStore.

This function is slow. Only use it for debugging and/or testing purposes.

Deprecated since 4.10

Use list models

iter

the iterator to check

Returns

true if the iter is valid, false if the iter is invalid.

pub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Moves @iter in @self to the position after @position. Note that this function only works with unsorted stores. If @position is None, @iter will be moved to the start of the list.

Deprecated since 4.10

Use list models

iter

A TreeIter

position

A TreeIter

pub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Moves @iter in @self to the position before @position. Note that this function only works with unsorted stores. If @position is None, @iter will be moved to the end of the list.

Deprecated since 4.10

Use list models

iter

A TreeIter

position

A TreeIter

pub fn prepend(&self) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

Prepends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

Returns
iter

An unset TreeIter to set to the prepend row

pub fn remove(&self, iter: &TreeIter) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Removes the given row from the list store. After being removed, @iter is set to be the next valid row, or invalidated if it pointed to the last row in @self.

Deprecated since 4.10

Use list models

iter

A valid TreeIter

Returns

true if @iter is valid, false if not.

pub fn swap(&self, a: &TreeIter, b: &TreeIter)

๐Ÿ‘ŽDeprecated:

Since 4.10

Swaps @a and @b in @self. Note that this function only works with unsorted stores.

Deprecated since 4.10

Use list models

a

A TreeIter

b

Another TreeIter

Source

impl ListStore

pub fn new(column_types: &[Type]) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new list store.

The list store will have @n_columns columns, with each column using the given type passed to this function.

Note that only types derived from standard GObject fundamental types are supported.

As an example:

โš ๏ธ The following code is in c โš ๏ธ

gtk_list_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_TEXTURE);

will create a new ListStore with three columns, of type int, gchararray and gdk::Texture, respectively.

Deprecated since 4.10

Use Gio::ListStore instead

Returns

a new ListStore

pub fn insert_with_values( &self, position: Option<u32>, columns_and_values: &[(u32, &dyn ToValue)], ) -> TreeIter

๐Ÿ‘ŽDeprecated:

Since 4.10

A variant of gtk_list_store_insert_with_values() which takes the columns and values as two arrays, instead of varargs.

This function is mainly intended for language-bindings.

Deprecated since 4.10

Use list models

position

position to insert the new row, or -1 for last

columns

an array of column numbers

values

an array of GValues

Returns
iter

An unset TreeIter to set to the new row

pub fn reorder(&self, new_order: &[u32])

๐Ÿ‘ŽDeprecated:

Since 4.10

Reorders @self to follow the order indicated by @new_order. Note that this function only works with unsorted stores.

Deprecated since 4.10

Use list models

new_order

an array of integers mapping the new position of each child to its old position before the re-ordering, i.e. @new_order[newpos] = oldpos. It must have exactly as many items as the list storeโ€™s length.

pub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the value of one or more cells in the row referenced by @iter. The variable argument list should contain integer column numbers, each column number followed by the value to be set. The list is terminated by a -1. For example, to set column 0 with type G_TYPE_STRING to โ€œFooโ€, you would write gtk_list_store_set (store, iter, 0, "Foo", -1).

The value will be referenced by the store if it is a G_TYPE_OBJECT, and it will be copied if it is a G_TYPE_STRING or G_TYPE_BOXED.

Deprecated since 4.10

Use list models

iter

row iterator

pub fn set_column_types(&self, types: &[Type])

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the types of the columns of a list store.

This function is meant primarily for objects that inherit from ListStore, and should only be used when constructing a new instance.

This function cannot be called after a row has been added, or a method on the TreeModel interface is called.

Deprecated since 4.10

Use list models

types

An array length n of GTypes

pub fn set_value(&self, iter: &TreeIter, column: u32, value: &Value)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the data in the cell specified by @iter and @column. The type of @value must be convertible to the type of the column.

Deprecated since 4.10

Use list models

iter

A valid TreeIter for the row being modified

column

column number to modify

value

new value for the cell