pub struct MountOperation { /* private fields */ }Expand description
Asks the user for passwords and other information required to mount a volume.
MountOperation is needed when mounting volumes:
It is an implementation of GMountOperation that can be used with
GIO functions for mounting volumes such as
[FileExtManual::mount_enclosing_volume()][crate::gio::prelude::FileExtManual::mount_enclosing_volume()],
[FileExtManual::mount_mountable()][crate::gio::prelude::FileExtManual::mount_mountable()],
Gio::Volume::mount(),
Gio::Mount::unmount_with_operation() and others.
When necessary, MountOperation shows dialogs to let the user
enter passwords, ask questions or show processes blocking unmount.
Properties
display
The display where dialogs will be shown.
Readable | Writable
is-showing
Whether a dialog is currently shown.
Readable
parent
The parent window.
Readable | Writable
MountOperation
anonymous
Whether to use an anonymous user when authenticating.
Readable | Writable
choice
The index of the user’s choice when a question is asked during the mount operation. See the #GMountOperation::ask-question signal.
Readable | Writable
domain
The domain to use for the mount operation.
Readable | Writable
is-tcrypt-hidden-volume
Whether the device to be unlocked is a TCRYPT hidden volume. See the VeraCrypt documentation.
Readable | Writable
is-tcrypt-system-volume
Whether the device to be unlocked is a TCRYPT system volume. In this context, a system volume is a volume with a bootloader and operating system installed. This is only supported for Windows operating systems. For further documentation, see the VeraCrypt documentation.
Readable | Writable
password
The password that is used for authentication when carrying out the mount operation.
Readable | Writable
password-save
Determines if and how the password information should be saved.
Readable | Writable
pim
The VeraCrypt PIM value, when unlocking a VeraCrypt volume. See the VeraCrypt documentation.
Readable | Writable
username
The user name that is used for authentication when carrying out the mount operation.
Readable | Writable
Implements
GtkMountOperationExt, [trait@gio::prelude::MountOperationExt], [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl MountOperation
impl MountOperation
pub const NONE: Option<&'static MountOperation> = None
Sourcepub fn new(parent: Option<&impl IsA<Window>>) -> MountOperation
pub fn new(parent: Option<&impl IsA<Window>>) -> MountOperation
Sourcepub fn builder() -> MountOperationBuilder
pub fn builder() -> MountOperationBuilder
Creates a new builder-pattern struct instance to construct MountOperation objects.
This method returns an instance of MountOperationBuilder which can be used to create MountOperation objects.