pub struct PageSetupUnixDialog { /* private fields */ }Expand description
Presents a page setup dialog for platforms which don’t provide a native page setup dialog, like Unix.
It can be used very much like any other GTK dialog, at the
cost of the portability offered by the high-level printing
API in PrintOperation.
CSS nodes
PageSetupUnixDialog has a single CSS node with the name window and
style class .pagesetup.
Implements
DialogExt, GtkWindowExt, WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, NativeExt, RootExt, ShortcutManagerExt, DialogExtManual, WidgetExtManual, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl PageSetupUnixDialog
impl PageSetupUnixDialog
Sourcepub fn new(
title: Option<&str>,
parent: Option<&impl IsA<Window>>,
) -> PageSetupUnixDialog
pub fn new( title: Option<&str>, parent: Option<&impl IsA<Window>>, ) -> PageSetupUnixDialog
Creates a new page setup dialog.
title
the title of the dialog
parent
transient parent of the dialog
Returns
the new PageSetupUnixDialog
Sourcepub fn builder() -> PageSetupUnixDialogBuilder
pub fn builder() -> PageSetupUnixDialogBuilder
Creates a new builder-pattern struct instance to construct PageSetupUnixDialog objects.
This method returns an instance of PageSetupUnixDialogBuilder which can be used to create PageSetupUnixDialog objects.
Sourcepub fn page_setup(&self) -> PageSetup
pub fn page_setup(&self) -> PageSetup
Sourcepub fn print_settings(&self) -> Option<PrintSettings>
pub fn print_settings(&self) -> Option<PrintSettings>
Sourcepub fn set_page_setup(&self, page_setup: &PageSetup)
pub fn set_page_setup(&self, page_setup: &PageSetup)
Sourcepub fn set_print_settings(&self, print_settings: Option<&PrintSettings>)
pub fn set_print_settings(&self, print_settings: Option<&PrintSettings>)
Sets the PrintSettings from which the page setup dialog
takes its values.
print_settings