pub struct PrintDialog { /* private fields */ }Expand description
Asynchronous API to present a print dialog to the user.
PrintDialog collects the arguments that are needed to present
the dialog, such as a title for the dialog and whether it should
be modal.
The dialog is shown with the setup() function.
The actual printing can be done with print() or
print_file(). These APIs follows the GIO async pattern,
and the results can be obtained by calling the corresponding finish methods.
Properties
accept-label
A label that may be shown on the accept button of a print dialog
that is presented by PrintDialog::setup().
Readable | Writable
modal
Whether the print dialog is modal.
Readable | Writable
page-setup
The page setup to use.
Readable | Writable
print-settings
The print settings to use.
Readable | Writable
title
A title that may be shown on the print dialog that is
presented by PrintDialog::setup().
Readable | Writable
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl PrintDialog
impl PrintDialog
Sourcepub fn new() -> PrintDialog
pub fn new() -> PrintDialog
Sourcepub fn builder() -> PrintDialogBuilder
pub fn builder() -> PrintDialogBuilder
Creates a new builder-pattern struct instance to construct PrintDialog objects.
This method returns an instance of PrintDialogBuilder which can be used to create PrintDialog objects.
Sourcepub fn accept_label(&self) -> GString
pub fn accept_label(&self) -> GString
Returns the label that will be shown on the accept button of the print dialog.
Returns
the accept label
Sourcepub fn is_modal(&self) -> bool
pub fn is_modal(&self) -> bool
Returns whether the print dialog blocks interaction with the parent window while it is presented.
Returns
whether the print dialog is modal
Sourcepub fn page_setup(&self) -> Option<PageSetup>
pub fn page_setup(&self) -> Option<PageSetup>
Sourcepub fn print_settings(&self) -> Option<PrintSettings>
pub fn print_settings(&self) -> Option<PrintSettings>
Sourcepub fn print<P: FnOnce(Result<OutputStream, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
setup: Option<&PrintSetup>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn print<P: FnOnce(Result<OutputStream, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, setup: Option<&PrintSetup>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
This function prints content from a stream.
If you pass NULL as @setup, then this method will present a print dialog.
Otherwise, it will attempt to print directly, without user interaction.
The @callback will be called when the printing is done.
parent
the parent Window
setup
the PrintSetup to use
cancellable
a GCancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn print_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, setup: Option<&PrintSetup>, ) -> Pin<Box_<dyn Future<Output = Result<OutputStream, Error>> + 'static>>
Sourcepub fn print_file<P: FnOnce(Result<(), Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
setup: Option<&PrintSetup>,
file: &impl IsA<File>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn print_file<P: FnOnce(Result<(), Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, setup: Option<&PrintSetup>, file: &impl IsA<File>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
This function prints a file.
If you pass NULL as @setup, then this method will present a print dialog.
Otherwise, it will attempt to print directly, without user interaction.
parent
the parent Window
setup
the PrintSetup to use
file
the GFile to print
cancellable
a GCancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn print_file_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, setup: Option<&PrintSetup>, file: &(impl IsA<File> + Clone + 'static), ) -> Pin<Box_<dyn Future<Output = Result<(), Error>> + 'static>>
Sourcepub fn set_accept_label(&self, accept_label: &str)
pub fn set_accept_label(&self, accept_label: &str)
Sourcepub fn set_modal(&self, modal: bool)
pub fn set_modal(&self, modal: bool)
Sets whether the print dialog blocks interaction with the parent window while it is presented.
modal
the new value
Sourcepub fn set_page_setup(&self, page_setup: &PageSetup)
pub fn set_page_setup(&self, page_setup: &PageSetup)
Sourcepub fn set_print_settings(&self, print_settings: &PrintSettings)
pub fn set_print_settings(&self, print_settings: &PrintSettings)
Sourcepub fn setup<P: FnOnce(Result<PrintSetup, Error>) + 'static>(
&self,
parent: Option<&impl IsA<Window>>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn setup<P: FnOnce(Result<PrintSetup, Error>) + 'static>( &self, parent: Option<&impl IsA<Window>>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
This function presents a print dialog to let the user select a printer, and set up print settings and page setup.
The @callback will be called when the dialog is dismissed.
The obtained PrintSetup can then be passed
to print() or print_file().
One possible use for this method is to have the user select a printer,
then show a page setup UI in the application (e.g. to arrange images
on a page), then call print() on @self
to do the printing without further user interaction.
parent
the parent Window
cancellable
a GCancellable to cancel the operation
callback
a callback to call when the operation is complete
pub fn setup_future( &self, parent: Option<&(impl IsA<Window> + Clone + 'static)>, ) -> Pin<Box_<dyn Future<Output = Result<PrintSetup, Error>> + 'static>>
pub fn connect_accept_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_modal_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_page_setup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_print_settings_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId