pub struct RecentManager { /* private fields */ }Expand description
message); g_error_free (error); } else { // Use the info object gtk_recent_info_unref (info); }
In order to retrieve the list of recently used files, you can use
[`RecentManagerExt::items()`][crate::prelude::RecentManagerExt::items()], which returns a list of
[`RecentInfo`][crate::RecentInfo].
Note that the maximum age of the recently used files list is
controllable through the [`gtk-recent-files-max-age`][struct@crate::Settings#gtk-recent-files-max-age]
property.
## Properties
#### `filename`
The full path to the file to be used to store and read the
recently used resources list
Readable | Writable | Construct Only
#### `size`
The size of the recently used resources list.
Readable
## Signals
#### `changed`
Emitted when the current recently used resources manager changes
its contents.
This can happen either by calling [`RecentManagerExt::add_item()`][crate::prelude::RecentManagerExt::add_item()]
or by another application.
# Implements
[`RecentManagerExt`][trait@crate::prelude::RecentManagerExt], [`trait@glib::ObjectExt`]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl RecentManager
impl RecentManager
pub const NONE: Option<&'static RecentManager> = None
Sourcepub fn new() -> RecentManager
pub fn new() -> RecentManager
Creates a new recent manager object.
Recent manager objects are used to handle the list of recently used
resources. A RecentManager object monitors the recently used
resources list, and emits the changed
signal each time something inside the list changes.
RecentManager objects are expensive: be sure to create them
only when needed. You should use default()
instead.
Returns
A newly created RecentManager object
Sourcepub fn default() -> RecentManager
pub fn default() -> RecentManager
Gets a unique instance of RecentManager that you can share
in your application without caring about memory management.
Returns
A unique RecentManager. Do not ref or
unref it.