pub struct Scale { /* private fields */ }Expand description
slider
[`Scale`][crate::Scale] has a main CSS node with name scale and a subnode for its contents,
with subnodes named trough and slider.
The main node gets the style class .fine-tune added when the scale is in
'fine-tuning' mode.
If the scale has an origin (see [`ScaleExt::set_has_origin()`][crate::prelude::ScaleExt::set_has_origin()]), there is
a subnode with name highlight below the trough node that is used for rendering
the highlighted part of the trough.
If the scale is showing a fill level (see [`RangeExt::set_show_fill_level()`][crate::prelude::RangeExt::set_show_fill_level()]),
there is a subnode with name fill below the trough node that is used for
rendering the filled in part of the trough.
If marks are present, there is a marks subnode before or after the trough
node, below which each mark gets a node with name mark. The marks nodes get
either the .top or .bottom style class.
The mark node has a subnode named indicator. If the mark has text, it also
has a subnode named label. When the mark is either above or left of the
scale, the label subnode is the first when present. Otherwise, the indicator
subnode is the first.
The main CSS node gets the 'marks-before' and/or 'marks-after' style classes
added depending on what marks are present.
If the scale is displaying the value (see [`draw-value`][struct@crate::Scale#draw-value]),
there is subnode with name value. This node will get the .top or .bottom style
classes similar to the marks node.
# Accessibility
[`Scale`][crate::Scale] uses the [enum@Gtk.AccessibleRole.slider] role.
## Properties
#### `digits`
The number of decimal places that are displayed in the value.
Readable | Writable
#### `draw-value`
Whether the current value is displayed as a string next to the slider.
Readable | Writable
#### `has-origin`
Whether the scale has an origin.
Readable | Writable
#### `value-pos`
The position in which the current value is displayed.
Readable | Writable
<details><summary><h4>Range</h4></summary>
#### `adjustment`
The adjustment that is controlled by the range.
Readable | Writable | Construct
#### `fill-level`
The fill level (e.g. prebuffering of a network stream).
Readable | Writable
#### `inverted`
If [`true`], the direction in which the slider moves is inverted.
Readable | Writable
#### `restrict-to-fill-level`
Controls whether slider movement is restricted to an
upper boundary set by the fill level.
Readable | Writable
#### `round-digits`
The number of digits to round the value to when
it changes.
See [`change-value`][struct@crate::Range#change-value].
Readable | Writable
#### `show-fill-level`
Controls whether fill level indicator graphics are displayed
on the trough.
Readable | Writable
</details>
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Orientable</h4></summary>
#### `orientation`
The orientation of the orientable.
Readable | Writable
</details>
# Implements
[`ScaleExt`][trait@crate::prelude::ScaleExt], [`RangeExt`][trait@crate::prelude::RangeExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`AccessibleRangeExt`][trait@crate::prelude::AccessibleRangeExt], [`OrientableExt`][trait@crate::prelude::OrientableExt], [`ScaleExtManual`][trait@crate::prelude::ScaleExtManual], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Scale
impl Scale
pub const NONE: Option<&'static Scale> = None
Sourcepub fn new(
orientation: Orientation,
adjustment: Option<&impl IsA<Adjustment>>,
) -> Scale
pub fn new( orientation: Orientation, adjustment: Option<&impl IsA<Adjustment>>, ) -> Scale
Sourcepub fn with_range(
orientation: Orientation,
min: f64,
max: f64,
step: f64,
) -> Scale
pub fn with_range( orientation: Orientation, min: f64, max: f64, step: f64, ) -> Scale
s the distance the slider moves when using the arrow keys to adjust the scale value.
Note that the way in which the precision is derived works best if
@step is a power of ten. If the resulting precision is not suitable
for your needs, use ScaleExt::set_digits() to correct it.
orientation
s orientation.
min
minimum value
max
maximum value
step
step increment (tick size) used with keyboard shortcuts
Returns
a new Scale
Sourcepub fn builder() -> ScaleBuilder
pub fn builder() -> ScaleBuilder
Creates a new builder-pattern struct instance to construct Scale objects.
This method returns an instance of ScaleBuilder which can be used to create Scale objects.