pub struct Scrollable { /* private fields */ }Expand description
An interface for widgets with native scrolling ability.
To implement this interface you should override the
hadjustment and
vadjustment properties.
Creating a scrollable widget
All scrollable widgets should do the following.
-
When a parent widget sets the scrollable child widget’s adjustments, the widget should connect to the
value-changedsignal. The child widget should then populate the adjustments’ properties as soon as possible, which usually means queueing an allocation right away and populating the properties in theWidgetImpl::size_allocate()implementation. -
Because its preferred size is the size for a fully expanded widget, the scrollable widget must be able to cope with underallocations. This means that it must accept any value passed to its
WidgetImpl::size_allocate()implementation. -
When the parent allocates space to the scrollable child widget, the widget must ensure the adjustments’ property values are correct and up to date, for example using
AdjustmentExt::configure(). -
When any of the adjustments emits the
value-changedsignal, the scrollable widget should scroll its contents.
Properties
hadjustment
Horizontal Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
hscroll-policy
Determines when horizontal scrolling should start.
Readable | Writable
vadjustment
Vertical Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
vscroll-policy
Determines when vertical scrolling should start.
Readable | Writable
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Scrollable
impl Scrollable
pub const NONE: Option<&'static Scrollable> = None