pub struct SearchEntry { /* private fields */ }Expand description
text
[`SearchEntry`][crate::SearchEntry] has a single CSS node with name entry that carries
a `.search` style class, and the text node is a child of that.
## Accessibility
[`SearchEntry`][crate::SearchEntry] uses the [enum@Gtk.AccessibleRole.search_box] role.
## Properties
#### `activates-default`
Whether to activate the default widget when Enter is pressed.
Readable | Writable
#### `input-hints`
The hints about input for the [`SearchEntry`][crate::SearchEntry] used to alter the
behaviour of input methods.
Readable | Writable
#### `input-purpose`
The purpose for the [`SearchEntry`][crate::SearchEntry] input used to alter the
behaviour of input methods.
Readable | Writable
#### `key-capture-widget`
The widget that the entry will use to capture key events.
Key events are consumed by the search entry to start or continue a search.
Readable | Writable | Construct
#### `placeholder-text`
The text that will be displayed in the [`SearchEntry`][crate::SearchEntry]
when it is empty and unfocused.
Readable | Writable
#### `search-delay`
The delay in milliseconds from last keypress to the search
changed signal.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Editable</h4></summary>
#### `complete-text`
The contents of the entry, including uncommited content such as the
preedit.
Readable
#### `cursor-position`
The current position of the insertion cursor in chars.
Readable
#### `editable`
Whether the entry contents can be edited.
Readable | Writable
#### `enable-undo`
If undo/redo should be enabled for the editable.
Readable | Writable
#### `max-width-chars`
The desired maximum width of the entry, in characters.
Readable | Writable
#### `selection-bound`
The position of the opposite end of the selection from the cursor in chars.
Readable
#### `text`
The contents of the entry.
Readable | Writable
#### `width-chars`
Number of characters to leave space for in the entry.
Readable | Writable
#### `xalign`
The horizontal alignment, from 0 (left) to 1 (right).
Reversed for RTL layouts.
Readable | Writable
</details>
## Signals
#### `activate`
key.
Action
#### `next-match`
.
Action
#### `previous-match`
.
Action
#### `search-changed`
Emitted with a delay. The length of the delay can be
changed with the [`search-delay`][struct@crate::SearchEntry#search-delay]
property.
#### `search-started`
Emitted when the user initiated a search on the entry.
#### `stop-search`
.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
<details><summary><h4>Editable</h4></summary>
#### `changed`
Emitted at the end of a single user-visible operation on the
contents.
E.g., a paste operation that replaces the contents of the
selection will cause only one signal emission (even though it
is implemented by first deleting the selection, then inserting
the new content, and may cause multiple ::notify::text signals
to be emitted).
#### `delete-text`
Emitted when text is deleted from the widget by the user.
The default handler for this signal will normally be responsible for
deleting the text, so by connecting to this signal and then stopping
the signal with g_signal_stop_emission(), it is possible to modify the
range of deleted text, or prevent it from being deleted entirely.
The @start_pos and @end_pos parameters are interpreted as for
[`EditableExt::delete_text()`][crate::prelude::EditableExt::delete_text()].
#### `insert-text`
Emitted when text is inserted into the widget by the user.
The default handler for this signal will normally be responsible
for inserting the text, so by connecting to this signal and then
stopping the signal with g_signal_stop_emission(), it is possible
to modify the inserted text, or prevent it from being inserted entirely.
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`EditableExt`][trait@crate::prelude::EditableExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual], [`EditableExtManual`][trait@crate::prelude::EditableExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl SearchEntry
impl SearchEntry
Sourcepub fn new() -> SearchEntry
pub fn new() -> SearchEntry
Sourcepub fn builder() -> SearchEntryBuilder
pub fn builder() -> SearchEntryBuilder
Creates a new builder-pattern struct instance to construct SearchEntry objects.
This method returns an instance of SearchEntryBuilder which can be used to create SearchEntry objects.
Sourcepub fn input_hints(&self) -> InputHints
Available on crate feature v4_14 only.
pub fn input_hints(&self) -> InputHints
v4_14 only.Sourcepub fn input_purpose(&self) -> InputPurpose
Available on crate feature v4_14 only.
pub fn input_purpose(&self) -> InputPurpose
v4_14 only.Sourcepub fn key_capture_widget(&self) -> Option<Widget>
pub fn key_capture_widget(&self) -> Option<Widget>
Sourcepub fn search_delay(&self) -> u32
Available on crate feature v4_8 only.
pub fn search_delay(&self) -> u32
v4_8 only.Get the delay to be used between the last keypress and the
search-changed signal being emitted.
Returns
a delay in milliseconds.
Sourcepub fn set_input_hints(&self, hints: InputHints)
Available on crate feature v4_14 only.
pub fn set_input_hints(&self, hints: InputHints)
v4_14 only.Sourcepub fn set_input_purpose(&self, purpose: InputPurpose)
Available on crate feature v4_14 only.
pub fn set_input_purpose(&self, purpose: InputPurpose)
v4_14 only.Sourcepub fn set_key_capture_widget(&self, widget: Option<&impl IsA<Widget>>)
pub fn set_key_capture_widget(&self, widget: Option<&impl IsA<Widget>>)
Sets @widget as the widget that @self will capture key events from.
Key events are consumed by the search entry to start or continue a search.
If the entry is part of a SearchBar, it is preferable
to call SearchBar::set_key_capture_widget() instead,
which will reveal the entry in addition to triggering the
search entry.
Note that despite the name of this function, the events
are only ‘captured’ in the bubble phase, which means that
editable child widgets of @widget will receive text input
before it gets captured. If that is not desired, you can
capture and forward the events yourself with
EventControllerKey::forward().
widget
a Widget
Sourcepub fn set_search_delay(&self, delay: u32)
Available on crate feature v4_8 only.
pub fn set_search_delay(&self, delay: u32)
v4_8 only.Set the delay to be used between the last keypress and the
search-changed signal being emitted.
delay
a delay in milliseconds
Sourcepub fn activates_default(&self) -> bool
pub fn activates_default(&self) -> bool
Whether to activate the default widget when Enter is pressed.
Sourcepub fn set_activates_default(&self, activates_default: bool)
pub fn set_activates_default(&self, activates_default: bool)
Whether to activate the default widget when Enter is pressed.
pub fn placeholder_text(&self) -> Option<GString>
pub fn set_placeholder_text(&self, placeholder_text: Option<&str>)
Sourcepub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
key.
pub fn emit_activate(&self)
Sourcepub fn connect_next_match<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_next_match<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_next_match(&self)
Sourcepub fn connect_previous_match<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_previous_match<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_previous_match(&self)
Sourcepub fn connect_search_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_search_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted with a delay. The length of the delay can be
changed with the search-delay
property.
Sourcepub fn connect_search_started<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_search_started<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the user initiated a search on the entry.
Sourcepub fn connect_stop_search<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_stop_search<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_stop_search(&self)
pub fn connect_activates_default_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_input_hints_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_14 only.pub fn connect_input_purpose_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_14 only.pub fn connect_key_capture_widget_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_22 only.pub fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_search_delay_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_8 only.Trait Implementations
Sourceimpl Clone for SearchEntry
impl Clone for SearchEntry
Sourceimpl Debug for SearchEntry
impl Debug for SearchEntry
Sourceimpl Default for SearchEntry
impl Default for SearchEntry
impl Eq for SearchEntry
Sourceimpl HasParamSpec for SearchEntry
impl HasParamSpec for SearchEntry
type ParamSpec = ParamSpecObject
Sourcetype SetValue = SearchEntry
type SetValue = SearchEntry
type BuilderFn = fn(&str) -> ParamSpecObjectBuilder<'_, SearchEntry>
fn param_spec_builder() -> Self::BuilderFn
Sourceimpl Hash for SearchEntry
impl Hash for SearchEntry
impl IsA<Accessible> for SearchEntry
impl IsA<Buildable> for SearchEntry
impl IsA<ConstraintTarget> for SearchEntry
impl IsA<Editable> for SearchEntry
impl IsA<Widget> for SearchEntry
Sourceimpl Ord for SearchEntry
impl Ord for SearchEntry
Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
Comparison for two GObjects.
Compares the memory addresses of the provided objects.
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl ParentClassIs for SearchEntry
impl ParentClassIs for SearchEntry
Sourceimpl<OT: ObjectType> PartialEq<OT> for SearchEntry
impl<OT: ObjectType> PartialEq<OT> for SearchEntry
Sourceimpl<OT: ObjectType> PartialOrd<OT> for SearchEntry
impl<OT: ObjectType> PartialOrd<OT> for SearchEntry
Sourcefn partial_cmp(&self, other: &OT) -> Option<Ordering>
fn partial_cmp(&self, other: &OT) -> Option<Ordering>
Partial comparison for two GObjects.
Compares the memory addresses of the provided objects.
Sourceimpl StaticType for SearchEntry
impl StaticType for SearchEntry
Sourcefn static_type() -> Type
fn static_type() -> Type
Self.Auto Trait Implementations
impl !Send for SearchEntry
impl !Sync for SearchEntry
impl Freeze for SearchEntry
impl RefUnwindSafe for SearchEntry
impl Unpin for SearchEntry
impl UnsafeUnpin for SearchEntry
impl UnwindSafe for SearchEntry