pub struct SectionModel { /* private fields */ }Expand description
An interface that adds support for sections to list models.
A SectionModel groups successive items into so-called sections. List widgets
like ListView and GridView then allow displaying section headers for
these sections by installing a header factory.
Many GTK list models support sections inherently, or they pass through the sections of a model they are wrapping.
When the section groupings of a model change, the model will emit the
sections-changed signal by calling the
SectionModelExt::sections_changed() function. All sections in the given range
then need to be queried again.
The [items-changed][struct@crate::gio::ListModel#items-changed] signal has the same effect, all sections in
that range are invalidated, too.
Signals
sections-changed
Emitted when the start-of-section state of some of the items in @model changes.
Note that this signal does not specify the new section state of the items, they need to be queried manually. It is also not necessary for a model to change the section state of any of the items in the section model, though it would be rather useless to emit such a signal.
The [items-changed][struct@crate::gio::ListModel#items-changed] implies the effect of the
sections-changed signal for all the items
it covers.
ListModel
items-changed
This signal is emitted whenever items were added to or removed from @list. At @position, @removed items were removed and @added items were added in their place.
Note: If removed != added, the positions of all later items
in the model change.
Implements
SectionModelExt, [trait@gio::prelude::ListModelExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SectionModel
impl SectionModel
pub const NONE: Option<&'static SectionModel> = None