pub struct SelectionFilterModel { /* private fields */ }Expand description
A list model that presents the selection from a SelectionModel.
Properties
item-type
The type of items. See [ListModelExtManual::item_type()][crate::gio::prelude::ListModelExtManual::item_type()].
Readable
model
The model being filtered.
Readable | Writable
n-items
The number of items. See [ListModelExtManual::n_items()][crate::gio::prelude::ListModelExtManual::n_items()].
Readable
Implements
[trait@glib::ObjectExt], [trait@gio::prelude::ListModelExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SelectionFilterModel
impl SelectionFilterModel
Sourcepub fn new(model: Option<&impl IsA<SelectionModel>>) -> SelectionFilterModel
pub fn new(model: Option<&impl IsA<SelectionModel>>) -> SelectionFilterModel
Creates a new SelectionFilterModel that will include the
selected items from the underlying selection model.
model
the selection model to filter
Returns
a new SelectionFilterModel
Sourcepub fn model(&self) -> Option<SelectionModel>
pub fn model(&self) -> Option<SelectionModel>
Sourcepub fn set_model(&self, model: Option<&impl IsA<SelectionModel>>)
pub fn set_model(&self, model: Option<&impl IsA<SelectionModel>>)
Sets the model to be filtered.
Note that GTK makes no effort to ensure that @model conforms to the item type of @self. It assumes that the caller knows what they are doing and have set up an appropriate filter to ensure that item types match.
model
The model to be filtered
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId