pub struct Separator { /* private fields */ }Expand description
Draws a horizontal or vertical line to separate other widgets.
A Separator can be used to group the widgets within a window.
It displays a line with a shadow to make it appear sunken into the
interface.
CSS nodes
Separator has a single CSS node with name separator. The node
gets one of the .horizontal or .vertical style classes.
Accessibility
Separator uses the [enum@Gtk.AccessibleRole.separator] role.
Implements
WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, OrientableExt, WidgetExtManual, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Separator
impl Separator
Sourcepub fn new(orientation: Orientation) -> Separator
pub fn new(orientation: Orientation) -> Separator
Sourcepub fn builder() -> SeparatorBuilder
pub fn builder() -> SeparatorBuilder
Creates a new builder-pattern struct instance to construct Separator objects.
This method returns an instance of SeparatorBuilder which can be used to create Separator objects.