pub struct ShortcutLabel { /* private fields */ }Since 4.18
This widget will be removed in GTK 5
ShortcutLabel displays a single keyboard shortcut or gesture.
The main use case for ShortcutLabel is inside a ShortcutsWindow.
Properties
accelerator
The accelerator that @self_ displays.
See accelerator
for the accepted syntax.
Readable | Writable
disabled-text
The text that is displayed when no accelerator is set.
Readable | Writable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widgetโs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
Implements
WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, WidgetExtManual, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ShortcutLabel
impl ShortcutLabel
Sourcepub fn new(accelerator: &str) -> ShortcutLabel
๐Deprecated: Since 4.18
pub fn new(accelerator: &str) -> ShortcutLabel
Since 4.18
Creates a new ShortcutLabel with @accelerator set.
Deprecated since 4.18
This widget will be removed in GTK 5
accelerator
the initial accelerator
Returns
a newly-allocated ShortcutLabel
Sourcepub fn builder() -> ShortcutLabelBuilder
๐Deprecated: Since 4.18
pub fn builder() -> ShortcutLabelBuilder
Since 4.18
Creates a new builder-pattern struct instance to construct ShortcutLabel objects.
This method returns an instance of ShortcutLabelBuilder which can be used to create ShortcutLabel objects.
Sourcepub fn accelerator(&self) -> Option<GString>
๐Deprecated: Since 4.18
pub fn accelerator(&self) -> Option<GString>
Since 4.18
Sourcepub fn disabled_text(&self) -> Option<GString>
๐Deprecated: Since 4.18
pub fn disabled_text(&self) -> Option<GString>
Since 4.18
Sourcepub fn set_accelerator(&self, accelerator: &str)
๐Deprecated: Since 4.18
pub fn set_accelerator(&self, accelerator: &str)
Since 4.18
Sourcepub fn set_disabled_text(&self, disabled_text: &str)
๐Deprecated: Since 4.18
pub fn set_disabled_text(&self, disabled_text: &str)
Since 4.18
pub fn connect_accelerator_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.18
pub fn connect_disabled_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.18