pub struct SliceListModel { /* private fields */ }Expand description
A list model that presents a slice of another model.
This is useful when implementing paging by setting the size to the number of elements per page and updating the offset whenever a different page is opened.
SliceListModel passes through sections from the underlying model.
Properties
item-type
The type of items. See [ListModelExtManual::item_type()][crate::gio::prelude::ListModelExtManual::item_type()].
Readable
model
Child model to take slice from.
Readable | Writable
n-items
The number of items. See [ListModelExtManual::n_items()][crate::gio::prelude::ListModelExtManual::n_items()].
Readable
offset
Offset of slice.
Readable | Writable
size
Maximum size of slice.
Readable | Writable
Implements
[trait@glib::ObjectExt], [trait@gio::prelude::ListModelExt], SectionModelExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SliceListModel
impl SliceListModel
Sourcepub fn new(
model: Option<impl IsA<ListModel>>,
offset: u32,
size: u32,
) -> SliceListModel
pub fn new( model: Option<impl IsA<ListModel>>, offset: u32, size: u32, ) -> SliceListModel
Creates a new slice model.
It presents the slice from @offset to offset + @size of the given @model.
model
The model to use
offset
the offset of the slice
size
maximum size of the slice
Returns
A new SliceListModel
Sourcepub fn builder() -> SliceListModelBuilder
pub fn builder() -> SliceListModelBuilder
Creates a new builder-pattern struct instance to construct SliceListModel objects.
This method returns an instance of SliceListModelBuilder which can be used to create SliceListModel objects.
Sourcepub fn set_model(&self, model: Option<&impl IsA<ListModel>>)
pub fn set_model(&self, model: Option<&impl IsA<ListModel>>)
Sets the model to show a slice of.
The model’s item type must conform to @self’s item type.
model
The model to be sliced
Sourcepub fn set_offset(&self, offset: u32)
pub fn set_offset(&self, offset: u32)
Sets the offset into the original model for this slice.
If the offset is too large for the sliced model, @self will end up empty.
offset
the new offset to use
Sourcepub fn set_size(&self, size: u32)
pub fn set_size(&self, size: u32)
Sets the maximum size. @self will never have more items than @size.
It can however have fewer items if the offset is too large or the model sliced from doesn’t have enough items.
size
the maximum size
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_offset_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId