pub struct StackPage { /* private fields */ }Expand description
An auxiliary class used by Stack.
Properties
child
The child that this page is for.
Readable | Writable | Construct Only
icon-name
The icon name of the child page.
Readable | Writable
name
The name of the child page.
Readable | Writable
needs-attention
Whether the page requires the user attention.
This is used by the StackSwitcher to change the
appearance of the corresponding button when a page needs
attention and it is not the current one.
Readable | Writable
title
The title of the child page.
Readable | Writable
use-underline
If set, an underline in the title indicates a mnemonic.
Readable | Writable
visible
Whether this page is visible.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
Implements
[trait@glib::ObjectExt], AccessibleExt, AccessibleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl StackPage
impl StackPage
Sourcepub fn needs_attention(&self) -> bool
pub fn needs_attention(&self) -> bool
Returns whether the page is marked as “needs attention”.
Returns
The value of the needs-attention
property.
Sourcepub fn uses_underline(&self) -> bool
pub fn uses_underline(&self) -> bool
Gets whether underlines in the page title indicate mnemonics.
Returns
The value of the use-underline property
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Sourcepub fn set_icon_name(&self, setting: &str)
pub fn set_icon_name(&self, setting: &str)
Sourcepub fn set_needs_attention(&self, setting: bool)
pub fn set_needs_attention(&self, setting: bool)
Sourcepub fn set_use_underline(&self, setting: bool)
pub fn set_use_underline(&self, setting: bool)
Sourcepub fn set_visible(&self, visible: bool)
pub fn set_visible(&self, visible: bool)
pub fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_needs_attention_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_use_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId