pub struct StringList { /* private fields */ }Expand description
A list model that wraps an array of strings.
The objects in the model are of type StringObject and have
a “string” property that can be used inside expressions.
StringList is well-suited for any place where you would
typically use a char*[], but need a list model.
GtkStringList as GtkBuildable
The StringList implementation of the Buildable interface
supports adding items directly using the <items> element and
specifying <item> elements for each item. Each <item> element
supports the regular translation attributes “translatable”,
“context” and “comments”.
Here is a UI definition fragment specifying a StringList
<object class="GtkStringList">
<items>
<item translatable="yes">Factory</item>
<item translatable="yes">Home</item>
<item translatable="yes">Subway</item>
</items>
</object>Properties
item-type
The type of items. See [ListModelExtManual::item_type()][crate::gio::prelude::ListModelExtManual::item_type()].
Readable
n-items
The number of items. See [ListModelExtManual::n_items()][crate::gio::prelude::ListModelExtManual::n_items()].
Readable
strings
The strings in the model.
Writable | Construct Only
Implements
[trait@glib::ObjectExt], [trait@gio::prelude::ListModelExt], BuildableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl StringList
impl StringList
Sourcepub fn new(strings: &[&str]) -> StringList
pub fn new(strings: &[&str]) -> StringList
Creates a new StringList with the given @strings.
strings
The strings to put in the model
Returns
a new StringList
Sourcepub fn append(&self, string: &str)
pub fn append(&self, string: &str)
Appends @string to @self.
The @string will be copied. See
Gtk::StringList::take() for a way to avoid that.
string
the string to insert
Sourcepub fn remove(&self, position: u32)
pub fn remove(&self, position: u32)
Removes the string at @position from @self.
@position must be smaller than the current length of the list.
position
the position of the string that is to be removed
Sourcepub fn splice(&self, position: u32, n_removals: u32, additions: &[&str])
pub fn splice(&self, position: u32, n_removals: u32, additions: &[&str])
Changes @self by removing @n_removals strings and adding @additions to it.
This function is more efficient than append()
and remove(), because it only emits the
::items-changed signal once for the change.
This function copies the strings in @additions.
The parameters @position and @n_removals must be correct (ie: @position + @n_removals must be less than or equal to the length of the list at the time this function is called).
position
the position at which to make the change
n_removals
the number of strings to remove
additions
The strings to add