pub struct TextView { /* private fields */ }Expand description
[window.popup]
[`TextView`][crate::TextView] has a main css node with name textview and style class .view,
and subnodes for each of the border windows, and the main text area,
with names border and text, respectively. The border nodes each get
one of the style classes .left, .right, .top or .bottom.
A node representing the selection will appear below the text node.
If a context menu is opened, the window node will appear as a subnode
of the main node.
If using an input method with a pre-edit buffer, this string will be styled
with a `preedit` subnode of the `text` node. the different style classes
express the possible roles of a piece of text in the pre-edit buffer:
- `.whole` denotes the parts of the pre-edit buffer without a special role
- `.selection`, `.prefix` and `.suffix` style classes will be used to
highlight the specific portions of the pre-edit buffer being edited and its
surroundings
- `.prediction` will be used for parts of the pre-edit buffer not typed by the
user (e.g. autocompletion)
- `.spelling-error` and `.compose-error` will be respectively used to indicate
errors in spelling or character composition (e.g. non-existent transliterations).
## Accessibility
[`TextView`][crate::TextView] uses the [enum@Gtk.AccessibleRole.text_box] role.
## Properties
#### `accepts-tab`
Whether Tab will result in a tab character being entered.
Readable | Writable
#### `bottom-margin`
The bottom margin for text in the text view.
Note that this property is confusingly named. In CSS terms,
the value set here is padding, and it is applied in addition
to the padding from the theme.
Don't confuse this property with [`margin-bottom`][struct@crate::Widget#margin-bottom].
Readable | Writable
#### `buffer`
The buffer which is displayed.
Readable | Writable
#### `cursor-visible`
If the insertion cursor is shown.
Readable | Writable
#### `editable`
Whether the text can be modified by the user.
Readable | Writable
#### `extra-menu`
A menu model whose contents will be appended to the context menu.
Readable | Writable
#### `im-module`
Which IM (input method) module should be used for this text_view.
See [`IMMulticontext`][crate::IMMulticontext].
Setting this to a non-[`None`] value overrides the system-wide IM module
setting. See the GtkSettings [`gtk-im-module`][struct@crate::Settings#gtk-im-module] property.
Readable | Writable
#### `indent`
Amount to indent the paragraph, in pixels.
A negative value of indent will produce a hanging indentation.
That is, the first line will have the full width, and subsequent
lines will be indented by the absolute value of indent.
Readable | Writable
#### `input-hints`
Additional hints (beyond [`input-purpose`][struct@crate::TextView#input-purpose])
that allow input methods to fine-tune their behaviour.
Readable | Writable
#### `input-purpose`
The purpose of this text field.
This property can be used by on-screen keyboards and other input
methods to adjust their behaviour.
Readable | Writable
#### `justification`
Left, right, or center justification.
Readable | Writable
#### `left-margin`
The default left margin for text in the text view.
Tags in the buffer may override the default.
Note that this property is confusingly named. In CSS terms,
the value set here is padding, and it is applied in addition
to the padding from the theme.
Readable | Writable
#### `monospace`
Whether text should be displayed in a monospace font.
If [`true`], set the .monospace style class on the
text view to indicate that a monospace font is desired.
Readable | Writable
#### `overwrite`
Whether entered text overwrites existing contents.
Readable | Writable
#### `pixels-above-lines`
Pixels of blank space above paragraphs.
Readable | Writable
#### `pixels-below-lines`
Pixels of blank space below paragraphs.
Readable | Writable
#### `pixels-inside-wrap`
Pixels of blank space between wrapped lines in a paragraph.
Readable | Writable
#### `right-margin`
The default right margin for text in the text view.
Tags in the buffer may override the default.
Note that this property is confusingly named. In CSS terms,
the value set here is padding, and it is applied in addition
to the padding from the theme.
Readable | Writable
#### `tabs`
Custom tabs for this text.
Readable | Writable
#### `top-margin`
The top margin for text in the text view.
Note that this property is confusingly named. In CSS terms,
the value set here is padding, and it is applied in addition
to the padding from the theme.
Don't confuse this property with [`margin-top`][struct@crate::Widget#margin-top].
Readable | Writable
#### `wrap-mode`
Whether to wrap lines never, at word boundaries, or at character boundaries.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Scrollable</h4></summary>
#### `hadjustment`
Horizontal [`Adjustment`][crate::Adjustment] of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
#### `hscroll-policy`
Determines when horizontal scrolling should start.
Readable | Writable
#### `vadjustment`
Vertical [`Adjustment`][crate::Adjustment] of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
#### `vscroll-policy`
Determines when vertical scrolling should start.
Readable | Writable
</details>
## Signals
#### `backspace`
.
Action
#### `copy-clipboard`
.
Action
#### `cut-clipboard`
.
Action
#### `delete-from-cursor`
for
deleting a word backwards.
Action
#### `extend-selection`
Emitted when the selection needs to be extended at @location.
#### `insert-at-cursor`
Gets emitted when the user initiates the insertion of a
fixed string at the cursor.
The ::insert-at-cursor signal is a [keybinding signal](class.SignalAction.html).
This signal has no default bindings.
Action
#### `insert-emoji`
/kbd
Action
#### `move-cursor`
move horizontally by pages
Action
#### `move-viewport`
Gets emitted to move the viewport.
The ::move-viewport signal is a [keybinding signal](class.SignalAction.html),
which can be bound to key combinations to allow the user to move the viewport,
i.e. change what part of the text view is visible in a containing scrolled
window.
There are no default bindings for this signal.
Action
#### `paste-clipboard`
.
Action
#### `preedit-changed`
Emitted when preedit text of the active IM changes.
If an input method is used, the typed text will not immediately
be committed to the buffer. So if you are interested in the text,
connect to this signal.
This signal is only emitted if the text at the given position
is actually editable.
Action
#### `select-all`
for unselecting.
Action
#### `set-anchor`
Gets emitted when the user initiates settings the "anchor" mark.
The ::set-anchor signal is a [keybinding signal](class.SignalAction.html)
which gets emitted when the user initiates setting the "anchor"
mark. The "anchor" mark gets placed at the same position as the
"insert" mark.
This signal has no default bindings.
Action
#### `toggle-cursor-visible`
.
Action
#### `toggle-overwrite`
.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`TextViewExt`][trait@crate::prelude::TextViewExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`AccessibleTextExt`][trait@crate::prelude::AccessibleTextExt], [`ScrollableExt`][trait@crate::prelude::ScrollableExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl TextView
impl TextView
pub const NONE: Option<&'static TextView> = None
Sourcepub fn new() -> TextView
pub fn new() -> TextView
t call TextViewExt::set_buffer() before using the
text view, an empty default buffer will be created for you. Get the
buffer with TextViewExt::buffer(). If you want to specify
your own buffer, consider with_buffer().
Returns
a new TextView
Sourcepub fn with_buffer(buffer: &impl IsA<TextBuffer>) -> TextView
pub fn with_buffer(buffer: &impl IsA<TextBuffer>) -> TextView
Creates a new TextView widget displaying the buffer @buffer.
One buffer can be shared among many widgets. @buffer may be None
to create a default buffer, in which case this function is equivalent
to new(). The text view adds its own reference count
to the buffer; it does not take over an existing reference.
buffer
Returns
a new TextView.
Sourcepub fn builder() -> TextViewBuilder
pub fn builder() -> TextViewBuilder
Creates a new builder-pattern struct instance to construct TextView objects.
This method returns an instance of TextViewBuilder which can be used to create TextView objects.