pub struct Tooltip { /* private fields */ }Expand description
Represents a widget tooltip.
Basic tooltips can be realized simply by using
WidgetExt::set_tooltip_text() or
WidgetExt::set_tooltip_markup() without
any explicit tooltip object.
When you need a tooltip with a little more fancy contents,
like adding an image, or you want the tooltip to have different
contents per TreeView row or cell, you will have to do a
little more work:
-
Set the
has-tooltipproperty totrue. This will make GTK monitor the widget for motion and related events which are needed to determine when and where to show a tooltip. -
Connect to the
query-tooltipsignal. This signal will be emitted when a tooltip is supposed to be shown. One of the arguments passed to the signal handler is aTooltipobject. This is the object that we are about to display as a tooltip, and can be manipulated in your callback using functions likeset_icon(). There are functions for setting the tooltip’s markup, setting an image from a named icon, or even putting in a custom widget. -
Return
truefrom your ::query-tooltip handler. This causes the tooltip to be show. If you returnfalse, it will not be shown.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Tooltip
impl Tooltip
Sourcepub fn set_custom(&self, custom_widget: Option<&impl IsA<Widget>>)
pub fn set_custom(&self, custom_widget: Option<&impl IsA<Widget>>)
Sourcepub fn set_icon(&self, paintable: Option<&impl IsA<Paintable>>)
pub fn set_icon(&self, paintable: Option<&impl IsA<Paintable>>)
Sourcepub fn set_icon_from_gicon(&self, gicon: Option<&impl IsA<Icon>>)
pub fn set_icon_from_gicon(&self, gicon: Option<&impl IsA<Icon>>)
Sourcepub fn set_icon_from_icon_name(&self, icon_name: Option<&str>)
pub fn set_icon_from_icon_name(&self, icon_name: Option<&str>)
Sourcepub fn set_markup(&self, markup: Option<&str>)
pub fn set_markup(&self, markup: Option<&str>)
Sourcepub fn set_text(&self, text: Option<&str>)
pub fn set_text(&self, text: Option<&str>)
Sets the text of the tooltip to be @text.
If @text is None, the label will be hidden.
See also set_markup().
text
a text string
Sourcepub fn set_tip_area(&self, rect: &Rectangle)
pub fn set_tip_area(&self, rect: &Rectangle)
Sets the area of the widget, where the contents of this tooltip apply,
to be @rect (in widget coordinates). This is especially useful for
properly setting tooltips on TreeView rows and cells, GtkIconViews,
etc.
For setting tooltips on TreeView, please refer to the convenience
functions for this: gtk_tree_view_set_tooltip_row() and
gtk_tree_view_set_tooltip_cell().
rect