pub struct TreeExpander { /* private fields */ }Expand description
[`TreeExpander`][crate::TreeExpander] has zero or one CSS nodes with the name "expander" that
should display the expander icon. The node will be `:checked` when it
is expanded. If the node is not expandable, an "indent" node will be
displayed instead.
For every level of depth, another "indent" node is prepended.
## Accessibility
Until GTK 4.10, [`TreeExpander`][crate::TreeExpander] used the [enum@Gtk.AccessibleRole.group] role.
Since GTK 4.12, [`TreeExpander`][crate::TreeExpander] uses the [enum@Gtk.AccessibleRole.button] role.
Toggling it will change the `GTK_ACCESSIBLE_STATE_EXPANDED` state.
## Properties
#### `child`
The child widget with the actual contents.
Readable | Writable
#### `hide-expander`
Whether the expander icon should be hidden in a GtkTreeListRow.
Note that this property simply hides the icon. The actions and keybinding
(i.e. collapse and expand) are not affected by this property.
A common use for this property would be to bind to the number of children in a
GtkTreeListRow's model in order to hide the expander when a row has no children.
Readable | Writable
#### `indent-for-depth`
TreeExpander indents the child according to its depth.
Readable | Writable
#### `indent-for-icon`
TreeExpander indents the child by the width of an expander-icon if it is not expandable.
Readable | Writable
#### `item`
The item held by this expander's row.
Readable
#### `list-row`
The list row to track for expander state.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl TreeExpander
impl TreeExpander
Sourcepub fn new() -> TreeExpander
pub fn new() -> TreeExpander
Sourcepub fn builder() -> TreeExpanderBuilder
pub fn builder() -> TreeExpanderBuilder
Creates a new builder-pattern struct instance to construct TreeExpander objects.
This method returns an instance of TreeExpanderBuilder which can be used to create TreeExpander objects.
Sourcepub fn hides_expander(&self) -> bool
Available on crate feature v4_10 only.
pub fn hides_expander(&self) -> bool
v4_10 only.Gets whether the TreeExpander should be hidden in a GtkTreeListRow.
Returns
TRUE if the expander icon should be hidden. Otherwise FALSE.
Sourcepub fn is_indent_for_depth(&self) -> bool
Available on crate feature v4_10 only.
pub fn is_indent_for_depth(&self) -> bool
v4_10 only.TreeExpander indents each level of depth with an additional indent.
Returns
TRUE if the child should be indented . Otherwise FALSE.
Sourcepub fn is_indent_for_icon(&self) -> bool
Available on crate feature v4_6 only.
pub fn is_indent_for_icon(&self) -> bool
v4_6 only.TreeExpander indents the child by the width of an expander-icon if it is not expandable.
Returns
TRUE if the child should be indented when not expandable. Otherwise FALSE.
Sourcepub fn item(&self) -> Option<Object>
pub fn item(&self) -> Option<Object>
Forwards the item set on the TreeListRow that @self is managing.
This call is essentially equivalent to calling:
⚠️ The following code is in c ⚠️
gtk_tree_list_row_get_item (gtk_tree_expander_get_list_row (@self));Returns
The item of the row
Sourcepub fn list_row(&self) -> Option<TreeListRow>
pub fn list_row(&self) -> Option<TreeListRow>
Sourcepub fn set_hide_expander(&self, hide_expander: bool)
Available on crate feature v4_10 only.
pub fn set_hide_expander(&self, hide_expander: bool)
v4_10 only.Sets whether the expander icon should be visible in a GtkTreeListRow.
hide_expander
TRUE if the expander should be hidden. Otherwise FALSE.
Sourcepub fn set_indent_for_depth(&self, indent_for_depth: bool)
Available on crate feature v4_10 only.
pub fn set_indent_for_depth(&self, indent_for_depth: bool)
v4_10 only.Sets if the TreeExpander should indent the child according to its depth.
indent_for_depth
TRUE if the child should be indented. Otherwise FALSE.
Sourcepub fn set_indent_for_icon(&self, indent_for_icon: bool)
Available on crate feature v4_6 only.
pub fn set_indent_for_icon(&self, indent_for_icon: bool)
v4_6 only.Sets if the TreeExpander should indent the child by the width of an expander-icon when it is not expandable.
indent_for_icon
TRUE if the child should be indented without expander. Otherwise FALSE.
Sourcepub fn set_list_row(&self, list_row: Option<&TreeListRow>)
pub fn set_list_row(&self, list_row: Option<&TreeListRow>)
pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_hide_expander_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_10 only.pub fn connect_indent_for_depth_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_10 only.pub fn connect_indent_for_icon_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v4_6 only.pub fn connect_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_list_row_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId