pub struct TreeListModel { /* private fields */ }Expand description
A list model that can create child models on demand.
Properties
autoexpand
If all rows should be expanded by default.
Readable | Writable
item-type
The type of items. See [ListModelExtManual::item_type()][crate::gio::prelude::ListModelExtManual::item_type()].
Readable
model
The root model displayed.
Readable
n-items
The number of items. See [ListModelExtManual::n_items()][crate::gio::prelude::ListModelExtManual::n_items()].
Readable
passthrough
Gets whether the model is in passthrough mode.
If false, the GListModel functions for this object return custom
TreeListRow objects. If true, the values of the child
models are pass through unmodified.
Readable | Writable | Construct Only
Implements
[trait@glib::ObjectExt], [trait@gio::prelude::ListModelExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TreeListModel
impl TreeListModel
Sourcepub fn new<P: Fn(&Object) -> Option<ListModel> + 'static>(
root: impl IsA<ListModel>,
passthrough: bool,
autoexpand: bool,
create_func: P,
) -> TreeListModel
pub fn new<P: Fn(&Object) -> Option<ListModel> + 'static>( root: impl IsA<ListModel>, passthrough: bool, autoexpand: bool, create_func: P, ) -> TreeListModel
Creates a new empty TreeListModel displaying @root
with all rows collapsed.
root
The GListModel to use as root
passthrough
true to pass through items from the models
autoexpand
true to set the autoexpand property and expand the @root model
create_func
function to
call to create the GListModel for the children of an item
Returns
a newly created TreeListModel.
Sourcepub fn is_autoexpand(&self) -> bool
pub fn is_autoexpand(&self) -> bool
Gets whether the model is set to automatically expand new rows that get added.
This can be either rows added by changes to the underlying
models or via TreeListRow::set_expanded().
Returns
true if the model is set to autoexpand
Sourcepub fn child_row(&self, position: u32) -> Option<TreeListRow>
pub fn child_row(&self, position: u32) -> Option<TreeListRow>
Sourcepub fn is_passthrough(&self) -> bool
pub fn is_passthrough(&self) -> bool
Gets whether the model is passing through original row items.
If this function returns false, the GListModel functions for @self
return custom TreeListRow objects. You need to call
TreeListRow::item() on these objects to get the original
item.
If true, the values of the child models are passed through in their
original state. You then need to call row()
to get the custom TreeListRows.
Returns
true if the model is passing through original row items
Sourcepub fn row(&self, position: u32) -> Option<TreeListRow>
pub fn row(&self, position: u32) -> Option<TreeListRow>
Gets the row object for the given row.
If @position is greater than the number of items in @self,
None is returned.
The row object can be used to expand and collapse rows as well as to inspect its position in the tree. See its documentation for details.
This row object is persistent and will refer to the current item as long as the row is present in @self, independent of other rows being added or removed.
If @self is set to not be passthrough, this function is equivalent to calling g_list_model_get_item().
Do not confuse this function with child_row().
position
the position of the row to fetch
Returns
The row item
Sourcepub fn set_autoexpand(&self, autoexpand: bool)
pub fn set_autoexpand(&self, autoexpand: bool)
Sets whether the model should autoexpand.
If set to true, the model will recursively expand all rows that
get added to the model. This can be either rows added by changes
to the underlying models or via TreeListRow::set_expanded().
autoexpand
true to make the model autoexpand its rows
pub fn connect_autoexpand_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId