TreeView

Struct TreeView 

pub struct TreeView { /* private fields */ }
👎Deprecated:

Since 4.10

Use ListView for lists, and ColumnView for tabular lists [dndtarget]


[`TreeView`][crate::TreeView] has a main CSS node with name `treeview` and style class `.view`.
It has a subnode with name `header`, which is the parent for all the column
header widgets' CSS nodes.

Each column header consists of a `button`, which among other content, has a
child with name `sort-indicator`, which carries the `.ascending` or `.descending`
style classes when the column header should show a sort indicator. The CSS
is expected to provide a suitable image using the `-gtk-icon-source` property.

For rubberband selection, a subnode with name `rubberband` is used.

For the drop target location during DND, a subnode with name `dndtarget` is used.

## Properties


#### `activate-on-single-click`
 The activate-on-single-click property specifies whether the "row-activated" signal
will be emitted after a single click.

Readable | Writable


#### `enable-grid-lines`
 Readable | Writable


#### `enable-search`
 Readable | Writable


#### `enable-tree-lines`
 Readable | Writable


#### `expander-column`
 Readable | Writable


#### `fixed-height-mode`
 Setting the ::fixed-height-mode property to [`true`] speeds up
[`TreeView`][crate::TreeView] by assuming that all rows have the same height.
Only enable this option if all rows are the same height.
Please see gtk_tree_view_set_fixed_height_mode() for more
information on this option.

Readable | Writable


#### `headers-clickable`
 Readable | Writable


#### `headers-visible`
 Readable | Writable


#### `hover-expand`
 Enables or disables the hover expansion mode of @tree_view.
Hover expansion makes rows expand or collapse if the pointer moves
over them.

This mode is primarily intended for treeviews in popups, e.g.
in [`ComboBox`][crate::ComboBox] or [`EntryCompletion`][crate::EntryCompletion].

Readable | Writable


#### `hover-selection`
 Enables or disables the hover selection mode of @tree_view.
Hover selection makes the selected row follow the pointer.
Currently, this works only for the selection modes
[`SelectionMode::Single`][crate::SelectionMode::Single] and [`SelectionMode::Browse`][crate::SelectionMode::Browse].

This mode is primarily intended for treeviews in popups, e.g.
in [`ComboBox`][crate::ComboBox] or [`EntryCompletion`][crate::EntryCompletion].

Readable | Writable


#### `level-indentation`
 Extra indentation for each level.

Readable | Writable


#### `model`
 Readable | Writable


#### `reorderable`
 Readable | Writable


#### `rubber-banding`
 Readable | Writable


#### `search-column`
 Readable | Writable


#### `show-expanders`
 [`true`] if the view has expanders.

Readable | Writable


#### `tooltip-column`
 Readable | Writable
<details><summary><h4>Widget</h4></summary>


#### `can-focus`
 Whether the widget or any of its descendents can accept
the input focus.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `can-target`
 Whether the widget can receive pointer events.

Readable | Writable


#### `css-classes`
 A list of css classes applied to this widget.

Readable | Writable


#### `css-name`
 The name of this widget in the CSS tree.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable | Construct Only


#### `cursor`
 The cursor used by @widget.

Readable | Writable


#### `focus-on-click`
 Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writable


#### `focusable`
 Whether this widget itself will accept the input focus.

Readable | Writable


#### `halign`
 How to distribute horizontal space if widget gets extra space.

Readable | Writable


#### `has-default`
 Whether the widget is the default widget.

Readable


#### `has-focus`
 Whether the widget has the input focus.

Readable


#### `has-tooltip`
 Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.

A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.

Readable | Writable


#### `height-request`
 Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writable


#### `hexpand`
 Whether to expand horizontally.

Readable | Writable


#### `hexpand-set`
 Whether to use the `hexpand` property.

Readable | Writable


#### `layout-manager`
 The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `limit-events`
 Makes this widget act like a modal dialog, with respect to
event delivery.

Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].

Readable | Writable


#### `margin-bottom`
 Margin on bottom side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-end`
 Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-start`
 Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `margin-top`
 Margin on top side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.

Readable | Writable


#### `name`
 The name of the widget.

Readable | Writable


#### `opacity`
 The requested opacity of the widget.

Readable | Writable


#### `overflow`
 How content outside the widget's content area is treated.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `parent`
 The parent widget of this widget.

Readable


#### `receives-default`
 Whether the widget will receive the default action when it is focused.

Readable | Writable


#### `root`
 The [`Root`][crate::Root] widget of the widget tree containing this widget.

This will be `NULL` if the widget is not contained in a root widget.

Readable


#### `scale-factor`
 The scale factor of the widget.

Readable


#### `sensitive`
 Whether the widget responds to input.

Readable | Writable


#### `tooltip-markup`
 Sets the text of tooltip to be the given string, which is marked up
with Pango markup.

Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `tooltip-text`
 Sets the text of tooltip to be the given string.

Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `valign`
 How to distribute vertical space if widget gets extra space.

Readable | Writable


#### `vexpand`
 Whether to expand vertically.

Readable | Writable


#### `vexpand-set`
 Whether to use the `vexpand` property.

Readable | Writable


#### `visible`
 Whether the widget is visible.

Readable | Writable


#### `width-request`
 Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>


#### `accessible-role`
 The accessible role of the given [`Accessible`][crate::Accessible] implementation.

The accessible role cannot be changed once set.

Readable | Writable
</details>
<details><summary><h4>Scrollable</h4></summary>


#### `hadjustment`
 Horizontal [`Adjustment`][crate::Adjustment] of the scrollable widget.

This adjustment is shared between the scrollable widget and its parent.

Readable | Writable | Construct


#### `hscroll-policy`
 Determines when horizontal scrolling should start.

Readable | Writable


#### `vadjustment`
 Vertical [`Adjustment`][crate::Adjustment] of the scrollable widget.

This adjustment is shared between the scrollable widget and its parent.

Readable | Writable | Construct


#### `vscroll-policy`
 Determines when vertical scrolling should start.

Readable | Writable
</details>

## Signals


#### `columns-changed`
 The number of columns of the treeview has changed.




#### `cursor-changed`
 The position of the cursor (focused cell) has changed.




#### `expand-collapse-cursor-row`
 Action


#### `move-cursor`
 The [`TreeView`][crate::TreeView]::move-cursor signal is a [keybinding
signal][`SignalAction`][crate::SignalAction] which gets emitted when the user
presses one of the cursor keys.

Applications should not connect to it, but may emit it with
g_signal_emit_by_name() if they need to control the cursor
programmatically. In contrast to gtk_tree_view_set_cursor() and
gtk_tree_view_set_cursor_on_cell() when moving horizontally
[`TreeView`][crate::TreeView]::move-cursor does not reset the current selection.

Action


#### `row-activated`
  is pressed.

For selection handling refer to the
[tree widget conceptual overview](https://docs.gtk.org/gtk4/section-tree-widget.html)
as well as [`TreeSelection`][crate::TreeSelection].

Action


#### `row-collapsed`
 The given row has been collapsed (child nodes are hidden).




#### `row-expanded`
 The given row has been expanded (child nodes are shown).




#### `select-all`
 Action


#### `select-cursor-parent`
 Action


#### `select-cursor-row`
 Action


#### `start-interactive-search`
 Action


#### `test-collapse-row`
 The given row is about to be collapsed (hide its children nodes). Use this
signal if you need to control the collapsibility of individual rows.




#### `test-expand-row`
 The given row is about to be expanded (show its children nodes). Use this
signal if you need to control the expandability of individual rows.




#### `toggle-cursor-row`
 Action


#### `unselect-all`
 Action
<details><summary><h4>Widget</h4></summary>


#### `destroy`
 Signals that all holders of a reference to the widget should release
the reference that they hold.

May result in finalization of the widget if all references are released.

This signal is not suitable for saving widget state.




#### `direction-changed`
 Emitted when the text direction of a widget changes.




#### `hide`
 Emitted when @widget is hidden.




#### `keynav-failed`
 Emitted if keyboard navigation fails.

See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.




#### `map`
 Emitted when @widget is going to be mapped.

A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.

The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].




#### `mnemonic-activate`
 Emitted when a widget is activated via a mnemonic.

The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.




#### `move-focus`
  to move backward.

Action


#### `query-tooltip`
 s tooltip is about to be shown.

This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.

Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.

The signal handler is free to manipulate @tooltip with the therefore
destined function calls.




#### `realize`
 Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].

This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).




#### `show`
 Emitted when @widget is shown.




#### `state-flags-changed`
 Emitted when the widget state changes.

See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].




#### `unmap`
 Emitted when @widget is going to be unmapped.

A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.

As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.




#### `unrealize`
 Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.

This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).


</details>

# Implements

[`TreeViewExt`][trait@crate::prelude::TreeViewExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`ScrollableExt`][trait@crate::prelude::ScrollableExt], [`TreeViewExtManual`][trait@crate::prelude::TreeViewExtManual], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl TreeView

pub const NONE: Option<&'static TreeView> = None

👎Deprecated:

Since 4.10

pub fn new() -> TreeView

👎Deprecated:

Since 4.10

Creates a new TreeView widget.

Deprecated since 4.10

Use ListView or ColumnView instead

Returns

A newly created TreeView widget.

pub fn with_model(model: &impl IsA<TreeModel>) -> TreeView

👎Deprecated:

Since 4.10

Creates a new TreeView widget with the model initialized to @model.

Deprecated since 4.10

Use ListView or ColumnView instead

model

the model.

Returns

A newly created TreeView widget.

pub fn builder() -> TreeViewBuilder

👎Deprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct TreeView objects.

This method returns an instance of TreeViewBuilder which can be used to create TreeView objects.