TreeViewColumn

Struct TreeViewColumn 

pub struct TreeViewColumn { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

Use ColumnView and ColumnViewColumn instead of TreeView to show a tabular list A visible column in a TreeView widget

The TreeViewColumn object represents a visible column in a TreeView widget. It allows to set properties of the column header, and functions as a holding pen for the cell renderers which determine how the data in the column is displayed.

Please refer to the tree widget conceptual overview for an overview of all the objects and data types related to the tree widget and how they work together, and to the TreeView documentation for specifics about the CSS node structure for treeviews and their headers.

Properties

alignment

Readable | Writable

cell-area

The CellArea used to layout cell renderers for this column.

If no area is specified when creating the tree view column with gtk_tree_view_column_new_with_area() a horizontally oriented CellAreaBox will be used.

Readable | Writable | Construct Only

clickable

Readable | Writable

expand

Readable | Writable

fixed-width

Readable | Writable

max-width

Readable | Writable

min-width

Readable | Writable

reorderable

Readable | Writable

resizable

Readable | Writable

sizing

Readable | Writable

sort-column-id

Logical sort column ID this column sorts on when selected for sorting. Setting the sort column ID makes the column header clickable. Set to -1 to make the column unsortable.

Readable | Writable

sort-indicator

Readable | Writable

sort-order

Readable | Writable

spacing

Readable | Writable

title

Readable | Writable

visible

Readable | Writable

widget

Readable | Writable

width

Readable

x-offset

Readable

Signals

clicked

Emitted when the columnโ€™s header has been clicked.

Implements

[trait@glib::ObjectExt], BuildableExt, CellLayoutExt, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl TreeViewColumn

pub fn new() -> TreeViewColumn

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new TreeViewColumn.

Deprecated since 4.10

Use GtkColumnView instead

Returns

A newly created TreeViewColumn.

pub fn with_area(area: &impl IsA<CellArea>) -> TreeViewColumn

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new TreeViewColumn using @area to render its cells.

Deprecated since 4.10

Use GtkColumnView instead

area

the CellArea that the newly created column should use to layout cells.

Returns

A newly created TreeViewColumn.

pub fn builder() -> TreeViewColumnBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct TreeViewColumn objects.

This method returns an instance of TreeViewColumnBuilder which can be used to create TreeViewColumn objects.

pub fn add_attribute( &self, cell_renderer: &impl IsA<CellRenderer>, attribute: &str, column: i32, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Adds an attribute mapping to the list in @self.

The @column is the column of the model to get a value from, and the @attribute is the parameter on @cell_renderer to be set from the value. So for example if column 2 of the model contains strings, you could have the โ€œtextโ€ attribute of a CellRendererText get its values from column 2.

Deprecated since 4.10

Use GtkColumnView instead

cell_renderer

the CellRenderer to set attributes on

attribute

An attribute on the renderer

column

The column position on the model to get the attribute from.

pub fn cell_get_position( &self, cell_renderer: &impl IsA<CellRenderer>, ) -> Option<(i32, i32)>

๐Ÿ‘ŽDeprecated:

Since 4.10

Obtains the horizontal position and size of a cell in a column.

If the cell is not found in the column, @start_pos and @width are not changed and false is returned.

Deprecated since 4.10

Use GtkColumnView instead

cell_renderer

a CellRenderer

Returns

true if @cell belongs to @self

x_offset

return location for the horizontal position of @cell within @self

width

return location for the width of @cell

pub fn cell_get_size(&self) -> (i32, i32, i32, i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Obtains the width and height needed to render the column. This is used primarily by the TreeView.

Deprecated since 4.10

Use GtkColumnView instead

Returns
x_offset

location to return x offset of a cell relative to @cell_area

y_offset

location to return y offset of a cell relative to @cell_area

width

location to return width needed to render a cell

height

location to return height needed to render a cell

pub fn cell_is_visible(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if any of the cells packed into the @self are visible. For this to be meaningful, you must first initialize the cells with gtk_tree_view_column_cell_set_cell_data()

Deprecated since 4.10

Use GtkColumnView instead

Returns

true, if any of the cells packed into the @self are currently visible

pub fn cell_set_cell_data( &self, tree_model: &impl IsA<TreeModel>, iter: &TreeIter, is_expander: bool, is_expanded: bool, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the cell renderer based on the @tree_model and @iter. That is, for every attribute mapping in @self, it will get a value from the set column on the @iter, and use that value to set the attribute on the cell renderer. This is used primarily by the TreeView.

Deprecated since 4.10

Use GtkColumnView instead

tree_model

The TreeModel to get the cell renderers attributes from.

iter

The TreeIter to get the cell rendererโ€™s attributes from.

is_expander

true, if the row has children

is_expanded

true, if the row has visible children

pub fn clear(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Unsets all the mappings on all renderers on the @self.

Deprecated since 4.10

Use GtkColumnView instead

pub fn clear_attributes(&self, cell_renderer: &impl IsA<CellRenderer>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Clears all existing attributes previously set with gtk_tree_view_column_set_attributes().

Deprecated since 4.10

Use GtkColumnView instead

cell_renderer

a CellRenderer to clear the attribute mapping on.

pub fn clicked(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Emits the โ€œclickedโ€ signal on the column. This function will only work if @self is clickable.

Deprecated since 4.10

Use GtkColumnView instead

pub fn focus_cell(&self, cell: &impl IsA<CellRenderer>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the current keyboard focus to be at @cell, if the column contains 2 or more editable and activatable cells.

Deprecated since 4.10

Use GtkColumnView instead

cell

A CellRenderer

pub fn alignment(&self) -> f32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the current x alignment of @self. This value can range between 0.0 and 1.0.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The current alignent of @self.

pub fn button(&self) -> Widget

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the button used in the treeview column header

Deprecated since 4.10

Use GtkColumnView instead

Returns

The button for the column header.

pub fn is_clickable(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if the user can click on the header for the column.

Deprecated since 4.10

Use GtkColumnView instead

Returns

true if user can click the column header.

pub fn expands(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if the column expands to fill available space.

Deprecated since 4.10

Use GtkColumnView instead

Returns

true if the column expands to fill available space.

pub fn fixed_width(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the fixed width of the column. This may not be the actual displayed width of the column; for that, use gtk_tree_view_column_get_width().

Deprecated since 4.10

Use GtkColumnView instead

Returns

The fixed width of the column.

pub fn max_width(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the maximum width in pixels of the @self, or -1 if no maximum width is set.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The maximum width of the @self.

pub fn min_width(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the minimum width in pixels of the @self, or -1 if no minimum width is set.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The minimum width of the @self.

pub fn is_reorderable(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if the @self can be reordered by the user.

Deprecated since 4.10

Use GtkColumnView instead

Returns

true if the @self can be reordered by the user.

pub fn is_resizable(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if the @self can be resized by the end user.

Deprecated since 4.10

Use GtkColumnView instead

Returns

true, if the @self can be resized.

pub fn sizing(&self) -> TreeViewColumnSizing

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the current type of @self.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The type of @self.

pub fn sort_column_id(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the logical @sort_column_id that the model sorts on when this column is selected for sorting.

See set_sort_column_id().

Deprecated since 4.10

Use GtkColumnView instead

Returns

the current @sort_column_id for this column, or -1 if this column canโ€™t be used for sorting

pub fn is_sort_indicator(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the value set by gtk_tree_view_column_set_sort_indicator().

Deprecated since 4.10

Use GtkColumnView instead

Returns

whether the sort indicator arrow is displayed

pub fn sort_order(&self) -> SortType

๐Ÿ‘ŽDeprecated:

Since 4.10

Gets the value set by gtk_tree_view_column_set_sort_order().

Deprecated since 4.10

Use GtkColumnView instead

Returns

the sort order the sort indicator is indicating

pub fn spacing(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the spacing of @self.

Deprecated since 4.10

Use GtkColumnView instead

Returns

the spacing of @self.

pub fn title(&self) -> GString

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the title of the widget.

Deprecated since 4.10

Use GtkColumnView instead

Returns

the title of the column. This string should not be modified or freed.

pub fn tree_view(&self) -> Option<Widget>

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the TreeView wherein @self has been inserted. If @column is currently not inserted in any tree view, None is returned.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The tree view wherein @column has been inserted

pub fn is_visible(&self) -> bool

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns true if @self is visible.

Deprecated since 4.10

Use GtkColumnView instead

Returns

whether the column is visible or not. If it is visible, then the tree will show the column.

pub fn widget(&self) -> Option<Widget>

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the Widget in the button on the column header.

If a custom widget has not been set then None is returned.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The Widget in the column header

pub fn width(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the current size of @self in pixels.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The current width of @self.

pub fn x_offset(&self) -> i32

๐Ÿ‘ŽDeprecated:

Since 4.10

Returns the current X offset of @self in pixels.

Deprecated since 4.10

Use GtkColumnView instead

Returns

The current X offset of @self.

pub fn pack_end(&self, cell: &impl IsA<CellRenderer>, expand: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Adds the @cell to end of the column. If @expand is false, then the @cell is allocated no more space than it needs. Any unused space is divided evenly between cells for which @expand is true.

Deprecated since 4.10

Use GtkColumnView instead

cell

The CellRenderer

expand

true if @cell is to be given extra space allocated to @self.

pub fn pack_start(&self, cell: &impl IsA<CellRenderer>, expand: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Packs the @cell into the beginning of the column. If @expand is false, then the @cell is allocated no more space than it needs. Any unused space is divided evenly between cells for which @expand is true.

Deprecated since 4.10

Use GtkColumnView instead

cell

The CellRenderer

expand

true if @cell is to be given extra space allocated to @self.

pub fn queue_resize(&self)

๐Ÿ‘ŽDeprecated:

Since 4.10

Flags the column, and the cell renderers added to this column, to have their sizes renegotiated.

Deprecated since 4.10

Use GtkColumnView instead

pub fn set_alignment(&self, xalign: f32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the alignment of the title or custom widget inside the column header. The alignment determines its location inside the button โ€“ 0.0 for left, 0.5 for center, 1.0 for right.

Deprecated since 4.10

Use GtkColumnView instead

xalign

The alignment, which is between [0.0 and 1.0] inclusive.

pub fn set_cell_data_func<P: Fn(&TreeViewColumn, &CellRenderer, &TreeModel, &TreeIter) + 'static>( &self, cell_renderer: &impl IsA<CellRenderer>, func: P, )

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the GtkTreeCellDataFunc to use for the column.

This function is used instead of the standard attributes mapping for setting the column value, and should set the value of @selfโ€™s cell renderer as appropriate. @func may be None to remove an older one.

Deprecated since 4.10

Use GtkColumnView instead

cell_renderer

A CellRenderer

func

The GtkTreeCellDataFunc to use.

func_data

The user data for @func.

pub fn set_clickable(&self, clickable: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the header to be active if @clickable is true. When the header is active, then it can take keyboard focus, and can be clicked.

Deprecated since 4.10

Use GtkColumnView instead

clickable

true if the header is active.

pub fn set_expand(&self, expand: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the column to take available extra space. This space is shared equally amongst all columns that have the expand set to true. If no column has this option set, then the last column gets all extra space. By default, every column is created with this false.

Along with โ€œfixed-widthโ€, the โ€œexpandโ€ property changes when the column is resized by the user.

Deprecated since 4.10

Use GtkColumnView instead

expand

true if the column should expand to fill available space.

pub fn set_fixed_width(&self, fixed_width: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

If @fixed_width is not -1, sets the fixed width of @self; otherwise unsets it. The effective value of @fixed_width is clamped between the minimum and maximum width of the column; however, the value stored in the โ€œfixed-widthโ€ property is not clamped. If the column sizing is TreeViewColumnSizing::GrowOnly or TreeViewColumnSizing::Autosize, setting a fixed width overrides the automatically calculated width. Note that @fixed_width is only a hint to GTK; the width actually allocated to the column may be greater or less than requested.

Along with โ€œexpandโ€, the โ€œfixed-widthโ€ property changes when the column is resized by the user.

Deprecated since 4.10

Use GtkColumnView instead

fixed_width

The new fixed width, in pixels, or -1.

pub fn set_max_width(&self, max_width: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the maximum width of the @self. If @max_width is -1, then the maximum width is unset. Note, the column can actually be wider than max width if itโ€™s the last column in a view. In this case, the column expands to fill any extra space.

Deprecated since 4.10

Use GtkColumnView instead

max_width

The maximum width of the column in pixels, or -1.

pub fn set_min_width(&self, min_width: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the minimum width of the @self. If @min_width is -1, then the minimum width is unset.

Deprecated since 4.10

Use GtkColumnView instead

min_width

The minimum width of the column in pixels, or -1.

pub fn set_reorderable(&self, reorderable: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

If @reorderable is true, then the column can be reordered by the end user dragging the header.

Deprecated since 4.10

Use GtkColumnView instead

reorderable

true, if the column can be reordered.

pub fn set_resizable(&self, resizable: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

If @resizable is true, then the user can explicitly resize the column by grabbing the outer edge of the column button.

If resizable is true and sizing mode of the column is TreeViewColumnSizing::Autosize, then the sizing mode is changed to TreeViewColumnSizing::GrowOnly.

Deprecated since 4.10

Use GtkColumnView instead

resizable

true, if the column can be resized

pub fn set_sizing(&self, type_: TreeViewColumnSizing)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the growth behavior of @self to @type_.

Deprecated since 4.10

Use GtkColumnView instead

type_

The TreeViewColumnSizing.

pub fn set_sort_column_id(&self, sort_column_id: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the logical @sort_column_id that this column sorts on when this column is selected for sorting. Doing so makes the column header clickable.

Deprecated since 4.10

Use GtkColumnView instead

sort_column_id

The @sort_column_id of the model to sort on.

pub fn set_sort_indicator(&self, setting: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Call this function with a @setting of true to display an arrow in the header button indicating the column is sorted. Call gtk_tree_view_column_set_sort_order() to change the direction of the arrow.

Deprecated since 4.10

Use GtkColumnView instead

setting

true to display an indicator that the column is sorted

pub fn set_sort_order(&self, order: SortType)

๐Ÿ‘ŽDeprecated:

Since 4.10

Changes the appearance of the sort indicator.

This does not actually sort the model. Use gtk_tree_view_column_set_sort_column_id() if you want automatic sorting support. This function is primarily for custom sorting behavior, and should be used in conjunction with gtk_tree_sortable_set_sort_column_id() to do that. For custom models, the mechanism will vary.

The sort indicator changes direction to indicate normal sort or reverse sort. Note that you must have the sort indicator enabled to see anything when calling this function; see gtk_tree_view_column_set_sort_indicator().

Deprecated since 4.10

Use GtkColumnView instead

order

sort order that the sort indicator should indicate

pub fn set_spacing(&self, spacing: i32)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the spacing field of @self, which is the number of pixels to place between cell renderers packed into it.

Deprecated since 4.10

Use GtkColumnView instead

spacing

distance between cell renderers in pixels.

pub fn set_title(&self, title: &str)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the title of the @self. If a custom widget has been set, then this value is ignored.

Deprecated since 4.10

Use GtkColumnView instead

title

The title of the @self.

pub fn set_visible(&self, visible: bool)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the visibility of @self.

Deprecated since 4.10

Use GtkColumnView instead

visible

true if the @self is visible.

pub fn set_widget(&self, widget: Option<&impl IsA<Widget>>)

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the widget in the header to be @widget. If widget is None, then the header button is set with a Label set to the title of @self.

Deprecated since 4.10

Use GtkColumnView instead

widget

A child Widget

pub fn cell_area(&self) -> Option<CellArea>

๐Ÿ‘ŽDeprecated:

Since 4.10

The CellArea used to layout cell renderers for this column.

If no area is specified when creating the tree view column with gtk_tree_view_column_new_with_area() a horizontally oriented CellAreaBox will be used.

pub fn connect_clicked<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Emitted when the columnโ€™s header has been clicked.

pub fn connect_alignment_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_clickable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_expand_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_fixed_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_max_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_min_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_reorderable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_resizable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_sizing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_sort_column_id_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_sort_indicator_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_sort_order_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_visible_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_widget_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn connect_x_offset_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.10

Source

impl TreeViewColumn

pub fn with_attributes( title: &str, cell_renderer: &impl IsA<CellRenderer>, attributes: &[(&str, i32)], ) -> Self

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new TreeViewColumn with a number of default values. This is equivalent to calling gtk_tree_view_column_set_title(), gtk_tree_view_column_pack_start(), and gtk_tree_view_column_set_attributes() on the newly created TreeViewColumn.

Hereโ€™s a simple example:

โš ๏ธ The following code is in c โš ๏ธ

 enum { TEXT_COLUMN, COLOR_COLUMN, N_COLUMNS };
 // ...
 {
   GtkTreeViewColumn *column;
   GtkCellRenderer   *renderer = gtk_cell_renderer_text_new ();

   column = gtk_tree_view_column_new_with_attributes ("Title",
                                                      renderer,
                                                      "text", TEXT_COLUMN,
                                                      "foreground", COLOR_COLUMN,
                                                      NULL);
 }
Deprecated since 4.10

Use GtkColumnView instead

title

The title to set the header to

cell

The CellRenderer

Returns

A newly created TreeViewColumn.

pub fn set_attributes( &self, cell_renderer: &impl IsA<CellRenderer>, attributes: &[(&str, i32)], )

๐Ÿ‘ŽDeprecated:

Since 4.10

Sets the attributes in the list as the attributes of @self.

The attributes should be in attribute/column order, as in gtk_tree_view_column_add_attribute(). All existing attributes are removed, and replaced with the new attributes.

Deprecated since 4.10

Use GtkColumnView instead

cell_renderer

the CellRenderer weโ€™re setting the attributes of

pub fn unset_cell_data_func(&self, cell_renderer: &impl IsA<CellRenderer>)

๐Ÿ‘ŽDeprecated:

Since 4.10