pub struct TryExpression { /* private fields */ }v4_22 only.Expand description
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl TryExpression
impl TryExpression
Sourcepub fn as_ptr(&self) -> *mut GtkTryExpression
pub fn as_ptr(&self) -> *mut GtkTryExpression
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut GtkTryExpression) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut GtkTryExpression) -> &Self
Borrows the underlying C value.
Sourceimpl TryExpression
impl TryExpression
pub fn upcast(self) -> Expression
pub fn upcast_ref(&self) -> &Expression
Sourceimpl TryExpression
impl TryExpression
pub fn new(params: impl IntoIterator<Item = impl AsRef<Expression>>) -> Self
Methods from Deref<Target = Expression>
Sourcepub fn as_ptr(&self) -> *mut GtkExpression
pub fn as_ptr(&self) -> *mut GtkExpression
Return the inner pointer to the underlying C value.
pub const NONE: Option<&'static Expression> = None
pub fn bind( &self, target: &impl IsA<Object>, property: &str, this_: Option<&impl IsA<Object>>, ) -> ExpressionWatch
pub fn value_type(&self) -> Type
pub fn is_static(&self) -> bool
pub fn watch<P: Fn() + 'static>( &self, this_: Option<&impl IsA<Object>>, notify: P, ) -> ExpressionWatch
pub fn upcast_ref(&self) -> &Self
pub fn is<E: IsExpression>(&self) -> bool
pub fn downcast_ref<E: IsExpression>(&self) -> Option<&E>
pub fn type_(&self) -> Type
pub fn evaluate(&self, this: Option<&impl IsA<Object>>) -> Option<Value>
Sourcepub fn evaluate_as<V: for<'b> FromValue<'b> + 'static, T: IsA<Object>>(
&self,
this: Option<&T>,
) -> Option<V>
pub fn evaluate_as<V: for<'b> FromValue<'b> + 'static, T: IsA<Object>>( &self, this: Option<&T>, ) -> Option<V>
Similar to Self::evaluate but panics if the value is of a different
type.
Sourcepub fn chain_property<T: IsA<Object>>(
&self,
property_name: &str,
) -> PropertyExpression
pub fn chain_property<T: IsA<Object>>( &self, property_name: &str, ) -> PropertyExpression
Create a PropertyExpression that looks up
for property_name with self as parameter. This is useful in long
chains of Expressions.
Sourcepub fn chain_closure<R>(&self, closure: RustClosure) -> ClosureExpressionwhere
R: ValueType,
pub fn chain_closure<R>(&self, closure: RustClosure) -> ClosureExpressionwhere
R: ValueType,
Create a ClosureExpression from a
glib::Closure with self as the second parameter and R as the
return type. The return type is checked at run-time and must always
be specified. This is useful in long chains of
Expressions when using the glib::closure!
macro.
Note that the first parameter will always be the this object bound to
the expression. If None is passed as this then the type of the
first parameter must be Option<glib::Object> otherwise type
checking will panic.
use glib::{closure, Object};
use gtk::{glib, prelude::*};
let button = gtk::Button::new();
button.set_label("Hello");
let label = button
.property_expression("label")
.chain_closure::<String>(closure!(|_: Option<Object>, label: &str| {
format!("{} World", label)
}))
.evaluate_as::<String, _>(gtk::Widget::NONE);
assert_eq!(label.unwrap(), "Hello World");Sourcepub fn chain_closure_with_callback<F, R>(&self, f: F) -> ClosureExpression
pub fn chain_closure_with_callback<F, R>(&self, f: F) -> ClosureExpression
Create a ClosureExpression with self as
the second parameter. This is useful in long chains of
Expressions.
Sourcepub fn chain_try(&self, fallback: impl AsRef<Expression>) -> TryExpression
pub fn chain_try(&self, fallback: impl AsRef<Expression>) -> TryExpression
Create a TryExpression with self as the first
parameter and fallback as the second parameter. This is useful in long
chains of Expressions.