pub struct Widget { /* private fields */ }Expand description
dispose = foo_widget_dispose;
gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), “/com/example/ui/foowidget.ui”); gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), FooWidget, hello_button); gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), FooWidget, goodbye_button); }
static void foo_widget_init (FooWidget *widget) { gtk_widget_init_template (GTK_WIDGET (widget)); }
You can also use [method@Gtk.WidgetClass.bind_template_callback_full] (or
is wrapper macro [func@Gtk.widget_class_bind_template_callback]) to connect
a signal callback defined in the template with a function visible in the
scope of the class, e.g.
```c
// the signal handler has the instance and user data swapped
// because of the swapped="yes" attribute in the template XML
static void
hello_button_clicked (FooWidget *self,
GtkButton *button)
{
g_print ("Hello, world!\n");
}
static void
foo_widget_class_init (FooWidgetClass *klass)
{
// ...
gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
"/com/example/ui/foowidget.ui");
gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), hello_button_clicked);
}
```text
This is an Abstract Base Class, you cannot instantiate it.
## Properties
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
## Signals
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Widget
impl Widget
pub const NONE: Option<&'static Widget> = None
Sourcepub fn default_direction() -> TextDirection
pub fn default_direction() -> TextDirection
Sourcepub fn set_default_direction(dir: TextDirection)
pub fn set_default_direction(dir: TextDirection)
Sets the default reading direction for widgets.
See WidgetExt::set_direction().
dir
the new default direction, either [enum@Gtk.TextDirection.ltr] or [enum@Gtk.TextDirection.rtl]