pub struct WindowGroup { /* private fields */ }Expand description
Creates groups of windows that behave like separate applications.
It achieves this by limiting the effect of GTK grabs and modality to windows in the same group.
A window can be a member in at most one window group at a time. Windows that have not been explicitly assigned to a group are implicitly treated like windows of the default window group.
WindowGroup objects are referenced by each window in the group,
so once you have added all windows to a WindowGroup, you can drop
the initial reference to the window group with g_object_unref(). If the
windows in the window group are subsequently destroyed, then they will
be removed from the window group and drop their references on the window
group; when all window have been removed, the window group will be
freed.
Implements
WindowGroupExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl WindowGroup
impl WindowGroup
pub const NONE: Option<&'static WindowGroup> = None
Sourcepub fn new() -> WindowGroup
pub fn new() -> WindowGroup
Creates a new WindowGroup object.
Modality of windows only affects windows
within the same WindowGroup.
Returns
a new WindowGroup.