pub trait ComboBoxImpl: WidgetImpl + ObjectSubclass<Type: IsA<ComboBox> + IsA<CellEditable> + IsA<CellLayout>> {
// Provided methods
fn activate(&self) { ... }
fn changed(&self) { ... }
fn format_entry_text(&self, path: &str) -> Option<GString> { ... }
}๐Deprecated:
Since 4.10
Provided Methods
fn activate(&self)
๐Deprecated:
Since 4.10
Available on crate feature
v4_6 only.Sourcefn changed(&self)
๐Deprecated: Since 4.10
fn changed(&self)
Since 4.10
Signal is emitted when the active item is changed.
Sourcefn format_entry_text(&self, path: &str) -> Option<GString>
๐Deprecated: Since 4.10
fn format_entry_text(&self, path: &str) -> Option<GString>
Since 4.10
Signal which allows you to change how the text displayed in a combo boxโs entry is displayed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".