DialogImpl

Trait DialogImpl 

pub trait DialogImpl: WindowImpl + ObjectSubclass<Type: IsA<Dialog>> {
    // Provided methods
    fn response(&self, response: ResponseType) { ... }
    fn close(&self) { ... }
}

Provided Methods

fn response(&self, response: ResponseType)

Emits the ::response signal with the given response ID.

Used to indicate that the user has responded to the dialog in some way.

Deprecated since 4.10

Use Window instead

response_id

response ID

fn close(&self)

Signal emitted when the user uses a keybinding to close the dialog.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors