PrintOperationImpl

Trait PrintOperationImpl 

pub trait PrintOperationImpl: ObjectImpl + ObjectSubclass<Type: IsA<PrintOperation> + IsA<PrintOperationPreview>> {
    // Provided methods
    fn begin_print(&self, context: &PrintContext) { ... }
    fn create_custom_widget(&self) -> Option<Widget> { ... }
    fn custom_widget_apply(&self, widget: &Widget) { ... }
    fn done(&self, result: PrintOperationResult) { ... }
    fn draw_page(&self, context: &PrintContext, page_nr: i32) { ... }
    fn end_print(&self, context: &PrintContext) { ... }
    fn paginate(&self, context: &PrintContext) -> bool { ... }
    fn preview(
        &self,
        preview: &PrintOperationPreview,
        context: &PrintContext,
        parent: Option<&Window>,
    ) -> bool { ... }
    fn request_page_setup(
        &self,
        context: &PrintContext,
        page_nr: i32,
        setup: &PageSetup,
    ) { ... }
    fn status_changed(&self) { ... }
    fn update_custom_widget(
        &self,
        widget: &Widget,
        setup: &PageSetup,
        settings: &PrintSettings,
    ) { ... }
}

Provided Methods

fn begin_print(&self, context: &PrintContext)

Signal emitted after the user has finished changing print settings in the dialog, before the actual rendering starts.

fn create_custom_widget(&self) -> Option<Widget>

Signal emitted when displaying the print dialog.

fn custom_widget_apply(&self, widget: &Widget)

Signal emitted right before “begin-print” if you added a custom widget in the “create-custom-widget” handler.

fn done(&self, result: PrintOperationResult)

Signal emitted when the print operation run has finished doing everything required for printing.

fn draw_page(&self, context: &PrintContext, page_nr: i32)

Signal emitted for every page that is printed.

fn end_print(&self, context: &PrintContext)

Signal emitted after all pages have been rendered.

fn paginate(&self, context: &PrintContext) -> bool

Signal emitted after the “begin-print” signal, but before the actual rendering starts.

fn preview( &self, preview: &PrintOperationPreview, context: &PrintContext, parent: Option<&Window>, ) -> bool

Signal emitted when a preview is requested from the native dialog.

fn request_page_setup( &self, context: &PrintContext, page_nr: i32, setup: &PageSetup, )

Emitted once for every page that is printed, to give the application a chance to modify the page setup.

fn status_changed(&self)

Emitted at between the various phases of the print operation.

fn update_custom_widget( &self, widget: &Widget, setup: &PageSetup, settings: &PrintSettings, )

Emitted after change of selected printer.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors