CompositeTemplateClass

Trait CompositeTemplateClass 

pub trait CompositeTemplateClass {
    // Required method
    fn bind_template(&mut self);
}
An extension trait for ClassStruct types to allow binding a composite template directly on self. This is a convenience wrapper around the CompositeTemplate trait.

Required Methods

fn bind_template(&mut self)

Binds the template callbacks from this type into the default template scope for self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, U> CompositeTemplateClass for T
where T: ClassStruct<Type = U>, U: ObjectSubclass<Class = T> + CompositeTemplate,