CompositeTemplateInstanceCallbacksClass

Trait CompositeTemplateInstanceCallbacksClass 

pub trait CompositeTemplateInstanceCallbacksClass {
    // Required method
    fn bind_template_instance_callbacks(&mut self);
}
An extension trait for ClassStruct types to allow binding the instance template callbacks directly on self. This is a convenience wrapper around the CompositeTemplateCallbacks trait.

Required Methods

fn bind_template_instance_callbacks(&mut self)

Binds the template callbacks from the instance type into the default template scope for self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors