pub fn check_version(
required_major: u32,
required_minor: u32,
required_micro: u32,
) -> Option<GString>Expand description
t completely reliable, since the module may be linked against an old version of GTK and calling the old version of gtk_check_version(), but still get loaded into an application using a newer version of GTK.
required_major
the required major version
required_minor
the required minor version
required_micro
the required micro version
Returns
None if the GTK library is compatible with the
given version, or a string describing the version mismatch.
The returned string is owned by GTK and should not be modified
or freed.