pub trait ComboBoxExt: IsA<ComboBox> + 'static {
Show 44 methods
// Provided methods
fn active_id(&self) -> Option<GString> { ... }
fn active_iter(&self) -> Option<TreeIter> { ... }
fn button_sensitivity(&self) -> SensitivityType { ... }
fn child(&self) -> Option<Widget> { ... }
fn entry_text_column(&self) -> i32 { ... }
fn has_entry(&self) -> bool { ... }
fn id_column(&self) -> i32 { ... }
fn model(&self) -> Option<TreeModel> { ... }
fn is_popup_fixed_width(&self) -> bool { ... }
fn popdown(&self) { ... }
fn popup(&self) { ... }
fn popup_for_device(&self, device: &Device) { ... }
fn set_active_id(&self, active_id: Option<&str>) -> bool { ... }
fn set_active_iter(&self, iter: Option<&TreeIter>) { ... }
fn set_button_sensitivity(&self, sensitivity: SensitivityType) { ... }
fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... }
fn set_entry_text_column(&self, text_column: i32) { ... }
fn set_id_column(&self, id_column: i32) { ... }
fn set_model(&self, model: Option<&impl IsA<TreeModel>>) { ... }
fn set_popup_fixed_width(&self, fixed: bool) { ... }
fn set_row_separator_func<P: Fn(&TreeModel, &TreeIter) -> bool + 'static>(
&self,
func: P,
) { ... }
fn has_frame(&self) -> bool { ... }
fn set_has_frame(&self, has_frame: bool) { ... }
fn is_popup_shown(&self) -> bool { ... }
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn emit_activate(&self) { ... }
fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_format_entry_text<F: Fn(&Self, &str) -> String + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_move_active<F: Fn(&Self, ScrollType) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn emit_move_active(&self, scroll_type: ScrollType) { ... }
fn connect_popdown<F: Fn(&Self) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn emit_popdown(&self) -> bool { ... }
fn connect_popup<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn emit_popup(&self) { ... }
fn connect_active_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_active_id_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_button_sensitivity_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_entry_text_column_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_has_frame_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_id_column_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_popup_fixed_width_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_popup_shown_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Since 4.10
Provided Methods
Sourcefn active_id(&self) -> Option<GString>
๐Deprecated: Since 4.10
fn active_id(&self) -> Option<GString>
Since 4.10
Returns the ID of the active row of @self.
This value is taken from the active row and the column specified
by the id-column property of @self
(see set_id_column()).
The returned value is an interned string which means that you can compare the pointer by value to other interned strings and that you must not free it.
If the id-column property of @self is
not set, or if no row is active, or if the active row has a None
ID value, then None is returned.
Deprecated since 4.10
Use DropDown
Returns
the ID of the active row
Sourcefn active_iter(&self) -> Option<TreeIter>
๐Deprecated: Since 4.10
fn active_iter(&self) -> Option<TreeIter>
Since 4.10
๐Deprecated: Since 4.10
Since 4.10
Returns whether the combo box sets the dropdown button sensitive or not when there are no items in the model.
Deprecated since 4.10
Use DropDown
Returns
SensitivityType::On if the dropdown button
is sensitive when the model is empty, SensitivityType::Off
if the button is always insensitive or SensitivityType::Auto
if it is only sensitive as long as the model has one item to
be selected.
Sourcefn entry_text_column(&self) -> i32
๐Deprecated: Since 4.10
fn entry_text_column(&self) -> i32
Since 4.10
Sourcefn is_popup_fixed_width(&self) -> bool
๐Deprecated: Since 4.10
fn is_popup_fixed_width(&self) -> bool
Since 4.10
Sourcefn popup_for_device(&self, device: &Device)
๐Deprecated: Since 4.10
fn popup_for_device(&self, device: &Device)
Since 4.10
Pops up the menu of @self.
Note that currently this does not do anything with the device, as it was previously only used for list-mode combo boxes, and those were removed in GTK 4. However, it is retained in case similar functionality is added back later.
Deprecated since 4.10
Use DropDown
device
Sourcefn set_active_id(&self, active_id: Option<&str>) -> bool
๐Deprecated: Since 4.10
fn set_active_id(&self, active_id: Option<&str>) -> bool
Since 4.10
Changes the active row of @self to the one that has an ID equal to @active_id.
If @active_id is None, the active row is unset. Rows having
a None ID string cannot be made active by this function.
If the id-column property of @self is
unset or if no row has the given ID then the function does nothing
and returns false.
Deprecated since 4.10
Use DropDown
active_id
the ID of the row to select
Returns
true if a row with a matching ID was found. If a None
@active_id was given to unset the active row, the function
always returns true.
Sourcefn set_active_iter(&self, iter: Option<&TreeIter>)
๐Deprecated: Since 4.10
fn set_active_iter(&self, iter: Option<&TreeIter>)
Since 4.10
๐Deprecated: Since 4.10
Since 4.10
Sourcefn set_entry_text_column(&self, text_column: i32)
๐Deprecated: Since 4.10
fn set_entry_text_column(&self, text_column: i32)
Since 4.10
Sets the model column which @self should use to get strings from to be @text_column.
For this column no separate
CellRenderer is needed.
The column @text_column in the model of @self must be of
type G_TYPE_STRING.
This is only relevant if @self has been created with
has-entry as true.
Deprecated since 4.10
Use DropDown
text_column
A column in @model to get the strings from for the internal entry
Sourcefn set_id_column(&self, id_column: i32)
๐Deprecated: Since 4.10
fn set_id_column(&self, id_column: i32)
Since 4.10
Sourcefn set_model(&self, model: Option<&impl IsA<TreeModel>>)
๐Deprecated: Since 4.10
fn set_model(&self, model: Option<&impl IsA<TreeModel>>)
Since 4.10
Sets the model used by @self to be @model.
Will unset a previously set model (if applicable). If model is None,
then it will unset the model.
Note that this function does not clear the cell renderers, you have to
call CellLayoutExt::clear() yourself if you need to set up different
cell renderers for the new model.
Deprecated since 4.10
Use DropDown
model
Sourcefn set_popup_fixed_width(&self, fixed: bool)
๐Deprecated: Since 4.10
fn set_popup_fixed_width(&self, fixed: bool)
Since 4.10
Sourcefn set_row_separator_func<P: Fn(&TreeModel, &TreeIter) -> bool + 'static>(
&self,
func: P,
)
๐Deprecated: Since 4.10
fn set_row_separator_func<P: Fn(&TreeModel, &TreeIter) -> bool + 'static>( &self, func: P, )
Since 4.10
Sourcefn has_frame(&self) -> bool
๐Deprecated: Since 4.10
fn has_frame(&self) -> bool
Since 4.10
The has-frame property controls whether a frame is drawn around the entry.
Sourcefn set_has_frame(&self, has_frame: bool)
๐Deprecated: Since 4.10
fn set_has_frame(&self, has_frame: bool)
Since 4.10
The has-frame property controls whether a frame is drawn around the entry.
Sourcefn is_popup_shown(&self) -> bool
๐Deprecated: Since 4.10
fn is_popup_shown(&self) -> bool
Since 4.10
Whether the combo boxes dropdown is popped up.
Note that this property is mainly useful, because it allows you to connect to notify::popup-shown.
Sourcefn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
Available on crate feature v4_6 only.
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
v4_6 only.Emitted to when the combo box is activated.
The ::activate signal on ComboBox is an action signal and
emitting it causes the combo box to pop up its dropdown.
fn emit_activate(&self)
Since 4.10
v4_6 only.Sourcefn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
Emitted when the active item is changed.
The can be due to the user selecting a different item from the list,
or due to a call to set_active_iter(). It will
also be emitted while typing into the entry of a combo box with an entry.
Sourcefn connect_format_entry_text<F: Fn(&Self, &str) -> String + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
fn connect_format_entry_text<F: Fn(&Self, &str) -> String + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
value, -1);
return g_strdup_printf (โgโ, value);
}
## `path`
the [`TreePath`][crate::TreePath] string from the combo box's current model
to format text for
# Returns
a newly allocated string representing @path
for the current [`ComboBox`][crate::ComboBox] model.Sourcefn connect_move_active<F: Fn(&Self, ScrollType) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
fn connect_move_active<F: Fn(&Self, ScrollType) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn emit_move_active(&self, scroll_type: ScrollType)
Since 4.10
Sourcefn connect_popdown<F: Fn(&Self) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
fn connect_popdown<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Emitted to popdown the combo box list.
This is an keybinding signal.
The default bindings for this signal are Alt+Up and Escape.
Returns
whether the combo box was popped down
fn emit_popdown(&self) -> bool
Since 4.10
Sourcefn connect_popup<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
fn connect_popup<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
Emitted to popup the combo box list.
This is an keybinding signal.
The default binding for this signal is Alt+Down.
fn emit_popup(&self)
Since 4.10
fn connect_active_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_active_id_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Since 4.10
fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_entry_text_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_has_frame_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_id_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_model_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
fn connect_popup_fixed_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
fn connect_popup_shown_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".