pub trait FlowBoxChildExt: IsA<FlowBoxChild> + 'static {
// Provided methods
fn changed(&self) { ... }
fn child(&self) -> Option<Widget> { ... }
fn index(&self) -> i32 { ... }
fn is_selected(&self) -> bool { ... }
fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... }
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn emit_activate(&self) { ... }
fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn changed(&self)
fn changed(&self)
t fully control the data model, you have to duplicate the data that affects the sorting and filtering functions into the widgets themselves.
Another alternative is to call FlowBox::invalidate_sort()
on any model change, but that is more expensive.
Sourcefn is_selected(&self) -> bool
fn is_selected(&self) -> bool
Sourcefn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
.
fn emit_activate(&self)
fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".