pub trait TreeSortableExtManual: IsA<TreeSortable> + 'static {
// Provided methods
fn set_default_sort_func<F>(&self, sort_func: F)
where F: Fn(&Self, &TreeIter, &TreeIter) -> Ordering + 'static { ... }
fn set_sort_func<F>(&self, sort_column_id: SortColumn, sort_func: F)
where F: Fn(&Self, &TreeIter, &TreeIter) -> Ordering + 'static { ... }
fn sort_column_id(&self) -> Option<(SortColumn, SortType)> { ... }
fn set_sort_column_id(&self, sort_column_id: SortColumn, order: SortType) { ... }
fn set_unsorted(&self) { ... }
}Since 4.10
Trait containing manually implemented methods of
TreeSortable.
Provided Methods
Sourcefn set_default_sort_func<F>(&self, sort_func: F)
👎Deprecated: Since 4.10
fn set_default_sort_func<F>(&self, sort_func: F)
Since 4.10
Sourcefn set_sort_func<F>(&self, sort_column_id: SortColumn, sort_func: F)
👎Deprecated: Since 4.10
fn set_sort_func<F>(&self, sort_column_id: SortColumn, sort_func: F)
Since 4.10
Sourcefn sort_column_id(&self) -> Option<(SortColumn, SortType)>
👎Deprecated: Since 4.10
fn sort_column_id(&self) -> Option<(SortColumn, SortType)>
Since 4.10
Fills in @sort_column_id and @order with the current sort column and the
order. It returns true unless the @sort_column_id is
GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID or
GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID.
Deprecated since 4.10
Returns
true if the sort column is not one of the special sort
column ids.
sort_column_id
The sort column id to be filled in
order
The SortType to be filled in
Sourcefn set_sort_column_id(&self, sort_column_id: SortColumn, order: SortType)
👎Deprecated: Since 4.10
fn set_sort_column_id(&self, sort_column_id: SortColumn, order: SortType)
Since 4.10
Sets the current sort column to be @sort_column_id. The @self will
resort itself to reflect this change, after emitting a
GtkTreeSortable::sort-column-changed signal. @sort_column_id may either be
a regular column id, or one of the following special values:
-
GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID: the default sort function will be used, if it is set -
GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID: no sorting will occur
Deprecated since 4.10
sort_column_id
the sort column id to set
order
The sort order of the column
fn set_unsorted(&self)
Since 4.10
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".