CellArea

Struct CellArea 

pub struct CellArea { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

List views use widgets for displaying their contents An abstract class for laying out CellRenderers

The CellArea is an abstract class for CellLayout widgets (also referred to as โ€œlayouting widgetsโ€) to interface with an arbitrary number of CellRenderers and interact with the user for a given TreeModel row.

The cell area handles events, focus navigation, drawing and size requests and allocations for a given row of data.

Usually users dont have to interact with the CellArea directly unless they are implementing a cell-layouting widget themselves.

Requesting area sizes

As outlined in GtkWidgetโ€™s geometry management section, GTK uses a height-for-width geometry management system to compute the sizes of widgets and user interfaces. CellArea uses the same semantics to calculate the size of an area for an arbitrary number of TreeModel rows.

When requesting the size of a cell area one needs to calculate the size for a handful of rows, and this will be done differently by different layouting widgets. For instance a TreeViewColumn always lines up the areas from top to bottom while a IconView on the other hand might enforce that all areas received the same width and wrap the areas around, requesting height for more cell areas when allocated less width.

Itโ€™s also important for areas to maintain some cell alignments with areas rendered for adjacent rows (cells can appear โ€œcolumnizedโ€ inside an area even when the size of cells are different in each row). For this reason the CellArea uses a CellAreaContext object to store the alignments and sizes along the way (as well as the overall largest minimum and natural size for all the rows which have been calculated with the said context).

The CellAreaContext is an opaque object specific to the CellArea which created it (see CellAreaExt::create_context()).

The owning cell-layouting widget can create as many contexts as it wishes to calculate sizes of rows which should receive the same size in at least one orientation (horizontally or vertically), However, itโ€™s important that the same CellAreaContext which was used to request the sizes for a given TreeModel row be used when rendering or processing events for that row.

In order to request the width of all the rows at the root level of a TreeModel one would do the following:

โš ๏ธ The following code is in c โš ๏ธ

GtkTreeIter iter;
int minimum_width;
int natural_width;

valid = gtk_tree_model_get_iter_first (model, &iter);
while (valid)
  {
    gtk_cell_area_apply_attributes (area, model, &iter, FALSE, FALSE);
    gtk_cell_area_get_preferred_width (area, context, widget, NULL, NULL);

    valid = gtk_tree_model_iter_next (model, &iter);
  }

gtk_cell_area_context_get_preferred_width (context, &minimum_width, &natural_width);

Note that in this example itโ€™s not important to observe the returned minimum and natural width of the area for each row unless the cell-layouting object is actually interested in the widths of individual rows. The overall width is however stored in the accompanying CellAreaContext object and can be consulted at any time.

This can be useful since CellLayout widgets usually have to support requesting and rendering rows in treemodels with an exceedingly large amount of rows. The CellLayout widget in that case would calculate the required width of the rows in an idle or timeout source (see timeout_add()) and when the widget is requested its actual width in WidgetImpl::measure() it can simply consult the width accumulated so far in the CellAreaContext object.

A simple example where rows are rendered from top to bottom and take up the full width of the layouting widget would look like:

โš ๏ธ The following code is in c โš ๏ธ

static void
foo_get_preferred_width (GtkWidget *widget,
                         int       *minimum_size,
                         int       *natural_size)
{
  Foo *self = FOO (widget);
  FooPrivate *priv = foo_get_instance_private (self);

  foo_ensure_at_least_one_handfull_of_rows_have_been_requested (self);

  gtk_cell_area_context_get_preferred_width (priv->context, minimum_size, natural_size);
}

In the above example the Foo widget has to make sure that some row sizes have been calculated (the amount of rows that Foo judged was appropriate to request space for in a single timeout iteration) before simply returning the amount of space required by the area via the CellAreaContext.

Requesting the height for width (or width for height) of an area is a similar task except in this case the CellAreaContext does not store the data (actually, it does not know how much space the layouting widget plans to allocate it for every row. Itโ€™s up to the layouting widget to render each row of data with the appropriate height and width which was requested by the CellArea).

In order to request the height for width of all the rows at the root level of a TreeModel one would do the following:

โš ๏ธ The following code is in c โš ๏ธ

GtkTreeIter iter;
int minimum_height;
int natural_height;
int full_minimum_height = 0;
int full_natural_height = 0;

valid = gtk_tree_model_get_iter_first (model, &iter);
while (valid)
  {
    gtk_cell_area_apply_attributes (area, model, &iter, FALSE, FALSE);
    gtk_cell_area_get_preferred_height_for_width (area, context, widget,
                                                  width, &minimum_height, &natural_height);

    if (width_is_for_allocation)
       cache_row_height (&iter, minimum_height, natural_height);

    full_minimum_height += minimum_height;
    full_natural_height += natural_height;

    valid = gtk_tree_model_iter_next (model, &iter);
  }

Note that in the above example we would need to cache the heights returned for each row so that we would know what sizes to render the areas for each row. However we would only want to really cache the heights if the request is intended for the layouting widgets real allocation.

In some cases the layouting widget is requested the height for an arbitrary for_width, this is a special case for layouting widgets who need to request size for tens of thousands of rows. For this case itโ€™s only important that the layouting widget calculate one reasonably sized chunk of rows and return that height synchronously. The reasoning here is that any layouting widget is at least capable of synchronously calculating enough height to fill the screen height (or scrolled window height) in response to a single call to WidgetImpl::measure(). Returning a perfect height for width that is larger than the screen area is inconsequential since after the layouting receives an allocation from a scrolled window it simply continues to drive the scrollbar values while more and more height is required for the row heights that are calculated in the background.

Rendering Areas

Once area sizes have been acquired at least for the rows in the visible area of the layouting widget they can be rendered at WidgetImpl::snapshot() time.

A crude example of how to render all the rows at the root level runs as follows:

โš ๏ธ The following code is in c โš ๏ธ

GtkAllocation allocation;
GdkRectangle cell_area = { 0, };
GtkTreeIter iter;
int minimum_width;
int natural_width;

gtk_widget_get_allocation (widget, &allocation);
cell_area.width = allocation.width;

valid = gtk_tree_model_get_iter_first (model, &iter);
while (valid)
  {
    cell_area.height = get_cached_height_for_row (&iter);

    gtk_cell_area_apply_attributes (area, model, &iter, FALSE, FALSE);
    gtk_cell_area_render (area, context, widget, cr,
                          &cell_area, &cell_area, state_flags, FALSE);

    cell_area.y += cell_area.height;

    valid = gtk_tree_model_iter_next (model, &iter);
  }

Note that the cached height in this example really depends on how the layouting widget works. The layouting widget might decide to give every row its minimum or natural height or, if the model content is expected to fit inside the layouting widget without scrolling, it would make sense to calculate the allocation for each row at the time the widget is allocated using distribute_natural_allocation().

Handling Events and Driving Keyboard Focus

Passing events to the area is as simple as handling events on any normal widget and then passing them to the CellAreaExt::event() API as they come in. Usually CellArea is only interested in button events, however some customized derived areas can be implemented who are interested in handling other events. Handling an event can trigger the focus-changed signal to fire; as well as add-editable in the case that an editable cell was clicked and needs to start editing. You can call CellAreaExt::stop_editing() at any time to cancel any cell editing that is currently in progress.

The CellArea drives keyboard focus from cell to cell in a way similar to Widget. For layouting widgets that support giving focus to cells itโ€™s important to remember to pass GTK_CELL_RENDERER_FOCUSED to the area functions for the row that has focus and to tell the area to paint the focus at render time.

Layouting widgets that accept focus on cells should implement the WidgetImpl::focus() virtual method. The layouting widget is always responsible for knowing where TreeModel rows are rendered inside the widget, so at WidgetImpl::focus() time the layouting widget should use the CellArea methods to navigate focus inside the area and then observe the DirectionType to pass the focus to adjacent rows and areas.

A basic example of how the WidgetImpl::focus() virtual method should be implemented:

static gboolean
foo_focus (GtkWidget       *widget,
           GtkDirectionType direction)
{
  Foo *self = FOO (widget);
  FooPrivate *priv = foo_get_instance_private (self);
  int focus_row = priv->focus_row;
  gboolean have_focus = FALSE;

  if (!gtk_widget_has_focus (widget))
    gtk_widget_grab_focus (widget);

  valid = gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, priv->focus_row);
  while (valid)
    {
      gtk_cell_area_apply_attributes (priv->area, priv->model, &iter, FALSE, FALSE);

      if (gtk_cell_area_focus (priv->area, direction))
        {
           priv->focus_row = focus_row;
           have_focus = TRUE;
           break;
        }
      else
        {
          if (direction == GTK_DIR_RIGHT ||
              direction == GTK_DIR_LEFT)
            break;
          else if (direction == GTK_DIR_UP ||
                   direction == GTK_DIR_TAB_BACKWARD)
           {
              if (focus_row == 0)
                break;
              else
               {
                  focus_row--;
                  valid = gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, focus_row);
               }
            }
          else
            {
              if (focus_row == last_row)
                break;
              else
                {
                  focus_row++;
                  valid = gtk_tree_model_iter_next (priv->model, &iter);
                }
            }
        }
    }
    return have_focus;
}

Note that the layouting widget is responsible for matching the DirectionType values to the way it lays out its cells.

Cell Properties

The CellArea introduces cell properties for CellRenderers. This provides some general interfaces for defining the relationship cell areas have with their cells. For instance in a CellAreaBox a cell might โ€œexpandโ€ and receive extra space when the area is allocated more than its full natural request, or a cell might be configured to โ€œalignโ€ with adjacent rows which were requested and rendered with the same CellAreaContext.

Use [CellAreaClassExt::install_cell_property()][crate::subclass::prelude::CellAreaClassExt::install_cell_property()] to install cell properties for a cell area class and CellAreaClassExt::find_cell_property() or CellAreaClassExt::list_cell_properties() to get information about existing cell properties.

To set the value of a cell property, use [CellAreaExtManual::cell_set_property()][crate::prelude::CellAreaExtManual::cell_set_property()], Gtk::CellArea::cell_set() or Gtk::CellArea::cell_set_valist(). To obtain the value of a cell property, use [CellAreaExtManual::cell_get_property()][crate::prelude::CellAreaExtManual::cell_get_property()] Gtk::CellArea::cell_get() or Gtk::CellArea::cell_get_valist().

This is an Abstract Base Class, you cannot instantiate it.

Properties

edit-widget

The widget currently editing the edited cell

This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().

Readable

edited-cell

The cell in the area that is currently edited

This property is read-only and only changes as a result of a call gtk_cell_area_activate_cell().

Readable

focus-cell

The cell in the area that currently has focus

Readable | Writable

Signals

add-editable

Indicates that editing has started on @renderer and that @editable should be added to the owning cell-layouting widget at @cell_area.

apply-attributes

This signal is emitted whenever applying attributes to @area from @model

focus-changed

Indicates that focus changed on this @area. This signal is emitted either as a result of focus handling or event handling.

Itโ€™s possible that the signal is emitted even if the currently focused renderer did not change, this is because focus may change to the same renderer in the same cell area for a different row of data.

remove-editable

Indicates that editing finished on @renderer and that @editable should be removed from the owning cell-layouting widget.

Implements

CellAreaExt, [trait@glib::ObjectExt], BuildableExt, CellLayoutExt, CellAreaExtManual, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl CellArea

pub const NONE: Option<&'static CellArea> = None

๐Ÿ‘ŽDeprecated:

Since 4.10