pub struct CellLayout { /* private fields */ }👎Deprecated:
Since 4.10
List views use widgets to display their contents.
See LayoutManager for layout manager delegate objects
## Subclassing GtkCellLayout implementations
When subclassing a widget that implements `GtkCellLayout` like
`GtkIconView` or `GtkComboBox`, there are some considerations related
to the fact that these widgets internally use a `GtkCellArea`.
The cell area is exposed as a construct-only property by these
widgets. This means that it is possible to e.g. do
```c
GtkWIdget *combo =
g_object_new (GTK_TYPE_COMBO_BOX, "cell-area", my_cell_area, NULL);
```text
to use a custom cell area with a combo box. But construct properties
are only initialized after instance `init()`
functions have run, which means that using functions which rely on
the existence of the cell area in your subclass `init()` function will
cause the default cell area to be instantiated. In this case, a provided
construct property value will be ignored (with a warning, to alert
you to the problem).
```c
static void
my_combo_box_init (MyComboBox *b)
{
GtkCellRenderer *cell;
cell = gtk_cell_renderer_pixbuf_new ();
// The following call causes the default cell area for combo boxes,
// a GtkCellAreaBox, to be instantiated
gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (b), cell, FALSE);
...
}
GtkWidget *
my_combo_box_new (GtkCellArea *area)
{
// This call is going to cause a warning about area being ignored
return g_object_new (MY_TYPE_COMBO_BOX, "cell-area", area, NULL);
}
```text
If supporting alternative cell areas with your derived widget is
not important, then this does not have to concern you. If you want
to support alternative cell areas, you can do so by moving the
problematic calls out of `init()` and into a `constructor()`
for your class.
# Implements
[`CellLayoutExt`][trait@crate::prelude::CellLayoutExt], [`CellLayoutExtManual`][trait@crate::prelude::CellLayoutExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl CellLayout
impl CellLayout
pub const NONE: Option<&'static CellLayout> = None
👎Deprecated:
Since 4.10