pub struct CellRendererSpin { /* private fields */ }Since 4.10
List views use widgets to display their contents.
You should use SpinButton instead
Renders a spin button in a cell
CellRendererSpin renders text in a cell like CellRendererText from
which it is derived. But while CellRendererText offers a simple entry to
edit the text, CellRendererSpin offers a SpinButton widget. Of course,
that means that the text has to be parseable as a floating point number.
The range of the spinbutton is taken from the adjustment property of the
cell renderer, which can be set explicitly or mapped to a column in the
tree model, like all properties of cell renders. CellRendererSpin
also has properties for the GtkCellRendererSpin:climb-rate and the number
of GtkCellRendererSpin:digits to display. Other SpinButton properties
can be set in a handler for the GtkCellRenderer::editing-started signal.
Properties
adjustment
The adjustment that holds the value of the spinbutton.
This must be non-None for the cell renderer to be editable.
Readable | Writable
climb-rate
The acceleration rate when you hold down a button.
Readable | Writable
digits
The number of decimal places to display.
Readable | Writable
CellRendererText
align-set
Readable | Writable
alignment
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The โxalignโ property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
Readable | Writable
attributes
Readable | Writable
background
Writable
background-rgba
Background color as a gdk::RGBA
Readable | Writable
background-set
Readable | Writable
editable
Readable | Writable
editable-set
Readable | Writable
ellipsize
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
[pango::EllipsizeMode::None][crate::pango::EllipsizeMode::None] turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
Readable | Writable
ellipsize-set
Readable | Writable
family
Readable | Writable
family-set
Readable | Writable
font
Readable | Writable
font-desc
Readable | Writable
foreground
Writable
foreground-rgba
Foreground color as a gdk::RGBA
Readable | Writable
foreground-set
Readable | Writable
language
Readable | Writable
language-set
Readable | Writable
markup
Writable
max-width-chars
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cellโs siblings
have received their natural width.
Readable | Writable
placeholder-text
The text that will be displayed in the CellRenderer if
GtkCellRendererText:editable is true and the cell is empty.
Readable | Writable
rise
Readable | Writable
rise-set
Readable | Writable
scale
Readable | Writable
scale-set
Readable | Writable
single-paragraph-mode
Readable | Writable
size
Readable | Writable
size-points
Readable | Writable
size-set
Readable | Writable
stretch
Readable | Writable
stretch-set
Readable | Writable
strikethrough
Readable | Writable
strikethrough-set
Readable | Writable
style
Readable | Writable
style-set
Readable | Writable
text
Readable | Writable
underline
Readable | Writable
underline-set
Readable | Writable
variant
Readable | Writable
variant-set
Readable | Writable
weight
Readable | Writable
weight-set
Readable | Writable
width-chars
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Readable | Writable
wrap-mode
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Readable | Writable
wrap-width
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Implements
CellRendererTextExt, CellRendererExt, [trait@glib::ObjectExt], [CellRendererExtManual][trait@crate::prelude::CellRendererExtManual]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererSpin
impl CellRendererSpin
Sourcepub fn new() -> CellRendererSpin
๐Deprecated: Since 4.10
pub fn new() -> CellRendererSpin
Since 4.10
Sourcepub fn builder() -> CellRendererSpinBuilder
๐Deprecated: Since 4.10
pub fn builder() -> CellRendererSpinBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct CellRendererSpin objects.
This method returns an instance of CellRendererSpinBuilder which can be used to create CellRendererSpin objects.
Sourcepub fn adjustment(&self) -> Option<Adjustment>
๐Deprecated: Since 4.10
pub fn adjustment(&self) -> Option<Adjustment>
Since 4.10
The adjustment that holds the value of the spinbutton.
This must be non-None for the cell renderer to be editable.
Sourcepub fn set_adjustment<P: IsA<Adjustment>>(&self, adjustment: Option<&P>)
๐Deprecated: Since 4.10
pub fn set_adjustment<P: IsA<Adjustment>>(&self, adjustment: Option<&P>)
Since 4.10
The adjustment that holds the value of the spinbutton.
This must be non-None for the cell renderer to be editable.
Sourcepub fn climb_rate(&self) -> f64
๐Deprecated: Since 4.10
pub fn climb_rate(&self) -> f64
Since 4.10
The acceleration rate when you hold down a button.
Sourcepub fn set_climb_rate(&self, climb_rate: f64)
๐Deprecated: Since 4.10
pub fn set_climb_rate(&self, climb_rate: f64)
Since 4.10
The acceleration rate when you hold down a button.
Sourcepub fn digits(&self) -> u32
๐Deprecated: Since 4.10
pub fn digits(&self) -> u32
Since 4.10
The number of decimal places to display.
Sourcepub fn set_digits(&self, digits: u32)
๐Deprecated: Since 4.10
pub fn set_digits(&self, digits: u32)
Since 4.10
The number of decimal places to display.
pub fn connect_adjustment_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_climb_rate_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_digits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10