ComboBox

Struct ComboBox 

pub struct ComboBox { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.10

Use DropDown instead A ComboBox is a widget that allows the user to choose from a list of valid choices.

An example GtkComboBox

The ComboBox displays the selected choice; when activated, the ComboBox displays a popup which allows the user to make a new choice.

The ComboBox uses the model-view pattern; the list of valid choices is specified in the form of a tree model, and the display of the choices can be adapted to the data in the model by using cell renderers, as you would in a tree view. This is possible since ComboBox implements the CellLayout interface. The tree model holding the valid choices is not restricted to a flat list, it can be a real tree, and the popup will reflect the tree structure.

To allow the user to enter values not in the model, the has-entry property allows the ComboBox to contain a Entry. This entry can be accessed by calling ComboBoxExt::child() on the combo box.

For a simple list of textual choices, the model-view API of ComboBox can be a bit overwhelming. In this case, ComboBoxText offers a simple alternative. Both ComboBox and ComboBoxText can contain an entry.

CSS nodes

combobox
โ”œโ”€โ”€ box.linked
โ”‚   โ•ฐโ”€โ”€ button.combo
โ”‚       โ•ฐโ”€โ”€ box
โ”‚           โ”œโ”€โ”€ cellview
โ”‚           โ•ฐโ”€โ”€ arrow
โ•ฐโ”€โ”€ window.popup

A normal combobox contains a box with the .linked class, a button with the .combo class and inside those buttons, there are a cellview and an arrow.

combobox
โ”œโ”€โ”€ box.linked
โ”‚   โ”œโ”€โ”€ entry.combo
โ”‚   โ•ฐโ”€โ”€ button.combo
โ”‚       โ•ฐโ”€โ”€ box
โ”‚           โ•ฐโ”€โ”€ arrow
โ•ฐโ”€โ”€ window.popup

A ComboBox with an entry has a single CSS node with name combobox. It contains a box with the .linked class. That box contains an entry and a button, both with the .combo class added. The button also contains another node with name arrow.

Accessibility

ComboBox uses the [enum@Gtk.AccessibleRole.combo_box] role.

Properties

active

The item which is currently active.

If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this property has the value gtk_tree_path_get_indices (path)[0], where path is the TreePath of the active item.

Readable | Writable

active-id

The value of the ID column of the active row.

Readable | Writable

button-sensitivity

Whether the dropdown button is sensitive when the model is empty.

Readable | Writable

child

The child widget.

Readable | Writable

entry-text-column

The model column to associate with strings from the entry.

This is property only relevant if the combo was created with has-entry is true.

Readable | Writable

has-entry

Whether the combo box has an entry.

Readable | Writable | Construct Only

has-frame

The has-frame property controls whether a frame is drawn around the entry.

Readable | Writable

id-column

The model column that provides string IDs for the values in the model, if != -1.

Readable | Writable

model

The model from which the combo box takes its values.

Readable | Writable

Whether the popupโ€™s width should be a fixed width matching the allocated width of the combo box.

Readable | Writable

Whether the combo boxes dropdown is popped up.

Note that this property is mainly useful, because it allows you to connect to notify::popup-shown.

Readable

Widget

can-focus

Whether the widget or any of its descendents can accept the input focus.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

can-target

Whether the widget can receive pointer events.

Readable | Writable

css-classes

A list of css classes applied to this widget.

Readable | Writable

css-name

The name of this widget in the CSS tree.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable | Construct Only

cursor

The cursor used by @widget.

Readable | Writable

focus-on-click

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writable

focusable

Whether this widget itself will accept the input focus.

Readable | Writable

halign

How to distribute horizontal space if widget gets extra space.

Readable | Writable

has-default

Whether the widget is the default widget.

Readable

has-focus

Whether the widget has the input focus.

Readable

has-tooltip

Enables or disables the emission of the query-tooltip signal on @widget.

A true value indicates that @widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Readable | Writable

height-request

Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writable

hexpand

Whether to expand horizontally.

Readable | Writable

hexpand-set

Whether to use the hexpand property.

Readable | Writable

layout-manager

The LayoutManager instance to use to compute the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

limit-events

Makes this widget act like a modal dialog, with respect to event delivery.

Global event controllers will not handle events with targets inside the widget, unless they are set up to ignore propagation limits. See EventControllerExt::set_propagation_limit().

Readable | Writable

margin-bottom

Margin on bottom side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-end

Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-start

Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

margin-top

Margin on top side of widget.

This property adds margin outside of the widgetโ€™s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writable

name

The name of the widget.

Readable | Writable

opacity

The requested opacity of the widget.

Readable | Writable

overflow

How content outside the widgetโ€™s content area is treated.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writable

parent

The parent widget of this widget.

Readable

receives-default

Whether the widget will receive the default action when it is focused.

Readable | Writable

root

The Root widget of the widget tree containing this widget.

This will be NULL if the widget is not contained in a root widget.

Readable

scale-factor

The scale factor of the widget.

Readable

sensitive

Whether the widget responds to input.

Readable | Writable

tooltip-markup

Sets the text of tooltip to be the given string, which is marked up with Pango markup.

Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writable

tooltip-text

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writable

valign

How to distribute vertical space if widget gets extra space.

Readable | Writable

vexpand

Whether to expand vertically.

Readable | Writable

vexpand-set

Whether to use the vexpand property.

Readable | Writable

visible

Whether the widget is visible.

Readable | Writable

width-request

Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writable

Accessible

accessible-role

The accessible role of the given Accessible implementation.

The accessible role cannot be changed once set.

Readable | Writable

CellEditable

editing-canceled

Indicates whether editing on the cell has been canceled.

Readable | Writable

Signals

activate

Emitted to when the combo box is activated.

The ::activate signal on ComboBox is an action signal and emitting it causes the combo box to pop up its dropdown.

Action

changed

Emitted when the active item is changed.

The can be due to the user selecting a different item from the list, or due to a call to ComboBoxExt::set_active_iter(). It will also be emitted while typing into the entry of a combo box with an entry.

format-entry-text

Emitted to allow changing how the text in a combo boxโ€™s entry is displayed.

See has-entry.

Connect a signal handler which returns an allocated string representing @path. That string will then be used to set the text in the combo boxโ€™s entry. The default signal handler uses the text from the entry-text-column model column.

Hereโ€™s an example signal handler which fetches data from the model and displays it in the entry. โš ๏ธ The following code is in c โš ๏ธ

static char *
format_entry_text_callback (GtkComboBox *combo,
                            const char *path,
                            gpointer     user_data)
{
  GtkTreeIter iter;
  GtkTreeModel model;
  double       value;

  model = gtk_combo_box_get_model (combo);

  gtk_tree_model_get_iter_from_string (model, &iter, path);
  gtk_tree_model_get (model, &iter,
                      THE_DOUBLE_VALUE_COLUMN, &value,
                      -1);

  return g_strdup_printf ("%g", value);
}
move-active

Emitted to move the active selection.

This is an keybinding signal.

Action

popdown

Emitted to popdown the combo box list.

This is an keybinding signal.

The default bindings for this signal are Alt+Up and Escape.

Action

Emitted to popup the combo box list.

This is an keybinding signal.

The default binding for this signal is Alt+Down.

Action

Widget

destroy

Signals that all holders of a reference to the widget should release the reference that they hold.

May result in finalization of the widget if all references are released.

This signal is not suitable for saving widget state.

direction-changed

Emitted when the text direction of a widget changes.

hide

Emitted when @widget is hidden.

keynav-failed

Emitted if keyboard navigation fails.

See WidgetExt::keynav_failed() for details.

map

Emitted when @widget is going to be mapped.

A widget is mapped when the widget is visible (which is controlled with visible) and all its parents up to the toplevel widget are also visible.

The ::map signal can be used to determine whether a widget will be drawn, for instance it can resume an animation that was stopped during the emission of unmap.

mnemonic-activate

Emitted when a widget is activated via a mnemonic.

The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.

move-focus

Emitted when the focus is moved.

The ::move-focus signal is a keybinding signal.

The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.

Action

query-tooltip

Emitted when the widgetโ€™s tooltip is about to be shown.

This happens when the has-tooltip property is true and the hover timeout has expired with the cursor hovering above @widget; or emitted when @widget got focus in keyboard mode.

Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.

The signal handler is free to manipulate @tooltip with the therefore destined function calls.

realize

Emitted when @widget is associated with a gdk::Surface.

This means that WidgetExt::realize() has been called or the widget has been mapped (that is, it is going to be drawn).

show

Emitted when @widget is shown.

state-flags-changed

Emitted when the widget state changes.

See WidgetExt::state_flags().

unmap

Emitted when @widget is going to be unmapped.

A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.

As ::unmap indicates that a widget will not be shown any longer, it can be used to, for example, stop an animation on the widget.

unrealize

Emitted when the gdk::Surface associated with @widget is destroyed.

This means that WidgetExt::unrealize() has been called or the widget has been unmapped (that is, it is going to be hidden).

CellEditable

editing-done

This signal is a sign for the cell renderer to update its value from the @cell_editable.

Implementations of CellEditable are responsible for emitting this signal when they are done editing, e.g. Entry emits this signal when the user presses Enter. Typical things to do in a handler for ::editing-done are to capture the edited value, disconnect the @cell_editable from signals on the CellRenderer, etc.

gtk_cell_editable_editing_done() is a convenience method for emitting GtkCellEditable::editing-done.

remove-widget

This signal is meant to indicate that the cell is finished editing, and the @cell_editable widget is being removed and may subsequently be destroyed.

Implementations of CellEditable are responsible for emitting this signal when they are done editing. It must be emitted after the GtkCellEditable::editing-done signal, to give the cell renderer a chance to update the cellโ€™s value before the widget is removed.

gtk_cell_editable_remove_widget() is a convenience method for emitting GtkCellEditable::remove-widget.

Implements

ComboBoxExt, WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, CellEditableExt, CellLayoutExt, ComboBoxExtManual, WidgetExtManual, AccessibleExtManual, CellLayoutExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl ComboBox

pub const NONE: Option<&'static ComboBox> = None

๐Ÿ‘ŽDeprecated:

Since 4.10

pub fn new() -> ComboBox

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new empty ComboBox.

Deprecated since 4.10

Use DropDown

Returns

A new ComboBox

pub fn with_entry() -> ComboBox

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new empty ComboBox with an entry.

In order to use a combo box with entry, you need to tell it which column of the model contains the text for the entry by calling ComboBoxExt::set_entry_text_column().

Deprecated since 4.10

Use DropDown

Returns

A new ComboBox

pub fn with_model(model: &impl IsA<TreeModel>) -> ComboBox

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new ComboBox with a model.

Deprecated since 4.10

Use DropDown

model

a TreeModel

Returns

A new ComboBox

pub fn with_model_and_entry(model: &impl IsA<TreeModel>) -> ComboBox

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new empty ComboBox with an entry and a model.

See also with_entry().

Deprecated since 4.10

Use DropDown

model

A TreeModel

Returns

A new ComboBox

pub fn builder() -> ComboBoxBuilder

๐Ÿ‘ŽDeprecated:

Since 4.10

Creates a new builder-pattern struct instance to construct ComboBox objects.

This method returns an instance of ComboBoxBuilder which can be used to create ComboBox objects.