pub struct Entry { /* private fields */ }Expand description
The start and end attributes specify the range of characters to which the
Pango attribute applies. If start and end are not specified, the attribute
is applied to the whole text. Note that specifying ranges does not make much
sense with translatable attributes. Use markup embedded in the translatable
content instead.
# Accessibility
[`Entry`][crate::Entry] uses the [enum@Gtk.AccessibleRole.text_box] role.
## Properties
#### `activates-default`
Whether to activate the default widget when Enter is pressed.
Readable | Writable
#### `attributes`
A list of Pango attributes to apply to the text of the entry.
This is mainly useful to change the size or weight of the text.
The `PangoAttribute`'s @start_index and @end_index must refer to the
[`EntryBuffer`][crate::EntryBuffer] text, i.e. without the preedit string.
Readable | Writable
#### `buffer`
The buffer object which actually stores the text.
Readable | Writable | Construct
#### `completion`
The auxiliary completion object to use with the entry.
Readable | Writable
#### `enable-emoji-completion`
Whether to suggest Emoji replacements for :-delimited names
like `:heart:`.
Readable | Writable
#### `extra-menu`
A menu model whose contents will be appended to the context menu.
Readable | Writable
#### `has-frame`
Whether the entry should draw a frame.
Readable | Writable
#### `im-module`
Which IM (input method) module should be used for this entry.
See [`IMContext`][crate::IMContext].
Setting this to a non-[`None`] value overrides the system-wide IM
module setting. See the GtkSettings [`gtk-im-module`][struct@crate::Settings#gtk-im-module]
property.
Readable | Writable
#### `input-hints`
Additional hints that allow input methods to fine-tune their behavior.
Also see [`input-purpose`][struct@crate::Entry#input-purpose]
Readable | Writable
#### `input-purpose`
The purpose of this text field.
This property can be used by on-screen keyboards and other input
methods to adjust their behaviour.
Note that setting the purpose to [`InputPurpose::Password`][crate::InputPurpose::Password] or
[`InputPurpose::Pin`][crate::InputPurpose::Pin] is independent from setting
[`visibility`][struct@crate::Entry#visibility].
Readable | Writable
#### `invisible-char`
).
Readable | Writable
#### `invisible-char-set`
Whether the invisible char has been set for the [`Entry`][crate::Entry].
Readable | Writable
#### `max-length`
Maximum number of characters for this entry.
Readable | Writable
#### `menu-entry-icon-primary-text`
Text for an item in the context menu to activate the primary icon action.
When the primary icon is activatable and this property has been set, a new entry
in the context menu of this GtkEntry will appear with this text. Selecting that
menu entry will result in the primary icon being activated, exactly in the same way
as it would be activated from a mouse click.
This simplifies adding accessibility support to applications using activatable
icons. The activatable icons aren't focusable when navigating the interface with
the keyboard This is why Gtk recommends to also add those actions in the context
menu. This set of methods greatly simplifies this, by adding a menu item that, when
enabled, calls the same callback than clicking on the icon.
Readable | Writable
#### `menu-entry-icon-secondary-text`
Text for an item in the context menu to activate the secondary icon action.
When the primary icon is activatable and this property has been set, a new entry
in the context menu of this GtkEntry will appear with this text. Selecting that
menu entry will result in the primary icon being activated, exactly in the same way
as it would be activated from a mouse click.
This simplifies adding accessibility support to applications using activatable
icons. The activatable icons aren't focusable when navigating the interface with
the keyboard This is why Gtk recommends to also add those actions in the context
menu. This set of methods greatly simplifies this, by adding a menu item that, when
enabled, calls the same callback than clicking on the icon.
Readable | Writable
#### `overwrite-mode`
If text is overwritten when typing in the [`Entry`][crate::Entry].
Readable | Writable
#### `placeholder-text`
The text that will be displayed in the [`Entry`][crate::Entry] when it is empty
and unfocused.
Readable | Writable
#### `primary-icon-activatable`
Whether the primary icon is activatable.
GTK emits the [`icon-press`][struct@crate::Entry#icon-press] and
[`icon-release`][struct@crate::Entry#icon-release] signals only on sensitive,
activatable icons.
Sensitive, but non-activatable icons can be used for purely
informational purposes.
Readable | Writable
#### `primary-icon-gicon`
The `GIcon` to use for the primary icon for the entry.
Readable | Writable
#### `primary-icon-name`
The icon name to use for the primary icon for the entry.
Readable | Writable
#### `primary-icon-paintable`
A [`gdk::Paintable`][crate::gdk::Paintable] to use as the primary icon for the entry.
Readable | Writable
#### `primary-icon-sensitive`
Whether the primary icon is sensitive.
An insensitive icon appears grayed out. GTK does not emit the
[`icon-press`][struct@crate::Entry#icon-press] and [`icon-release`][struct@crate::Entry#icon-release]
signals and does not allow DND from insensitive icons.
An icon should be set insensitive if the action that would trigger
when clicked is currently not available.
Readable | Writable
#### `primary-icon-storage-type`
The representation which is used for the primary icon of the entry.
Readable
#### `primary-icon-tooltip-markup`
The contents of the tooltip on the primary icon, with markup.
Also see [`EntryExt::set_icon_tooltip_markup()`][crate::prelude::EntryExt::set_icon_tooltip_markup()].
Readable | Writable
#### `primary-icon-tooltip-text`
The contents of the tooltip on the primary icon.
Also see [`EntryExt::set_icon_tooltip_text()`][crate::prelude::EntryExt::set_icon_tooltip_text()].
Readable | Writable
#### `progress-fraction`
The current fraction of the task that's been completed.
Readable | Writable
#### `progress-pulse-step`
The fraction of total entry width to move the progress
bouncing block for each pulse.
See [`EntryExt::progress_pulse()`][crate::prelude::EntryExt::progress_pulse()].
Readable | Writable
#### `scroll-offset`
Number of pixels of the entry scrolled off the screen to the left.
Readable
#### `secondary-icon-activatable`
Whether the secondary icon is activatable.
GTK emits the [`icon-press`][struct@crate::Entry#icon-press] and
[`icon-release`][struct@crate::Entry#icon-release] signals only on sensitive,
activatable icons.
Sensitive, but non-activatable icons can be used for purely
informational purposes.
Readable | Writable
#### `secondary-icon-gicon`
The `GIcon` to use for the secondary icon for the entry.
Readable | Writable
#### `secondary-icon-name`
The icon name to use for the secondary icon for the entry.
Readable | Writable
#### `secondary-icon-paintable`
A [`gdk::Paintable`][crate::gdk::Paintable] to use as the secondary icon for the entry.
Readable | Writable
#### `secondary-icon-sensitive`
Whether the secondary icon is sensitive.
An insensitive icon appears grayed out. GTK does not emit the
[`icon-press`][struct@crate::Entry#icon-press][ and [`icon-release`][struct@crate::Entry#icon-release]
signals and does not allow DND from insensitive icons.
An icon should be set insensitive if the action that would trigger
when clicked is currently not available.
Readable | Writable
#### `secondary-icon-storage-type`
The representation which is used for the secondary icon of the entry.
Readable
#### `secondary-icon-tooltip-markup`
The contents of the tooltip on the secondary icon, with markup.
Also see [`EntryExt::set_icon_tooltip_markup()`][crate::prelude::EntryExt::set_icon_tooltip_markup()].
Readable | Writable
#### `secondary-icon-tooltip-text`
The contents of the tooltip on the secondary icon.
Also see [`EntryExt::set_icon_tooltip_text()`][crate::prelude::EntryExt::set_icon_tooltip_text()].
Readable | Writable
#### `show-emoji-icon`
Whether the entry will show an Emoji icon in the secondary icon position
to open the Emoji chooser.
Readable | Writable
#### `tabs`
A list of tabstops to apply to the text of the entry.
Readable | Writable
#### `text-length`
The length of the text in the [`Entry`][crate::Entry].
Readable
#### `truncate-multiline`
When [`true`], pasted multi-line text is truncated to the first line.
Readable | Writable
#### `visibility`
).
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>CellEditable</h4></summary>
#### `editing-canceled`
Indicates whether editing on the cell has been canceled.
Readable | Writable
</details>
<details><summary><h4>Editable</h4></summary>
#### `complete-text`
The contents of the entry, including uncommited content such as the
preedit.
Readable
#### `cursor-position`
The current position of the insertion cursor in chars.
Readable
#### `editable`
Whether the entry contents can be edited.
Readable | Writable
#### `enable-undo`
If undo/redo should be enabled for the editable.
Readable | Writable
#### `max-width-chars`
The desired maximum width of the entry, in characters.
Readable | Writable
#### `selection-bound`
The position of the opposite end of the selection from the cursor in chars.
Readable
#### `text`
The contents of the entry.
Readable | Writable
#### `width-chars`
Number of characters to leave space for in the entry.
Readable | Writable
#### `xalign`
The horizontal alignment, from 0 (left) to 1 (right).
Reversed for RTL layouts.
Readable | Writable
</details>
## Signals
#### `activate`
Emitted when the entry is activated.
The keybindings for this signal are all forms of the Enter key.
Action
#### `icon-press`
Emitted when an activatable icon is clicked.
#### `icon-release`
Emitted on the button release from a mouse click
over an activatable icon.
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
<details><summary><h4>CellEditable</h4></summary>
#### `editing-done`
This signal is a sign for the cell renderer to update its
value from the @cell_editable.
Implementations of [`CellEditable`][crate::CellEditable] are responsible for
emitting this signal when they are done editing, e.g.
[`Entry`][crate::Entry] emits this signal when the user presses Enter. Typical things to
do in a handler for ::editing-done are to capture the edited value,
disconnect the @cell_editable from signals on the [`CellRenderer`][crate::CellRenderer], etc.
gtk_cell_editable_editing_done() is a convenience method
for emitting `GtkCellEditable::editing-done`.
#### `remove-widget`
This signal is meant to indicate that the cell is finished
editing, and the @cell_editable widget is being removed and may
subsequently be destroyed.
Implementations of [`CellEditable`][crate::CellEditable] are responsible for
emitting this signal when they are done editing. It must
be emitted after the `GtkCellEditable::editing-done` signal,
to give the cell renderer a chance to update the cell's value
before the widget is removed.
gtk_cell_editable_remove_widget() is a convenience method
for emitting `GtkCellEditable::remove-widget`.
</details>
<details><summary><h4>Editable</h4></summary>
#### `changed`
Emitted at the end of a single user-visible operation on the
contents.
E.g., a paste operation that replaces the contents of the
selection will cause only one signal emission (even though it
is implemented by first deleting the selection, then inserting
the new content, and may cause multiple ::notify::text signals
to be emitted).
#### `delete-text`
Emitted when text is deleted from the widget by the user.
The default handler for this signal will normally be responsible for
deleting the text, so by connecting to this signal and then stopping
the signal with g_signal_stop_emission(), it is possible to modify the
range of deleted text, or prevent it from being deleted entirely.
The @start_pos and @end_pos parameters are interpreted as for
[`EditableExt::delete_text()`][crate::prelude::EditableExt::delete_text()].
#### `insert-text`
Emitted when text is inserted into the widget by the user.
The default handler for this signal will normally be responsible
for inserting the text, so by connecting to this signal and then
stopping the signal with g_signal_stop_emission(), it is possible
to modify the inserted text, or prevent it from being inserted entirely.
</details>
# Implements
[`EntryExt`][trait@crate::prelude::EntryExt], [`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`CellEditableExt`][trait@crate::prelude::CellEditableExt], [`EditableExt`][trait@crate::prelude::EditableExt], [`EntryExtManual`][trait@crate::prelude::EntryExtManual], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual], [`EditableExtManual`][trait@crate::prelude::EditableExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Entry
impl Entry
pub const NONE: Option<&'static Entry> = None
Sourcepub fn with_buffer(buffer: &impl IsA<EntryBuffer>) -> Entry
pub fn with_buffer(buffer: &impl IsA<EntryBuffer>) -> Entry
Sourcepub fn builder() -> EntryBuilder
pub fn builder() -> EntryBuilder
Creates a new builder-pattern struct instance to construct Entry objects.
This method returns an instance of EntryBuilder which can be used to create Entry objects.