pub struct FontChooser { /* private fields */ }Since 4.10
Use FontDialog and FontDialogButton
instead
FontChooser is an interface that can be implemented by widgets
for choosing fonts.
In GTK, the main objects that implement this interface are
FontChooserWidget, FontChooserDialog and
FontButton.
Properties
font
The font description as a string, e.g. โSans Italic 12โ.
Readable | Writable
font-desc
The font description as a [pango::FontDescription][crate::pango::FontDescription].
Readable | Writable
font-features
The selected font features.
The format of the string is compatible with CSS and with Pango attributes.
Readable
language
The language for which the font features were selected.
Readable | Writable
level
The level of granularity to offer for selecting fonts.
Readable | Writable
preview-text
The string with which to preview the font.
Readable | Writable
show-preview-entry
Whether to show an entry to change the preview text.
Readable | Writable
Signals
font-activated
Emitted when a font is activated.
This usually happens when the user double clicks an item, or an item is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.
Implements
FontChooserExt, FontChooserExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FontChooser
impl FontChooser
pub const NONE: Option<&'static FontChooser> = None
Since 4.10