pub struct FontChooserWidget { /* private fields */ }Since 4.10
Direct use of FontChooserWidget is deprecated.
The FontChooserWidget widget lets the user select a font.
It is used in the FontChooserDialog widget to provide a
dialog for selecting fonts.
To set the font which is initially selected, use
FontChooserExt::set_font() or FontChooserExt::set_font_desc().
To get the selected font use FontChooserExt::font() or
FontChooserExt::font_desc().
To change the text which is shown in the preview area, use
FontChooserExt::set_preview_text().
CSS nodes
FontChooserWidget has a single CSS node with name fontchooser.
Properties
tweak-action
A toggle action that can be used to switch to the tweak page of the font chooser widget, which lets the user tweak the OpenType features and variation axes of the selected font.
The action will be enabled or disabled depending on whether the selected font has any features or axes.
Readable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widgetโs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
FontChooser
font
The font description as a string, e.g. โSans Italic 12โ.
Readable | Writable
font-desc
The font description as a [pango::FontDescription][crate::pango::FontDescription].
Readable | Writable
font-features
The selected font features.
The format of the string is compatible with CSS and with Pango attributes.
Readable
language
The language for which the font features were selected.
Readable | Writable
level
The level of granularity to offer for selecting fonts.
Readable | Writable
preview-text
The string with which to preview the font.
Readable | Writable
show-preview-entry
Whether to show an entry to change the preview text.
Readable | Writable
Implements
WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, FontChooserExt, WidgetExtManual, AccessibleExtManual, FontChooserExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FontChooserWidget
impl FontChooserWidget
Sourcepub fn new() -> FontChooserWidget
๐Deprecated: Since 4.10
pub fn new() -> FontChooserWidget
Since 4.10
Creates a new FontChooserWidget.
Deprecated since 4.10
Direct use of FontChooserWidget is deprecated.
Returns
a new FontChooserWidget
Sourcepub fn builder() -> FontChooserWidgetBuilder
๐Deprecated: Since 4.10
pub fn builder() -> FontChooserWidgetBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct FontChooserWidget objects.
This method returns an instance of FontChooserWidgetBuilder which can be used to create FontChooserWidget objects.
Sourcepub fn tweak_action(&self) -> Option<Action>
๐Deprecated: Since 4.10
pub fn tweak_action(&self) -> Option<Action>
Since 4.10
A toggle action that can be used to switch to the tweak page of the font chooser widget, which lets the user tweak the OpenType features and variation axes of the selected font.
The action will be enabled or disabled depending on whether the selected font has any features or axes.
pub fn connect_tweak_action_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10