pub struct IconView { /* private fields */ }Since 4.10
Use GridView instead
IconView is a widget which displays data in a grid of icons.
IconView provides an alternative view on a TreeModel.
It displays the model as a grid of icons with labels. Like
TreeView, it allows to select one or multiple items
(depending on the selection mode, see set_selection_mode()).
In addition to selection with the arrow keys, IconView supports
rubberband selection, which is controlled by dragging the pointer.
Note that if the tree model is backed by an actual tree store (as
opposed to a flat list where the mapping to icons is obvious),
IconView will only display the first level of the tree and
ignore the treeโs branches.
CSS nodes
iconview.view
โฐโโ [rubberband]IconView has a single CSS node with name iconview and style class .view.
For rubberband selection, a subnode with name rubberband is used.
Properties
activate-on-single-click
The activate-on-single-click property specifies whether the โitem-activatedโ signal will be emitted after a single click.
Readable | Writable
cell-area
The CellArea used to layout cell renderers for this view.
If no area is specified when creating the icon view with gtk_icon_view_new_with_area()
a CellAreaBox will be used.
Readable | Writable | Construct Only
column-spacing
The column-spacing property specifies the space which is inserted between the columns of the icon view.
Readable | Writable
columns
The columns property contains the number of the columns in which the items should be displayed. If it is -1, the number of columns will be chosen automatically to fill the available area.
Readable | Writable
item-orientation
The item-orientation property specifies how the cells (i.e. the icon and the text) of the item are positioned relative to each other.
Readable | Writable
item-padding
The item-padding property specifies the padding around each of the icon viewโs item.
Readable | Writable
item-width
The item-width property specifies the width to use for each item. If it is set to -1, the icon view will automatically determine a suitable item size.
Readable | Writable
margin
The margin property specifies the space which is inserted at the edges of the icon view.
Readable | Writable
markup-column
The ::markup-column property contains the number of the model column
containing markup information to be displayed. The markup column must be
of type G_TYPE_STRING. If this property and the :text-column property
are both set to column numbers, it overrides the text column.
If both are set to -1, no texts are displayed.
Readable | Writable
model
The model of the icon view.
Readable | Writable
pixbuf-column
The ::pixbuf-column property contains the number of the model column
containing the pixbufs which are displayed. The pixbuf column must be
of type GDK_TYPE_PIXBUF. Setting this property to -1 turns off the
display of pixbufs.
Readable | Writable
reorderable
The reorderable property specifies if the items can be reordered by DND.
Readable | Writable
row-spacing
The row-spacing property specifies the space which is inserted between the rows of the icon view.
Readable | Writable
selection-mode
The ::selection-mode property specifies the selection mode of
icon view. If the mode is SelectionMode::Multiple, rubberband selection
is enabled, for the other modes, only keyboard selection is possible.
Readable | Writable
spacing
The spacing property specifies the space which is inserted between the cells (i.e. the icon and the text) of an item.
Readable | Writable
text-column
The ::text-column property contains the number of the model column
containing the texts which are displayed. The text column must be
of type G_TYPE_STRING. If this property and the :markup-column
property are both set to -1, no texts are displayed.
Readable | Writable
tooltip-column
The column of the icon view model which is being used for displaying tooltips on itโs rows.
Readable | Writable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See EventControllerExt::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widgetโs normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widgetโs content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
Scrollable
hadjustment
Horizontal Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
hscroll-policy
Determines when horizontal scrolling should start.
Readable | Writable
vadjustment
Vertical Adjustment of the scrollable widget.
This adjustment is shared between the scrollable widget and its parent.
Readable | Writable | Construct
vscroll-policy
Determines when vertical scrolling should start.
Readable | Writable
Signals
activate-cursor-item
A [keybinding signal]SignalAction
which gets emitted when the user activates the currently
focused item.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control activation programmatically.
The default bindings for this signal are Space, Return and Enter.
Action
item-activated
The ::item-activated signal is emitted when the method
gtk_icon_view_item_activated() is called, when the user double
clicks an item with the โactivate-on-single-clickโ property set
to false, or when the user single clicks an item when the
โactivate-on-single-clickโ property set to true. It is also
emitted when a non-editable item is selected and one of the keys:
Space, Return or Enter is pressed.
move-cursor
The ::move-cursor signal is a
[keybinding signal]SignalAction
which gets emitted when the user initiates a cursor movement.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control the cursor programmatically.
The default bindings for this signal include
- Arrow keys which move by individual steps
- Home/End keys which move to the first/last item
- PageUp/PageDown which move by โpagesโ All of these will extend the selection when combined with the Shift modifier.
Action
select-all
A [keybinding signal]SignalAction
which gets emitted when the user selects all items.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
The default binding for this signal is Ctrl-a.
Action
select-cursor-item
A [keybinding signal]SignalAction
which gets emitted when the user selects the item that is currently
focused.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
There is no default binding for this signal.
Action
selection-changed
The ::selection-changed signal is emitted when the selection (i.e. the set of selected items) changes.
toggle-cursor-item
A [keybinding signal]SignalAction
which gets emitted when the user toggles whether the currently
focused item is selected or not. The exact effect of this
depend on the selection mode.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
There is no default binding for this signal is Ctrl-Space.
Action
unselect-all
A [keybinding signal]SignalAction
which gets emitted when the user unselects all items.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
The default binding for this signal is Ctrl-Shift-a.
Action
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See WidgetExt::keynav_failed() for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widgetโs tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a gdk::Surface.
This means that WidgetExt::realize() has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the gdk::Surface associated with @widget is destroyed.
This means that WidgetExt::unrealize() has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
WidgetExt, [trait@glib::ObjectExt], AccessibleExt, BuildableExt, ConstraintTargetExt, CellLayoutExt, ScrollableExt, WidgetExtManual, AccessibleExtManual, CellLayoutExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl IconView
impl IconView
Sourcepub fn with_model(model: &impl IsA<TreeModel>) -> IconView
๐Deprecated: Since 4.10
pub fn with_model(model: &impl IsA<TreeModel>) -> IconView
Since 4.10
Sourcepub fn builder() -> IconViewBuilder
๐Deprecated: Since 4.10
pub fn builder() -> IconViewBuilder
Since 4.10
Creates a new builder-pattern struct instance to construct IconView objects.
This method returns an instance of IconViewBuilder which can be used to create IconView objects.
Sourcepub fn create_drag_icon(&self, path: &TreePath) -> Option<Paintable>
๐Deprecated: Since 4.10
pub fn create_drag_icon(&self, path: &TreePath) -> Option<Paintable>
Since 4.10
Creates a gdk::Paintable representation of the item at @path.
This image is used for a drag icon.
Deprecated since 4.10
Use GridView instead
path
a TreePath in @self
Returns
a newly-allocated gdk::Paintable of the drag icon.
Sourcepub fn enable_model_drag_dest(
&self,
formats: &ContentFormats,
actions: DragAction,
)
๐Deprecated: Since 4.10
pub fn enable_model_drag_dest( &self, formats: &ContentFormats, actions: DragAction, )
Since 4.10
Sourcepub fn enable_model_drag_source(
&self,
start_button_mask: ModifierType,
formats: &ContentFormats,
actions: DragAction,
)
๐Deprecated: Since 4.10
pub fn enable_model_drag_source( &self, start_button_mask: ModifierType, formats: &ContentFormats, actions: DragAction, )
Since 4.10
Turns @self into a drag source for automatic DND. Calling this
method sets IconView:reorderable to false.
Deprecated since 4.10
Use GridView instead
start_button_mask
Mask of allowed buttons to start drag
formats
the formats that the drag will support
actions
the bitmask of possible actions for a drag from this widget
Sourcepub fn activates_on_single_click(&self) -> bool
๐Deprecated: Since 4.10
pub fn activates_on_single_click(&self) -> bool
Since 4.10
Sourcepub fn cell_rect(
&self,
path: &TreePath,
cell: Option<&impl IsA<CellRenderer>>,
) -> Option<Rectangle>
๐Deprecated: Since 4.10
pub fn cell_rect( &self, path: &TreePath, cell: Option<&impl IsA<CellRenderer>>, ) -> Option<Rectangle>
Since 4.10
Fills the bounding rectangle in widget coordinates for the cell specified by
@path and @cell. If @cell is None the main cell area is used.
This function is only valid if @self is realized.
Deprecated since 4.10
Use GridView instead
path
a TreePath
cell
Returns
false if there is no such item, true otherwise
rect
rectangle to fill with cell rect
Sourcepub fn column_spacing(&self) -> i32
๐Deprecated: Since 4.10
pub fn column_spacing(&self) -> i32
Since 4.10
Sourcepub fn cursor(&self) -> Option<(TreePath, CellRenderer)>
๐Deprecated: Since 4.10
pub fn cursor(&self) -> Option<(TreePath, CellRenderer)>
Since 4.10
Fills in @path and @cell with the current cursor path and cell.
If the cursor isnโt currently set, then *@path will be None.
If no cell currently has focus, then *@cell will be None.
The returned TreePath must be freed with gtk_tree_path_free().
Deprecated since 4.10
Use GridView instead
Returns
true if the cursor is set.
path
Return location for the current cursor path
cell
Return location the current focus cell
Sourcepub fn dest_item_at_pos(
&self,
drag_x: i32,
drag_y: i32,
) -> Option<(TreePath, IconViewDropPosition)>
๐Deprecated: Since 4.10
pub fn dest_item_at_pos( &self, drag_x: i32, drag_y: i32, ) -> Option<(TreePath, IconViewDropPosition)>
Since 4.10
Determines the destination item for a given position.
Deprecated since 4.10
Use GridView instead
drag_x
the position to determine the destination item for
drag_y
the position to determine the destination item for
Returns
whether there is an item at the given position.
path
Return location for the path of the item
pos
Return location for the drop position
Sourcepub fn drag_dest_item(&self) -> (Option<TreePath>, IconViewDropPosition)
๐Deprecated: Since 4.10
pub fn drag_dest_item(&self) -> (Option<TreePath>, IconViewDropPosition)
Since 4.10
Sourcepub fn item_at_pos(&self, x: i32, y: i32) -> Option<(TreePath, CellRenderer)>
๐Deprecated: Since 4.10
pub fn item_at_pos(&self, x: i32, y: i32) -> Option<(TreePath, CellRenderer)>
Since 4.10
Gets the path and cell for the icon at the given position.
Deprecated since 4.10
Use GridView instead
x
The x position to be identified
y
The y position to be identified
Returns
true if an item exists at the specified position
path
Return location for the path
cell
Return location for the renderer responsible for the cell at (@x, @y)
Sourcepub fn item_column(&self, path: &TreePath) -> i32
๐Deprecated: Since 4.10
pub fn item_column(&self, path: &TreePath) -> i32
Since 4.10
Sourcepub fn item_orientation(&self) -> Orientation
๐Deprecated: Since 4.10
pub fn item_orientation(&self) -> Orientation
Since 4.10
Sourcepub fn item_padding(&self) -> i32
๐Deprecated: Since 4.10
pub fn item_padding(&self) -> i32
Since 4.10
Sourcepub fn item_width(&self) -> i32
๐Deprecated: Since 4.10
pub fn item_width(&self) -> i32
Since 4.10
Sourcepub fn markup_column(&self) -> i32
๐Deprecated: Since 4.10
pub fn markup_column(&self) -> i32
Since 4.10
Sourcepub fn pixbuf_column(&self) -> i32
๐Deprecated: Since 4.10
pub fn pixbuf_column(&self) -> i32
Since 4.10
Sourcepub fn is_reorderable(&self) -> bool
๐Deprecated: Since 4.10
pub fn is_reorderable(&self) -> bool
Since 4.10
Sourcepub fn row_spacing(&self) -> i32
๐Deprecated: Since 4.10
pub fn row_spacing(&self) -> i32
Since 4.10
Sourcepub fn selected_items(&self) -> Vec<TreePath>
๐Deprecated: Since 4.10
pub fn selected_items(&self) -> Vec<TreePath>
Since 4.10
Creates a list of paths of all selected items. Additionally, if you are
planning on modifying the model after calling this function, you may
want to convert the returned list into a list of GtkTreeRowReferences.
To do this, you can use gtk_tree_row_reference_new().
To free the return value, use g_list_free_full:
โ ๏ธ The following code is in c โ ๏ธ
GtkWidget *icon_view = gtk_icon_view_new ();
// Use icon_view
GList *list = gtk_icon_view_get_selected_items (GTK_ICON_VIEW (icon_view));
// use list
g_list_free_full (list, (GDestroyNotify) gtk_tree_path_free);Deprecated since 4.10
Use GridView instead
Returns
A GList containing a TreePath for each selected row.
Sourcepub fn selection_mode(&self) -> SelectionMode
๐Deprecated: Since 4.10
pub fn selection_mode(&self) -> SelectionMode
Since 4.10
Sourcepub fn text_column(&self) -> i32
๐Deprecated: Since 4.10
pub fn text_column(&self) -> i32
Since 4.10
Sourcepub fn tooltip_column(&self) -> i32
๐Deprecated: Since 4.10
pub fn tooltip_column(&self) -> i32
Since 4.10
Sourcepub fn tooltip_context(
&self,
x: i32,
y: i32,
keyboard_tip: bool,
) -> Option<(TreeModel, TreePath, TreeIter)>
๐Deprecated: Since 4.10
pub fn tooltip_context( &self, x: i32, y: i32, keyboard_tip: bool, ) -> Option<(TreeModel, TreePath, TreeIter)>
Since 4.10
This function is supposed to be used in a GtkWidget::query-tooltip
signal handler for IconView. The @x, @y and @keyboard_tip values
which are received in the signal handler, should be passed to this
function without modification.
The return value indicates whether there is an icon view item at the given
coordinates (true) or not (false) for mouse tooltips. For keyboard
tooltips the item returned will be the cursor item. When true, then any of
@model, @path and @iter which have been provided will be set to point to
that row and the corresponding model.
Deprecated since 4.10
Use GridView instead
x
the x coordinate (relative to widget coordinates)
y
the y coordinate (relative to widget coordinates)
keyboard_tip
whether this is a keyboard tooltip or not
Returns
whether or not the given tooltip context points to an item
model
a pointer to receive a TreeModel
path
a pointer to receive a TreePath
iter
a pointer to receive a TreeIter
Sourcepub fn visible_range(&self) -> Option<(TreePath, TreePath)>
๐Deprecated: Since 4.10
pub fn visible_range(&self) -> Option<(TreePath, TreePath)>
Since 4.10
Sets @start_path and @end_path to be the first and last visible path. Note that there may be invisible paths in between.
Both paths should be freed with gtk_tree_path_free() after use.
Deprecated since 4.10
Use GridView instead
Returns
true, if valid paths were placed in @start_path and @end_path
start_path
Return location for start of region
end_path
Return location for end of region
Sourcepub fn item_activated(&self, path: &TreePath)
๐Deprecated: Since 4.10
pub fn item_activated(&self, path: &TreePath)
Since 4.10
Sourcepub fn path_is_selected(&self, path: &TreePath) -> bool
๐Deprecated: Since 4.10
pub fn path_is_selected(&self, path: &TreePath) -> bool
Since 4.10
Sourcepub fn scroll_to_path(
&self,
path: &TreePath,
use_align: bool,
row_align: f32,
col_align: f32,
)
๐Deprecated: Since 4.10
pub fn scroll_to_path( &self, path: &TreePath, use_align: bool, row_align: f32, col_align: f32, )
Since 4.10
Moves the alignments of @self to the position specified by @path. @row_align determines where the row is placed, and @col_align determines where @column is placed. Both are expected to be between 0.0 and 1.0. 0.0 means left/top alignment, 1.0 means right/bottom alignment, 0.5 means center.
If @use_align is false, then the alignment arguments are ignored, and the
tree does the minimum amount of work to scroll the item onto the screen.
This means that the item will be scrolled to the edge closest to its current
position. If the item is currently visible on the screen, nothing is done.
This function only works if the model is set, and @path is a valid row on the model. If the model changes before the @self is realized, the centered path will be modified to reflect this change.
Deprecated since 4.10
Use GridView instead
path
The path of the item to move to.
use_align
whether to use alignment arguments, or false.
row_align
The vertical alignment of the item specified by @path.
col_align
The horizontal alignment of the item specified by @path.
Sourcepub fn select_all(&self)
๐Deprecated: Since 4.10
pub fn select_all(&self)
Since 4.10
Selects all the icons. @self must has its selection mode set
to SelectionMode::Multiple.
Deprecated since 4.10
Use GridView instead
Sourcepub fn select_path(&self, path: &TreePath)
๐Deprecated: Since 4.10
pub fn select_path(&self, path: &TreePath)
Since 4.10
Sourcepub fn selected_foreach<P: FnMut(&IconView, &TreePath)>(&self, func: P)
๐Deprecated: Since 4.10
pub fn selected_foreach<P: FnMut(&IconView, &TreePath)>(&self, func: P)
Since 4.10
Sourcepub fn set_activate_on_single_click(&self, single: bool)
๐Deprecated: Since 4.10
pub fn set_activate_on_single_click(&self, single: bool)
Since 4.10
Sourcepub fn set_column_spacing(&self, column_spacing: i32)
๐Deprecated: Since 4.10
pub fn set_column_spacing(&self, column_spacing: i32)
Since 4.10
Sourcepub fn set_columns(&self, columns: i32)
๐Deprecated: Since 4.10
pub fn set_columns(&self, columns: i32)
Since 4.10
Sourcepub fn set_cursor(
&self,
path: &TreePath,
cell: Option<&impl IsA<CellRenderer>>,
start_editing: bool,
)
๐Deprecated: Since 4.10
pub fn set_cursor( &self, path: &TreePath, cell: Option<&impl IsA<CellRenderer>>, start_editing: bool, )
Since 4.10
Sets the current keyboard focus to be at @path, and selects it. This is
useful when you want to focus the userโs attention on a particular item.
If @cell is not None, then focus is given to the cell specified by
it. Additionally, if @start_editing is true, then editing should be
started in the specified cell.
This function is often followed by gtk_widget_grab_focus (icon_view) in order to give keyboard focus to the widget.
Please note that editing can only happen when the widget is realized.
Deprecated since 4.10
Use GridView instead
path
A TreePath
cell
One of the cell renderers of @self
start_editing
true if the specified cell should start being edited.
Sourcepub fn set_drag_dest_item(
&self,
path: Option<&TreePath>,
pos: IconViewDropPosition,
)
๐Deprecated: Since 4.10
pub fn set_drag_dest_item( &self, path: Option<&TreePath>, pos: IconViewDropPosition, )
Since 4.10
Sourcepub fn set_item_orientation(&self, orientation: Orientation)
๐Deprecated: Since 4.10
pub fn set_item_orientation(&self, orientation: Orientation)
Since 4.10
Sourcepub fn set_item_padding(&self, item_padding: i32)
๐Deprecated: Since 4.10
pub fn set_item_padding(&self, item_padding: i32)
Since 4.10
Sourcepub fn set_item_width(&self, item_width: i32)
๐Deprecated: Since 4.10
pub fn set_item_width(&self, item_width: i32)
Since 4.10
Sourcepub fn set_margin(&self, margin: i32)
๐Deprecated: Since 4.10
pub fn set_margin(&self, margin: i32)
Since 4.10
Sourcepub fn set_markup_column(&self, column: i32)
๐Deprecated: Since 4.10
pub fn set_markup_column(&self, column: i32)
Since 4.10
Sets the column with markup information for @self to be
@column. The markup column must be of type G_TYPE_STRING.
If the markup column is set to something, it overrides
the text column set by gtk_icon_view_set_text_column().
Deprecated since 4.10
Use GridView instead
column
A column in the currently used model, or -1 to display no text
Sourcepub fn set_pixbuf_column(&self, column: i32)
๐Deprecated: Since 4.10
pub fn set_pixbuf_column(&self, column: i32)
Since 4.10
Sourcepub fn set_reorderable(&self, reorderable: bool)
๐Deprecated: Since 4.10
pub fn set_reorderable(&self, reorderable: bool)
Since 4.10
This function is a convenience function to allow you to reorder models that
support the GtkTreeDragSourceIface and the GtkTreeDragDestIface. Both
TreeStore and ListStore support these. If @reorderable is true, then
the user can reorder the model by dragging and dropping rows. The
developer can listen to these changes by connecting to the modelโs
row_inserted and row_deleted signals. The reordering is implemented by setting up
the icon view as a drag source and destination. Therefore, drag and
drop can not be used in a reorderable view for any other purpose.
This function does not give you any degree of control over the order โ any reordering is allowed. If more control is needed, you should probably handle drag and drop manually.
Deprecated since 4.10
Use GridView instead
reorderable
true, if the list of items can be reordered.
Sourcepub fn set_row_spacing(&self, row_spacing: i32)
๐Deprecated: Since 4.10
pub fn set_row_spacing(&self, row_spacing: i32)
Since 4.10
Sourcepub fn set_selection_mode(&self, mode: SelectionMode)
๐Deprecated: Since 4.10
pub fn set_selection_mode(&self, mode: SelectionMode)
Since 4.10
Sourcepub fn set_spacing(&self, spacing: i32)
๐Deprecated: Since 4.10
pub fn set_spacing(&self, spacing: i32)
Since 4.10
Sourcepub fn set_text_column(&self, column: i32)
๐Deprecated: Since 4.10
pub fn set_text_column(&self, column: i32)
Since 4.10
Sourcepub fn set_tooltip_cell(
&self,
tooltip: &Tooltip,
path: &TreePath,
cell: Option<&impl IsA<CellRenderer>>,
)
๐Deprecated: Since 4.10
pub fn set_tooltip_cell( &self, tooltip: &Tooltip, path: &TreePath, cell: Option<&impl IsA<CellRenderer>>, )
Since 4.10
Sourcepub fn set_tooltip_column(&self, column: i32)
๐Deprecated: Since 4.10
pub fn set_tooltip_column(&self, column: i32)
Since 4.10
If you only plan to have simple (text-only) tooltips on full items, you
can use this function to have IconView handle these automatically
for you. @column should be set to the column in @selfโs model
containing the tooltip texts, or -1 to disable this feature.
When enabled, GtkWidget:has-tooltip will be set to true and
@self will connect a GtkWidget::query-tooltip signal handler.
Note that the signal handler sets the text with gtk_tooltip_set_markup(), so &, <, etc have to be escaped in the text.
Deprecated since 4.10
Use GridView instead
column
an integer, which is a valid column number for @selfโs model
Sourcepub fn set_tooltip_item(&self, tooltip: &Tooltip, path: &TreePath)
๐Deprecated: Since 4.10
pub fn set_tooltip_item(&self, tooltip: &Tooltip, path: &TreePath)
Since 4.10
Sourcepub fn unselect_all(&self)
๐Deprecated: Since 4.10
pub fn unselect_all(&self)
Since 4.10
Sourcepub fn unselect_path(&self, path: &TreePath)
๐Deprecated: Since 4.10
pub fn unselect_path(&self, path: &TreePath)
Since 4.10
Sourcepub fn unset_model_drag_dest(&self)
๐Deprecated: Since 4.10
pub fn unset_model_drag_dest(&self)
Since 4.10
Sourcepub fn unset_model_drag_source(&self)
๐Deprecated: Since 4.10
pub fn unset_model_drag_source(&self)
Since 4.10
Sourcepub fn cell_area(&self) -> Option<CellArea>
๐Deprecated: Since 4.10
pub fn cell_area(&self) -> Option<CellArea>
Since 4.10
The CellArea used to layout cell renderers for this view.
If no area is specified when creating the icon view with gtk_icon_view_new_with_area()
a CellAreaBox will be used.
Sourcepub fn connect_activate_cursor_item<F: Fn(&Self) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_activate_cursor_item<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
A [keybinding signal]SignalAction
which gets emitted when the user activates the currently
focused item.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control activation programmatically.
The default bindings for this signal are Space, Return and Enter.
Returns
whether the item was activated
pub fn emit_activate_cursor_item(&self) -> bool
Since 4.10
Sourcepub fn connect_item_activated<F: Fn(&Self, &TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_item_activated<F: Fn(&Self, &TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
The ::item-activated signal is emitted when the method
gtk_icon_view_item_activated() is called, when the user double
clicks an item with the โactivate-on-single-clickโ property set
to false, or when the user single clicks an item when the
โactivate-on-single-clickโ property set to true. It is also
emitted when a non-editable item is selected and one of the keys:
Space, Return or Enter is pressed.
path
the TreePath for the activated item
Sourcepub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_move_cursor<F: Fn(&Self, MovementStep, i32, bool, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
The ::move-cursor signal is a
[keybinding signal]SignalAction
which gets emitted when the user initiates a cursor movement.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control the cursor programmatically.
The default bindings for this signal include
- Arrow keys which move by individual steps
- Home/End keys which move to the first/last item
- PageUp/PageDown which move by โpagesโ All of these will extend the selection when combined with the Shift modifier.
step
the granularity of the move, as a MovementStep
count
the number of @step units to move
extend
whether to extend the selection
modify
whether to modify the selection
Returns
whether the cursor was moved
pub fn emit_move_cursor( &self, step: MovementStep, count: i32, extend: bool, modify: bool, ) -> bool
Since 4.10
Sourcepub fn connect_select_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_select_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
A [keybinding signal]SignalAction
which gets emitted when the user selects all items.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
The default binding for this signal is Ctrl-a.
pub fn emit_select_all(&self)
Since 4.10
Sourcepub fn connect_select_cursor_item<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_select_cursor_item<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
A [keybinding signal]SignalAction
which gets emitted when the user selects the item that is currently
focused.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
There is no default binding for this signal.
pub fn emit_select_cursor_item(&self)
Since 4.10
Sourcepub fn connect_selection_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_selection_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
The ::selection-changed signal is emitted when the selection (i.e. the set of selected items) changes.
Sourcepub fn connect_toggle_cursor_item<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_toggle_cursor_item<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
A [keybinding signal]SignalAction
which gets emitted when the user toggles whether the currently
focused item is selected or not. The exact effect of this
depend on the selection mode.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
There is no default binding for this signal is Ctrl-Space.
pub fn emit_toggle_cursor_item(&self)
Since 4.10
Sourcepub fn connect_unselect_all<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_unselect_all<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
A [keybinding signal]SignalAction
which gets emitted when the user unselects all items.
Applications should not connect to it, but may emit it with g_signal_emit_by_name() if they need to control selection programmatically.
The default binding for this signal is Ctrl-Shift-a.
pub fn emit_unselect_all(&self)
Since 4.10
pub fn connect_activate_on_single_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_column_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_columns_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_item_orientation_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_item_padding_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_item_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_margin_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_markup_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_pixbuf_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_reorderable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_row_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_selection_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_text_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
pub fn connect_tooltip_column_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10