ListStore

Struct ListStore 

pub struct ListStore { /* private fields */ }
👎Deprecated:

Since 4.10

Use Gio::ListStore instead



# Implements

[`trait@glib::ObjectExt`], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`TreeDragDestExt`][trait@crate::prelude::TreeDragDestExt], [`TreeDragSourceExt`][trait@crate::prelude::TreeDragSourceExt], [`TreeModelExt`][trait@crate::prelude::TreeModelExt], [`TreeSortableExt`][trait@crate::prelude::TreeSortableExt], [`TreeModelExtManual`][trait@crate::prelude::TreeModelExtManual], [`TreeSortableExtManual`][trait@crate::prelude::TreeSortableExtManual]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl ListStore

pub fn append(&self) -> TreeIter

👎Deprecated:

Since 4.10

Appends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

Returns
iter

An unset TreeIter to set to the appended row

pub fn clear(&self)

👎Deprecated:

Since 4.10

Removes all rows from the list store.

Deprecated since 4.10

Use list models

pub fn insert(&self, position: i32) -> TreeIter

👎Deprecated:

Since 4.10

Creates a new row at @position. @iter will be changed to point to this new row. If @position is -1 or is larger than the number of rows on the list, then the new row will be appended to the list. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

position

position to insert the new row, or -1 for last

Returns
iter

An unset TreeIter to set to the new row

pub fn insert_after(&self, sibling: Option<&TreeIter>) -> TreeIter

👎Deprecated:

Since 4.10

Inserts a new row after @sibling. If @sibling is None, then the row will be prepended to the beginning of the list. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

sibling

A valid TreeIter

Returns
iter

An unset TreeIter to set to the new row

pub fn insert_before(&self, sibling: Option<&TreeIter>) -> TreeIter

👎Deprecated:

Since 4.10

Inserts a new row before @sibling. If @sibling is None, then the row will be appended to the end of the list. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

sibling

A valid TreeIter

Returns
iter

An unset TreeIter to set to the new row

pub fn iter_is_valid(&self, iter: &TreeIter) -> bool

👎Deprecated:

Since 4.10

Checks if the given iter is a valid iter for this ListStore.

This function is slow. Only use it for debugging and/or testing purposes.

Deprecated since 4.10

Use list models

iter

the iterator to check

Returns

true if the iter is valid, false if the iter is invalid.

pub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)

👎Deprecated:

Since 4.10

Moves @iter in @self to the position after @position. Note that this function only works with unsorted stores. If @position is None, @iter will be moved to the start of the list.

Deprecated since 4.10

Use list models

iter

A TreeIter

position

A TreeIter

pub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)

👎Deprecated:

Since 4.10

Moves @iter in @self to the position before @position. Note that this function only works with unsorted stores. If @position is None, @iter will be moved to the end of the list.

Deprecated since 4.10

Use list models

iter

A TreeIter

position

A TreeIter

pub fn prepend(&self) -> TreeIter

👎Deprecated:

Since 4.10

Prepends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().

Deprecated since 4.10

Use list models

Returns
iter

An unset TreeIter to set to the prepend row

pub fn remove(&self, iter: &TreeIter) -> bool

👎Deprecated:

Since 4.10

Removes the given row from the list store. After being removed, @iter is set to be the next valid row, or invalidated if it pointed to the last row in @self.

Deprecated since 4.10

Use list models

iter

A valid TreeIter

Returns

true if @iter is valid, false if not.

pub fn swap(&self, a: &TreeIter, b: &TreeIter)

👎Deprecated:

Since 4.10

Swaps @a and @b in @self. Note that this function only works with unsorted stores.

Deprecated since 4.10

Use list models

a

A TreeIter

b

Another TreeIter

Source

impl ListStore

pub fn new(column_types: &[Type]) -> Self

👎Deprecated:

Since 4.10

Creates a new list store.

The list store will have @n_columns columns, with each column using the given type passed to this function.

Note that only types derived from standard GObject fundamental types are supported.

As an example:

⚠️ The following code is in c ⚠️

gtk_list_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_TEXTURE);

will create a new ListStore with three columns, of type int, gchararray and gdk::Texture, respectively.

Deprecated since 4.10

Use Gio::ListStore instead

Returns

a new ListStore

pub fn insert_with_values( &self, position: Option<u32>, columns_and_values: &[(u32, &dyn ToValue)], ) -> TreeIter

👎Deprecated:

Since 4.10

A variant of gtk_list_store_insert_with_values() which takes the columns and values as two arrays, instead of varargs.

This function is mainly intended for language-bindings.

Deprecated since 4.10

Use list models

position

position to insert the new row, or -1 for last

columns

an array of column numbers

values

an array of GValues

Returns
iter

An unset TreeIter to set to the new row

pub fn reorder(&self, new_order: &[u32])

👎Deprecated:

Since 4.10

Reorders @self to follow the order indicated by @new_order. Note that this function only works with unsorted stores.

Deprecated since 4.10

Use list models

new_order

s length.

pub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])

👎Deprecated:

Since 4.10

, you would write gtk_list_store_set (store, iter, 0, "Foo", -1).

The value will be referenced by the store if it is a G_TYPE_OBJECT, and it will be copied if it is a G_TYPE_STRING or G_TYPE_BOXED.

Deprecated since 4.10

Use list models

iter

row iterator

pub fn set_column_types(&self, types: &[Type])

👎Deprecated:

Since 4.10

Sets the types of the columns of a list store.

This function is meant primarily for objects that inherit from ListStore, and should only be used when constructing a new instance.

This function cannot be called after a row has been added, or a method on the TreeModel interface is called.

Deprecated since 4.10

Use list models

types

An array length n of GTypes

pub fn set_value(&self, iter: &TreeIter, column: u32, value: &Value)

👎Deprecated:

Since 4.10

Sets the data in the cell specified by @iter and @column. The type of @value must be convertible to the type of the column.

Deprecated since 4.10

Use list models

iter

A valid TreeIter for the row being modified

column

column number to modify

value

new value for the cell