pub struct ListStore { /* private fields */ }Since 4.10
Use Gio::ListStore instead
# Implements
[`trait@glib::ObjectExt`], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`TreeDragDestExt`][trait@crate::prelude::TreeDragDestExt], [`TreeDragSourceExt`][trait@crate::prelude::TreeDragSourceExt], [`TreeModelExt`][trait@crate::prelude::TreeModelExt], [`TreeSortableExt`][trait@crate::prelude::TreeSortableExt], [`TreeModelExtManual`][trait@crate::prelude::TreeModelExtManual], [`TreeSortableExtManual`][trait@crate::prelude::TreeSortableExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ListStore
impl ListStore
Sourcepub fn append(&self) -> TreeIter
👎Deprecated: Since 4.10
pub fn append(&self) -> TreeIter
Since 4.10
Appends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().
Deprecated since 4.10
Use list models
Returns
iter
An unset TreeIter to set to the appended row
Sourcepub fn insert(&self, position: i32) -> TreeIter
👎Deprecated: Since 4.10
pub fn insert(&self, position: i32) -> TreeIter
Since 4.10
Creates a new row at @position. @iter will be changed to point to this new row. If @position is -1 or is larger than the number of rows on the list, then the new row will be appended to the list. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().
Deprecated since 4.10
Use list models
position
position to insert the new row, or -1 for last
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn insert_after(&self, sibling: Option<&TreeIter>) -> TreeIter
👎Deprecated: Since 4.10
pub fn insert_after(&self, sibling: Option<&TreeIter>) -> TreeIter
Since 4.10
Inserts a new row after @sibling. If @sibling is None, then the row will be
prepended to the beginning of the list. @iter will be changed to point to
this new row. The row will be empty after this function is called. To fill
in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().
Deprecated since 4.10
Use list models
sibling
A valid TreeIter
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn insert_before(&self, sibling: Option<&TreeIter>) -> TreeIter
👎Deprecated: Since 4.10
pub fn insert_before(&self, sibling: Option<&TreeIter>) -> TreeIter
Since 4.10
Inserts a new row before @sibling. If @sibling is None, then the row will
be appended to the end of the list. @iter will be changed to point to this
new row. The row will be empty after this function is called. To fill in
values, you need to call gtk_list_store_set() or gtk_list_store_set_value().
Deprecated since 4.10
Use list models
sibling
A valid TreeIter
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn iter_is_valid(&self, iter: &TreeIter) -> bool
👎Deprecated: Since 4.10
pub fn iter_is_valid(&self, iter: &TreeIter) -> bool
Since 4.10
Sourcepub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)
👎Deprecated: Since 4.10
pub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)
Since 4.10
Sourcepub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)
👎Deprecated: Since 4.10
pub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)
Since 4.10
Sourcepub fn prepend(&self) -> TreeIter
👎Deprecated: Since 4.10
pub fn prepend(&self) -> TreeIter
Since 4.10
Prepends a new row to @self. @iter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_list_store_set() or gtk_list_store_set_value().
Deprecated since 4.10
Use list models
Returns
iter
An unset TreeIter to set to the prepend row
Sourceimpl ListStore
impl ListStore
Sourcepub fn new(column_types: &[Type]) -> Self
👎Deprecated: Since 4.10
pub fn new(column_types: &[Type]) -> Self
Since 4.10
Creates a new list store.
The list store will have @n_columns columns, with each column using the given type passed to this function.
Note that only types derived from standard GObject fundamental types are supported.
As an example:
⚠️ The following code is in c ⚠️
gtk_list_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_TEXTURE);will create a new ListStore with three columns, of type int,
gchararray and gdk::Texture, respectively.
Deprecated since 4.10
Use Gio::ListStore instead
Returns
a new ListStore
Sourcepub fn insert_with_values(
&self,
position: Option<u32>,
columns_and_values: &[(u32, &dyn ToValue)],
) -> TreeIter
👎Deprecated: Since 4.10
pub fn insert_with_values( &self, position: Option<u32>, columns_and_values: &[(u32, &dyn ToValue)], ) -> TreeIter
Since 4.10
A variant of gtk_list_store_insert_with_values() which takes the columns and values as two arrays, instead of varargs.
This function is mainly intended for language-bindings.
Deprecated since 4.10
Use list models
position
position to insert the new row, or -1 for last
columns
an array of column numbers
values
an array of GValues
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])
👎Deprecated: Since 4.10
pub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])
Since 4.10
Sourcepub fn set_column_types(&self, types: &[Type])
👎Deprecated: Since 4.10
pub fn set_column_types(&self, types: &[Type])
Since 4.10
Sets the types of the columns of a list store.
This function is meant primarily for objects that inherit
from ListStore, and should only be used when constructing
a new instance.
This function cannot be called after a row has been added, or
a method on the TreeModel interface is called.
Deprecated since 4.10
Use list models
types
An array length n of GTypes