pub struct Notebook { /* private fields */ }Expand description
[`Notebook`][crate::Notebook] has a main CSS node with name `notebook`, a subnode
with name `header` and below that a subnode with name `tabs` which
contains one subnode per tab with name `tab`.
If action widgets are present, their CSS nodes are placed next
to the `tabs` node. If the notebook is scrollable, CSS nodes with
name `arrow` are placed as first and last child of the `tabs` node.
The main node gets the `.frame` style class when the notebook
has a border (see [`set_show_border()`][Self::set_show_border()]).
The header node gets one of the style class `.top`, `.bottom`,
`.left` or `.right`, depending on where the tabs are placed. For
reorderable pages, the tab node gets the `.reorderable-page` class.
A `tab` node gets the `.dnd` style class while it is moved with drag-and-drop.
The nodes are always arranged from left-to-right, regardless of text direction.
# Accessibility
[`Notebook`][crate::Notebook] uses the following roles:
- [enum@Gtk.AccessibleRole.group] for the notebook widget
- [enum@Gtk.AccessibleRole.tab_list] for the list of tabs
- [enum@Gtk.AccessibleRole.tab] role for each tab
- [enum@Gtk.AccessibleRole.tab_panel] for each page
## Properties
#### `enable-popup`
If [`true`], pressing the right mouse button on the notebook shows a page switching menu.
Readable | Writable
#### `group-name`
Group name for tab drag and drop.
Readable | Writable
#### `page`
The index of the current page.
Readable | Writable
#### `pages`
A selection model with the pages.
Readable
#### `scrollable`
If [`true`], scroll arrows are added if there are too many pages to fit.
Readable | Writable
#### `show-border`
Whether the border should be shown.
Readable | Writable
#### `show-tabs`
Whether tabs should be shown.
Readable | Writable
#### `tab-pos`
Which side of the notebook holds the tabs.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
## Signals
#### `change-current-page`
.
Action
#### `create-window`
The ::create-window signal is emitted when a detachable
tab is dropped on the root window.
A handler for this signal can create a window containing
a notebook where the tab will be attached. It is also
responsible for moving/resizing the window and adding the
necessary properties to the notebook (e.g. the
[`Notebook`][crate::Notebook]:group-name ).
#### `focus-tab`
Emitted when a tab should be focused.
Action
#### `move-focus-out`
.
Action
#### `page-added`
the ::page-added signal is emitted in the notebook
right after a page is added to the notebook.
#### `page-removed`
the ::page-removed signal is emitted in the notebook
right after a page is removed from the notebook.
#### `page-reordered`
the ::page-reordered signal is emitted in the notebook
right after a page has been reordered.
#### `reorder-tab`
.
Action
#### `select-page`
.
Action
#### `switch-page`
Emitted when the user or a function changes the current page.
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Notebook
impl Notebook
Sourcepub fn builder() -> NotebookBuilder
pub fn builder() -> NotebookBuilder
Creates a new builder-pattern struct instance to construct Notebook objects.
This method returns an instance of NotebookBuilder which can be used to create Notebook objects.
Sourcepub fn detach_tab(&self, child: &impl IsA<Widget>)
pub fn detach_tab(&self, child: &impl IsA<Widget>)
Removes the child from the notebook.
This function is very similar to remove_page(),
but additionally informs the notebook that the removal
is happening as part of a tab DND operation, which should
not be cancelled.
child
a child
Sourcepub fn action_widget(&self, pack_type: PackType) -> Option<Widget>
pub fn action_widget(&self, pack_type: PackType) -> Option<Widget>
Gets one of the action widgets.
See set_action_widget().
pack_type
pack type of the action widget to receive
Returns
The action widget
with the given @pack_type or None when this action
widget has not been set
Sourcepub fn group_name(&self) -> Option<GString>
pub fn group_name(&self) -> Option<GString>
Retrieves the text of the menu label for the page containing @child.
child
the child widget of a page of the notebook.
Returns
the text of the tab label, or None if
the widget does not have a menu label other than the default
menu label, or the menu label widget is not a Label.
The string is owned by the widget and must not be freed.
Sourcepub fn page(&self, child: &impl IsA<Widget>) -> NotebookPage
pub fn page(&self, child: &impl IsA<Widget>) -> NotebookPage
Sourcepub fn pages(&self) -> ListModel
pub fn pages(&self) -> ListModel
Returns a GListModel that contains the pages of the notebook.
This can be used to keep an up-to-date view. The model also
implements SelectionModel and can be used to track
and modify the visible page.
Returns
a
GListModel for the notebook’s children
Sourcepub fn is_scrollable(&self) -> bool
pub fn is_scrollable(&self) -> bool
Sourcepub fn shows_border(&self) -> bool
pub fn shows_border(&self) -> bool
Sourcepub fn shows_tabs(&self) -> bool
pub fn shows_tabs(&self) -> bool
Sourcepub fn tab_is_detachable(&self, child: &impl IsA<Widget>) -> bool
pub fn tab_is_detachable(&self, child: &impl IsA<Widget>) -> bool
Sourcepub fn tab_pos(&self) -> PositionType
pub fn tab_pos(&self) -> PositionType
Sourcepub fn tab_is_reorderable(&self, child: &impl IsA<Widget>) -> bool
pub fn tab_is_reorderable(&self, child: &impl IsA<Widget>) -> bool
Sourcepub fn next_page(&self)
pub fn next_page(&self)
Switches to the next page.
Nothing happens if the current page is the last page.
Sourcepub fn popup_disable(&self)
pub fn popup_disable(&self)
Disables the popup menu.
Sourcepub fn popup_enable(&self)
pub fn popup_enable(&self)
Enables the popup menu.
If the user clicks with the right mouse button on the tab labels, a menu with all the pages will be popped up.
Sourcepub fn prev_page(&self)
pub fn prev_page(&self)
Switches to the previous page.
Nothing happens if the current page is the first page.
Sourcepub fn set_action_widget(&self, widget: &impl IsA<Widget>, pack_type: PackType)
pub fn set_action_widget(&self, widget: &impl IsA<Widget>, pack_type: PackType)
Sourcepub fn set_group_name(&self, group_name: Option<&str>)
pub fn set_group_name(&self, group_name: Option<&str>)
Sourcepub fn set_scrollable(&self, scrollable: bool)
pub fn set_scrollable(&self, scrollable: bool)
Sourcepub fn set_show_border(&self, show_border: bool)
pub fn set_show_border(&self, show_border: bool)
Sourcepub fn set_show_tabs(&self, show_tabs: bool)
pub fn set_show_tabs(&self, show_tabs: bool)
Sourcepub fn set_tab_detachable(&self, child: &impl IsA<Widget>, detachable: bool)
pub fn set_tab_detachable(&self, child: &impl IsA<Widget>, detachable: bool)
Sets whether the tab can be detached from @self to another notebook or widget.
Note that two notebooks must share a common group identifier
(see set_group_name()) to allow automatic tabs
interchange between them.
If you want a widget to interact with a notebook through DnD
(i.e.: accept dragged tabs from it) it must be set as a drop
destination by adding to it a DropTarget controller that accepts
the GType GTK_TYPE_NOTEBOOK_PAGE. The :value of said drop target will be
preloaded with a NotebookPage object that corresponds to the
dropped tab, so you can process the value via ::accept or ::drop signals.
Note that you should use detach_tab() instead
of remove_page() if you want to remove the tab
from the source notebook as part of accepting a drop. Otherwise,
the source notebook will think that the dragged tab was removed
from underneath the ongoing drag operation, and will initiate a
drag cancel animation.
⚠️ The following code is in c ⚠️
static void
on_drag_data_received (GtkWidget *widget,
GdkDrop *drop,
GtkSelectionData *data,
guint time,
gpointer user_data)
{
GtkDrag *drag;
GtkWidget *notebook;
GtkWidget **child;
drag = gtk_drop_get_drag (drop);
notebook = g_object_get_data (drag, "gtk-notebook-drag-origin");
child = (void*) gtk_selection_data_get_data (data);
// process_widget (*child);
gtk_notebook_detach_tab (GTK_NOTEBOOK (notebook), *child);
}If you want a notebook to accept drags from other widgets, you will have to set your own DnD code to do it.
child
a child Widget
detachable
whether the tab is detachable or not
Sourcepub fn set_tab_label(
&self,
child: &impl IsA<Widget>,
tab_label: Option<&impl IsA<Widget>>,
)
pub fn set_tab_label( &self, child: &impl IsA<Widget>, tab_label: Option<&impl IsA<Widget>>, )
Sourcepub fn set_tab_label_text(&self, child: &impl IsA<Widget>, tab_text: &str)
pub fn set_tab_label_text(&self, child: &impl IsA<Widget>, tab_text: &str)
Sourcepub fn set_tab_pos(&self, pos: PositionType)
pub fn set_tab_pos(&self, pos: PositionType)
Sourcepub fn set_tab_reorderable(&self, child: &impl IsA<Widget>, reorderable: bool)
pub fn set_tab_reorderable(&self, child: &impl IsA<Widget>, reorderable: bool)
Sourcepub fn enables_popup(&self) -> bool
pub fn enables_popup(&self) -> bool
If true, pressing the right mouse button on the notebook shows a page switching menu.
Sourcepub fn set_enable_popup(&self, enable_popup: bool)
pub fn set_enable_popup(&self, enable_popup: bool)
If true, pressing the right mouse button on the notebook shows a page switching menu.
Sourcepub fn connect_change_current_page<F: Fn(&Self, i32) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_change_current_page<F: Fn(&Self, i32) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn emit_change_current_page(&self, page: i32) -> bool
Sourcepub fn connect_create_window<F: Fn(&Self, &Widget) -> Option<Notebook> + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_create_window<F: Fn(&Self, &Widget) -> Option<Notebook> + 'static>( &self, f: F, ) -> SignalHandlerId
The ::create-window signal is emitted when a detachable tab is dropped on the root window.
A handler for this signal can create a window containing
a notebook where the tab will be attached. It is also
responsible for moving/resizing the window and adding the
necessary properties to the notebook (e.g. the
Notebook:group-name ).
page
the tab of @notebook that is being detached
Returns
a Notebook that
@page should be added to
Sourcepub fn connect_focus_tab<F: Fn(&Self, NotebookTab) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_focus_tab<F: Fn(&Self, NotebookTab) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn emit_focus_tab(&self, tab: NotebookTab) -> bool
Sourcepub fn connect_move_focus_out<F: Fn(&Self, DirectionType) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_move_focus_out<F: Fn(&Self, DirectionType) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn emit_move_focus_out(&self, direction: DirectionType)
Sourcepub fn connect_page_added<F: Fn(&Self, &Widget, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_page_added<F: Fn(&Self, &Widget, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_page_removed<F: Fn(&Self, &Widget, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_page_removed<F: Fn(&Self, &Widget, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_page_reordered<F: Fn(&Self, &Widget, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_page_reordered<F: Fn(&Self, &Widget, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_reorder_tab<F: Fn(&Self, DirectionType, bool) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_reorder_tab<F: Fn(&Self, DirectionType, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn emit_reorder_tab( &self, direction: DirectionType, move_to_last: bool, ) -> bool
Sourcepub fn connect_select_page<F: Fn(&Self, bool) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_select_page<F: Fn(&Self, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn emit_select_page(&self, move_focus: bool) -> bool
Sourcepub fn connect_switch_page<F: Fn(&Self, &Widget, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_switch_page<F: Fn(&Self, &Widget, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_popup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_group_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_page_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_pages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_scrollable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_border_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_tabs_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_tab_pos_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl Notebook
impl Notebook
Sourcepub fn append_page(
&self,
child: &impl IsA<Widget>,
tab_label: Option<&impl IsA<Widget>>,
) -> u32
pub fn append_page( &self, child: &impl IsA<Widget>, tab_label: Option<&impl IsA<Widget>>, ) -> u32
Appends a page to @self, specifying the widget to use as the label in the popup menu.
child
the Widget to use as the contents of the page
tab_label
page N
menu_label
the widget to use as a label for the
page-switch menu, if that is enabled. If None, and @tab_label
is a Label or None, then the menu label will be a newly
created label with the same text as @tab_label; if @tab_label
is not a Label, @menu_label must be specified if the
page-switch menu is to be used.
Returns
the index (starting from 0) of the appended page in the notebook, or -1 if function fails
Sourcepub fn current_page(&self) -> Option<u32>
pub fn current_page(&self) -> Option<u32>
Returns the page number of the current page.
Returns
the index (starting from 0) of the current page in the notebook. If the notebook has no pages, then -1 will be returned.
Sourcepub fn insert_page(
&self,
child: &impl IsA<Widget>,
tab_label: Option<&impl IsA<Widget>>,
position: Option<u32>,
) -> u32
pub fn insert_page( &self, child: &impl IsA<Widget>, tab_label: Option<&impl IsA<Widget>>, position: Option<u32>, ) -> u32
Insert a page into @self at the given position.
child
the Widget to use as the contents of the page
tab_label
page N
position
the index (starting at 0) at which to insert the page, or -1 to append the page after all other pages
Returns
the index (starting from 0) of the inserted page in the notebook, or -1 if function fails
Insert a page into @self at the given position, specifying the widget to use as the label in the popup menu.
child
the Widget to use as the contents of the page
tab_label
page N
menu_label
the widget to use as a label for the
page-switch menu, if that is enabled. If None, and @tab_label
is a Label or None, then the menu label will be a newly
created label with the same text as @tab_label; if @tab_label
is not a Label, @menu_label must be specified if the
page-switch menu is to be used.
position
the index (starting at 0) at which to insert the page, or -1 to append the page after all other pages.
Returns
the index (starting from 0) of the inserted page in the notebook
Sourcepub fn prepend_page(
&self,
child: &impl IsA<Widget>,
tab_label: Option<&impl IsA<Widget>>,
) -> u32
pub fn prepend_page( &self, child: &impl IsA<Widget>, tab_label: Option<&impl IsA<Widget>>, ) -> u32
Prepends a page to @self, specifying the widget to use as the label in the popup menu.
child
the Widget to use as the contents of the page
tab_label
page N
menu_label
the widget to use as a label for the
page-switch menu, if that is enabled. If None, and @tab_label
is a Label or None, then the menu label will be a newly
created label with the same text as @tab_label; if @tab_label
is not a Label, @menu_label must be specified if the
page-switch menu is to be used.
Returns
the index (starting from 0) of the prepended page in the notebook, or -1 if function fails
Sourcepub fn remove_page(&self, page_num: Option<u32>)
pub fn remove_page(&self, page_num: Option<u32>)
Removes a page from the notebook given its index in the notebook.
page_num
the index of a notebook page, starting from 0. If -1, the last page will be removed.
Sourcepub fn set_current_page(&self, page_num: Option<u32>)
pub fn set_current_page(&self, page_num: Option<u32>)
Switches to the page number @page_num.
Note that due to historical reasons, GtkNotebook refuses to switch to a page unless the child widget is visible. Therefore, it is recommended to show child widgets before adding them to a notebook.
page_num
index of the page to switch to, starting from 0. If negative, the last page will be used. If greater than the number of pages in the notebook, nothing will be done.