pub struct Snapshot { /* private fields */ }Expand description
Assists in creating gsk::RenderNodes for widgets.
It functions in a similar way to a cairo context, and maintains a stack of render nodes and their associated transformations.
The node at the top of the stack is the one that gtk_snapshot_append_…()
functions operate on. Use the gtk_snapshot_push_…() functions and
SnapshotExt::pop() to change the current node.
The typical way to obtain a Snapshot object is as an argument to
the WidgetImpl::snapshot() vfunc. If you need to create your own
Snapshot, use new().
Note that Snapshot applies some optimizations, so the node
it produces may not match the API calls 1:1. For example, it will
omit clip nodes if the child node is entirely contained within the
clip rectangle.
Implements
SnapshotExt, [trait@gdk::prelude::SnapshotExt], [trait@glib::ObjectExt], SnapshotExtManual
GLib type: GObject with reference counted clone semantics.
Implementations