pub struct Text { /* private fields */ }Expand description
[window.popup]
[`Text`][crate::Text] has a main node with the name `text`. Depending on the properties
of the widget, the `.read-only` style class may appear.
When the entry has a selection, it adds a subnode with the name `selection`.
When the entry is in overwrite mode, it adds a subnode with the name
`block-cursor` that determines how the block cursor is drawn.
The CSS node for a context menu is added as a subnode with the name `popup`.
The `undershoot` nodes are used to draw the underflow indication when content
is scrolled out of view. These nodes get the `.left` or `.right` style class
added depending on where the indication is drawn.
When touch is used and touch selection handles are shown, they are using
CSS nodes with name `cursor-handle`. They get the `.top` or `.bottom` style
class depending on where they are shown in relation to the selection. If
there is just a single handle for the text cursor, it gets the style class
`.insertion-cursor`.
If using an input method with a pre-edit buffer, this string will be styled
with the `preedit` CSS node, the different style classes express the possible
roles of a piece of text in the pre-edit buffer:
- `.whole` denotes the parts of the pre-edit buffer without a special role
- `.selection`, `.prefix` and `.suffix` style classes will be used to
highlight the specific portions of the pre-edit buffer being edited and its
surroundings
- `.prediction` will be used for parts of the pre-edit buffer not typed by the
user (e.g. autocompletion)
- `.spelling-error` and `.compose-error` will be respectively used to indicate
errors in spelling or character composition (e.g. non-existent transliterations).
# Accessibility
[`Text`][crate::Text] uses the [enum@Gtk.AccessibleRole.none] role, which causes it to be
skipped for accessibility. This is because [`Text`][crate::Text] is expected to be used
as a delegate for a [`Editable`][crate::Editable] implementation that will be represented
to accessibility.
## Properties
#### `activates-default`
is pressed.
Readable | Writable
#### `attributes`
A list of Pango attributes to apply to the text.
This is mainly useful to change the size or weight of the text.
The `PangoAttribute`'s @start_index and @end_index must refer to the
[`EntryBuffer`][crate::EntryBuffer] text, i.e. without the preedit string.
Readable | Writable
#### `buffer`
The [`EntryBuffer`][crate::EntryBuffer] object which stores the text.
Readable | Writable | Construct
#### `enable-emoji-completion`
Whether to suggest Emoji replacements.
Readable | Writable
#### `extra-menu`
A menu model whose contents will be appended to the context menu.
Readable | Writable
#### `im-module`
Which input method module should be used.
See [`IMMulticontext`][crate::IMMulticontext].
Setting this to a non-`NULL` value overrides the system-wide
input method. See the [`gtk-im-module`][struct@crate::Settings#gtk-im-module]
setting.
Readable | Writable
#### `input-hints`
Additional hints that allow input methods to fine-tune
their behaviour.
Readable | Writable
#### `input-purpose`
The purpose of this text field.
This information can be used by on-screen keyboards and other input
methods to adjust their behaviour.
Note that setting the purpose to [enum@Gtk.InputPurpose.password]
or [enum@Gtk.InputPurpose.pin] is independent from setting
[`visibility`][struct@crate::Text#visibility].
Readable | Writable
#### `invisible-char`
).
Readable | Writable
#### `invisible-char-set`
Whether the invisible char has been set.
Readable | Writable
#### `max-length`
Maximum number of characters that are allowed.
Zero indicates no limit.
Readable | Writable
#### `overwrite-mode`
If text is overwritten when typing.
Readable | Writable
#### `placeholder-text`
The text that will be displayed in the [`Text`][crate::Text] when it is empty
and unfocused.
Readable | Writable
#### `propagate-text-width`
Whether the widget should grow and shrink with the content.
Readable | Writable
#### `scroll-offset`
Number of pixels scrolled of the screen to the left.
Readable
#### `tabs`
Custom tabs for this text widget.
Readable | Writable
#### `truncate-multiline`
When true, pasted multi-line text is truncated to the first line.
Readable | Writable
#### `visibility`
.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`LayoutManager`][crate::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See [`EventControllerExt::set_propagation_limit()`][crate::prelude::EventControllerExt::set_propagation_limit()].
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExt::set_size_request()`][crate::prelude::WidgetExt::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`Root`][crate::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see [`Tooltip::set_markup()`][crate::Tooltip::set_markup()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see [`Tooltip::set_text()`][crate::Tooltip::set_text()].
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`Accessible`][crate::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Editable</h4></summary>
#### `complete-text`
The contents of the entry, including uncommited content such as the
preedit.
Readable
#### `cursor-position`
The current position of the insertion cursor in chars.
Readable
#### `editable`
Whether the entry contents can be edited.
Readable | Writable
#### `enable-undo`
If undo/redo should be enabled for the editable.
Readable | Writable
#### `max-width-chars`
The desired maximum width of the entry, in characters.
Readable | Writable
#### `selection-bound`
The position of the opposite end of the selection from the cursor in chars.
Readable
#### `text`
The contents of the entry.
Readable | Writable
#### `width-chars`
Number of characters to leave space for in the entry.
Readable | Writable
#### `xalign`
The horizontal alignment, from 0 (left) to 1 (right).
Reversed for RTL layouts.
Readable | Writable
</details>
## Signals
#### `activate`
key.
Action
#### `backspace`
.
Action
#### `copy-clipboard`
.
Action
#### `cut-clipboard`
.
Action
#### `delete-from-cursor`
for deleting a word.
Action
#### `insert-at-cursor`
Emitted when the user initiates the insertion of a
fixed string at the cursor.
This is a [keybinding signal](class.SignalAction.html).
This signal has no default bindings.
Action
#### `insert-emoji`
/kbd
Action
#### `move-cursor`
move to the ends of the buffer
Action
#### `paste-clipboard`
.
Action
#### `preedit-changed`
Emitted when the preedit text changes.
If an input method is used, the typed text will not immediately
be committed to the buffer. So if you are interested in the text,
connect to this signal.
Action
#### `toggle-overwrite`
.
Action
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExt::keynav_failed()`][crate::prelude::WidgetExt::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a [`gdk::Surface`][crate::gdk::Surface].
This means that [`WidgetExt::realize()`][crate::prelude::WidgetExt::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExt::state_flags()`][crate::prelude::WidgetExt::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the [`gdk::Surface`][crate::gdk::Surface] associated with @widget is destroyed.
This means that [`WidgetExt::unrealize()`][crate::prelude::WidgetExt::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
<details><summary><h4>Editable</h4></summary>
#### `changed`
Emitted at the end of a single user-visible operation on the
contents.
E.g., a paste operation that replaces the contents of the
selection will cause only one signal emission (even though it
is implemented by first deleting the selection, then inserting
the new content, and may cause multiple ::notify::text signals
to be emitted).
#### `delete-text`
Emitted when text is deleted from the widget by the user.
The default handler for this signal will normally be responsible for
deleting the text, so by connecting to this signal and then stopping
the signal with g_signal_stop_emission(), it is possible to modify the
range of deleted text, or prevent it from being deleted entirely.
The @start_pos and @end_pos parameters are interpreted as for
[`EditableExt::delete_text()`][crate::prelude::EditableExt::delete_text()].
#### `insert-text`
Emitted when text is inserted into the widget by the user.
The default handler for this signal will normally be responsible
for inserting the text, so by connecting to this signal and then
stopping the signal with g_signal_stop_emission(), it is possible
to modify the inserted text, or prevent it from being inserted entirely.
</details>
# Implements
[`WidgetExt`][trait@crate::prelude::WidgetExt], [`trait@glib::ObjectExt`], [`AccessibleExt`][trait@crate::prelude::AccessibleExt], [`BuildableExt`][trait@crate::prelude::BuildableExt], [`ConstraintTargetExt`][trait@crate::prelude::ConstraintTargetExt], [`AccessibleTextExt`][trait@crate::prelude::AccessibleTextExt], [`EditableExt`][trait@crate::prelude::EditableExt], [`WidgetExtManual`][trait@crate::prelude::WidgetExtManual], [`AccessibleExtManual`][trait@crate::prelude::AccessibleExtManual], [`EditableExtManual`][trait@crate::prelude::EditableExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Text
impl Text
Sourcepub fn with_buffer(buffer: &impl IsA<EntryBuffer>) -> Text
pub fn with_buffer(buffer: &impl IsA<EntryBuffer>) -> Text
Sourcepub fn builder() -> TextBuilder
pub fn builder() -> TextBuilder
Creates a new builder-pattern struct instance to construct Text objects.
This method returns an instance of TextBuilder which can be used to create Text objects.
Sourcepub fn compute_cursor_extents(&self, position: usize) -> (Rect, Rect)
Available on crate feature v4_4 only.
pub fn compute_cursor_extents(&self, position: usize) -> (Rect, Rect)
v4_4 only.Determines the positions of the strong and weak cursors for a given character position.
The position of each cursor is stored as a zero-width rectangle. The strong cursor location is the location where characters of the directionality equal to the base direction are inserted. The weak cursor location is the location where characters of the directionality opposite to the base direction are inserted.
The rectangle positions are in widget coordinates.
position
the character position
Returns
strong
location to store the strong cursor position
weak
location to store the weak cursor position
Sourcepub fn activates_default(&self) -> bool
pub fn activates_default(&self) -> bool
will activate the default widget for the window containing the widget.
Returns
true if @self will activate the default widget
Sourcepub fn attributes(&self) -> Option<AttrList>
pub fn attributes(&self) -> Option<AttrList>
Gets the attribute list that was set on the text widget.
See set_attributes().
Returns
the attribute list
Sourcepub fn buffer(&self) -> EntryBuffer
pub fn buffer(&self) -> EntryBuffer
Sourcepub fn enables_emoji_completion(&self) -> bool
pub fn enables_emoji_completion(&self) -> bool
Sourcepub fn input_hints(&self) -> InputHints
pub fn input_hints(&self) -> InputHints
Sourcepub fn input_purpose(&self) -> InputPurpose
pub fn input_purpose(&self) -> InputPurpose
Sourcepub fn invisible_char(&self) -> char
pub fn invisible_char(&self) -> char
Retrieves the character displayed when visibility is set to false.
Note that GTK does not compute this value unless it needs it,
so the value returned by this function is not very useful unless
it has been explicitly set with set_invisible_char().
Returns
the current invisible char, or 0, if @text does not show invisible text at all
Sourcepub fn max_length(&self) -> i32
pub fn max_length(&self) -> i32
Retrieves the maximum allowed length of the contents.
See set_max_length().
This is equivalent to getting @self’s EntryBuffer and
calling EntryBufferExtManual::max_length() on it.
Returns
the maximum allowed number of characters, or 0 if there is no limit
Sourcepub fn is_overwrite_mode(&self) -> bool
pub fn is_overwrite_mode(&self) -> bool
Gets whether text is overwritten when typing.
See set_overwrite_mode().
Returns
whether text is overwritten when typing
Sourcepub fn placeholder_text(&self) -> Option<GString>
pub fn placeholder_text(&self) -> Option<GString>
Retrieves the text that will be displayed when the text widget is empty and unfocused
Returns
the placeholder text
Sourcepub fn propagates_text_width(&self) -> bool
pub fn propagates_text_width(&self) -> bool
Returns whether the text widget will grow and shrink with the content.
Returns
true if @self will propagate the text width
Sourcepub fn text_length(&self) -> u16
pub fn text_length(&self) -> u16
Retrieves the length of the contents.
This is equivalent to getting @self’s EntryBuffer
and calling EntryBufferExtManual::length() on it.
Returns
the length of the contents, in characters
Sourcepub fn must_truncate_multiline(&self) -> bool
pub fn must_truncate_multiline(&self) -> bool
Returns whether pasted text will be truncated to the first line.
Returns
true if @self will truncate pasted multi-line text
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Sourcepub fn grab_focus_without_selecting(&self) -> bool
pub fn grab_focus_without_selecting(&self) -> bool
Causes the text widget to have the keyboard focus.
It behaves like WidgetExt::grab_focus(),
except that it does not select the contents of @self.
You only want to call this on some special entries which the user usually doesn’t want to replace all text in, such as search-as-you-type entries.
Returns
true if focus is now inside @self
Sourcepub fn set_activates_default(&self, activates: bool)
pub fn set_activates_default(&self, activates: bool)
will activate the default widget.
This usually means that the dialog containing @self will be closed, since the default widget is usually one of the dialog buttons.
activates
keypress
Sourcepub fn set_attributes(&self, attrs: Option<&AttrList>)
pub fn set_attributes(&self, attrs: Option<&AttrList>)
Sourcepub fn set_buffer(&self, buffer: &impl IsA<EntryBuffer>)
pub fn set_buffer(&self, buffer: &impl IsA<EntryBuffer>)
Sourcepub fn set_enable_emoji_completion(&self, enable_emoji_completion: bool)
pub fn set_enable_emoji_completion(&self, enable_emoji_completion: bool)
Sets whether Emoji completion is enabled.
If it is, typing ‘:’, followed by a recognized keyword, will pop up a window with suggested Emojis matching the keyword.
enable_emoji_completion
true to enable Emoji completion
Sourcepub fn set_input_hints(&self, hints: InputHints)
pub fn set_input_hints(&self, hints: InputHints)
Sourcepub fn set_input_purpose(&self, purpose: InputPurpose)
pub fn set_input_purpose(&self, purpose: InputPurpose)
Sets the input purpose of the text widget.
The input purpose can be used by on-screen keyboards and other input methods to adjust their behaviour.
purpose
the input purpose
Sourcepub fn set_invisible_char(&self, ch: char)
pub fn set_invisible_char(&self, ch: char)
.
By default, GTK picks the best invisible char available in the current font. If you set the invisible char to 0, then the user will get no feedback at all; there will be no text on the screen as they type.
ch
a Unicode character
Sourcepub fn set_max_length(&self, length: i32)
pub fn set_max_length(&self, length: i32)
Sets the maximum allowed length of the contents.
If the current contents are longer than the given length, they will be truncated to fit.
This is equivalent to getting @self’s EntryBuffer and
calling EntryBufferExtManual::set_max_length() on it.
length
the maximum length of the text, or 0 for no maximum. (other than the maximum length of entries.) The value passed in will be clamped to the range 0-65536
Sourcepub fn set_overwrite_mode(&self, overwrite: bool)
pub fn set_overwrite_mode(&self, overwrite: bool)
Sourcepub fn set_placeholder_text(&self, text: Option<&str>)
pub fn set_placeholder_text(&self, text: Option<&str>)
Sets the text to be displayed when the text widget is empty and unfocused.
This can be used to give a visual hint of the expected contents of the text widget.
text
a string to be displayed when @self is empty and unfocused
Sourcepub fn set_propagate_text_width(&self, propagate_text_width: bool)
pub fn set_propagate_text_width(&self, propagate_text_width: bool)
Sets whether the text widget should grow and shrink with the content.
propagate_text_width
true to propagate the text width
Sourcepub fn set_truncate_multiline(&self, truncate_multiline: bool)
pub fn set_truncate_multiline(&self, truncate_multiline: bool)
Sets whether pasted text should be truncated to the first line.
truncate_multiline
true to truncate multi-line text
Sourcepub fn set_visibility(&self, visible: bool)
pub fn set_visibility(&self, visible: bool)
Sets whether the contents of the text widget are visible or not.
When visibility is set to false, characters are displayed as the invisible char, and it will also appear that way when the text in the widget is copied to the clipboard.
By default, GTK picks the best invisible character available
in the current font, but it can be changed with
set_invisible_char().
Note that you probably want to set input-purpose
to [enum@Gtk.InputPurpose.password] or [enum@Gtk.InputPurpose.pin]
to inform input methods about the purpose of this widget, in addition
to setting visibility to false.
visible
true if the contents of the text widget are displayed as plain text
Sourcepub fn unset_invisible_char(&self)
pub fn unset_invisible_char(&self)
Unsets the invisible char.
After calling this, the default invisible char is used again.
Sourcepub fn im_module(&self) -> Option<GString>
pub fn im_module(&self) -> Option<GString>
Which input method module should be used.
See IMMulticontext.
Setting this to a non-NULL value overrides the system-wide
input method. See the gtk-im-module
setting.
Sourcepub fn set_im_module(&self, im_module: Option<&str>)
pub fn set_im_module(&self, im_module: Option<&str>)
Which input method module should be used.
See IMMulticontext.
Setting this to a non-NULL value overrides the system-wide
input method. See the gtk-im-module
setting.
Sourcepub fn is_invisible_char_set(&self) -> bool
pub fn is_invisible_char_set(&self) -> bool
Whether the invisible char has been set.
Sourcepub fn scroll_offset(&self) -> i32
pub fn scroll_offset(&self) -> i32
Number of pixels scrolled of the screen to the left.
pub fn connect_activates_default_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_attributes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_buffer_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_emoji_completion_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_im_module_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_input_hints_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_input_purpose_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_invisible_char_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_invisible_char_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_max_length_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_overwrite_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_propagate_text_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_scroll_offset_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_tabs_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_truncate_multiline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visibility_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl Text
impl Text
Sourcepub fn connect_activate<F: Fn(&Text) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_activate<F: Fn(&Text) + 'static>(&self, f: F) -> SignalHandlerId
key.
Sourcepub fn connect_backspace<F: Fn(&Text) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_backspace<F: Fn(&Text) + 'static>(&self, f: F) -> SignalHandlerId
.
Sourcepub fn connect_copy_clipboard<F: Fn(&Text) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_copy_clipboard<F: Fn(&Text) + 'static>( &self, f: F, ) -> SignalHandlerId
.
Sourcepub fn connect_cut_clipboard<F: Fn(&Text) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_cut_clipboard<F: Fn(&Text) + 'static>( &self, f: F, ) -> SignalHandlerId
.
Sourcepub fn connect_delete_from_cursor<F: Fn(&Text, DeleteType, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_delete_from_cursor<F: Fn(&Text, DeleteType, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_insert_at_cursor<F: Fn(&Text, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_insert_at_cursor<F: Fn(&Text, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the user initiates the insertion of a fixed string at the cursor.
This is a keybinding signal.
This signal has no default bindings.
string
the string to insert
Sourcepub fn connect_insert_emoji<F: Fn(&Text) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_insert_emoji<F: Fn(&Text) + 'static>( &self, f: F, ) -> SignalHandlerId
/kbd
Sourcepub fn connect_move_cursor<F: Fn(&Text, MovementStep, i32, bool) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_move_cursor<F: Fn(&Text, MovementStep, i32, bool) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_paste_clipboard<F: Fn(&Text) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_paste_clipboard<F: Fn(&Text) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn connect_populate_popup<F: Fn(&Text, &Widget) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_preedit_changed<F: Fn(&Text, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_preedit_changed<F: Fn(&Text, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the preedit text changes.
If an input method is used, the typed text will not immediately be committed to the buffer. So if you are interested in the text, connect to this signal.
preedit
the current preedit string
Sourcepub fn connect_toggle_overwrite<F: Fn(&Text) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_toggle_overwrite<F: Fn(&Text) + 'static>( &self, f: F, ) -> SignalHandlerId
.
pub fn emit_activate(&self)
pub fn emit_backspace(&self)
pub fn emit_copy_clipboard(&self)
pub fn emit_cut_clipboard(&self)
pub fn emit_delete_from_cursor(&self, type_: DeleteType, count: i32)
pub fn emit_insert_at_cursor(&self, string: impl IntoGStr)
pub fn emit_insert_emoji(&self)
pub fn emit_move_cursor(&self, step: MovementStep, count: i32, extend: bool)
pub fn emit_paste_clipboard(&self)
pub fn emit_preedit_changed(&self, preedit: impl IntoGStr)
pub fn emit_toggle_overwrite(&self)