pub struct TreeModelFilter { /* private fields */ }Since 4.10
Use FilterListModel instead.
A TreeModel which hides parts of an underlying tree model
A TreeModelFilter is a tree model which wraps another tree model,
and can do the following things:
-
Filter specific rows, based on data from a โvisible columnโ, a column storing booleans indicating whether the row should be filtered or not, or based on the return value of a โvisible functionโ, which gets a model, iter and user_data and returns a boolean indicating whether the row should be filtered or not.
-
Modify the โappearanceโ of the model, using a modify function. This is extremely powerful and allows for just changing some values and also for creating a completely different model based on the given child model.
-
Set a different root node, also known as a โvirtual rootโ. You can pass in a
TreePathindicating the root node for the filter at construction time.
The basic API is similar to TreeModelSort. For an example on its usage,
see the section on TreeModelSort.
When using TreeModelFilter, it is important to realize that
TreeModelFilter maintains an internal cache of all nodes which are
visible in its clients. The cache is likely to be a subtree of the tree
exposed by the child model. TreeModelFilter will not cache the entire
child model when unnecessary to not compromise the caching mechanism
that is exposed by the reference counting scheme. If the child model
implements reference counting, unnecessary signals may not be emitted
because of reference counting rule 3, see the TreeModel
documentation. (Note that e.g. TreeStore does not implement
reference counting and will always emit all signals, even when
the receiving node is not visible).
Because of this, limitations for possible visible functions do apply.
In general, visible functions should only use data or properties from
the node for which the visibility state must be determined, its siblings
or its parents. Usually, having a dependency on the state of any child
node is not possible, unless references are taken on these explicitly.
When no such reference exists, no signals may be received for these child
nodes (see reference counting rule number 3 in the TreeModel section).
Determining the visibility state of a given node based on the state
of its child nodes is a frequently occurring use case. Therefore,
TreeModelFilter explicitly supports this. For example, when a node
does not have any children, you might not want the node to be visible.
As soon as the first row is added to the nodeโs child level (or the
last row removed), the nodeโs visibility should be updated.
This introduces a dependency from the node on its child nodes. In order
to accommodate this, TreeModelFilter must make sure the necessary
signals are received from the child model. This is achieved by building,
for all nodes which are exposed as visible nodes to TreeModelFilterโs
clients, the child level (if any) and take a reference on the first node
in this level. Furthermore, for every row-inserted, row-changed or
row-deleted signal (also these which were not handled because the node
was not cached), TreeModelFilter will check if the visibility state
of any parent node has changed.
Beware, however, that this explicit support is limited to these two
cases. For example, if you want a node to be visible only if two nodes
in a childโs child level (2 levels deeper) are visible, you are on your
own. In this case, either rely on TreeStore to emit all signals
because it does not implement reference counting, or for models that
do implement reference counting, obtain references on these child levels
yourself.
Properties
child-model
The child model of the tree model filter.
Readable | Writable | Construct Only
virtual-root
The virtual root of the tree model filter.
Readable | Writable | Construct Only
Implements
TreeModelFilterExt, [trait@glib::ObjectExt], TreeDragSourceExt, TreeModelExt, TreeModelFilterExtManual, TreeModelExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TreeModelFilter
impl TreeModelFilter
pub const NONE: Option<&'static TreeModelFilter> = None
Since 4.10