pub struct TreeSelection { /* private fields */ }Since 4.10
Use SelectionModel instead
The selection object for GtkTreeView
The TreeSelection object is a helper object to manage the selection
for a TreeView widget. The TreeSelection object is
automatically created when a new TreeView widget is created, and
cannot exist independently of this widget. The primary reason the
TreeSelection objects exists is for cleanliness of code and API.
That is, there is no conceptual reason all these functions could not be
methods on the TreeView widget instead of a separate function.
The TreeSelection object is gotten from a TreeView by calling
gtk_tree_view_get_selection(). It can be manipulated to check the
selection status of the tree, as well as select and deselect individual
rows. Selection is done completely view side. As a result, multiple
views of the same model can have completely different selections.
Additionally, you cannot change the selection of a row on the model that
is not currently displayed by the view without expanding its parents
first.
One of the important things to remember when monitoring the selection of
a view is that the TreeSelection::changed signal is mostly a hint.
That is, it may only emit one signal when a range of rows is selected.
Additionally, it may on occasion emit a TreeSelection::changed signal
when nothing has happened (mostly as a result of programmers calling
select_row on an already selected row).
Properties
mode
Selection mode. See gtk_tree_selection_set_mode() for more information on this property.
Readable | Writable
Signals
changed
Emitted whenever the selection has (possibly) changed. Please note that this signal is mostly a hint. It may only be emitted once when a range of rows are selected, and it may occasionally be emitted when nothing has happened.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TreeSelection
impl TreeSelection
Sourcepub fn count_selected_rows(&self) -> i32
๐Deprecated: Since 4.10
pub fn count_selected_rows(&self) -> i32
Since 4.10
Sourcepub fn mode(&self) -> SelectionMode
๐Deprecated: Since 4.10
pub fn mode(&self) -> SelectionMode
Since 4.10
Sourcepub fn selected(&self) -> Option<(TreeModel, TreeIter)>
๐Deprecated: Since 4.10
pub fn selected(&self) -> Option<(TreeModel, TreeIter)>
Since 4.10
Sets @iter to the currently selected node if @self is set to
SelectionMode::Single or SelectionMode::Browse. @iter may be NULL if you
just want to test if @self has any selected nodes. @model is filled
with the current model as a convenience. This function will not work if you
use @self is SelectionMode::Multiple.
Deprecated since 4.10
Use GtkListView or GtkColumnView
Returns
TRUE, if there is a selected node.
model
A pointer to set to the TreeModel
iter
The TreeIter
Sourcepub fn selected_rows(&self) -> (Vec<TreePath>, TreeModel)
๐Deprecated: Since 4.10
pub fn selected_rows(&self) -> (Vec<TreePath>, TreeModel)
Since 4.10
Creates a list of path of all selected rows. Additionally, if you are
planning on modifying the model after calling this function, you may
want to convert the returned list into a list of TreeRowReferences.
To do this, you can use gtk_tree_row_reference_new().
To free the return value, use:
โ ๏ธ The following code is in c โ ๏ธ
g_list_free_full (list, (GDestroyNotify) gtk_tree_path_free);Deprecated since 4.10
Use GtkListView or GtkColumnView
Returns
A GList containing a TreePath for each selected row.
model
A pointer to set to the TreeModel
Sourcepub fn iter_is_selected(&self, iter: &TreeIter) -> bool
๐Deprecated: Since 4.10
pub fn iter_is_selected(&self, iter: &TreeIter) -> bool
Since 4.10
Sourcepub fn path_is_selected(&self, path: &TreePath) -> bool
๐Deprecated: Since 4.10
pub fn path_is_selected(&self, path: &TreePath) -> bool
Since 4.10
Sourcepub fn select_all(&self)
๐Deprecated: Since 4.10
pub fn select_all(&self)
Since 4.10
Selects all the nodes. @self must be set to SelectionMode::Multiple
mode.
Deprecated since 4.10
Use GtkListView or GtkColumnView
Sourcepub fn select_iter(&self, iter: &TreeIter)
๐Deprecated: Since 4.10
pub fn select_iter(&self, iter: &TreeIter)
Since 4.10
Sourcepub fn select_path(&self, path: &TreePath)
๐Deprecated: Since 4.10
pub fn select_path(&self, path: &TreePath)
Since 4.10
Sourcepub fn select_range(&self, start_path: &TreePath, end_path: &TreePath)
๐Deprecated: Since 4.10
pub fn select_range(&self, start_path: &TreePath, end_path: &TreePath)
Since 4.10
Selects a range of nodes, determined by @start_path and @end_path inclusive.
@self must be set to SelectionMode::Multiple mode.
Deprecated since 4.10
Use GtkListView or GtkColumnView
start_path
The initial node of the range.
end_path
The final node of the range.
Sourcepub fn selected_foreach<P: FnMut(&TreeModel, &TreePath, &TreeIter)>(
&self,
func: P,
)
๐Deprecated: Since 4.10
pub fn selected_foreach<P: FnMut(&TreeModel, &TreePath, &TreeIter)>( &self, func: P, )
Since 4.10
Calls a function for each selected node. Note that you cannot modify the tree or selection from within this function. As a result, gtk_tree_selection_get_selected_rows() might be more useful.
Deprecated since 4.10
Use GtkListView or GtkColumnView
func
The function to call for each selected node.
Sourcepub fn set_mode(&self, type_: SelectionMode)
๐Deprecated: Since 4.10
pub fn set_mode(&self, type_: SelectionMode)
Since 4.10
Sets the selection mode of the @self. If the previous type was
SelectionMode::Multiple, then the anchor is kept selected, if it was
previously selected.
Deprecated since 4.10
Use GtkListView or GtkColumnView
type_
The selection mode
Sourcepub fn set_select_function<P: Fn(&TreeSelection, &TreeModel, &TreePath, bool) -> bool + 'static>(
&self,
func: P,
)
๐Deprecated: Since 4.10
pub fn set_select_function<P: Fn(&TreeSelection, &TreeModel, &TreePath, bool) -> bool + 'static>( &self, func: P, )
Since 4.10
Sets the selection function.
If set, this function is called before any node is selected or unselected,
giving some control over which nodes are selected. The select function
should return true if the state of the node may be toggled, and false
if the state of the node should be left unchanged.
Deprecated since 4.10
Use GtkListView or GtkColumnView
func
The selection function. May be None
Sourcepub fn unselect_all(&self)
๐Deprecated: Since 4.10
pub fn unselect_all(&self)
Since 4.10
Sourcepub fn unselect_iter(&self, iter: &TreeIter)
๐Deprecated: Since 4.10
pub fn unselect_iter(&self, iter: &TreeIter)
Since 4.10
Sourcepub fn unselect_path(&self, path: &TreePath)
๐Deprecated: Since 4.10
pub fn unselect_path(&self, path: &TreePath)
Since 4.10
Sourcepub fn unselect_range(&self, start_path: &TreePath, end_path: &TreePath)
๐Deprecated: Since 4.10
pub fn unselect_range(&self, start_path: &TreePath, end_path: &TreePath)
Since 4.10
Sourcepub fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
๐Deprecated: Since 4.10
pub fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Since 4.10
Emitted whenever the selection has (possibly) changed. Please note that this signal is mostly a hint. It may only be emitted once when a range of rows are selected, and it may occasionally be emitted when nothing has happened.
pub fn connect_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 4.10
Sourceimpl TreeSelection
impl TreeSelection
pub fn unset_select_function(&self)
Since 4.10