pub struct TreeStore { /* private fields */ }Since 4.10
Use TreeListModel instead
A tree-like data structure that can be used with the TreeView.
The TreeStore object is a list model for use with a TreeView
widget. It implements the TreeModel interface, and consequently,
can use all of the methods available there. It also implements the
TreeSortable interface so it can be sorted by the view.
Finally, it also implements the tree dragcrate::TreeDragSource
and dropcrate::TreeDragDest interfaces.
TreeStore is deprecated since GTK 4.10, and should not be used in newly
written code. You should use TreeListModel for a tree-like model
object.
GtkTreeStore as GtkBuildable
The GtkTreeStore implementation of the Buildable interface allows
to specify the model columns with a <columns> element that may contain
multiple <column> elements, each specifying one model column. The โtypeโ
attribute specifies the data type for the column.
An example of a UI Definition fragment for a tree store:
<object class="GtkTreeStore">
<columns>
<column type="gchararray"/>
<column type="gchararray"/>
<column type="gint"/>
</columns>
</object>Implements
[trait@glib::ObjectExt], BuildableExt, TreeDragDestExt, TreeDragSourceExt, TreeModelExt, TreeSortableExt, TreeModelExtManual, TreeSortableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TreeStore
impl TreeStore
Sourcepub fn append(&self, parent: Option<&TreeIter>) -> TreeIter
๐Deprecated: Since 4.10
pub fn append(&self, parent: Option<&TreeIter>) -> TreeIter
Since 4.10
Appends a new row to @self.
If @parent is non-None, then it will append the new row after the last
child of @parent, otherwise it will append a row to the top level.
The @iter parameter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_tree_store_set() or gtk_tree_store_set_value().
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
Returns
iter
An unset TreeIter to set to the appended row
Sourcepub fn insert(&self, parent: Option<&TreeIter>, position: i32) -> TreeIter
๐Deprecated: Since 4.10
pub fn insert(&self, parent: Option<&TreeIter>, position: i32) -> TreeIter
Since 4.10
Creates a new row at @position.
If parent is non-None, then the row will be made a child of @parent.
Otherwise, the row will be created at the toplevel.
If @position is -1 or is larger than the number of rows at that level,
then the new row will be inserted to the end of the list.
The @iter parameter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_tree_store_set() or gtk_tree_store_set_value().
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
position
position to insert the new row, or -1 for last
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn insert_after(
&self,
parent: Option<&TreeIter>,
sibling: Option<&TreeIter>,
) -> TreeIter
๐Deprecated: Since 4.10
pub fn insert_after( &self, parent: Option<&TreeIter>, sibling: Option<&TreeIter>, ) -> TreeIter
Since 4.10
Inserts a new row after @sibling.
If @sibling is None, then the row will be prepended to @parentโs children.
If @parent and @sibling are None, then the row will be prepended to the
toplevel.
If both @sibling and @parent are set, then @parent must be the parent of @sibling. When @sibling is set, @parent is optional.
The @iter parameter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_tree_store_set() or gtk_tree_store_set_value().
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
sibling
A valid TreeIter
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn insert_before(
&self,
parent: Option<&TreeIter>,
sibling: Option<&TreeIter>,
) -> TreeIter
๐Deprecated: Since 4.10
pub fn insert_before( &self, parent: Option<&TreeIter>, sibling: Option<&TreeIter>, ) -> TreeIter
Since 4.10
Inserts a new row before @sibling.
If @sibling is None, then the row will be appended to @parentโs children.
If @parent and @sibling are None, then the row will be appended to the
toplevel.
If both @sibling and @parent are set, then @parent must be the parent of @sibling. When @sibling is set, @parent is optional.
The @iter parameter will be changed to point to this new row. The row will be empty after this function is called. To fill in values, you need to call gtk_tree_store_set() or gtk_tree_store_set_value().
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
sibling
A valid TreeIter
Returns
iter
An unset TreeIter to set to the new row
Sourcepub fn is_ancestor(&self, iter: &TreeIter, descendant: &TreeIter) -> bool
๐Deprecated: Since 4.10
pub fn is_ancestor(&self, iter: &TreeIter, descendant: &TreeIter) -> bool
Since 4.10
Sourcepub fn iter_depth(&self, iter: &TreeIter) -> i32
๐Deprecated: Since 4.10
pub fn iter_depth(&self, iter: &TreeIter) -> i32
Since 4.10
Returns the depth of the position pointed by the iterator
The depth will be 0 for anything on the root level, 1 for anything down a level, etc.
Deprecated since 4.10
Use TreeListModel instead
iter
A valid TreeIter
Returns
The depth of the position pointed by the iterator
Sourcepub fn iter_is_valid(&self, iter: &TreeIter) -> bool
๐Deprecated: Since 4.10
pub fn iter_is_valid(&self, iter: &TreeIter) -> bool
Since 4.10
Checks if the given iter is a valid iter for this TreeStore.
This function is slow. Only use it for debugging and/or testing purposes.
Deprecated since 4.10
Use TreeListModel instead
iter
the iterator to check
Returns
true if the iter is valid, and false otherwise
Sourcepub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)
๐Deprecated: Since 4.10
pub fn move_after(&self, iter: &TreeIter, position: Option<&TreeIter>)
Since 4.10
Moves @iter in @self to the position after @position.
@iter and @position should be in the same level.
Note that this function only works with unsorted stores.
If @position is None, @iter will be moved to the start of the level.
Deprecated since 4.10
Use TreeListModel instead
iter
A TreeIter.
position
A TreeIter.
Sourcepub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)
๐Deprecated: Since 4.10
pub fn move_before(&self, iter: &TreeIter, position: Option<&TreeIter>)
Since 4.10
Moves @iter in @self to the position before @position.
@iter and @position should be in the same level.
Note that this function only works with unsorted stores.
If @position is None, @iter will be moved to the end of the level.
Deprecated since 4.10
Use TreeListModel instead
iter
A TreeIter
position
A TreeIter
Sourcepub fn prepend(&self, parent: Option<&TreeIter>) -> TreeIter
๐Deprecated: Since 4.10
pub fn prepend(&self, parent: Option<&TreeIter>) -> TreeIter
Since 4.10
Prepends a new row to @self.
If @parent is non-None, then it will prepend the new row before the first
child of @parent, otherwise it will prepend a row to the top level. The
iter parameter will be changed to point to this new row. The row will
be empty after this function is called. To fill in values, you need to
call gtk_tree_store_set() or gtk_tree_store_set_value().
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
Returns
iter
An unset TreeIter to set to the prepended row
Sourcepub fn remove(&self, iter: &TreeIter) -> bool
๐Deprecated: Since 4.10
pub fn remove(&self, iter: &TreeIter) -> bool
Since 4.10
Removes @iter from @self.
After being removed, @iter is set to the next valid row at that level, or invalidated if it previously pointed to the last one.
Deprecated since 4.10
Use TreeListModel instead
iter
A valid TreeIter
Returns
true if @iter is still valid, and false otherwise
Sourceimpl TreeStore
impl TreeStore
Sourcepub fn new(column_types: &[Type]) -> Self
๐Deprecated: Since 4.10
pub fn new(column_types: &[Type]) -> Self
Since 4.10
Creates a new tree store.
The tree store will have @n_columns, with each column using the corresponding type passed to this function.
Note that only types derived from standard GObject fundamental types are supported.
As an example:
โ ๏ธ The following code is in c โ ๏ธ
gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_TEXTURE);will create a new TreeStore with three columns of type
int, gchararray, and gdk::Texture respectively.
Deprecated since 4.10
Use TreeListModel instead
Returns
a new TreeStore
Sourcepub fn insert_with_values(
&self,
parent: Option<&TreeIter>,
position: Option<u32>,
columns_and_values: &[(u32, &dyn ToValue)],
) -> TreeIter
๐Deprecated: Since 4.10
pub fn insert_with_values( &self, parent: Option<&TreeIter>, position: Option<u32>, columns_and_values: &[(u32, &dyn ToValue)], ) -> TreeIter
Since 4.10
A variant of gtk_tree_store_insert_with_values() which takes the columns and values as two arrays, instead of varargs.
This function is mainly intended for language bindings.
Deprecated since 4.10
Use TreeListModel instead
parent
A valid TreeIter
position
position to insert the new row, or -1 for last
columns
an array of column numbers
values
an array of GValues
Returns
iter
An unset TreeIter to set the new row
Sourcepub fn reorder(&self, parent: &TreeIter, new_order: &[u32])
๐Deprecated: Since 4.10
pub fn reorder(&self, parent: &TreeIter, new_order: &[u32])
Since 4.10
Reorders the children of @parent in @self to follow the order indicated by @new_order.
Note that this function only works with unsorted stores.
Deprecated since 4.10
Use TreeListModel instead
parent
the parent of the children to re-order
new_order
an array of integers mapping the new position
of each child to its old position before the re-ordering,
i.e. new_order[newpos] = oldpos
Sourcepub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])
๐Deprecated: Since 4.10
pub fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])
Since 4.10
Sets the value of one or more cells in the row referenced by @iter.
The variable argument list should contain integer column numbers, each column number followed by the value to be set.
The list is terminated by a value of -1.
For example, to set column 0 with type G_TYPE_STRING to โFooโ, you would
write
โ ๏ธ The following code is in c โ ๏ธ
gtk_tree_store_set (store, iter, 0, "Foo", -1);The value will be referenced by the store if it is a G_TYPE_OBJECT, and it
will be copied if it is a G_TYPE_STRING or G_TYPE_BOXED.
Deprecated since 4.10
Use TreeListModel instead
iter
A valid TreeIter for the row being modified
Sourcepub fn set_column_types(&self, types: &[Type])
๐Deprecated: Since 4.10
pub fn set_column_types(&self, types: &[Type])
Since 4.10
Sets the type of the columns in a tree store.
This function is meant primarily for types that inherit from
TreeStore, and should only be used when constructing a new
TreeStore.
This functions cannot be called after a row has been added,
or a method on the TreeModel interface is called on the
tree store.
Deprecated since 4.10
Use TreeListModel instead
types
An array of GType types, one for each column